@@ -31,28 +31,28 @@
 
 #include "config.h"
 
-#include <cstdint>
-#include <string>
-#include <sstream>
 #include <algorithm>
+#include <cstdint>
+#include <sstream>
+#include <string>
 
 #include "crc.h"
 
 #include "Constructor.h"
 #include "Grid.h"
 
-#include "DMR.h"
-#include "XMLWriter.h"
+#include "D4Group.h"
 #include "D4StreamMarshaller.h"
 #include "D4StreamUnMarshaller.h"
-#include "D4Group.h"
+#include "DMR.h"
+#include "XMLWriter.h"
 
 #include "D4Attributes.h"
 
+#include "DapIndent.h"
+#include "InternalErr.h"
 #include "escaping.h"
 #include "util.h"
-#include "InternalErr.h"
-#include "DapIndent.h"
 
 #include "debug.h"
 
@@ -62,14 +62,12 @@ namespace libdap {
 
 // Private member functions
 
-void
-Constructor::m_duplicate(const Constructor &c)
-{
-	// Clear out any spurious vars in Constructor::d_vars
-	// Moved from Grid::m_duplicate. jhrg 4/3/13
-	d_vars.clear(); // [mjohnson 10 Sep 2009]
+void Constructor::m_duplicate(const Constructor &c) {
+    // Clear out any spurious vars in Constructor::d_vars
+    // Moved from Grid::m_duplicate. jhrg 4/3/13
+    d_vars.clear(); // [mjohnson 10 Sep 2009]
 
-    for (auto var: c.d_vars) {
+    for (auto var : c.d_vars) {
         BaseType *btp = var->ptr_duplicate();
         btp->set_parent(this);
         d_vars.push_back(btp);
@@ -81,9 +79,7 @@ Constructor::m_duplicate(const Constructor &c)
 // A public method, but just barely...
 // TODO Understand what this method does. What is dest? Is it the parent-to-be
 //  of the variables in this Constructor? jhrg 4/25/22
-void
-Constructor::transform_to_dap4(D4Group *root, Constructor *dest)
-{
+void Constructor::transform_to_dap4(D4Group *root, Constructor *dest) {
     for (Constructor::Vars_citer i = var_begin(), e = var_end(); i != e; ++i) {
 
         BaseType *d4_var = dest->var((*i)->name());
@@ -99,37 +95,31 @@ Constructor::transform_to_dap4(D4Group *root, Constructor *dest)
     dest->set_is_dap4(true);
 }
 
-string
-Constructor::FQN() const
-{
-	if (get_parent() == 0)
-		return name();
-	else if (get_parent()->type() == dods_group_c)
-		return get_parent()->FQN() + name();
-	else if (get_parent()->type() == dods_array_c)
-		return get_parent()->FQN();
-	else
-		return get_parent()->FQN() + "." + name();
+string Constructor::FQN() const {
+    if (get_parent() == 0)
+        return name();
+    else if (get_parent()->type() == dods_group_c)
+        return get_parent()->FQN() + name();
+    else if (get_parent()->type() == dods_array_c)
+        return get_parent()->FQN();
+    else
+        return get_parent()->FQN() + "." + name();
 }
 
-int
-Constructor::element_count(bool leaves)
-{
+int Constructor::element_count(bool leaves) {
     if (!leaves)
         return d_vars.size();
     else {
         int i = 0;
-        for (auto var: d_vars) {
+        for (auto var : d_vars) {
             i += var->element_count(leaves);
         }
         return i;
     }
 }
 
-void
-Constructor::set_send_p(bool state)
-{
-    for (auto var: d_vars) {
+void Constructor::set_send_p(bool state) {
+    for (auto var : d_vars) {
         var->set_send_p(state);
     }
 
@@ -147,10 +137,8 @@ Constructor::set_send_p(bool state)
  *
  * @param state Set the read_p property to this state.
  */
-void
-Constructor::set_read_p(bool state)
-{
-    for (auto var: d_vars) {
+void Constructor::set_read_p(bool state) {
+    for (auto var : d_vars) {
         var->set_read_p(state);
     }
 
@@ -165,17 +153,14 @@ Constructor::set_read_p(bool state)
     @return  The number of bytes used by the variable.
     @deprecated Use width_ll()
  */
-unsigned int
-Constructor::width(bool constrained) const
-{
+unsigned int Constructor::width(bool constrained) const {
     unsigned int sz = 0;
 
-    for (auto var: d_vars) {
+    for (auto var : d_vars) {
         if (constrained) {
             if (var->send_p())
                 sz += var->width(constrained);
-        }
-        else {
+        } else {
             sz += var->width(constrained);
         }
     }
@@ -188,17 +173,14 @@ Constructor::width(bool constrained) const
  * @param constrained If true, return the constrained size
  * @return The number of bytes needed to store the values of this instance
  */
-int64_t
-Constructor::width_ll(bool constrained) const
-{
+int64_t Constructor::width_ll(bool constrained) const {
     int64_t sz = 0;
 
-    for (auto var: d_vars) {
+    for (auto var : d_vars) {
         if (constrained) {
             if (var->send_p())
                 sz += var->width_ll(constrained);
-        }
-        else {
+        } else {
             sz += var->width_ll(constrained);
         }
     }
@@ -206,9 +188,7 @@ Constructor::width_ll(bool constrained) const
     return sz;
 }
 
-BaseType *
-Constructor::var(const string &name, bool exact_match, btp_stack *s)
-{
+BaseType *Constructor::var(const string &name, bool exact_match, btp_stack *s) {
     string n = www2id(name);
 
     if (exact_match)
@@ -218,11 +198,9 @@ Constructor::var(const string &name, bool exact_match, btp_stack *s)
 }
 
 /** @deprecated See comment in BaseType */
-BaseType *
-Constructor::var(const string &n, btp_stack &s)
-{
-	// This should probably be removed. The BES code should remove web encoding
-	// with the possible exception of spaces. jhrg 11/25/13
+BaseType *Constructor::var(const string &n, btp_stack &s) {
+    // This should probably be removed. The BES code should remove web encoding
+    // with the possible exception of spaces. jhrg 11/25/13
     string name = www2id(n);
 
     BaseType *btp = m_exact_match(name, &s);
@@ -233,10 +211,8 @@ Constructor::var(const string &n, btp_stack &s)
 }
 
 // Protected method
-BaseType *
-Constructor::m_leaf_match(const string &name, btp_stack *s)
-{
-    for (auto var: d_vars) {
+BaseType *Constructor::m_leaf_match(const string &name, btp_stack *s) {
+    for (auto var : d_vars) {
         if (var->name() == name) {
             if (s) {
                 s->push(static_cast<BaseType *>(this));
@@ -258,11 +234,9 @@ Constructor::m_leaf_match(const string &name, btp_stack *s)
 }
 
 // Protected method
-BaseType *
-Constructor::m_exact_match(const string &name, btp_stack *s)
-{
+BaseType *Constructor::m_exact_match(const string &name, btp_stack *s) {
     // Look for name at the top level first.
-    for (auto var: d_vars) {
+    for (auto var : d_vars) {
         if (var->name() == name) {
             if (s)
                 s->push(static_cast<BaseType *>(this));
@@ -284,77 +258,52 @@ Constructor::m_exact_match(const string &name, btp_stack *s)
                 s->push(static_cast<BaseType *>(this));
 
             return agg_ptr->var(field, true, s); // recurse
-        }
-        else
-            return nullptr;  // qualified names must be *fully* qualified
+        } else
+            return nullptr; // qualified names must be *fully* qualified
     }
 
     return nullptr;
 }
 
 /** Returns an iterator referencing the first structure element. */
-Constructor::Vars_iter
-Constructor::var_begin()
-{
-    return d_vars.begin();
-}
+Constructor::Vars_iter Constructor::var_begin() { return d_vars.begin(); }
 
 /** Returns an iterator referencing the end of the list of structure
     elements. Does not reference the last structure element. */
-Constructor::Vars_iter
-Constructor::var_end()
-{
-    return d_vars.end();
-}
+Constructor::Vars_iter Constructor::var_end() { return d_vars.end(); }
 
 /** Return a reverse iterator that references the last element. */
-Constructor::Vars_riter
-Constructor::var_rbegin()
-{
-    return d_vars.rbegin();
-}
+Constructor::Vars_riter Constructor::var_rbegin() { return d_vars.rbegin(); }
 
 /** Return a reverse iterator that references a point 'before' the first
     element. */
-Constructor::Vars_riter
-Constructor::var_rend()
-{
-    return d_vars.rend();
-}
+Constructor::Vars_riter Constructor::var_rend() { return d_vars.rend(); }
 
 /** Return the iterator for the \e ith variable.
     @param i the index
     @return The corresponding  Vars_iter */
-Constructor::Vars_iter
-Constructor::get_vars_iter(int i)
-{
-    return d_vars.begin() + i;
-}
+Constructor::Vars_iter Constructor::get_vars_iter(int i) { return d_vars.begin() + i; }
 
 /** Return the BaseType pointer for the \e ith variable.
     @param i This index
     @return The corresponding BaseType*. */
-BaseType *
-Constructor::get_var_index(int i)
-{
-    return *(d_vars.begin() + i);
-}
+BaseType *Constructor::get_var_index(int i) { return *(d_vars.begin() + i); }
 
 /**
  * @brief Set the ith element of d_vars to a variable object.
- * @note  This method only sets the ith element to a BaseType object. 
+ * @note  This method only sets the ith element to a BaseType object.
  * The user should be responsible to release or allocate the resource properly.
- * Use this method cautionally. 
+ * Use this method cautionally.
  * @param bt A pointer to the variable that is assigned to the ith element.
  * @param i The index of the variable to be set.
  */
 
-void Constructor::set_var_index(BaseType *bt,int i) {
+void Constructor::set_var_index(BaseType *bt, int i) {
 
     if (!bt)
         throw InternalErr(__FILE__, __LINE__, "The BaseType parameter cannot be null.");
 
-    if (i<0 || i>= (int)(d_vars.size())) 
+    if (i < 0 || i >= (int)(d_vars.size()))
         throw InternalErr(__FILE__, __LINE__, "The index must be within the variable vector  range..");
 
     bt->set_parent(this);
@@ -364,16 +313,13 @@ void Constructor::set_var_index(BaseType *bt,int i) {
         set_is_dap4(true);
 
     d_vars[i] = bt;
-
 }
 
 /** Adds an element to a Constructor.
 
     @param bt A pointer to the variable to add to this Constructor.
     @param part Not used by this class, defaults to nil */
-void
-Constructor::add_var(BaseType *bt, Part)
-{
+void Constructor::add_var(BaseType *bt, Part) {
     // Jose Garcia
     // Passing and invalid pointer to an object is a developer's error.
     if (!bt)
@@ -391,9 +337,7 @@ Constructor::add_var(BaseType *bt, Part)
 
     @param bt A pointer to thee variable to add to this Constructor.
     @param part Not used by this class, defaults to nil */
-void
-Constructor::add_var_nocopy(BaseType *bt, Part)
-{
+void Constructor::add_var_nocopy(BaseType *bt, Part) {
     if (!bt)
         throw InternalErr(__FILE__, __LINE__, "The BaseType parameter cannot be null.");
 
@@ -412,12 +356,9 @@ Constructor::add_var_nocopy(BaseType *bt, Part)
  * version would just remove the first variable.
  * @param n name of the variable to remove
  */
-void
-Constructor::del_var(const string &n)
-{
-    auto to_remove = stable_partition(d_vars.begin(), d_vars.end(),
-                                      [n](BaseType* btp){ return btp->name() != n; });
-    for_each(to_remove, d_vars.end(), [](BaseType* btp){ delete btp; });
+void Constructor::del_var(const string &n) {
+    auto to_remove = stable_partition(d_vars.begin(), d_vars.end(), [n](BaseType *btp) { return btp->name() != n; });
+    for_each(to_remove, d_vars.end(), [](BaseType *btp) { delete btp; });
     d_vars.erase(to_remove, d_vars.end());
 }
 
@@ -426,9 +367,7 @@ Constructor::del_var(const string &n)
  * @note It is OK to call this with an iterator that points to nullptr.
  * @param i The iterator that points to the BaseType.
  */
-void
-Constructor::del_var(Vars_iter i)
-{
+void Constructor::del_var(Vars_iter i) {
     delete *i;
     d_vars.erase(i);
 }
@@ -444,10 +383,9 @@ Constructor::del_var(Vars_iter i)
  *
  * @return returns false; the return value is a relic.
  */
-bool Constructor::read()
-{
+bool Constructor::read() {
     if (!read_p()) {
-        for (auto var: d_vars) {
+        for (auto var : d_vars) {
             if (var->send_p())
                 var->read();
         }
@@ -458,35 +396,34 @@ bool Constructor::read()
     return false;
 }
 
-void
-Constructor::intern_data(ConstraintEvaluator & eval, DDS & dds)
-{
+void Constructor::intern_data(ConstraintEvaluator &eval, DDS &dds) {
     if (is_dap4())
-        throw Error(string("A method usable only with DAP2 variables was called on a DAP4 variable (").append(name()).append(")."), __FILE__, __LINE__);
+        throw Error(string("A method usable only with DAP2 variables was called on a DAP4 variable (")
+                        .append(name())
+                        .append(")."),
+                    __FILE__, __LINE__);
 
     if (!read_p())
-        read();          // read() throws Error and InternalErr
+        read(); // read() throws Error and InternalErr
 
-    for (auto var: d_vars) {
+    for (auto var : d_vars) {
         if (var->send_p()) {
             var->intern_data(eval, dds);
         }
     }
 }
 
-bool
-Constructor::serialize(ConstraintEvaluator &eval, DDS &dds, Marshaller &m, bool ce_eval)
-{
+bool Constructor::serialize(ConstraintEvaluator &eval, DDS &dds, Marshaller &m, bool ce_eval) {
     if (!read_p())
-        read();  // read() throws Error and InternalErr
+        read(); // read() throws Error and InternalErr
 
     if (ce_eval && !eval.eval_selection(dds, dataset()))
         return true;
 
-    for (auto var: d_vars) {
+    for (auto var : d_vars) {
         if (var->send_p()) {
 #ifdef CHECKSUMS
-            XDRStreamMarshaller *sm = dynamic_cast<XDRStreamMarshaller*>(&m);
+            XDRStreamMarshaller *sm = dynamic_cast<XDRStreamMarshaller *>(&m);
             if (sm && sm->checksums() && var->type() != dods_structure_c && var->type() != dods_grid_c)
                 sm->reset_checksum();
 
@@ -505,29 +442,23 @@ Constructor::serialize(ConstraintEvaluator &eval, DDS &dds, Marshaller &m, bool
     return true;
 }
 
-bool
-Constructor::deserialize(UnMarshaller &um, DDS *dds, bool reuse)
-{
-    for (auto var: d_vars) {
+bool Constructor::deserialize(UnMarshaller &um, DDS *dds, bool reuse) {
+    for (auto var : d_vars) {
         var->deserialize(um, dds, reuse);
     }
 
     return false;
 }
 
-void
-Constructor::compute_checksum(Crc32 &)
-{
-	throw InternalErr(__FILE__, __LINE__, "Computing a checksum alone is not supported for Constructor types.");
+void Constructor::compute_checksum(Crc32 &) {
+    throw InternalErr(__FILE__, __LINE__, "Computing a checksum alone is not supported for Constructor types.");
 }
 
-void
-Constructor::intern_data()
-{
+void Constructor::intern_data() {
     if (!read_p())
-        read();  // read() throws Error
+        read(); // read() throws Error
 
-    for (auto var: d_vars) {
+    for (auto var : d_vars) {
         if (var->send_p()) {
             var->intern_data(/*checksum, dmr, eval*/);
         }
@@ -545,56 +476,48 @@ Constructor::intern_data()
  * @param filter Unused
  * @exception Error is thrown if the value needs to be read and that operation fails.
  */
-void
-Constructor::serialize(D4StreamMarshaller &m, DMR &dmr, bool filter)
-{
-	// Not used for the same reason the equivalent code in D4Group::serialize()
-	// is not used. Fail for D4Sequence and general issues with memory use.
-	//
-	// Revisit this - I had to uncomment this to get the netcdf_handler code
-	// to work - it relies on having NCStructure::read() called. The D4Sequence
-	// ::serialize() method calls read_next_instance(). What seems to be happening
-	// is that this call to read gets the first set of values, but does not store
-	// them; the call to serialize then runs the D4Sequence::serialize() method that
-	// _does_ read all the sequence data and then serialize it. However, the first
-	// sequence instance is missing...
+void Constructor::serialize(D4StreamMarshaller &m, DMR &dmr, bool filter) {
+    // Not used for the same reason the equivalent code in D4Group::serialize()
+    // is not used. Fail for D4Sequence and general issues with memory use.
+    //
+    // Revisit this - I had to uncomment this to get the netcdf_handler code
+    // to work - it relies on having NCStructure::read() called. The D4Sequence
+    // ::serialize() method calls read_next_instance(). What seems to be happening
+    // is that this call to read gets the first set of values, but does not store
+    // them; the call to serialize then runs the D4Sequence::serialize() method that
+    // _does_ read all the sequence data and then serialize it. However, the first
+    // sequence instance is missing...
     if (!read_p())
-        read();  // read() throws Error
+        read(); // read() throws Error
 
-    for (auto var: d_vars) {
+    for (auto var : d_vars) {
         if (var->send_p()) {
             var->serialize(m, dmr, filter);
         }
     }
 }
 
-void
-Constructor::deserialize(D4StreamUnMarshaller &um, DMR &dmr)
-{
-    for (auto var: d_vars) {
+void Constructor::deserialize(D4StreamUnMarshaller &um, DMR &dmr) {
+    for (auto var : d_vars) {
         var->deserialize(um, dmr);
     }
 }
 
-void
-Constructor::print_decl(FILE *out, string space, bool print_semi, bool constraint_info, bool constrained)
-{
+void Constructor::print_decl(FILE *out, string space, bool print_semi, bool constraint_info, bool constrained) {
     ostringstream oss;
     print_decl(oss, space, print_semi, constraint_info, constrained);
     fwrite(oss.str().data(), sizeof(char), oss.str().length(), out);
 }
 
-void
-Constructor::print_decl(ostream &out, string space, bool print_semi, bool constraint_info, bool constrained)
-{
+void Constructor::print_decl(ostream &out, string space, bool print_semi, bool constraint_info, bool constrained) {
     if (constrained && !send_p())
         return;
 
-    out << space << type_name() << " {\n" ;
-    for (auto var: d_vars) {
+    out << space << type_name() << " {\n";
+    for (auto var : d_vars) {
         var->print_decl(out, space + "    ", true, constraint_info, constrained);
     }
-    out << space << "} " << id2www(name()) ;
+    out << space << "} " << id2www(name());
 
     if (constraint_info) { // Used by test drivers only.
         if (send_p())
@@ -604,42 +527,36 @@ Constructor::print_decl(ostream &out, string space, bool print_semi, bool constr
     }
 
     if (print_semi)
-        out << ";\n" ;
+        out << ";\n";
 }
 
-void
-Constructor::print_val(FILE *out, string space, bool print_decl_p)
-{
+void Constructor::print_val(FILE *out, string space, bool print_decl_p) {
     ostringstream oss;
     print_val(oss, space, print_decl_p);
     fwrite(oss.str().data(), sizeof(char), oss.str().length(), out);
 }
 
-void
-Constructor::print_val(ostream &out, string space, bool print_decl_p)
-{
+void Constructor::print_val(ostream &out, string space, bool print_decl_p) {
     if (print_decl_p) {
         print_decl(out, space, false);
-        out << " = " ;
+        out << " = ";
     }
 
-    out << "{ " ;
+    out << "{ ";
     for (Vars_citer i = d_vars.begin(), e = d_vars.end(); i != e; i++, (void)(i != e && out << ", ")) {
         (*i)->print_val(out, "", false);
     }
 
-    out << " }" ;
+    out << " }";
 
     if (print_decl_p)
-        out << ";\n" ;
+        out << ";\n";
 }
 
 /**
  * @deprecated
  */
-void
-Constructor::print_xml(FILE *out, string space, bool constrained)
-{
+void Constructor::print_xml(FILE *out, string space, bool constrained) {
     XMLWriter xml(space);
     print_xml_writer(xml, constrained);
     fwrite(xml.get_doc(), sizeof(char), xml.get_doc_size(), out);
@@ -648,25 +565,21 @@ Constructor::print_xml(FILE *out, string space, bool constrained)
 /**
  * @deprecated
  */
-void
-Constructor::print_xml(ostream &out, string space, bool constrained)
-{
+void Constructor::print_xml(ostream &out, string space, bool constrained) {
     XMLWriter xml(space);
     print_xml_writer(xml, constrained);
     out << xml.get_doc();
 }
 
-void
-Constructor::print_xml_writer(XMLWriter &xml, bool constrained)
-{
+void Constructor::print_xml_writer(XMLWriter &xml, bool constrained) {
     if (constrained && !send_p())
         return;
 
-    if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar*)type_name().c_str()) < 0)
+    if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar *)type_name().c_str()) < 0)
         throw InternalErr(__FILE__, __LINE__, "Could not write " + type_name() + " element");
 
     if (!name().empty())
-        if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "name", (const xmlChar*)name().c_str()) < 0)
+        if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar *)"name", (const xmlChar *)name().c_str()) < 0)
             throw InternalErr(__FILE__, __LINE__, "Could not write attribute for name");
 
     // DAP2 prints attributes first. For some reason we decided that DAP4 should
@@ -685,17 +598,15 @@ Constructor::print_xml_writer(XMLWriter &xml, bool constrained)
         throw InternalErr(__FILE__, __LINE__, "Could not end " + type_name() + " element");
 }
 
-void
-Constructor::print_dap4(XMLWriter &xml, bool constrained)
-{
+void Constructor::print_dap4(XMLWriter &xml, bool constrained) {
     if (constrained && !send_p())
         return;
 
-    if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar*)type_name().c_str()) < 0)
+    if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar *)type_name().c_str()) < 0)
         throw InternalErr(__FILE__, __LINE__, "Could not write " + type_name() + " element");
 
     if (!name().empty())
-        if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "name", (const xmlChar*)name().c_str()) < 0)
+        if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar *)"name", (const xmlChar *)name().c_str()) < 0)
             throw InternalErr(__FILE__, __LINE__, "Could not write attribute for name");
 
     if (!d_vars.empty())
@@ -708,9 +619,7 @@ Constructor::print_dap4(XMLWriter &xml, bool constrained)
         throw InternalErr(__FILE__, __LINE__, "Could not end " + type_name() + " element");
 }
 
-bool
-Constructor::check_semantics(string &msg, bool all)
-{
+bool Constructor::check_semantics(string &msg, bool all) {
     if (!BaseType::check_semantics(msg))
         return false;
 
@@ -718,7 +627,7 @@ Constructor::check_semantics(string &msg, bool all)
         return false;
 
     if (all) {
-        for (auto var: d_vars) {
+        for (auto var : d_vars) {
             if (!var->check_semantics(msg, true)) {
                 return false;
             }
@@ -737,42 +646,33 @@ Constructor::check_semantics(string &msg, bool all)
     @brief Check to see whether this variable can be printed simply.
     @return True if the instance can be printed as a single table of
     values, false otherwise. */
-bool
-Constructor::is_linear()
-{
-    return false;
-}
+bool Constructor::is_linear() { return false; }
 
 /** Set the \e in_selection property for this variable and all of its
     children.
 
     @brief Set the \e in_selection property.
     @param state Set the property value to \e state. */
-void
-Constructor::set_in_selection(bool state)
-{
-    for (auto var: d_vars) {
+void Constructor::set_in_selection(bool state) {
+    for (auto var : d_vars) {
         var->set_in_selection(state);
     }
 
     BaseType::set_in_selection(state);
 }
 
-void Constructor::transfer_attributes(AttrTable *at_container)
-{
+void Constructor::transfer_attributes(AttrTable *at_container) {
     AttrTable *at = at_container->get_attr_table(name());
 
     if (at) {
         BaseType::transfer_attributes(at_container);
-        for (auto var: d_vars) {
+        for (auto var : d_vars) {
             var->transfer_attributes(at);
         }
     }
 }
 
-AttrTable *
-Constructor::make_dropped_vars_attr_table(vector<BaseType *> *dropped_vars)
-{
+AttrTable *Constructor::make_dropped_vars_attr_table(vector<BaseType *> *dropped_vars) {
     AttrTable *dv_table = nullptr;
     if (!dropped_vars->empty()) {
         dv_table = new AttrTable;
@@ -789,8 +689,8 @@ Constructor::make_dropped_vars_attr_table(vector<BaseType *> *dropped_vars)
             string type_name = bt->type_name();
 
             if (bt->is_vector_type()) {
-                Array *array = dynamic_cast <Array *>(bt);
-                if (array) {    // This is always true - only an Array is_vector_type(). jhrg 4/25/22
+                Array *array = dynamic_cast<Array *>(bt);
+                if (array) { // This is always true - only an Array is_vector_type(). jhrg 4/25/22
                     type_name = array->prototype()->type_name();
                     Array::Dim_iter d_iter = array->dim_begin();
                     Array::Dim_iter end = array->dim_end();
@@ -813,26 +713,23 @@ Constructor::make_dropped_vars_attr_table(vector<BaseType *> *dropped_vars)
     return dv_table;
 }
 
-
 /**
  * When send_p() is true and the attributes or variables contain dap4 data types then
  *   a description of the instance is added to the inventory and true is returned.
  * @param inventory is a value-result parameter
  * @return True when send_p() is true and this object contains dap4 types variables or attributes, false otherwise
  */
-bool Constructor::is_dap4_projected(std::vector<std::string> &inventory)
-{
+bool Constructor::is_dap4_projected(std::vector<std::string> &inventory) {
     bool has_projected_dap4 = false;
-    if(send_p()) {
-        has_projected_dap4 = attributes()->has_dap4_types(FQN(),inventory);
-        for (const auto var: variables()) {
+    if (send_p()) {
+        has_projected_dap4 = attributes()->has_dap4_types(FQN(), inventory);
+        for (const auto var : variables()) {
             has_projected_dap4 |= var->is_dap4_projected(inventory);
         }
     }
     return has_projected_dap4;
 }
 
-
 /** @brief dumps information about this object
  *
  * Displays the pointer value of this instance and information about this
@@ -841,15 +738,14 @@ bool Constructor::is_dap4_projected(std::vector<std::string> &inventory)
  * @param strm C++ i/o stream to dump the information to
  * @return void
  */
-void
-Constructor::dump(ostream &strm) const {
-    strm << DapIndent::LMarg << "Constructor::dump - (" << (void *) this << ")" << endl;
+void Constructor::dump(ostream &strm) const {
+    strm << DapIndent::LMarg << "Constructor::dump - (" << (void *)this << ")" << endl;
     DapIndent::Indent();
     BaseType::dump(strm);
     strm << DapIndent::LMarg << "vars: " << endl;
     DapIndent::Indent();
 
-    for (auto var: d_vars) {
+    for (auto var : d_vars) {
         var->dump(strm);
     }
 
@@ -858,4 +754,3 @@ Constructor::dump(ostream &strm) const {
 }
 
 } // namespace libdap
-
