@@ -24,26 +24,26 @@
 
 #include "config.h"
 
-//#define DODS_DEBUG
+// #define DODS_DEBUG
 
 #include <algorithm>
-#include <string>
 #include <sstream>
+#include <string>
 
 #include "D4Sequence.h"
 
 #include "D4StreamMarshaller.h"
 #include "D4StreamUnMarshaller.h"
 
+#include "D4FilterClause.h" // also contains D4FilterClauseList
 #include "D4RValue.h"
-#include "D4FilterClause.h"     // also contains D4FilterClauseList
 
-#include "debug.h"
+#include "DapIndent.h"
 #include "Error.h"
 #include "InternalErr.h"
-#include "util.h"
+#include "debug.h"
 #include "escaping.h"
-#include "DapIndent.h"
+#include "util.h"
 
 #undef CLEAR_LOCAL_DATA
 
@@ -59,8 +59,7 @@ namespace libdap {
 // typedef vector<D4SeqRow *> D4SeqValues;
 // D4SeqValues d_values;
 
-void D4Sequence::m_duplicate(const D4Sequence &s)
-{
+void D4Sequence::m_duplicate(const D4Sequence &s) {
     d_length = s.d_length;
 #if INDEX_SUBSETTING
     d_starting_row_number = s.d_starting_row_number;
@@ -80,7 +79,7 @@ void D4Sequence::m_duplicate(const D4Sequence &s)
     }
 
     d_copy_clauses = s.d_copy_clauses;
-    d_clauses = (s.d_clauses != 0) ? new D4FilterClauseList(*s.d_clauses) : 0;    // deep copy if != 0
+    d_clauses = (s.d_clauses != 0) ? new D4FilterClauseList(*s.d_clauses) : 0; // deep copy if != 0
 }
 
 // Public member functions
@@ -93,10 +92,8 @@ void D4Sequence::m_duplicate(const D4Sequence &s)
  created.
 
  @brief The Sequence constructor. */
-D4Sequence::D4Sequence(const string &n) :
-        Constructor(n, dods_sequence_c, true /* is dap4 */), d_clauses(0), d_copy_clauses(true), d_length(0)
-{
-}
+D4Sequence::D4Sequence(const string &n)
+    : Constructor(n, dods_sequence_c, true /* is dap4 */), d_clauses(0), d_copy_clauses(true), d_length(0) {}
 
 /** The Sequence server-side constructor requires the name of the variable
  to be created and the dataset name from which this variable is being
@@ -108,43 +105,28 @@ D4Sequence::D4Sequence(const string &n) :
  variable is being created.
 
  @brief The Sequence server-side constructor. */
-D4Sequence::D4Sequence(const string &n, const string &d) :
-        Constructor(n, d, dods_sequence_c, true /* is dap4 */), d_clauses(0), d_copy_clauses(true), d_length(0)
-{
-}
+D4Sequence::D4Sequence(const string &n, const string &d)
+    : Constructor(n, d, dods_sequence_c, true /* is dap4 */), d_clauses(0), d_copy_clauses(true), d_length(0) {}
 
 /** @brief The Sequence copy constructor. */
-D4Sequence::D4Sequence(const D4Sequence &rhs) : Constructor(rhs)
-{
-    m_duplicate(rhs);
-}
+D4Sequence::D4Sequence(const D4Sequence &rhs) : Constructor(rhs) { m_duplicate(rhs); }
 
-BaseType *
-D4Sequence::ptr_duplicate()
-{
-    return new D4Sequence(*this);
-}
+BaseType *D4Sequence::ptr_duplicate() { return new D4Sequence(*this); }
 
-static inline void delete_bt(BaseType *bt_ptr)
-{
-    delete bt_ptr;
-}
+static inline void delete_bt(BaseType *bt_ptr) { delete bt_ptr; }
 
-static inline void delete_rows(D4SeqRow *bt_row_ptr)
-{
+static inline void delete_rows(D4SeqRow *bt_row_ptr) {
     for_each(bt_row_ptr->begin(), bt_row_ptr->end(), delete_bt);
 
     delete bt_row_ptr;
 }
 
-D4Sequence::~D4Sequence()
-{
+D4Sequence::~D4Sequence() {
     clear_local_data();
     delete d_clauses;
 }
 
-void D4Sequence::clear_local_data()
-{
+void D4Sequence::clear_local_data() {
     if (!d_values.empty()) {
         for_each(d_values.begin(), d_values.end(), delete_rows);
         d_values.resize(0);
@@ -153,10 +135,9 @@ void D4Sequence::clear_local_data()
     set_read_p(false);
 }
 
-D4Sequence &
-D4Sequence::operator=(const D4Sequence &rhs)
-{
-    if (this == &rhs) return *this;
+D4Sequence &D4Sequence::operator=(const D4Sequence &rhs) {
+    if (this == &rhs)
+        return *this;
     Constructor::operator=(rhs);
     m_duplicate(rhs);
     return *this;
@@ -185,14 +166,13 @@ D4Sequence::operator=(const D4Sequence &rhs)
  * @param filter
  * @return False when read() indicates that the EOF was found, true otherwise.
  */
-bool D4Sequence::read_next_instance(bool filter)
-{
+bool D4Sequence::read_next_instance(bool filter) {
     bool eof = false;
     bool done = false;
 
     do {
         eof = read();
-        if (eof) {  // bail if EOF
+        if (eof) { // bail if EOF
             continue;
         }
         // if we are supposed to filter and the clauses eval to true, we're done
@@ -214,10 +194,7 @@ bool D4Sequence::read_next_instance(bool filter)
     return !eof;
 }
 
-void D4Sequence::intern_data()
-{
-    read_sequence_values(true);
-}
+void D4Sequence::intern_data() { read_sequence_values(true); }
 
 /**
  * @brief Read a Sequence's value into memory
@@ -240,30 +217,29 @@ void D4Sequence::intern_data()
  * should be evaluated.
  * @see set_value()
  */
-void D4Sequence::read_sequence_values(bool filter)
-{
+void D4Sequence::read_sequence_values(bool filter) {
     DBG(cerr << __PRETTY_FUNCTION__ << " BEGIN" << endl);
 
-    if (read_p()) return;
+    if (read_p())
+        return;
 
     // Read the data values, then serialize. NB: read_next_instance sets d_length
     // evaluates the filter expression
     while (read_next_instance(filter)) {
         DBG(cerr << "read_sequence_values() - Adding row" << endl);
-        D4SeqRow* row = new D4SeqRow;
+        D4SeqRow *row = new D4SeqRow;
         for (Vars_iter i = d_vars.begin(), e = d_vars.end(); i != e; i++) {
             if ((*i)->send_p()) {
-                DBG(cerr << ":serialize() - reading data for " << (*i)->type_name() << " "  << (*i)->name() << endl);
+                DBG(cerr << ":serialize() - reading data for " << (*i)->type_name() << " " << (*i)->name() << endl);
                 if ((*i)->type() == dods_sequence_c) {
                     DBG(cerr << "Reading child sequence values for " << (*i)->name() << endl);
-                    D4Sequence *d4s = static_cast<D4Sequence*>(*i);
+                    D4Sequence *d4s = static_cast<D4Sequence *>(*i);
                     d4s->read_sequence_values(filter);
                     d4s->d_copy_clauses = false;
                     row->push_back(d4s->ptr_duplicate());
-                    d4s->d_copy_clauses = true;  // Must be sure to not break the object in general
+                    d4s->d_copy_clauses = true; // Must be sure to not break the object in general
                     row->back()->set_read_p(true);
-                }
-                else {
+                } else {
                     // store the variable's value.
                     row->push_back((*i)->ptr_duplicate());
                     // the copy should have read_p true to prevent the serialize() call
@@ -303,8 +279,7 @@ void D4Sequence::read_sequence_values(bool filter)
  * @param eval CE Evaluator object
  * @param filter True if the CE should be evaluated, false otherwise.
  */
-void D4Sequence::serialize(D4StreamMarshaller &m, DMR &dmr, bool filter)
-{
+void D4Sequence::serialize(D4StreamMarshaller &m, DMR &dmr, bool filter) {
     DBGN(cerr << __PRETTY_FUNCTION__ << " BEGIN" << endl);
 
     // Read the data values, then serialize. NB: read_next_instance sets d_length
@@ -318,15 +293,14 @@ void D4Sequence::serialize(D4StreamMarshaller &m, DMR &dmr, bool filter)
     // use the serialize methods to send them (but no need to test send_p).
     for (D4SeqValues::iterator i = d_values.begin(), e = d_values.end(); i != e; ++i) {
         for (D4SeqRow::iterator j = (*i)->begin(), f = (*i)->end(); j != f; ++j) {
-           (*j)->serialize(m, dmr, /*eval,*/false);
+            (*j)->serialize(m, dmr, /*eval,*/ false);
         }
     }
 
     DBGN(cerr << __PRETTY_FUNCTION__ << " END" << endl);
 }
 
-void D4Sequence::deserialize(D4StreamUnMarshaller &um, DMR &dmr)
-{
+void D4Sequence::deserialize(D4StreamUnMarshaller &um, DMR &dmr) {
     int64_t um_count = um.get_count();
 
     set_length(um_count);
@@ -351,13 +325,12 @@ void D4Sequence::deserialize(D4StreamUnMarshaller &um, DMR &dmr)
  * @return A reference to this D4Sequence's filter clause list
  * @see D4FilterClauseList
  */
-D4FilterClauseList & D4Sequence::clauses()
-{
-    if (!d_clauses) d_clauses = new D4FilterClauseList();
+D4FilterClauseList &D4Sequence::clauses() {
+    if (!d_clauses)
+        d_clauses = new D4FilterClauseList();
     return *d_clauses;
 }
 
-
 #if INDEX_SUBSETTING
 /** Set the start, stop and stride for a row-number type constraint.
  This should be used only when the sequence is constrained using the
@@ -367,10 +340,9 @@ D4FilterClauseList & D4Sequence::clauses()
  @param start The starting row number. The first row is row zero.
  @param stop The ending row number. The 20th row is row 19.
  @param stride The stride. A stride of two skips every other row. */
-virtual void set_row_number_constraint(int start, int stop, int stride)
-{
+virtual void set_row_number_constraint(int start, int stop, int stride) {
     if (stop < start)
-    throw Error(malformed_expr, "Starting row number must precede the ending row number.");
+        throw Error(malformed_expr, "Starting row number must precede the ending row number.");
 
     d_starting_row_number = start;
     d_row_stride = stride;
@@ -382,10 +354,9 @@ virtual void set_row_number_constraint(int start, int stop, int stride)
  @param row Get row number <i>row</i> from the sequence.
  @return A BaseTypeRow object (vector<BaseType *>). Null if there's no such
  row number as \e row. */
-D4SeqRow *
-D4Sequence::row_value(size_t row)
-{
-    if (row >= d_values.size()) return 0;
+D4SeqRow *D4Sequence::row_value(size_t row) {
+    if (row >= d_values.size())
+        return 0;
     return d_values[row];
 }
 
@@ -394,14 +365,12 @@ D4Sequence::row_value(size_t row)
  @param name Return <i>name</i> from <i>row</i>.
  @return A BaseType which holds the variable and its value.
  @see number_of_rows */
-BaseType *
-D4Sequence::var_value(size_t row_num, const string &name)
-{
+BaseType *D4Sequence::var_value(size_t row_num, const string &name) {
     D4SeqRow *row = row_value(row_num);
-    if (!row) return nullptr;
+    if (!row)
+        return nullptr;
 
-    auto elem = find_if(row->begin(), row->end(),
-                        [name](const BaseType *btp)  { return btp->name() == name; });
+    auto elem = find_if(row->begin(), row->end(), [name](const BaseType *btp) { return btp->name() == name; });
 
     return (elem != row->end()) ? *elem : nullptr;
 }
@@ -411,20 +380,20 @@ D4Sequence::var_value(size_t row_num, const string &name)
  @param i Return the $i^{th}$ variable from <i>row</i>.
  @return A BaseType which holds the variable and its value.
  @see number_of_rows */
-BaseType *
-D4Sequence::var_value(size_t row_num, size_t i)
-{
+BaseType *D4Sequence::var_value(size_t row_num, size_t i) {
     D4SeqRow *row = row_value(row_num);
-    if (!row) return 0;
+    if (!row)
+        return 0;
 
-    if (i >= row->size()) return 0;
+    if (i >= row->size())
+        return 0;
 
     return (*row)[i];
 }
 
-void D4Sequence::print_one_row(ostream &out, int row, string space, bool print_row_num)
-{
-    if (print_row_num) out << "\n" << space << row << ": ";
+void D4Sequence::print_one_row(ostream &out, int row, string space, bool print_row_num) {
+    if (print_row_num)
+        out << "\n" << space << row << ": ";
 
     out << "{ ";
 
@@ -441,9 +410,9 @@ void D4Sequence::print_one_row(ostream &out, int row, string space, bool print_r
     // Print the first value
     while (j < elements && !bt_ptr) {
         bt_ptr = var_value(row, j++);
-        if (bt_ptr) {  // data
-            if (bt_ptr->type() == dods_sequence_c) static_cast<D4Sequence*>(bt_ptr)->print_val_by_rows(out,
-                    space + "    ", false, print_row_num);
+        if (bt_ptr) { // data
+            if (bt_ptr->type() == dods_sequence_c)
+                static_cast<D4Sequence *>(bt_ptr)->print_val_by_rows(out, space + "    ", false, print_row_num);
             else
                 bt_ptr->print_val(out, space, false);
         }
@@ -452,10 +421,10 @@ void D4Sequence::print_one_row(ostream &out, int row, string space, bool print_r
     // Print the remaining values
     while (j < elements) {
         bt_ptr = var_value(row, j++);
-        if (bt_ptr) {  // data
+        if (bt_ptr) { // data
             out << ", ";
-            if (bt_ptr->type() == dods_sequence_c) static_cast<D4Sequence*>(bt_ptr)->print_val_by_rows(out,
-                    space + "    ", false, print_row_num);
+            if (bt_ptr->type() == dods_sequence_c)
+                static_cast<D4Sequence *>(bt_ptr)->print_val_by_rows(out, space + "    ", false, print_row_num);
             else
                 bt_ptr->print_val(out, space, false);
         }
@@ -464,8 +433,7 @@ void D4Sequence::print_one_row(ostream &out, int row, string space, bool print_r
     out << " }";
 }
 
-void D4Sequence::print_val_by_rows(ostream &out, string space, bool print_decl_p, bool print_row_numbers)
-{
+void D4Sequence::print_val_by_rows(ostream &out, string space, bool print_decl_p, bool print_row_numbers) {
     if (print_decl_p) {
         print_decl(out, space, false);
         out << " = ";
@@ -474,7 +442,7 @@ void D4Sequence::print_val_by_rows(ostream &out, string space, bool print_decl_p
     out << "{ ";
 
     if (length() != 0) {
-        int rows = length() - 1;	// -1 because the last row is treated specially
+        int rows = length() - 1; // -1 because the last row is treated specially
         for (int i = 0; i < rows; ++i) {
             print_one_row(out, i, space, print_row_numbers);
             out << ", ";
@@ -484,11 +452,11 @@ void D4Sequence::print_val_by_rows(ostream &out, string space, bool print_decl_p
 
     out << " }";
 
-    if (print_decl_p) out << ";\n";
+    if (print_decl_p)
+        out << ";\n";
 }
 
-void D4Sequence::print_val(ostream &out, string space, bool print_decl_p)
-{
+void D4Sequence::print_val(ostream &out, string space, bool print_decl_p) {
     DBG(cerr << name() << " isa " << type_name() << endl);
 
     print_val_by_rows(out, space, print_decl_p, false);
@@ -502,9 +470,8 @@ void D4Sequence::print_val(ostream &out, string space, bool print_decl_p)
  * @param strm C++ i/o stream to dump the information to
  * @return void
  */
-void D4Sequence::dump(ostream &strm) const
-{
-    strm << DapIndent::LMarg << "Sequence::dump - (" << (void *) this << ")" << endl;
+void D4Sequence::dump(ostream &strm) const {
+    strm << DapIndent::LMarg << "Sequence::dump - (" << (void *)this << ")" << endl;
     DapIndent::Indent();
     Constructor::dump(strm);
     strm << DapIndent::LMarg << "# rows deserialized: " << d_length << endl;
@@ -522,4 +489,3 @@ void D4Sequence::dump(ostream &strm) const
 }
 
 } // namespace libdap
-
