@@ -33,8 +33,7 @@
 
 class Crc32;
 
-namespace libdap
-{
+namespace libdap {
 class BaseType;
 class D4FilterClauseList;
 
@@ -52,7 +51,6 @@ typedef vector<BaseType *> BaseTypeRow;
 /** This type holds all of the values of a Sequence. */
 typedef vector<BaseTypeRow *> SequenceValues;
 
-
 /** This is the interface for the class D4Sequence. A sequence contains
     a single set of variables, all at the same lexical level just like
     a Structure.  Like a Structure, a D4Sequence may contain other
@@ -130,8 +128,7 @@ typedef vector<BaseTypeRow *> SequenceValues;
 
     @brief Holds a sequence. */
 
-class D4Sequence: public Constructor
-{
+class D4Sequence : public Constructor {
 private:
     // This may be zero (nullptr) but the accessor (clauses()) allocates an
     // instance if that is the case.
@@ -151,7 +148,7 @@ protected:
     // Allow these values to be accessed by subclasses
     D4SeqValues d_values;
 
-    int64_t d_length;	// How many elements are in the sequence; -1 if not currently known
+    int64_t d_length; // How many elements are in the sequence; -1 if not currently known
 
 #if INDEX_SUBSETTING
     int d_starting_row_number;
@@ -168,7 +165,6 @@ protected:
     friend class D4SequenceTest;
 
 public:
-
     D4Sequence(const string &n);
     D4Sequence(const string &n, const string &d);
 
@@ -202,13 +198,13 @@ public:
     virtual bool read_next_instance(bool filter);
 
     void intern_data(ConstraintEvaluator &, DDS &) override {
-    	throw InternalErr(__FILE__, __LINE__, "Not implemented for DAP4");
+        throw InternalErr(__FILE__, __LINE__, "Not implemented for DAP4");
     }
-    bool serialize(ConstraintEvaluator &, DDS &, Marshaller &, bool ) override {
-    	throw InternalErr(__FILE__, __LINE__, "Not implemented for DAP4");
+    bool serialize(ConstraintEvaluator &, DDS &, Marshaller &, bool) override {
+        throw InternalErr(__FILE__, __LINE__, "Not implemented for DAP4");
     }
-    bool deserialize(UnMarshaller &, DDS *, bool ) override {
-    	throw InternalErr(__FILE__, __LINE__, "Not implemented for DAP4");
+    bool deserialize(UnMarshaller &, DDS *, bool) override {
+        throw InternalErr(__FILE__, __LINE__, "Not implemented for DAP4");
     }
 
     // DAP4
@@ -269,7 +265,10 @@ public:
      * keep the serializer from trying to read each of them.
      * @param values
      */
-    virtual void set_value(D4SeqValues &values) { d_values = values; d_length = d_values.size(); }
+    virtual void set_value(D4SeqValues &values) {
+        d_values = values;
+        d_length = d_values.size();
+    }
 
     /**
      * @brief Get the values for this D4Sequence
@@ -296,10 +295,11 @@ public:
     virtual BaseType *var_value(size_t row, size_t i);
 
     virtual void print_one_row(ostream &out, int row, string space, bool print_row_num = false);
-    virtual void print_val_by_rows(ostream &out, string space = "", bool print_decl_p = true, bool print_row_numbers = true);
+    virtual void print_val_by_rows(ostream &out, string space = "", bool print_decl_p = true,
+                                   bool print_row_numbers = true);
     void print_val(ostream &out, string space = "", bool print_decl_p = true) override;
 
-    void dump(ostream &strm) const  override;
+    void dump(ostream &strm) const override;
 };
 
 } // namespace libdap
