@@ -25,28 +25,28 @@
 #include "config.h"
 
 #ifdef WIN32
+#include <fstream>
 #include <io.h>
 #include <process.h>
-#include <fstream>
 #endif
 
 #include <iostream>
-#include <sstream>
 #include <memory>
+#include <sstream>
 
-#include "D4Group.h"
-#include "BaseType.h"
 #include "Array.h"
-#include "Grid.h"
-#include "DMR.h"
-#include "XMLWriter.h"
-#include "D4BaseTypeFactory.h"
+#include "BaseType.h"
 #include "D4Attributes.h"
+#include "D4BaseTypeFactory.h"
+#include "D4Group.h"
+#include "DMR.h"
+#include "Grid.h"
+#include "XMLWriter.h"
 
-#include "DDS.h"	// Included so DMRs can be built using a DDS for 'legacy' handlers
+#include "DDS.h" // Included so DMRs can be built using a DDS for 'legacy' handlers
 
-#include "debug.h"
 #include "DapIndent.h"
+#include "debug.h"
 
 using namespace std;
 
@@ -57,9 +57,7 @@ namespace libdap {
  * This is defined because the we perform a deep copy of the root group object.
  * @param dmr
  */
-void
-DMR::m_duplicate(const DMR &dmr)
-{
+void DMR::m_duplicate(const DMR &dmr) {
     d_factory = dmr.d_factory; // Shallow copy here
 
     d_name = dmr.d_name;
@@ -67,7 +65,7 @@ DMR::m_duplicate(const DMR &dmr)
 
     d_dap_major = dmr.d_dap_major;
     d_dap_minor = dmr.d_dap_minor;
-    d_dap_version = dmr.d_dap_version;       // String version of the protocol
+    d_dap_version = dmr.d_dap_version; // String version of the protocol
 
     d_dmr_version = dmr.d_dmr_version;
 
@@ -81,7 +79,7 @@ DMR::m_duplicate(const DMR &dmr)
 
     // Deep copy, using ptr_duplicate()
     // d_root can only be a D4Group, so the thing returned by ptr_duplicate() must be a D4Group.
-    d_root = static_cast<D4Group*>(dmr.d_root->ptr_duplicate());
+    d_root = static_cast<D4Group *>(dmr.d_root->ptr_duplicate());
     DBG(cerr << "dmr.d_root: " << dmr.d_root << endl);
     DBG(cerr << "d_root (from ptr_dup(): " << d_root << endl);
 }
@@ -98,10 +96,7 @@ DMR::m_duplicate(const DMR &dmr)
  * @param name The name of the DMR - usually derived from the name of the
  * pathname or table name of the dataset.
  */
-DMR::DMR(D4BaseTypeFactory *factory, const string &name)
-        : d_factory(factory), d_name(name)
-{
-}
+DMR::DMR(D4BaseTypeFactory *factory, const string &name) : d_factory(factory), d_name(name) {}
 
 /** @brief Build a DMR using a DAP2 DDS.
  *
@@ -124,28 +119,19 @@ DMR::DMR(D4BaseTypeFactory *factory, const string &name)
  * @see BaseType::transform_to_dap4()
  */
 DMR::DMR(D4BaseTypeFactory *factory, DDS &dds)
-        : d_factory(factory), d_name(dds.get_dataset_name()), d_filename(dds.filename())
-{
+    : d_factory(factory), d_name(dds.get_dataset_name()), d_filename(dds.filename()) {
     build_using_dds(dds);
 }
 
 /** The DMR copy constructor. */
-DMR::DMR(const DMR &rhs) : DapObj()
-{
-    m_duplicate(rhs);
-}
+DMR::DMR(const DMR &rhs) : DapObj() { m_duplicate(rhs); }
 
 /** Delete a DMR. The BaseType factory is not freed, while the contained
  * group is.
  */
-DMR::~DMR()
-{
-    delete d_root;
-}
+DMR::~DMR() { delete d_root; }
 
-DMR &
-DMR::operator=(const DMR &rhs)
-{
+DMR &DMR::operator=(const DMR &rhs) {
     if (this == &rhs)
         return *this;
 
@@ -162,8 +148,7 @@ DMR::operator=(const DMR &rhs)
  *
  * @param dds Read variables and Attributes from this DDS
  */
-void DMR::build_using_dds(DDS &dds)
-{
+void DMR::build_using_dds(DDS &dds) {
     set_name(dds.get_dataset_name());
     set_filename(dds.filename());
 
@@ -174,19 +159,16 @@ void DMR::build_using_dds(DDS &dds)
         // because some of the child variables may add arrays
         // to the root object. For example, this happens in
         // Grid with the Map Arrays - ndp - 05/08/17
-        if(!d4_var){
+        if (!d4_var) {
             // no variable of this name is in the root group at this point. Add it.
-            DBG(cerr << __func__ << "() - Transforming top level variable: " <<
-                " (" << (*i)->type_name() << ":'" << (*i)->name() << "':"<<(void *)(*i) <<
-                ") (root:"<< root_grp << ")"<< endl; );
+            DBG(cerr << __func__ << "() - Transforming top level variable: " << " (" << (*i)->type_name() << ":'"
+                     << (*i)->name() << "':" << (void *)(*i) << ") (root:" << root_grp << ")" << endl;);
             (*i)->transform_to_dap4(root_grp, root_grp);
-            DBG(cerr << __func__ << "() - top level variable: '" <<
-                (*i)->name() << "' (type:" << (*i)->type_name() << ") Transformed"<< endl; );
-        }
-        else {
-            DBG(cerr << __func__ << "() - Skipping variable: " <<
-                d4_var->type_name() << " " << d4_var->name() << " because a variable with" <<
-                " this name already exists in the root group." << endl; );
+            DBG(cerr << __func__ << "() - top level variable: '" << (*i)->name() << "' (type:" << (*i)->type_name()
+                     << ") Transformed" << endl;);
+        } else {
+            DBG(cerr << __func__ << "() - Skipping variable: " << d4_var->type_name() << " " << d4_var->name()
+                     << " because a variable with" << " this name already exists in the root group." << endl;);
         }
     }
 
@@ -209,10 +191,8 @@ void DMR::build_using_dds(DDS &dds)
  *
  * @return A pointer to the newly allocated DDS.
  */
-DDS *
-DMR::getDDS()
-{
-    DBG( cerr << __func__ << "() - BEGIN" << endl);
+DDS *DMR::getDDS() {
+    DBG(cerr << __func__ << "() - BEGIN" << endl);
 
     BaseTypeFactory btf;
     DDS *dds = new DDS(&btf, name());
@@ -222,19 +202,19 @@ DMR::getDDS()
     // TODO Make this a unique_ptr<> and let the compiler delete it. jhrg 6/17/19
     // change made jhrg 2/4/22
 #if 1
-    unique_ptr< vector<BaseType *>> top_vars(root()->transform_to_dap2(&(dds->get_attr_table())/*, true*/));
+    unique_ptr<vector<BaseType *>> top_vars(root()->transform_to_dap2(&(dds->get_attr_table()) /*, true*/));
     for (vector<BaseType *>::iterator i = top_vars->begin(), e = top_vars->end(); i != e; i++) {
         dds->add_var_nocopy(*i);
     }
 #else
-    vector<BaseType *> *top_vars = root()->transform_to_dap2(&(dds->get_attr_table())/*, true*/);
+    vector<BaseType *> *top_vars = root()->transform_to_dap2(&(dds->get_attr_table()) /*, true*/);
     for (vector<BaseType *>::iterator i = top_vars->begin(), e = top_vars->end(); i != e; i++) {
         dds->add_var_nocopy(*i);
     }
     delete top_vars;
 #endif
-    DBG( cerr << __func__ << "() - END" << endl);
-    
+    DBG(cerr << __func__ << "() - END" << endl);
+
     dds->set_factory(0);
     return dds;
 }
@@ -245,11 +225,10 @@ DMR::getDDS()
  *
  * @return A pointer to the root group.
  */
-D4Group *
-DMR::root()
-{
-	if (!d_root) d_root = static_cast<D4Group*>(d_factory->NewVariable(dods_group_c, "/"));
-	return d_root;
+D4Group *DMR::root() {
+    if (!d_root)
+        d_root = static_cast<D4Group *>(d_factory->NewVariable(dods_group_c, "/"));
+    return d_root;
 }
 
 /**
@@ -257,9 +236,7 @@ DMR::root()
  *
  * @param v The version string.
  */
-void
-DMR::set_dap_version(const string &v)
-{
+void DMR::set_dap_version(const string &v) {
     istringstream iss(v);
 
     int major = -1, minor = -1;
@@ -284,12 +261,12 @@ DMR::set_dap_version(const string &v)
     // being constructed by a server the code to generate the XML document
     // needs these values to match the DAP version information.
     switch (d_dap_major) {
-        case 4:
-            d_namespace = c_dap40_namespace;
-            break;
-        default:
-            d_namespace = "";
-            break;
+    case 4:
+        d_namespace = c_dap40_namespace;
+        break;
+    default:
+        d_namespace = "";
+        break;
     }
 }
 
@@ -305,10 +282,7 @@ DMR::set_dap_version(const string &v)
  * @deprecated "Use DMR::request_size_kb()"
  */
 //[[deprecated("Use DMR::request_size_kb()")]]
-long DMR::request_size(bool constrained)
-{
-    return d_root->request_size(constrained);
-}
+long DMR::request_size(bool constrained) { return d_root->request_size(constrained); }
 
 /** Get the size of a response, in kilobytes. This method looks at the
  * variables in the DMR a computes the number of bytes in the response.
@@ -320,13 +294,7 @@ long DMR::request_size(bool constrained)
  * current constraint be taken into account?
  * @return The size of the request in kilobytes
  */
-uint64_t DMR::request_size_kb(bool constrained)
-{
-    return d_root->request_size_kb(constrained);
-}
-
-
-
+uint64_t DMR::request_size_kb(bool constrained) { return d_root->request_size_kb(constrained); }
 
 /**
  * Print the DAP4 DMR object.
@@ -335,28 +303,29 @@ uint64_t DMR::request_size_kb(bool constrained)
  * @param constrained Should the DMR be subject to a constraint? Defaults to
  * False
  */
-void
-DMR::print_dap4(XMLWriter &xml, bool constrained)
-{
-    if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar*) "Dataset") < 0)
+void DMR::print_dap4(XMLWriter &xml, bool constrained) {
+    if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar *)"Dataset") < 0)
         throw InternalErr(__FILE__, __LINE__, "Could not write Dataset element");
 
-    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xmlns", (const xmlChar*) get_namespace().c_str()) < 0)
+    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar *)"xmlns",
+                                    (const xmlChar *)get_namespace().c_str()) < 0)
         throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns");
 
     if (!request_xml_base().empty()) {
-        if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xml:base",
-                (const xmlChar*)request_xml_base().c_str()) < 0)
+        if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar *)"xml:base",
+                                        (const xmlChar *)request_xml_base().c_str()) < 0)
             throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xml:base");
     }
 
-    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "dapVersion",  (const xmlChar*)dap_version().c_str()) < 0)
+    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar *)"dapVersion",
+                                    (const xmlChar *)dap_version().c_str()) < 0)
         throw InternalErr(__FILE__, __LINE__, "Could not write attribute for dapVersion");
 
-    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "dmrVersion", (const xmlChar*)dmr_version().c_str()) < 0)
+    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar *)"dmrVersion",
+                                    (const xmlChar *)dmr_version().c_str()) < 0)
         throw InternalErr(__FILE__, __LINE__, "Could not write attribute for dapVersion");
 
-    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "name", (const xmlChar*)name().c_str()) < 0)
+    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar *)"name", (const xmlChar *)name().c_str()) < 0)
         throw InternalErr(__FILE__, __LINE__, "Could not write attribute for name");
 
     root()->print_dap4(xml, constrained);
@@ -365,25 +334,22 @@ DMR::print_dap4(XMLWriter &xml, bool constrained)
         throw InternalErr(__FILE__, __LINE__, "Could not end the top-level Group element");
 }
 
-
 /**
  * @brief Scans the inventory of projected variables and their attributes for projected DAP4 types.
  * As it locates projected DAP4 types it adds a description of each to the vector inventory
  * @param inventory
  * @return true when dap4 types have been requested, false otherwise.
  */
-bool DMR::is_dap4_projected(std::vector<string> &inventory)
-{
-    bool has_dap4 = root()->attributes()->has_dap4_types(root()->FQN(),inventory);
+bool DMR::is_dap4_projected(std::vector<string> &inventory) {
+    bool has_dap4 = root()->attributes()->has_dap4_types(root()->FQN(), inventory);
 
-    for(const auto var : root()->variables()){
+    for (const auto var : root()->variables()) {
         has_dap4 |= var->is_dap4_projected(inventory);
     }
-    for(const auto grp: root()->groups()){
+    for (const auto grp : root()->groups()) {
         has_dap4 |= grp->is_dap4_projected(inventory);
     }
     return has_dap4;
-
 }
 
 /** @brief dumps information about this object
@@ -393,19 +359,16 @@ bool DMR::is_dap4_projected(std::vector<string> &inventory)
  * @param strm C++ i/o stream to dump the information to
  * @return void
  */
-void
-DMR::dump(ostream &strm) const
-{
-    strm << DapIndent::LMarg << "DMR::dump - ("
-    << (void *)this << ")" << endl ;
-    DapIndent::Indent() ;
-    strm << DapIndent::LMarg << "factory: " << (void *)d_factory << endl ;
-    strm << DapIndent::LMarg << "name: " << d_name << endl ;
-    strm << DapIndent::LMarg << "filename: " << d_filename << endl ;
+void DMR::dump(ostream &strm) const {
+    strm << DapIndent::LMarg << "DMR::dump - (" << (void *)this << ")" << endl;
+    DapIndent::Indent();
+    strm << DapIndent::LMarg << "factory: " << (void *)d_factory << endl;
+    strm << DapIndent::LMarg << "name: " << d_name << endl;
+    strm << DapIndent::LMarg << "filename: " << d_filename << endl;
     strm << DapIndent::LMarg << "protocol major: " << d_dap_major << endl;
     strm << DapIndent::LMarg << "protocol minor: " << d_dap_minor << endl;
 
-    DapIndent::UnIndent() ;
+    DapIndent::UnIndent();
 }
 
 } // namespace libdap
