@@ -38,8 +38,7 @@
 
 #include <iostream>
 
-namespace libdap
-{
+namespace libdap {
 
 /** @brief libdap base object for common functionality of libdap objects
  *
@@ -47,8 +46,7 @@ namespace libdap
  * methods for dumping the contents of the object.
  */
 
-class DapObj
-{
+class DapObj {
 public:
     virtual ~DapObj() = default;
 
@@ -74,12 +72,9 @@ public:
  * @param strm C++ i/o stream to dump the object to
  * @param obj The DapObj to dump
  */
-inline std::ostream &
-operator<<(std::ostream &strm, const libdap::DapObj &obj)
-{
+inline std::ostream &operator<<(std::ostream &strm, const libdap::DapObj &obj) {
     obj.dump(strm);
     return strm;
 }
 
 #endif // A_DapObj_h
-
