@@ -62,7 +62,8 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-
+/* Substitute the type names.  */
+#define YYSTYPE         ERRORSTYPE
 /* Substitute the variable and function names.  */
 #define yyparse         Errorparse
 #define yylex           Errorlex
@@ -99,10 +100,18 @@
 #ifndef YY_ERROR_ERROR_TAB_HH_INCLUDED
 # define YY_ERROR_ERROR_TAB_HH_INCLUDED
 /* Debug traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 1
-#endif
+#ifndef ERRORDEBUG
+# if defined YYDEBUG
 #if YYDEBUG
+#   define ERRORDEBUG 1
+#  else
+#   define ERRORDEBUG 0
+#  endif
+# else /* ! defined YYDEBUG */
+#  define ERRORDEBUG 1
+# endif /* ! defined YYDEBUG */
+#endif  /* ! defined ERRORDEBUG */
+#if ERRORDEBUG
 extern int Errordebug;
 #endif
 /* "%code requires" blocks.  */
@@ -131,17 +140,16 @@ using namespace libdap;
 #define STATUS(arg) ((parser_arg *)(arg))->_status
 
 #define YYERROR_VERBOSE 0
-//#define YYPARSE_PARAM arg
 
 extern int error_line_num;	// defined in Error.lex
 
 
-#line 140 "Error.tab.cc" /* yacc.c:352  */
+#line 148 "Error.tab.cc" /* yacc.c:352  */
 
 /* Token type.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-  enum yytokentype
+#ifndef ERRORTOKENTYPE
+# define ERRORTOKENTYPE
+  enum Errortokentype
   {
     SCAN_INT = 258,
     SCAN_STR = 259,
@@ -152,11 +160,11 @@ extern int error_line_num;	// defined in Error.lex
 #endif
 
 /* Value type.  */
-#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+#if ! defined ERRORSTYPE && ! defined ERRORSTYPE_IS_DECLARED
 
-union YYSTYPE
+union ERRORSTYPE
 {
-#line 77 "Error.yy" /* yacc.c:352  */
+#line 75 "Error.yy" /* yacc.c:352  */
 
 #ifdef __SUNPRO_CC
     int boolean;
@@ -166,16 +174,16 @@ union YYSTYPE
     int integer;
     char *string;
 
-#line 170 "Error.tab.cc" /* yacc.c:352  */
+#line 178 "Error.tab.cc" /* yacc.c:352  */
 };
 
-typedef union YYSTYPE YYSTYPE;
-# define YYSTYPE_IS_TRIVIAL 1
-# define YYSTYPE_IS_DECLARED 1
+typedef union ERRORSTYPE ERRORSTYPE;
+# define ERRORSTYPE_IS_TRIVIAL 1
+# define ERRORSTYPE_IS_DECLARED 1
 #endif
 
 
-extern YYSTYPE Errorlval;
+extern ERRORSTYPE Errorlval;
 
 int Errorparse (parser_arg *arg);
 
@@ -183,14 +191,14 @@ int Errorparse (parser_arg *arg);
 
 
 /* Unqualified %code blocks.  */
-#line 62 "Error.yy" /* yacc.c:355  */
+#line 61 "Error.yy" /* yacc.c:355  */
 
 
 int Errorlex();			// the scanner
 void Errorerror(parser_arg *arg, const string &s);	// gotta love automatically generated names...
 
 
-#line 194 "Error.tab.cc" /* yacc.c:355  */
+#line 202 "Error.tab.cc" /* yacc.c:355  */
 
 #ifdef short
 # undef short
@@ -362,7 +370,7 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 
 #if (! defined yyoverflow \
      && (! defined __cplusplus \
-         || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))
+         || (defined ERRORSTYPE_IS_TRIVIAL && ERRORSTYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
@@ -475,15 +483,15 @@ static const yytype_uint8 yytranslate[] =
        5,     6,     7
 };
 
-#if YYDEBUG
+#if ERRORDEBUG
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,   105,   105,   108,   111,   112,   115,   123,   122
+       0,   103,   103,   106,   109,   110,   113,   121,   120
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || 0
+#if ERRORDEBUG || YYERROR_VERBOSE || 0
 /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const yytname[] =
@@ -615,7 +623,7 @@ static const yytype_uint8 yyr2[] =
 
 
 /* Enable debugging if requested.  */
-#if YYDEBUG
+#if ERRORDEBUG
 
 # ifndef YYFPRINTF
 #  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
@@ -737,12 +745,12 @@ do {                                    \
 /* Nonzero means print parse trace.  It is left uninitialized so that
    multiple parsers can coexist.  */
 int yydebug;
-#else /* !YYDEBUG */
+#else /* !ERRORDEBUG */
 # define YYDPRINTF(Args)
 # define YY_SYMBOL_PRINT(Title, Type, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
-#endif /* !YYDEBUG */
+#endif /* !ERRORDEBUG */
 
 
 /* YYINITDEPTH -- initial size of the parser's stacks.  */
@@ -1263,56 +1271,56 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 105 "Error.yy" /* yacc.c:1667  */
+#line 103 "Error.yy" /* yacc.c:1667  */
     { (yyval.boolean) = (yyvsp[-2].boolean); STATUS(arg) = (yyvsp[-2].boolean); }
-#line 1269 "Error.tab.cc" /* yacc.c:1667  */
+#line 1277 "Error.tab.cc" /* yacc.c:1667  */
     break;
 
   case 3:
-#line 108 "Error.yy" /* yacc.c:1667  */
+#line 106 "Error.yy" /* yacc.c:1667  */
     { (yyval.boolean) = (yyvsp[0].boolean); }
-#line 1275 "Error.tab.cc" /* yacc.c:1667  */
+#line 1283 "Error.tab.cc" /* yacc.c:1667  */
     break;
 
   case 4:
-#line 111 "Error.yy" /* yacc.c:1667  */
+#line 109 "Error.yy" /* yacc.c:1667  */
     { (yyval.boolean) = (yyvsp[-1].boolean) && (yyvsp[0].boolean); }
-#line 1281 "Error.tab.cc" /* yacc.c:1667  */
+#line 1289 "Error.tab.cc" /* yacc.c:1667  */
     break;
 
   case 5:
-#line 112 "Error.yy" /* yacc.c:1667  */
+#line 110 "Error.yy" /* yacc.c:1667  */
     { (yyval.boolean) = (yyvsp[0].boolean); }
-#line 1287 "Error.tab.cc" /* yacc.c:1667  */
+#line 1295 "Error.tab.cc" /* yacc.c:1667  */
     break;
 
   case 6:
-#line 116 "Error.yy" /* yacc.c:1667  */
+#line 114 "Error.yy" /* yacc.c:1667  */
     { 
 		    ERROR_OBJ(arg)->set_error_code((ErrorCode)(yyvsp[-1].integer));
 		    (yyval.boolean) = true; 
 		}
-#line 1296 "Error.tab.cc" /* yacc.c:1667  */
-    break;
-
-  case 7:
-#line 123 "Error.yy" /* yacc.c:1667  */
-    { 
-		    ERROR_OBJ(arg)->set_error_message((yyvsp[0].string));
-		}
 #line 1304 "Error.tab.cc" /* yacc.c:1667  */
     break;
 
-  case 8:
-#line 127 "Error.yy" /* yacc.c:1667  */
-    {
-		    (yyval.boolean) = true;
+  case 7:
+#line 121 "Error.yy" /* yacc.c:1667  */
+    { 
+		    ERROR_OBJ(arg)->set_error_message((yyvsp[0].string));
 		}
 #line 1312 "Error.tab.cc" /* yacc.c:1667  */
     break;
 
+  case 8:
+#line 125 "Error.yy" /* yacc.c:1667  */
+    {
+		    (yyval.boolean) = true;
+		}
+#line 1320 "Error.tab.cc" /* yacc.c:1667  */
+    break;
 
-#line 1316 "Error.tab.cc" /* yacc.c:1667  */
+
+#line 1324 "Error.tab.cc" /* yacc.c:1667  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1543,7 +1551,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 132 "Error.yy" /* yacc.c:1918  */
+#line 130 "Error.yy" /* yacc.c:1918  */
 
 
 void
