@@ -11,12 +11,12 @@
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
 // version 2.1 of the License, or (at your option) any later version.
-// 
+//
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -34,9 +34,7 @@
 #include <string>
 #endif
 
-namespace libdap
-{
-
+namespace libdap {
 
 /**
  * @brief Regular expression matching
@@ -53,8 +51,7 @@ namespace libdap
  *
  * @author James Gallagher <jgallagher@opendap.org>
  */
-class Regex
-{
+class Regex {
 private:
 #if USE_CPP_11_REGEX
     std::regex d_exp;
@@ -64,7 +61,7 @@ private:
 #else
     // d_preg was a regex_t* but I needed to include both regex.h and config.h
     // to make the gnulib code work. Because this header is installed (and is
-    // used by other libraries) it cannot include config.h, so I moved the 
+    // used by other libraries) it cannot include config.h, so I moved the
     // regex.h and config.h (among other) includes to the implementation. It
     // would be cleaner to use a special class, but for one field that seems
     // like overkill.
@@ -94,7 +91,7 @@ public:
     int match(const std::string &s) const;
 
     /// @brief How much of the string does the pattern match.
-    int search(const char *s, int len, int &matchlen, int pos = 0) const ;
+    int search(const char *s, int len, int &matchlen, int pos = 0) const;
     /// @brief How much of the string does the pattern match.
     int search(const std::string &s, int &matchlen) const;
 };
