@@ -26,18 +26,18 @@
 #include "config.h"
 
 #include <limits.h>
-#include <unistd.h>   // for stat
-#include <sys/types.h>  // for stat and mkdir
 #include <sys/stat.h>
+#include <sys/types.h> // for stat and mkdir
+#include <unistd.h>    // for stat
 
-#include <cstring>
 #include <cerrno>
+#include <cstring>
 
-#include <iostream>
-#include <sstream>
 #include <algorithm>
+#include <iostream>
 #include <iterator>
 #include <set>
+#include <sstream>
 
 #include "Error.h"
 #include "InternalErr.h"
@@ -46,27 +46,28 @@
 #include "SignalHandler.h"
 #endif
 #include "HTTPCacheInterruptHandler.h"
-#include "HTTPCacheTable.h"
 #include "HTTPCacheMacros.h"
+#include "HTTPCacheTable.h"
 
-#include "util_mit.h"
 #include "debug.h"
+#include "util_mit.h"
 
 #ifdef WIN32
 #include <direct.h>
-#include <time.h>
 #include <fcntl.h>
-#define MKDIR(a,b) _mkdir((a))
-#define REMOVE(a) do { \
-		int s = remove((a)); \
-		if (s != 0) \
-			throw InternalErr(__FILE__, __LINE__, "Cache error; could not remove file: " + long_to_string(s)); \
-	} while(0);
-#define MKSTEMP(a) _open(_mktemp((a)),_O_CREAT,_S_IREAD|_S_IWRITE)
+#include <time.h>
+#define MKDIR(a, b) _mkdir((a))
+#define REMOVE(a)                                                                                                      \
+    do {                                                                                                               \
+        int s = remove((a));                                                                                           \
+        if (s != 0)                                                                                                    \
+            throw InternalErr(__FILE__, __LINE__, "Cache error; could not remove file: " + long_to_string(s));         \
+    } while (0);
+#define MKSTEMP(a) _open(_mktemp((a)), _O_CREAT, _S_IREAD | _S_IWRITE)
 #define DIR_SEPARATOR_CHAR '\\'
 #define DIR_SEPARATOR_STR "\\"
 #else
-#define MKDIR(a,b) mkdir((a), (b))
+#define MKDIR(a, b) mkdir((a), (b))
 #define MKSTEMP(a) mkstemp((a))
 #define DIR_SEPARATOR_CHAR '/'
 #define DIR_SEPARATOR_STR "/"
@@ -76,8 +77,8 @@
 #define CACHE_INDEX ".index"
 #define CACHE_EMPTY_ETAG "@cache@"
 
-#define NO_LM_EXPIRATION 24*3600 // 24 hours
-#define MAX_LM_EXPIRATION 48*3600 // Max expiration from LM
+#define NO_LM_EXPIRATION 24 * 3600  // 24 hours
+#define MAX_LM_EXPIRATION 48 * 3600 // Max expiration from LM
 
 // If using LM to find the expiration then take 10% and no more than
 // MAX_LM_EXPIRATION.
@@ -94,9 +95,7 @@ namespace libdap {
 /** Compute the hash value for a URL.
     @param url
     @return An integer hash code between 0 and CACHE_TABLE_SIZE. */
-int
-get_hash(const string &url)
-{
+int get_hash(const string &url) {
     int hash = 0;
 
     for (const char *ptr = url.c_str(); *ptr; ptr++)
@@ -105,16 +104,15 @@ get_hash(const string &url)
     return hash;
 }
 
-HTTPCacheTable::HTTPCacheTable(const string &cache_root, int block_size) :
-    d_cache_root(cache_root), d_block_size(block_size), d_current_size(0), d_new_entries(0)
-{
+HTTPCacheTable::HTTPCacheTable(const string &cache_root, int block_size)
+    : d_cache_root(cache_root), d_block_size(block_size), d_current_size(0), d_new_entries(0) {
     d_cache_index = cache_root + CACHE_INDEX;
 
-    d_cache_table = new CacheEntries*[CACHE_TABLE_SIZE];
+    d_cache_table = new CacheEntries *[CACHE_TABLE_SIZE];
 
     // Initialize the cache table.
     for (int i = 0; i < CACHE_TABLE_SIZE; ++i)
-	d_cache_table[i] = 0;
+        d_cache_table[i] = 0;
 
     cache_index_read();
 }
@@ -122,15 +120,12 @@ HTTPCacheTable::HTTPCacheTable(const string &cache_root, int block_size) :
 /** Called by for_each inside ~HTTPCache().
     @param e The cache entry to delete. */
 
-static inline void
-delete_cache_entry(HTTPCacheTable::CacheEntry *e)
-{
+static inline void delete_cache_entry(HTTPCacheTable::CacheEntry *e) {
     DBG2(cerr << "Deleting CacheEntry: " << e << endl);
     delete e;
 }
 
-HTTPCacheTable::~HTTPCacheTable()
-{
+HTTPCacheTable::~HTTPCacheTable() {
     for (int i = 0; i < CACHE_TABLE_SIZE; ++i) {
         HTTPCacheTable::CacheEntries *cp = get_cache_table()[i];
         if (cp) {
@@ -154,37 +149,35 @@ HTTPCacheTable::~HTTPCacheTable()
     @see expired_gc. */
 
 class DeleteExpired : public unary_function<HTTPCacheTable::CacheEntry *&, void> {
-	time_t d_time;
-	HTTPCacheTable &d_table;
+    time_t d_time;
+    HTTPCacheTable &d_table;
 
 public:
-	DeleteExpired(HTTPCacheTable &table, time_t t) :
-		d_time(t), d_table(table) {
-		if (!t)
-			d_time = time(0); // 0 == now
-	} 
+    DeleteExpired(HTTPCacheTable &table, time_t t) : d_time(t), d_table(table) {
+        if (!t)
+            d_time = time(0); // 0 == now
+    }
 
-	void operator()(HTTPCacheTable::CacheEntry *&e) {
-		if (e && !e->readers && (e->freshness_lifetime
-				< (e->corrected_initial_age + (d_time - e->response_time)))) {
-			DBG(cerr << "Deleting expired cache entry: " << e->url << endl);
-			d_table.remove_cache_entry(e);
-			delete e; e = 0;
-		}
-	}
+    void operator()(HTTPCacheTable::CacheEntry *&e) {
+        if (e && !e->readers && (e->freshness_lifetime < (e->corrected_initial_age + (d_time - e->response_time)))) {
+            DBG(cerr << "Deleting expired cache entry: " << e->url << endl);
+            d_table.remove_cache_entry(e);
+            delete e;
+            e = 0;
+        }
+    }
 };
 
 // @param time base deletes againt this time, defaults to 0 (now)
 void HTTPCacheTable::delete_expired_entries(time_t time) {
-	// Walk through and delete all the expired entries.
-	for (int cnt = 0; cnt < CACHE_TABLE_SIZE; cnt++) {
-		HTTPCacheTable::CacheEntries *slot = get_cache_table()[cnt];
-		if (slot) {
-			for_each(slot->begin(), slot->end(), DeleteExpired(*this, time));
-			slot->erase(remove(slot->begin(), slot->end(),
-					static_cast<HTTPCacheTable::CacheEntry *>(0)), slot->end());
-		}
-	}
+    // Walk through and delete all the expired entries.
+    for (int cnt = 0; cnt < CACHE_TABLE_SIZE; cnt++) {
+        HTTPCacheTable::CacheEntries *slot = get_cache_table()[cnt];
+        if (slot) {
+            for_each(slot->begin(), slot->end(), DeleteExpired(*this, time));
+            slot->erase(remove(slot->begin(), slot->end(), static_cast<HTTPCacheTable::CacheEntry *>(0)), slot->end());
+        }
+    }
 }
 
 /** Functor which deletes and nulls a single CacheEntry which has less than
@@ -194,57 +187,51 @@ void HTTPCacheTable::delete_expired_entries(time_t time) {
     @see hits_gc. */
 
 class DeleteByHits : public unary_function<HTTPCacheTable::CacheEntry *&, void> {
-	HTTPCacheTable &d_table;
-	int d_hits;
+    HTTPCacheTable &d_table;
+    int d_hits;
 
 public:
-	DeleteByHits(HTTPCacheTable &table, int hits) :
-		d_table(table), d_hits(hits) {
-	}
+    DeleteByHits(HTTPCacheTable &table, int hits) : d_table(table), d_hits(hits) {}
 
-	void operator()(HTTPCacheTable::CacheEntry *&e) {
-		if (e && !e->readers && e->hits <= d_hits) {
-			DBG(cerr << "Deleting cache entry: " << e->url << endl);
-			d_table.remove_cache_entry(e);
-			delete e; e = 0;
-		}
-	}
+    void operator()(HTTPCacheTable::CacheEntry *&e) {
+        if (e && !e->readers && e->hits <= d_hits) {
+            DBG(cerr << "Deleting cache entry: " << e->url << endl);
+            d_table.remove_cache_entry(e);
+            delete e;
+            e = 0;
+        }
+    }
 };
 
-void 
-HTTPCacheTable::delete_by_hits(int hits) {
+void HTTPCacheTable::delete_by_hits(int hits) {
     for (int cnt = 0; cnt < CACHE_TABLE_SIZE; cnt++) {
         if (get_cache_table()[cnt]) {
             HTTPCacheTable::CacheEntries *slot = get_cache_table()[cnt];
             for_each(slot->begin(), slot->end(), DeleteByHits(*this, hits));
-            slot->erase(remove(slot->begin(), slot->end(),
-                               static_cast<HTTPCacheTable::CacheEntry*>(0)),
-                        slot->end());
-
+            slot->erase(remove(slot->begin(), slot->end(), static_cast<HTTPCacheTable::CacheEntry *>(0)), slot->end());
         }
     }
 }
 
-/** Functor which deletes and nulls a single CacheEntry which is larger than 
+/** Functor which deletes and nulls a single CacheEntry which is larger than
     a given size.
     @see hits_gc. */
 
 class DeleteBySize : public unary_function<HTTPCacheTable::CacheEntry *&, void> {
-	HTTPCacheTable &d_table;
-	unsigned int d_size;
+    HTTPCacheTable &d_table;
+    unsigned int d_size;
 
 public:
-	DeleteBySize(HTTPCacheTable &table, unsigned int size) :
-		d_table(table), d_size(size) {
-	}
+    DeleteBySize(HTTPCacheTable &table, unsigned int size) : d_table(table), d_size(size) {}
 
-	void operator()(HTTPCacheTable::CacheEntry *&e) {
-		if (e && !e->readers && e->size > d_size) {
-			DBG(cerr << "Deleting cache entry: " << e->url << endl);
-			d_table.remove_cache_entry(e);
-			delete e; e = 0;
-		}
-	}
+    void operator()(HTTPCacheTable::CacheEntry *&e) {
+        if (e && !e->readers && e->size > d_size) {
+            DBG(cerr << "Deleting cache entry: " << e->url << endl);
+            d_table.remove_cache_entry(e);
+            delete e;
+            e = 0;
+        }
+    }
 };
 
 void HTTPCacheTable::delete_by_size(unsigned int size) {
@@ -252,10 +239,7 @@ void HTTPCacheTable::delete_by_size(unsigned int size) {
         if (get_cache_table()[cnt]) {
             HTTPCacheTable::CacheEntries *slot = get_cache_table()[cnt];
             for_each(slot->begin(), slot->end(), DeleteBySize(*this, size));
-            slot->erase(remove(slot->begin(), slot->end(),
-                               static_cast<HTTPCacheTable::CacheEntry*>(0)),
-                        slot->end());
-
+            slot->erase(remove(slot->begin(), slot->end(), static_cast<HTTPCacheTable::CacheEntry *>(0)), slot->end());
         }
     }
 }
@@ -273,11 +257,9 @@ void HTTPCacheTable::delete_by_size(unsigned int size) {
 
     @return True if the file was deleted, otherwise false. */
 
-bool
-HTTPCacheTable::cache_index_delete()
-{
-	d_new_entries = 0;
-	
+bool HTTPCacheTable::cache_index_delete() {
+    d_new_entries = 0;
+
     return (REMOVE_BOOL(d_cache_index.c_str()) == 0);
 }
 
@@ -289,9 +271,7 @@ HTTPCacheTable::cache_index_delete()
 
     @return True when a cache index was found and read, false otherwise. */
 
-bool
-HTTPCacheTable::cache_index_read()
-{
+bool HTTPCacheTable::cache_index_read() {
     FILE *fp = fopen(d_cache_index.c_str(), "r");
     // If the cache index can't be opened that's OK; start with an empty
     // cache. 09/05/02 jhrg
@@ -301,17 +281,17 @@ HTTPCacheTable::cache_index_read()
 
     char line[1024];
     while (!feof(fp) && fgets(line, 1024, fp)) {
-    	add_entry_to_cache_table(cache_index_parse_line(line));
+        add_entry_to_cache_table(cache_index_parse_line(line));
         DBG2(cerr << line << endl);
     }
 
-    int res = fclose(fp) ;
+    int res = fclose(fp);
     if (res) {
         DBG(cerr << "HTTPCache::cache_index_read - Failed to close " << (void *)fp << endl);
     }
 
     d_new_entries = 0;
-    
+
     return true;
 }
 
@@ -322,11 +302,9 @@ HTTPCacheTable::cache_index_read()
     @param line A single line from the \c .index file.
     @return A CacheEntry initialized with the information from \c line. */
 
-HTTPCacheTable::CacheEntry *
-HTTPCacheTable::cache_index_parse_line(const char *line)
-{
+HTTPCacheTable::CacheEntry *HTTPCacheTable::cache_index_parse_line(const char *line) {
     // Read the line and create the cache object
-	HTTPCacheTable::CacheEntry *entry = new HTTPCacheTable::CacheEntry;
+    HTTPCacheTable::CacheEntry *entry = new HTTPCacheTable::CacheEntry;
     istringstream iss(line);
     iss >> entry->url;
     iss >> entry->cachename;
@@ -353,33 +331,19 @@ HTTPCacheTable::cache_index_parse_line(const char *line)
 
 /** Functor which writes a single CacheEntry to the \c .index file. */
 
-class WriteOneCacheEntry :
-	public unary_function<HTTPCacheTable::CacheEntry *, void>
-{
+class WriteOneCacheEntry : public unary_function<HTTPCacheTable::CacheEntry *, void> {
 
     FILE *d_fp;
 
 public:
-    WriteOneCacheEntry(FILE *fp) : d_fp(fp)
-    {}
+    WriteOneCacheEntry(FILE *fp) : d_fp(fp) {}
 
-    void operator()(HTTPCacheTable::CacheEntry *e)
-    {
-        if (e && fprintf(d_fp,
-                         "%s %s %s %ld %ld %ld %c %d %d %ld %ld %ld %c\r\n",
-                         e->url.c_str(),
-                         e->cachename.c_str(),
-                         e->etag == "" ? CACHE_EMPTY_ETAG : e->etag.c_str(),
-                         (long)(e->lm),
-                         (long)(e->expires),
-                         e->size,
+    void operator()(HTTPCacheTable::CacheEntry *e) {
+        if (e && fprintf(d_fp, "%s %s %s %ld %ld %ld %c %d %d %ld %ld %ld %c\r\n", e->url.c_str(), e->cachename.c_str(),
+                         e->etag == "" ? CACHE_EMPTY_ETAG : e->etag.c_str(), (long)(e->lm), (long)(e->expires), e->size,
                          e->range ? '1' : '0', // not used. 10/02/02 jhrg
-                         e->hash,
-                         e->hits,
-                         (long)(e->freshness_lifetime),
-                         (long)(e->response_time),
-                         (long)(e->corrected_initial_age),
-                         e->must_revalidate ? '1' : '0') < 0)
+                         e->hash, e->hits, (long)(e->freshness_lifetime), (long)(e->response_time),
+                         (long)(e->corrected_initial_age), e->must_revalidate ? '1' : '0') < 0)
             throw Error(internal_error, "Cache Index. Error writing cache index\n");
     }
 };
@@ -393,16 +357,13 @@ public:
     @exception Error Thrown if the index file cannot be opened for writing.
     @note The HTTPCache destructor calls this method and silently ignores
     this exception. */
-void
-HTTPCacheTable::cache_index_write()
-{
+void HTTPCacheTable::cache_index_write() {
     DBG(cerr << "Cache Index. Writing index " << d_cache_index << endl);
 
     // Open the file for writing.
-    FILE * fp = NULL;
+    FILE *fp = NULL;
     if ((fp = fopen(d_cache_index.c_str(), "wb")) == NULL) {
-        throw Error(string("Cache Index. Can't open `") + d_cache_index
-                    + string("' for writing"));
+        throw Error(string("Cache Index. Can't open `") + d_cache_index + string("' for writing"));
     }
 
     // Walk through the list and write it out. The format is really
@@ -417,8 +378,7 @@ HTTPCacheTable::cache_index_write()
     /* Done writing */
     int res = fclose(fp);
     if (res) {
-        DBG(cerr << "HTTPCache::cache_index_write - Failed to close "
-            << (void *)fp << endl);
+        DBG(cerr << "HTTPCache::cache_index_write - Failed to close " << (void *)fp << endl);
     }
 
     d_new_entries = 0;
@@ -438,9 +398,7 @@ HTTPCacheTable::cache_index_write()
     @return The pathname to the directory (even if it already existed).
     @exception Error Thrown if the directory cannot be created.*/
 
-string
-HTTPCacheTable::create_hash_directory(int hash)
-{
+string HTTPCacheTable::create_hash_directory(int hash) {
     ostringstream path;
     path << d_cache_root << hash;
 
@@ -451,7 +409,8 @@ HTTPCacheTable::create_hash_directory(int hash)
     errno = 0;
     if (mkdir(path.str().c_str(), 0777) < 0 && errno != EEXIST) {
         umask(mask);
-        throw Error(internal_error, "Could not create the directory for the cache at '" + path.str() + "' (" + strerror(errno) + ").");
+        throw Error(internal_error,
+                    "Could not create the directory for the cache at '" + path.str() + "' (" + strerror(errno) + ").");
     }
 
     // Restore themask
@@ -474,9 +433,7 @@ HTTPCacheTable::create_hash_directory(int hash)
     @param entry The cache entry object to operate on.
     @exception Error If the file for the response's body cannot be created. */
 
-void
-HTTPCacheTable::create_location(HTTPCacheTable::CacheEntry *entry)
-{
+void HTTPCacheTable::create_location(HTTPCacheTable::CacheEntry *entry) {
     string hash_dir = create_hash_directory(entry->hash);
 #ifdef WIN32
     hash_dir += "\\dodsXXXXXX";
@@ -501,7 +458,8 @@ HTTPCacheTable::create_location(HTTPCacheTable::CacheEntry *entry)
     if (fd < 0) {
         // delete[] templat; templat = 0;
         // close(fd); Calling close() when fd is < 0 is a bad idea! jhrg 7/2/15
-        throw Error(internal_error, "The HTTP Cache could not create a file to hold the response; it will not be cached.");
+        throw Error(internal_error,
+                    "The HTTP Cache could not create a file to hold the response; it will not be cached.");
     }
 
     entry->cachename = templat.data();
@@ -509,15 +467,11 @@ HTTPCacheTable::create_location(HTTPCacheTable::CacheEntry *entry)
     close(fd);
 }
 
-
 /** compute real disk space for an entry. */
-static inline int
-entry_disk_space(int size, unsigned int block_size)
-{
+static inline int entry_disk_space(int size, unsigned int block_size) {
     unsigned int num_of_blocks = (size + block_size) / block_size;
-    
-    DBG(cerr << "size: " << size << ", block_size: " << block_size
-        << ", num_of_blocks: " << num_of_blocks << endl);
+
+    DBG(cerr << "size: " << size << ", block_size: " << block_size << ", num_of_blocks: " << num_of_blocks << endl);
 
     return num_of_blocks * block_size;
 }
@@ -531,34 +485,30 @@ entry_disk_space(int size, unsigned int block_size)
     later is used by the garbage collection method.
 
     @param entry The CacheEntry instance to add. */
-void
-HTTPCacheTable::add_entry_to_cache_table(CacheEntry *entry)
-{
+void HTTPCacheTable::add_entry_to_cache_table(CacheEntry *entry) {
     int hash = entry->hash;
-    if (hash > CACHE_TABLE_SIZE-1 || hash < 0)
+    if (hash > CACHE_TABLE_SIZE - 1 || hash < 0)
         throw InternalErr(__FILE__, __LINE__, "Hash value too large!");
 
     if (!d_cache_table[hash])
         d_cache_table[hash] = new CacheEntries;
 
     d_cache_table[hash]->push_back(entry);
-    
-    DBG(cerr << "add_entry_to_cache_table, current_size: " << d_current_size
-        << ", entry->size: " << entry->size << ", block size: " << d_block_size 
-        << endl);
-    
+
+    DBG(cerr << "add_entry_to_cache_table, current_size: " << d_current_size << ", entry->size: " << entry->size
+             << ", block size: " << d_block_size << endl);
+
     d_current_size += entry_disk_space(entry->size, d_block_size);
 
     DBG(cerr << "add_entry_to_cache_table, current_size: " << d_current_size << endl);
-    
+
     increment_new_entries();
 }
 
 /** Get a pointer to a CacheEntry from the cache table.
 
     @param url Look for this URL. */
-HTTPCacheTable::CacheEntry *
-HTTPCacheTable::get_locked_entry_from_cache_table(const string &url) /*const*/
+HTTPCacheTable::CacheEntry *HTTPCacheTable::get_locked_entry_from_cache_table(const string &url) /*const*/
 {
     return get_locked_entry_from_cache_table(get_hash(url), url);
 }
@@ -570,21 +520,20 @@ HTTPCacheTable::get_locked_entry_from_cache_table(const string &url) /*const*/
     @param hash The hash code for \c url.
     @param url Look for this URL.
     @return The matching CacheEntry instance or NULL if none was found. */
-HTTPCacheTable::CacheEntry *
-HTTPCacheTable::get_locked_entry_from_cache_table(int hash, const string &url) /*const*/
+HTTPCacheTable::CacheEntry *HTTPCacheTable::get_locked_entry_from_cache_table(int hash, const string &url) /*const*/
 {
     DBG(cerr << "url: " << url << "; hash: " << hash << endl);
     DBG(cerr << "d_cache_table: " << hex << d_cache_table << dec << endl);
     if (d_cache_table[hash]) {
-	CacheEntries *cp = d_cache_table[hash];
-	for (CacheEntriesIter i = cp->begin(); i != cp->end(); ++i) {
-	    // Must test *i because perform_garbage_collection may have
-	    // removed this entry; the CacheEntry will then be null.
-	    if ((*i) && (*i)->url == url) {
-		(*i)->lock_read_response(); // Lock the response
-		return *i;
-	    }
-	}
+        CacheEntries *cp = d_cache_table[hash];
+        for (CacheEntriesIter i = cp->begin(); i != cp->end(); ++i) {
+            // Must test *i because perform_garbage_collection may have
+            // removed this entry; the CacheEntry will then be null.
+            if ((*i) && (*i)->url == url) {
+                (*i)->lock_read_response(); // Lock the response
+                return *i;
+            }
+        }
     }
 
     return 0;
@@ -596,18 +545,16 @@ HTTPCacheTable::get_locked_entry_from_cache_table(int hash, const string &url) /
 
     @param url Look for this URL.
     @return The matching CacheEntry instance or NULL if none was found. */
-HTTPCacheTable::CacheEntry *
-HTTPCacheTable::get_write_locked_entry_from_cache_table(const string &url)
-{
-	int hash = get_hash(url);
+HTTPCacheTable::CacheEntry *HTTPCacheTable::get_write_locked_entry_from_cache_table(const string &url) {
+    int hash = get_hash(url);
     if (d_cache_table[hash]) {
         CacheEntries *cp = d_cache_table[hash];
         for (CacheEntriesIter i = cp->begin(); i != cp->end(); ++i) {
             // Must test *i because perform_garbage_collection may have
             // removed this entry; the CacheEntry will then be null.
             if ((*i) && (*i)->url == url) {
-            	(*i)->lock_write_response();	// Lock the response
-            	return *i;
+                (*i)->lock_write_response(); // Lock the response
+                return *i;
             }
         }
     }
@@ -622,9 +569,7 @@ HTTPCacheTable::get_write_locked_entry_from_cache_table(const string &url)
 
     @param entry The CacheEntry to delete.
     @exception InternalErr Thrown if \c entry is in use. */
-void
-HTTPCacheTable::remove_cache_entry(HTTPCacheTable::CacheEntry *entry)
-{
+void HTTPCacheTable::remove_cache_entry(HTTPCacheTable::CacheEntry *entry) {
     // This should never happen; all calls to this method are protected by
     // the caller, hence the InternalErr.
     if (entry->readers)
@@ -637,29 +582,26 @@ HTTPCacheTable::remove_cache_entry(HTTPCacheTable::CacheEntry *entry)
 
     unsigned int eds = entry_disk_space(entry->size, get_block_size());
     set_current_size((eds > get_current_size()) ? 0 : get_current_size() - eds);
-    
+
     DBG(cerr << "remove_cache_entry, current_size: " << get_current_size() << endl);
 }
 
 /** Functor which deletes and nulls a CacheEntry if the given entry matches
     the url. */
-class DeleteCacheEntry: public unary_function<HTTPCacheTable::CacheEntry *&, void>
-{
+class DeleteCacheEntry : public unary_function<HTTPCacheTable::CacheEntry *&, void> {
     string d_url;
     HTTPCacheTable *d_cache_table;
 
 public:
-    DeleteCacheEntry(HTTPCacheTable *c, const string &url)
-            : d_url(url), d_cache_table(c)
-    {}
+    DeleteCacheEntry(HTTPCacheTable *c, const string &url) : d_url(url), d_cache_table(c) {}
 
-    void operator()(HTTPCacheTable::CacheEntry *&e)
-    {
+    void operator()(HTTPCacheTable::CacheEntry *&e) {
         if (e && e->url == d_url) {
-        	e->lock_write_response();
+            e->lock_write_response();
             d_cache_table->remove_cache_entry(e);
-        	e->unlock_write_response();
-            delete e; e = 0;
+            e->unlock_write_response();
+            delete e;
+            e = 0;
         }
     }
 };
@@ -670,48 +612,40 @@ public:
 
     @param url Remove this URL's entry.
     @exception InternalErr Thrown if the CacheEntry for \c url is locked. */
-void
-HTTPCacheTable::remove_entry_from_cache_table(const string &url)
-{
+void HTTPCacheTable::remove_entry_from_cache_table(const string &url) {
     int hash = get_hash(url);
     if (d_cache_table[hash]) {
         CacheEntries *cp = d_cache_table[hash];
         for_each(cp->begin(), cp->end(), DeleteCacheEntry(this, url));
-        cp->erase(remove(cp->begin(), cp->end(), static_cast<HTTPCacheTable::CacheEntry*>(0)),
-                  cp->end());
+        cp->erase(remove(cp->begin(), cp->end(), static_cast<HTTPCacheTable::CacheEntry *>(0)), cp->end());
     }
 }
 
 /** Functor to delete and null all unlocked HTTPCacheTable::CacheEntry objects. */
 
-class DeleteUnlockedCacheEntry: public unary_function<HTTPCacheTable::CacheEntry *&, void> {
+class DeleteUnlockedCacheEntry : public unary_function<HTTPCacheTable::CacheEntry *&, void> {
     HTTPCacheTable &d_table;
 
 public:
-    DeleteUnlockedCacheEntry(HTTPCacheTable &t) :
-	d_table(t)
-    {
-    }
-    void operator()(HTTPCacheTable::CacheEntry *&e)
-    {
-	if (e) {
-	    d_table.remove_cache_entry(e);
-	    delete e;
-	    e = 0;
-	}
+    DeleteUnlockedCacheEntry(HTTPCacheTable &t) : d_table(t) {}
+    void operator()(HTTPCacheTable::CacheEntry *&e) {
+        if (e) {
+            d_table.remove_cache_entry(e);
+            delete e;
+            e = 0;
+        }
     }
 };
 
-void HTTPCacheTable::delete_all_entries()
-{
+void HTTPCacheTable::delete_all_entries() {
     // Walk through the cache table and, for every entry in the cache, delete
     // it on disk and in the cache table.
     for (int cnt = 0; cnt < CACHE_TABLE_SIZE; cnt++) {
-	HTTPCacheTable::CacheEntries *slot = get_cache_table()[cnt];
-	if (slot) {
-	    for_each(slot->begin(), slot->end(), DeleteUnlockedCacheEntry(*this));
-	    slot->erase(remove(slot->begin(), slot->end(), static_cast<HTTPCacheTable::CacheEntry *> (0)), slot->end());
-	}
+        HTTPCacheTable::CacheEntries *slot = get_cache_table()[cnt];
+        if (slot) {
+            for_each(slot->begin(), slot->end(), DeleteUnlockedCacheEntry(*this));
+            slot->erase(remove(slot->begin(), slot->end(), static_cast<HTTPCacheTable::CacheEntry *>(0)), slot->end());
+        }
     }
 
     cache_index_delete();
@@ -730,9 +664,7 @@ void HTTPCacheTable::delete_all_entries()
     @param request_time When was the request made? I think this value must be
     passed into the method that calls this method... */
 
-void
-HTTPCacheTable::calculate_time(HTTPCacheTable::CacheEntry *entry, int default_expiration, time_t request_time)
-{
+void HTTPCacheTable::calculate_time(HTTPCacheTable::CacheEntry *entry, int default_expiration, time_t request_time) {
     entry->response_time = time(NULL);
     time_t apparent_age = max(0, static_cast<int>(entry->response_time - entry->date));
     time_t corrected_received_age = max(apparent_age, entry->age);
@@ -747,20 +679,17 @@ HTTPCacheTable::calculate_time(HTTPCacheTable::CacheEntry *entry, int default_ex
         if (entry->expires < 0) {
             if (entry->lm < 0) {
                 freshness_lifetime = default_expiration;
-            }
-            else {
+            } else {
                 freshness_lifetime = LM_EXPIRATION(entry->date - entry->lm);
             }
-        }
-        else
+        } else
             freshness_lifetime = entry->expires - entry->date;
     }
 
     entry->freshness_lifetime = max(0, static_cast<int>(freshness_lifetime));
 
-    DBG2(cerr << "Cache....... Received Age " << entry->age
-         << ", corrected " << entry->corrected_initial_age
-         << ", freshness lifetime " << entry->freshness_lifetime << endl);
+    DBG2(cerr << "Cache....... Received Age " << entry->age << ", corrected " << entry->corrected_initial_age
+              << ", freshness lifetime " << entry->freshness_lifetime << endl);
 }
 
 /** Parse various headers from the vector (which can be retrieved from
@@ -775,60 +704,54 @@ HTTPCacheTable::calculate_time(HTTPCacheTable::CacheEntry *entry, int default_ex
     @param headers A vector of header lines. */
 
 void HTTPCacheTable::parse_headers(HTTPCacheTable::CacheEntry *entry, unsigned long max_entry_size,
-	const vector<string> &headers)
-{
+                                   const vector<string> &headers) {
     vector<string>::const_iterator i;
     for (i = headers.begin(); i != headers.end(); ++i) {
-	// skip a blank header.
-	if ((*i).empty())
-	    continue;
+        // skip a blank header.
+        if ((*i).empty())
+            continue;
 
-	string::size_type colon = (*i).find(':');
+        string::size_type colon = (*i).find(':');
 
-	// skip a header with no colon in it.
-	if (colon == string::npos)
-	    continue;
+        // skip a header with no colon in it.
+        if (colon == string::npos)
+            continue;
 
-	string header = (*i).substr(0, (*i).find(':'));
-	string value = (*i).substr((*i).find(": ") + 2);
-	DBG2(cerr << "Header: " << header << endl);DBG2(cerr << "Value: " << value << endl);
+        string header = (*i).substr(0, (*i).find(':'));
+        string value = (*i).substr((*i).find(": ") + 2);
+        DBG2(cerr << "Header: " << header << endl);
+        DBG2(cerr << "Value: " << value << endl);
 
-	if (header == "ETag") {
-	    entry->etag = value;
-	}
-	else if (header == "Last-Modified") {
-	    entry->lm = parse_time(value.c_str());
-	}
-	else if (header == "Expires") {
-	    entry->expires = parse_time(value.c_str());
-	}
-	else if (header == "Date") {
-	    entry->date = parse_time(value.c_str());
-	}
-	else if (header == "Age") {
-	    entry->age = parse_time(value.c_str());
-	}
-	else if (header == "Content-Length") {
-	    unsigned long clength = strtoul(value.c_str(), 0, 0);
-	    if (clength > max_entry_size)
-		entry->set_no_cache(true);
-	}
-	else if (header == "Cache-Control") {
-	    // Ignored Cache-Control values: public, private, no-transform,
-	    // proxy-revalidate, s-max-age. These are used by shared caches.
-	    // See section 14.9 of RFC 2612. 10/02/02 jhrg
-	    if (value == "no-cache" || value == "no-store")
-		// Note that we *can* store a 'no-store' response in volatile
-		// memory according to RFC 2616 (section 14.9.2) but those
-		// will be rare coming from DAP servers. 10/02/02 jhrg
-		entry->set_no_cache(true);
-	    else if (value == "must-revalidate")
-		entry->must_revalidate = true;
-	    else if (value.find("max-age") != string::npos) {
-		string max_age = value.substr(value.find("=") + 1);
-		entry->max_age = parse_time(max_age.c_str());
-	    }
-	}
+        if (header == "ETag") {
+            entry->etag = value;
+        } else if (header == "Last-Modified") {
+            entry->lm = parse_time(value.c_str());
+        } else if (header == "Expires") {
+            entry->expires = parse_time(value.c_str());
+        } else if (header == "Date") {
+            entry->date = parse_time(value.c_str());
+        } else if (header == "Age") {
+            entry->age = parse_time(value.c_str());
+        } else if (header == "Content-Length") {
+            unsigned long clength = strtoul(value.c_str(), 0, 0);
+            if (clength > max_entry_size)
+                entry->set_no_cache(true);
+        } else if (header == "Cache-Control") {
+            // Ignored Cache-Control values: public, private, no-transform,
+            // proxy-revalidate, s-max-age. These are used by shared caches.
+            // See section 14.9 of RFC 2612. 10/02/02 jhrg
+            if (value == "no-cache" || value == "no-store")
+                // Note that we *can* store a 'no-store' response in volatile
+                // memory according to RFC 2616 (section 14.9.2) but those
+                // will be rare coming from DAP servers. 10/02/02 jhrg
+                entry->set_no_cache(true);
+            else if (value == "must-revalidate")
+                entry->must_revalidate = true;
+            else if (value.find("max-age") != string::npos) {
+                string max_age = value.substr(value.find("=") + 1);
+                entry->max_age = parse_time(max_age.c_str());
+            }
+        }
     }
 }
 
@@ -836,7 +759,7 @@ void HTTPCacheTable::parse_headers(HTTPCacheTable::CacheEntry *entry, unsigned l
 
 // @TODO Change name to record locked response
 void HTTPCacheTable::bind_entry_to_data(HTTPCacheTable::CacheEntry *entry, FILE *body) {
-	entry->hits++;  // Mark hit
+    entry->hits++;                  // Mark hit
     d_locked_entries[body] = entry; // record lock, see release_cached_r...
 }
 
@@ -853,8 +776,6 @@ void HTTPCacheTable::uncouple_entry_from_data(FILE *body) {
         throw InternalErr("An unlocked entry was released");
 }
 
-bool HTTPCacheTable::is_locked_read_responses() {
-	return !d_locked_entries.empty();
-}
+bool HTTPCacheTable::is_locked_read_responses() { return !d_locked_entries.empty(); }
 
 } // namespace libdap
