@@ -30,18 +30,17 @@
 
 #include <cstdio>
 
-#include <string>
-#include <iostream>
 #include <algorithm>
+#include <iostream>
 #include <iterator>
+#include <string>
 #include <vector>
 
 #include "Response.h"
-#include "util.h"
 #include "debug.h"
+#include "util.h"
 
-namespace libdap
-{
+namespace libdap {
 
 // defined in HTTPConnect.cc
 extern int dods_keep_temps;
@@ -53,11 +52,10 @@ extern void close_temp(FILE *s, const string &name);
 
     @todo Maybe refactor so that the header parsing code is here and not in
     HTTPConnect? */
-class HTTPResponse : public Response
-{
+class HTTPResponse : public Response {
 private:
     std::vector<std::string> *d_headers; // Response headers
-    std::string d_file;  // Temp file that holds response body
+    std::string d_file;                  // Temp file that holds response body
 
 protected:
     /** @name Suppressed default methods */
@@ -85,11 +83,9 @@ public:
     @param temp_file Name a the temporary file that holds the response
     body; this file is deleted when this instance is deleted. */
     HTTPResponse(FILE *s, int status, std::vector<std::string> *h, const std::string &temp_file)
-            : Response(s, status), d_headers(h), d_file(temp_file)
-    {
+        : Response(s, status), d_headers(h), d_file(temp_file) {
         DBG(cerr << "Headers: " << endl);
-        DBGN(copy(d_headers->begin(), d_headers->end(),
-                  ostream_iterator<string>(cerr, "\n")));
+        DBGN(copy(d_headers->begin(), d_headers->end(), ostream_iterator<string>(cerr, "\n")));
         DBGN(cerr << "end of headers." << endl);
     }
 
@@ -103,39 +99,35 @@ public:
      * @param temp_file
      */
     HTTPResponse(std::fstream *s, int status, std::vector<std::string> *h, const std::string &temp_file)
-            : Response(s, status), d_headers(h), d_file(temp_file)
-    {
+        : Response(s, status), d_headers(h), d_file(temp_file) {
         DBG(cerr << "Headers: " << endl);
-        DBGN(copy(d_headers->begin(), d_headers->end(),
-                  ostream_iterator<string>(cerr, "\n")));
+        DBGN(copy(d_headers->begin(), d_headers->end(), ostream_iterator<string>(cerr, "\n")));
         DBGN(cerr << "end of headers." << endl);
     }
 
     /** When an instance is destroyed, free the temporary resources: the
     temp_file and headers are deleted. If the tmp file name is "", it is
     not deleted. */
-    virtual ~HTTPResponse()
-    {
+    virtual ~HTTPResponse() {
         DBG(cerr << "Freeing HTTPConnect resources (" + d_file + ")... ");
 
         // This can always be done - if the cpp_stream is null, delete has no effect;
         // if non-null in this class it was allocated in HTTPConnect::plain_fetch_url
         // (or caching_fetch_url when that's implemented)
-		delete get_cpp_stream();
-		set_cpp_stream(0);
+        delete get_cpp_stream();
+        set_cpp_stream(0);
 
         if (!dods_keep_temps && !d_file.empty()) {
-			if (get_stream()) {
-				close_temp(get_stream(), d_file);
-				set_stream(0);
-			}
-			else {
-			    (void) unlink(d_file.c_str());
+            if (get_stream()) {
+                close_temp(get_stream(), d_file);
+                set_stream(0);
+            } else {
+                (void)unlink(d_file.c_str());
 #if 0
 				long res = unlink(d_file.c_str());
 				if (res != 0) throw InternalErr(__FILE__, __LINE__, "!FAIL! " + long_to_string(res));
 #endif
-			}
+            }
         }
 
         delete d_headers;
@@ -149,11 +141,11 @@ public:
      * @return
      */
     void transform_to_cpp() {
-    	// ~Response() will take care of closing the FILE*. A better version of this
-    	// code would not leave the FILE* open when it's not needed, but this implementation
-    	// can use the existing HTTPConnect and HTTPCache software with very minimal
-    	// (or no) modification. jhrg 11/8/13
-    	set_cpp_stream(new std::fstream(d_file.c_str(), std::ios::in|std::ios::binary));
+        // ~Response() will take care of closing the FILE*. A better version of this
+        // code would not leave the FILE* open when it's not needed, but this implementation
+        // can use the existing HTTPConnect and HTTPCache software with very minimal
+        // (or no) modification. jhrg 11/8/13
+        set_cpp_stream(new std::fstream(d_file.c_str(), std::ios::in | std::ios::binary));
     }
 
     /** @name Accessors */
