@@ -33,41 +33,40 @@
 //
 // jhrg 9/7/94
 
-
 #include "config.h"
 
-//#define DODS_DEBUG
+// #define DODS_DEBUG
 
 #include <sstream>
 
-#include "Byte.h"           // synonymous with UInt8 and Char
-#include "Int8.h"
-#include "Int16.h"
-#include "UInt16.h"
-#include "Int32.h"
-#include "UInt32.h"
-#include "Int64.h"
-#include "UInt64.h"
+#include "Byte.h" // synonymous with UInt8 and Char
 #include "Float32.h"
 #include "Float64.h"
+#include "Int16.h"
+#include "Int32.h"
+#include "Int64.h"
+#include "Int8.h"
 #include "Str.h"
+#include "UInt16.h"
+#include "UInt32.h"
+#include "UInt64.h"
 #include "Url.h"
 
 #include "DDS.h"
 #include "Marshaller.h"
 #include "UnMarshaller.h"
 
-#include "DMR.h"
 #include "D4StreamMarshaller.h"
 #include "D4StreamUnMarshaller.h"
+#include "DMR.h"
 
-#include "util.h"
-#include "parser.h"
-#include "Operators.h"
-#include "dods-limits.h"
-#include "debug.h"
-#include "InternalErr.h"
 #include "DapIndent.h"
+#include "InternalErr.h"
+#include "Operators.h"
+#include "debug.h"
+#include "dods-limits.h"
+#include "parser.h"
+#include "util.h"
 
 using std::cerr;
 using std::endl;
@@ -81,8 +80,7 @@ namespace libdap {
     @param n A string containing the name of the variable to be
     created.
 */
-Int32::Int32(const string &n) : BaseType(n, dods_int32_c), d_buf(0)
-{}
+Int32::Int32(const string &n) : BaseType(n, dods_int32_c), d_buf(0) {}
 
 /** The Int32 server-side constructor accepts the name of the variable and
     the dataset name from which this instance is created.
@@ -91,28 +89,15 @@ Int32::Int32(const string &n) : BaseType(n, dods_int32_c), d_buf(0)
     @param d A string containing the name of the dataset from which this
     variable is created
 */
-Int32::Int32(const string &n, const string &d) : BaseType(n, d, dods_int32_c), d_buf(0)
-{}
+Int32::Int32(const string &n, const string &d) : BaseType(n, d, dods_int32_c), d_buf(0) {}
 
-Int32::Int32(const Int32 &copy_from) : BaseType(copy_from)
-{
-    d_buf = copy_from.d_buf;
-}
+Int32::Int32(const Int32 &copy_from) : BaseType(copy_from) { d_buf = copy_from.d_buf; }
 
-BaseType *
-Int32::ptr_duplicate()
-{
-    return new Int32(*this);
-}
+BaseType *Int32::ptr_duplicate() { return new Int32(*this); }
 
-Int32::~Int32()
-{
-    DBG(cerr << "~Int32" << endl);
-}
+Int32::~Int32() { DBG(cerr << "~Int32" << endl); }
 
-Int32 &
-Int32::operator=(const Int32 &rhs)
-{
+Int32 &Int32::operator=(const Int32 &rhs) {
     if (this == &rhs)
         return *this;
     BaseType::operator=(rhs);
@@ -120,39 +105,30 @@ Int32::operator=(const Int32 &rhs)
     return *this;
 }
 
-bool
-Int32::serialize(ConstraintEvaluator &eval, DDS &dds,
-                 Marshaller &m, bool ce_eval)
-{
+bool Int32::serialize(ConstraintEvaluator &eval, DDS &dds, Marshaller &m, bool ce_eval) {
 #if USE_LOCAL_TIMEOUT_SCHEME
     dds.timeout_on();
 #endif
     if (!read_p())
-        read();  // read() throws Error and InternalErr
+        read(); // read() throws Error and InternalErr
 
     if (ce_eval && !eval.eval_selection(dds, dataset()))
         return true;
 #if USE_LOCAL_TIMEOUT_SCHEME
     dds.timeout_off();
 #endif
-    m.put_int32( d_buf ) ;
+    m.put_int32(d_buf);
 
     return true;
 }
 
-bool
-Int32::deserialize(UnMarshaller &um, DDS *, bool)
-{
-    um.get_int32( d_buf ) ;
+bool Int32::deserialize(UnMarshaller &um, DDS *, bool) {
+    um.get_int32(d_buf);
 
     return false;
 }
 
-void
-Int32::compute_checksum(Crc32 &checksum)
-{
-	checksum.AddData(reinterpret_cast<uint8_t*>(&d_buf), sizeof(d_buf));
-}
+void Int32::compute_checksum(Crc32 &checksum) { checksum.AddData(reinterpret_cast<uint8_t *>(&d_buf), sizeof(d_buf)); }
 
 /**
  * @brief Serialize an Int8
@@ -162,40 +138,29 @@ Int32::compute_checksum(Crc32 &checksum)
  * @param filter Unused
  * @exception Error is thrown if the value needs to be read and that operation fails.
  */
-void
-Int32::serialize(D4StreamMarshaller &m, DMR &, /*ConstraintEvaluator &,*/ bool)
-{
+void Int32::serialize(D4StreamMarshaller &m, DMR &, /*ConstraintEvaluator &,*/ bool) {
     if (!read_p())
-        read();          // read() throws Error
+        read(); // read() throws Error
 
-    m.put_int32( d_buf ) ;
+    m.put_int32(d_buf);
 }
 
-void
-Int32::deserialize(D4StreamUnMarshaller &um, DMR &)
-{
-    um.get_int32( d_buf ) ;
-}
+void Int32::deserialize(D4StreamUnMarshaller &um, DMR &) { um.get_int32(d_buf); }
 
-unsigned int
-Int32::val2buf(void *val, bool)
-{
+unsigned int Int32::val2buf(void *val, bool) {
     // Jose Garcia
     // This method is public therefore and I believe it has being designed
     // to be use by read which must be implemented on the surrogated library,
     // thus if the pointer val is NULL, is an Internal Error.
     if (!val)
-        throw InternalErr(__FILE__, __LINE__,
-                          "The incoming pointer does not contain any data.");
+        throw InternalErr(__FILE__, __LINE__, "The incoming pointer does not contain any data.");
 
     d_buf = *(dods_int32 *)val;
 
     return width();
 }
 
-unsigned int
-Int32::buf2val(void **val)
-{
+unsigned int Int32::buf2val(void **val) {
     // Jose Garcia
     // The same comment justifying throwing an Error in val2buf applies here.
     if (!val)
@@ -209,42 +174,30 @@ Int32::buf2val(void **val)
     return width();
 }
 
-dods_int32
-Int32::value() const
-{
-    return d_buf;
-}
+dods_int32 Int32::value() const { return d_buf; }
 
-bool
-Int32::set_value(dods_int32 i)
-{
+bool Int32::set_value(dods_int32 i) {
     d_buf = i;
     set_read_p(true);
 
     return true;
 }
 
-void
-Int32::print_val(FILE *out, string space, bool print_decl_p)
-{
+void Int32::print_val(FILE *out, string space, bool print_decl_p) {
     ostringstream oss;
     print_val(oss, space, print_decl_p);
     fwrite(oss.str().data(), sizeof(char), oss.str().length(), out);
 }
 
-void Int32::print_val(ostream &out, string space, bool print_decl_p)
-{
+void Int32::print_val(ostream &out, string space, bool print_decl_p) {
     if (print_decl_p) {
         print_decl(out, space, false);
-        out << " = " << (int) d_buf << ";\n";
-    }
-    else
-        out << (int) d_buf;
+        out << " = " << (int)d_buf << ";\n";
+    } else
+        out << (int)d_buf;
 }
 
-bool
-Int32::ops(BaseType *b, int op)
-{
+bool Int32::ops(BaseType *b, int op) {
     if (!read_p() && !read()) {
         // Jose Garcia
         // Since the read method is virtual and implemented outside
@@ -270,35 +223,34 @@ Int32::ops(BaseType *b, int op)
 /**
  * @see BaseType::d4_ops(BaseType *, int)
  */
-bool Int32::d4_ops(BaseType *b, int op)
-{
-	DBG(cerr << "b->typename(): " << b->type_name() << endl);
+bool Int32::d4_ops(BaseType *b, int op) {
+    DBG(cerr << "b->typename(): " << b->type_name() << endl);
     switch (b->type()) {
-        case dods_int8_c:
-            return Cmp<dods_int32, dods_int8>(op, d_buf, static_cast<Int8*>(b)->value());
-        case dods_byte_c:
-            return Cmp<dods_int32, dods_byte>(op, d_buf, static_cast<Byte*>(b)->value());
-        case dods_int16_c:
-            return Cmp<dods_int32, dods_int16>(op, d_buf, static_cast<Int16*>(b)->value());
-        case dods_uint16_c:
-            return Cmp<dods_int32, dods_uint16>(op, d_buf, static_cast<UInt16*>(b)->value());
-        case dods_int32_c:
-            return Cmp<dods_int32, dods_int32>(op, d_buf, static_cast<Int32*>(b)->value());
-        case dods_uint32_c:
-            return Cmp<dods_int32, dods_uint32>(op, d_buf, static_cast<UInt32*>(b)->value());
-        case dods_int64_c:
-            return Cmp<dods_int32, dods_int64>(op, d_buf, static_cast<Int64*>(b)->value());
-        case dods_uint64_c:
-            return Cmp<dods_int32, dods_uint64>(op, d_buf, static_cast<UInt64*>(b)->value());
-        case dods_float32_c:
-            return Cmp<dods_int32, dods_float32>(op, d_buf, static_cast<Float32*>(b)->value());
-        case dods_float64_c:
-            return Cmp<dods_int32, dods_float64>(op, d_buf, static_cast<Float64*>(b)->value());
-        case dods_str_c:
-        case dods_url_c:
-            throw Error(malformed_expr, "Relational operators can only compare compatible types (number, string).");
-        default:
-            throw Error(malformed_expr, "Relational operators only work with scalar types.");
+    case dods_int8_c:
+        return Cmp<dods_int32, dods_int8>(op, d_buf, static_cast<Int8 *>(b)->value());
+    case dods_byte_c:
+        return Cmp<dods_int32, dods_byte>(op, d_buf, static_cast<Byte *>(b)->value());
+    case dods_int16_c:
+        return Cmp<dods_int32, dods_int16>(op, d_buf, static_cast<Int16 *>(b)->value());
+    case dods_uint16_c:
+        return Cmp<dods_int32, dods_uint16>(op, d_buf, static_cast<UInt16 *>(b)->value());
+    case dods_int32_c:
+        return Cmp<dods_int32, dods_int32>(op, d_buf, static_cast<Int32 *>(b)->value());
+    case dods_uint32_c:
+        return Cmp<dods_int32, dods_uint32>(op, d_buf, static_cast<UInt32 *>(b)->value());
+    case dods_int64_c:
+        return Cmp<dods_int32, dods_int64>(op, d_buf, static_cast<Int64 *>(b)->value());
+    case dods_uint64_c:
+        return Cmp<dods_int32, dods_uint64>(op, d_buf, static_cast<UInt64 *>(b)->value());
+    case dods_float32_c:
+        return Cmp<dods_int32, dods_float32>(op, d_buf, static_cast<Float32 *>(b)->value());
+    case dods_float64_c:
+        return Cmp<dods_int32, dods_float64>(op, d_buf, static_cast<Float64 *>(b)->value());
+    case dods_str_c:
+    case dods_url_c:
+        throw Error(malformed_expr, "Relational operators can only compare compatible types (number, string).");
+    default:
+        throw Error(malformed_expr, "Relational operators only work with scalar types.");
     }
 }
 
@@ -310,16 +262,12 @@ bool Int32::d4_ops(BaseType *b, int op)
  * @param strm C++ i/o stream to dump the information to
  * @return void
  */
-void
-Int32::dump(ostream &strm) const
-{
-    strm << DapIndent::LMarg << "Int32::dump - ("
-    << (void *)this << ")" << endl ;
-    DapIndent::Indent() ;
-    BaseType::dump(strm) ;
-    strm << DapIndent::LMarg << "value: " << d_buf << endl ;
-    DapIndent::UnIndent() ;
+void Int32::dump(ostream &strm) const {
+    strm << DapIndent::LMarg << "Int32::dump - (" << (void *)this << ")" << endl;
+    DapIndent::Indent();
+    BaseType::dump(strm);
+    strm << DapIndent::LMarg << "value: " << d_buf << endl;
+    DapIndent::UnIndent();
 }
 
 } // namespace libdap
-
