@@ -33,43 +33,42 @@
 //
 // jhrg 9/7/94
 
-
 #include "config.h"
 
 #include <cassert>
 #include <sstream>
 
-#include "Byte.h"           // synonymous with UInt8 and Char
-#include "Int8.h"
-#include "Int16.h"
-#include "UInt16.h"
-#include "Int32.h"
-#include "UInt32.h"
-#include "Int64.h"
-#include "UInt64.h"
+#include "Byte.h" // synonymous with UInt8 and Char
 #include "Float32.h"
 #include "Float64.h"
+#include "Int16.h"
+#include "Int32.h"
+#include "Int64.h"
+#include "Int8.h"
 #include "Str.h"
+#include "UInt16.h"
+#include "UInt32.h"
+#include "UInt64.h"
 #include "Url.h"
 
 #if 0
 #include "Array.h"
-#include "Structure.h"
-#include "Sequence.h"
 #include "Grid.h"
+#include "Sequence.h"
+#include "Structure.h"
 #endif
 
-#include "DMR.h"
 #include "D4StreamMarshaller.h"
 #include "D4StreamUnMarshaller.h"
+#include "DMR.h"
 
-#include "util.h"
-#include "parser.h"
-#include "Operators.h"
-#include "dods-limits.h"
-#include "debug.h"
-#include "InternalErr.h"
 #include "DapIndent.h"
+#include "InternalErr.h"
+#include "Operators.h"
+#include "debug.h"
+#include "dods-limits.h"
+#include "parser.h"
+#include "util.h"
 
 using std::cerr;
 using std::endl;
@@ -86,8 +85,7 @@ namespace libdap {
     @param n A string containing the name of the variable to be
     created.
 */
-Int64::Int64(const string &n) : BaseType(n, dods_int64_c, true /*is_dap4*/), d_buf(0)
-{}
+Int64::Int64(const string &n) : BaseType(n, dods_int64_c, true /*is_dap4*/), d_buf(0) {}
 
 /** The Int64 server-side constructor accepts the name of the variable and
     the dataset name from which this instance is created.
@@ -99,28 +97,15 @@ Int64::Int64(const string &n) : BaseType(n, dods_int64_c, true /*is_dap4*/), d_b
     @param d A string containing the name of the dataset from which this
     variable is created
 */
-Int64::Int64(const string &n, const string &d) : BaseType(n, d, dods_int64_c, true /*is_dap4*/), d_buf(0)
-{}
+Int64::Int64(const string &n, const string &d) : BaseType(n, d, dods_int64_c, true /*is_dap4*/), d_buf(0) {}
 
-Int64::Int64(const Int64 &copy_from) : BaseType(copy_from)
-{
-    d_buf = copy_from.d_buf;
-}
+Int64::Int64(const Int64 &copy_from) : BaseType(copy_from) { d_buf = copy_from.d_buf; }
 
-BaseType *
-Int64::ptr_duplicate()
-{
-    return new Int64(*this);
-}
+BaseType *Int64::ptr_duplicate() { return new Int64(*this); }
 
-Int64::~Int64()
-{
-    DBG(cerr << "~Int64" << endl);
-}
+Int64::~Int64() { DBG(cerr << "~Int64" << endl); }
 
-Int64 &
-Int64::operator=(const Int64 &rhs)
-{
+Int64 &Int64::operator=(const Int64 &rhs) {
     if (this == &rhs)
         return *this;
     BaseType::operator=(rhs);
@@ -128,11 +113,7 @@ Int64::operator=(const Int64 &rhs)
     return *this;
 }
 
-void
-Int64::compute_checksum(Crc32 &checksum)
-{
-	checksum.AddData(reinterpret_cast<uint8_t*>(&d_buf), sizeof(d_buf));
-}
+void Int64::compute_checksum(Crc32 &checksum) { checksum.AddData(reinterpret_cast<uint8_t *>(&d_buf), sizeof(d_buf)); }
 
 /**
  * @brief Serialize an Int8
@@ -142,39 +123,25 @@ Int64::compute_checksum(Crc32 &checksum)
  * @param filter Unused
  * @exception Error is thrown if the value needs to be read and that operation fails.
  */
-void
-Int64::serialize(D4StreamMarshaller &m, DMR &, /*ConstraintEvaluator &,*/ bool)
-{
+void Int64::serialize(D4StreamMarshaller &m, DMR &, /*ConstraintEvaluator &,*/ bool) {
     if (!read_p())
-        read();          // read() throws Error
+        read(); // read() throws Error
 
-    m.put_int64( d_buf ) ;
+    m.put_int64(d_buf);
 }
 
-void
-Int64::deserialize(D4StreamUnMarshaller &um, DMR &)
-{
-    um.get_int64( d_buf ) ;
-}
+void Int64::deserialize(D4StreamUnMarshaller &um, DMR &) { um.get_int64(d_buf); }
 
-dods_int64
-Int64::value() const
-{
-    return d_buf;
-}
+dods_int64 Int64::value() const { return d_buf; }
 
-bool
-Int64::set_value(dods_int64 i)
-{
+bool Int64::set_value(dods_int64 i) {
     d_buf = i;
     set_read_p(true);
 
     return true;
 }
 
-unsigned int
-Int64::buf2val(void **val)
-{
+unsigned int Int64::buf2val(void **val) {
     if (!val)
         throw InternalErr(__FILE__, __LINE__, "NULL pointer.");
 
@@ -185,25 +152,21 @@ Int64::buf2val(void **val)
 
     return width();
 }
-void Int64::print_val(ostream &out, string space, bool print_decl_p)
-{
+void Int64::print_val(ostream &out, string space, bool print_decl_p) {
     if (print_decl_p) {
         print_decl(out, space, false);
         out << " = " << d_buf << ";\n";
-    }
-    else
+    } else
         out << d_buf;
 }
 
-bool
-Int64::ops(BaseType *b, int op)
-{
+bool Int64::ops(BaseType *b, int op) {
     // Get the arg's value.
     if (!read_p() && !read())
         throw InternalErr(__FILE__, __LINE__, "This value not read!");
 
     // Get the second arg's value.
-    if (!b || !(b->read_p() || b->read())) 
+    if (!b || !(b->read_p() || b->read()))
         throw InternalErr(__FILE__, __LINE__, "This value not read!");
 
     return d4_ops(b, op);
@@ -212,34 +175,33 @@ Int64::ops(BaseType *b, int op)
 /**
  * @see BaseType::d4_ops(BaseType *, int)
  */
-bool Int64::d4_ops(BaseType *b, int op)
-{
+bool Int64::d4_ops(BaseType *b, int op) {
     switch (b->type()) {
-        case dods_int8_c:
-            return Cmp<dods_int64, dods_int8>(op, d_buf, static_cast<Int8*>(b)->value());
-        case dods_byte_c:
-            return Cmp<dods_int64, dods_byte>(op, d_buf, static_cast<Byte*>(b)->value());
-        case dods_int16_c:
-            return Cmp<dods_int64, dods_int16>(op, d_buf, static_cast<Int16*>(b)->value());
-        case dods_uint16_c:
-            return Cmp<dods_int64, dods_uint16>(op, d_buf, static_cast<UInt16*>(b)->value());
-        case dods_int32_c:
-            return Cmp<dods_int64, dods_int32>(op, d_buf, static_cast<Int32*>(b)->value());
-        case dods_uint32_c:
-            return Cmp<dods_int64, dods_uint32>(op, d_buf, static_cast<UInt32*>(b)->value());
-        case dods_int64_c:
-            return Cmp<dods_int64, dods_int64>(op, d_buf, static_cast<Int64*>(b)->value());
-        case dods_uint64_c:
-            return Cmp<dods_int64, dods_uint64>(op, d_buf, static_cast<UInt64*>(b)->value());
-        case dods_float32_c:
-            return Cmp<dods_int64, dods_float32>(op, d_buf, static_cast<Float32*>(b)->value());
-        case dods_float64_c:
-            return Cmp<dods_int64, dods_float64>(op, d_buf, static_cast<Float64*>(b)->value());
-        case dods_str_c:
-        case dods_url_c:
-            throw Error(malformed_expr, "Relational operators can only compare compatible types (number, string).");
-        default:
-            throw Error(malformed_expr, "Relational operators only work with scalar types.");
+    case dods_int8_c:
+        return Cmp<dods_int64, dods_int8>(op, d_buf, static_cast<Int8 *>(b)->value());
+    case dods_byte_c:
+        return Cmp<dods_int64, dods_byte>(op, d_buf, static_cast<Byte *>(b)->value());
+    case dods_int16_c:
+        return Cmp<dods_int64, dods_int16>(op, d_buf, static_cast<Int16 *>(b)->value());
+    case dods_uint16_c:
+        return Cmp<dods_int64, dods_uint16>(op, d_buf, static_cast<UInt16 *>(b)->value());
+    case dods_int32_c:
+        return Cmp<dods_int64, dods_int32>(op, d_buf, static_cast<Int32 *>(b)->value());
+    case dods_uint32_c:
+        return Cmp<dods_int64, dods_uint32>(op, d_buf, static_cast<UInt32 *>(b)->value());
+    case dods_int64_c:
+        return Cmp<dods_int64, dods_int64>(op, d_buf, static_cast<Int64 *>(b)->value());
+    case dods_uint64_c:
+        return Cmp<dods_int64, dods_uint64>(op, d_buf, static_cast<UInt64 *>(b)->value());
+    case dods_float32_c:
+        return Cmp<dods_int64, dods_float32>(op, d_buf, static_cast<Float32 *>(b)->value());
+    case dods_float64_c:
+        return Cmp<dods_int64, dods_float64>(op, d_buf, static_cast<Float64 *>(b)->value());
+    case dods_str_c:
+    case dods_url_c:
+        throw Error(malformed_expr, "Relational operators can only compare compatible types (number, string).");
+    default:
+        throw Error(malformed_expr, "Relational operators only work with scalar types.");
     }
 }
 
@@ -249,9 +211,7 @@ bool Int64::d4_ops(BaseType *b, int op)
  *
  * @return A pointer to the transformed variable
  */
-vector<BaseType *> *
-Int64::transform_to_dap2(AttrTable *)
-{
+vector<BaseType *> *Int64::transform_to_dap2(AttrTable *) {
 #if 0
     BaseType *dest = this->ptr_duplicate();
     // convert the d4 attributes to a dap2 attribute table.
@@ -271,10 +231,9 @@ Int64::transform_to_dap2(AttrTable *)
  * @param inventory is a value-result parameter
  * @return True when send_p() is true, false otherwise
  */
-bool Int64::is_dap4_projected(std::vector<string> &inventory)
-{
+bool Int64::is_dap4_projected(std::vector<string> &inventory) {
     bool has_projected_dap4 = false;
-    if(send_p()) {
+    if (send_p()) {
         has_projected_dap4 = true;
         attributes()->has_dap4_types(FQN(), inventory);
         inventory.emplace_back(type_name() + " " + FQN());
@@ -282,7 +241,6 @@ bool Int64::is_dap4_projected(std::vector<string> &inventory)
     return has_projected_dap4;
 }
 
-
 /** @brief dumps information about this object
  *
  * Displays the pointer value of this instance and information about this
@@ -291,16 +249,12 @@ bool Int64::is_dap4_projected(std::vector<string> &inventory)
  * @param strm C++ i/o stream to dump the information to
  * @return void
  */
-void
-Int64::dump(ostream &strm) const
-{
-    strm << DapIndent::LMarg << "Int64::dump - ("
-    << (void *)this << ")" << endl ;
-    DapIndent::Indent() ;
-    BaseType::dump(strm) ;
-    strm << DapIndent::LMarg << "value: " << d_buf << endl ;
-    DapIndent::UnIndent() ;
+void Int64::dump(ostream &strm) const {
+    strm << DapIndent::LMarg << "Int64::dump - (" << (void *)this << ")" << endl;
+    DapIndent::Indent();
+    BaseType::dump(strm);
+    strm << DapIndent::LMarg << "value: " << d_buf << endl;
+    DapIndent::UnIndent();
 }
 
 } // namespace libdap
-
