@@ -51,13 +51,13 @@ namespace libdap {
  */
 class Locker {
 public:
+    Locker() = delete;
     Locker(pthread_mutex_t &lock, pthread_cond_t &cond, int &count);
     virtual ~Locker();
 
 private:
-    pthread_mutex_t& m_mutex;
+    pthread_mutex_t &m_mutex;
 
-    Locker();
     Locker(const Locker &rhs);
 };
 
@@ -73,16 +73,15 @@ private:
  */
 class ChildLocker {
 public:
+    ChildLocker() = delete;
+    ChildLocker(const Locker &rhs) = delete;
     ChildLocker(pthread_mutex_t &lock, pthread_cond_t &cond, int &count);
     virtual ~ChildLocker();
 
 private:
-    pthread_mutex_t& m_mutex;
-    pthread_cond_t& m_cond;
-    int& m_count;
-
-    ChildLocker();
-    ChildLocker(const Locker &rhs);
+    pthread_mutex_t &m_mutex;
+    pthread_cond_t &m_cond;
+    int &m_count;
 };
 
 /**
@@ -95,14 +94,14 @@ private:
  */
 class MarshallerThread {
 private:
-    pthread_t d_thread;
+    pthread_t d_thread = 0;
     pthread_attr_t d_thread_attr;
 
     pthread_mutex_t d_out_mutex;
     pthread_cond_t d_out_cond;
 
-    int d_child_thread_count;   // 0 or 1
-    std::string d_thread_error; // non-null indicates an error
+    int d_child_thread_count = 0; // 0 or 1
+    std::string d_thread_error;   // non-null indicates an error
 
     /**
      * Used to pass information into the static methods that run the
@@ -115,28 +114,27 @@ private:
         pthread_cond_t &d_cond;
         int &d_count;
         std::string &d_error;
-        std::ostream &d_out;     // The output stream protected by the mutex, ...
-        int d_out_file;       // file descriptor; if not -1, use this.
-        char *d_buf;        // The data to write to the stream
-        int d_num;          // The size of d_buf
+        std::ostream &d_out;   // The output stream protected by the mutex, ...
+        int d_out_file;        // file descriptor; if not -1, use this.
+        char *d_buf;           // The data to write to the stream
+        std::streamsize d_num; // The size of d_buf
 
         /**
          * Build args for an ostream. The file descriptor is set to -1
          */
-        write_args(pthread_mutex_t &m, pthread_cond_t &c, int &count, std::string &e, std::ostream &s, char *vals, int num) :
-            d_mutex(m), d_cond(c), d_count(count), d_error(e), d_out(s), d_out_file(-1), d_buf(vals), d_num(num)
-        {
-        }
+        write_args(pthread_mutex_t &m, pthread_cond_t &c, int &count, std::string &e, std::ostream &s, char *vals,
+                   std::streamsize num)
+            : d_mutex(m), d_cond(c), d_count(count), d_error(e), d_out(s), d_out_file(-1), d_buf(vals), d_num(num) {}
 
         /**
          * Build args for a file descriptr. The ostream is set to cerr (because it is
          * a reference and has to be initialized to something).
          */
-        write_args(pthread_mutex_t &m, pthread_cond_t &c, int &count, std::string &e, int fd, char *vals, int num) :
-            d_mutex(m), d_cond(c), d_count(count), d_error(e), d_out(std::cerr), d_out_file(fd), d_buf(vals), d_num(num)
-        {
-        }
-   };
+        write_args(pthread_mutex_t &m, pthread_cond_t &c, int &count, std::string &e, int fd, char *vals,
+                   std::streamsize num)
+            : d_mutex(m), d_cond(c), d_count(count), d_error(e), d_out(std::cerr), d_out_file(fd), d_buf(vals),
+              d_num(num) {}
+    };
 
 public:
     MarshallerThread();
@@ -148,8 +146,8 @@ public:
     int &get_child_thread_count() { return d_child_thread_count; }
     void increment_child_thread_count() { ++d_child_thread_count; }
 
-    void start_thread(void* (*thread)(void *arg), std::ostream &out, char *byte_buf, unsigned int bytes_written);
-    void start_thread(void* (*thread)(void *arg), int fd, char *byte_buf, unsigned int bytes_written);
+    void start_thread(void *(*thread)(void *arg), std::ostream &out, char *byte_buf, std::streamsize bytes_written);
+    void start_thread(void *(*thread)(void *arg), int fd, char *byte_buf, std::streamsize bytes_written);
 
     // These are static so they will have c-linkage - required because they
     // are passed to pthread_create()
@@ -157,6 +155,6 @@ public:
     static void *write_thread_part(void *arg);
 };
 
-}
+} // namespace libdap
 
 #endif /* MARSHALLERTHREAD_H_ */
