@@ -31,7 +31,6 @@
 // Authors:
 //      pwest       Patrick West <pwest@ucar.edu>
 
-
 #include "config.h"
 
 #ifdef HAVE_PTHREAD_H
@@ -40,9 +39,9 @@
 
 #include <cassert>
 
+#include <iomanip>
 #include <iostream>
 #include <sstream>
-#include <iomanip>
 
 // #define DODS_DEBUG
 
@@ -54,8 +53,8 @@
 #include "XDRUtils.h"
 #include "util.h"
 
-#include "debug.h"
 #include "DapIndent.h"
+#include "debug.h"
 
 using namespace std;
 
@@ -66,8 +65,7 @@ using namespace std;
 namespace libdap {
 
 char *XDRStreamMarshaller::d_buf = 0;
-static const int XDR_DAP_BUFF_SIZE=256;
-
+static const int XDR_DAP_BUFF_SIZE = 256;
 
 /** Build an instance of XDRStreamMarshaller. Bind the C++ stream out to this
  * instance. If the checksum parameter is true, initialize a checksum buffer
@@ -77,11 +75,11 @@ static const int XDR_DAP_BUFF_SIZE=256;
  * @param checksum If true, compute checksums. False by default
  * @param write_data If true, write data values. True by default
  */
-XDRStreamMarshaller::XDRStreamMarshaller(ostream &out) :
-    d_out(out), d_partial_put_byte_count(0), tm(0)
-{
-    if (!d_buf) d_buf = (char *) malloc(XDR_DAP_BUFF_SIZE);
-    if (!d_buf) throw Error(internal_error, "Failed to allocate memory for data serialization.");
+XDRStreamMarshaller::XDRStreamMarshaller(ostream &out) : d_out(out), d_partial_put_byte_count(0), tm(0) {
+    if (!d_buf)
+        d_buf = (char *)malloc(XDR_DAP_BUFF_SIZE);
+    if (!d_buf)
+        throw Error(internal_error, "Failed to allocate memory for data serialization.");
 
     xdrmem_create(&d_sink, d_buf, XDR_DAP_BUFF_SIZE, XDR_ENCODE);
 
@@ -90,8 +88,7 @@ XDRStreamMarshaller::XDRStreamMarshaller(ostream &out) :
 #endif
 }
 
-XDRStreamMarshaller::~XDRStreamMarshaller()
-{
+XDRStreamMarshaller::~XDRStreamMarshaller() {
     // Added this because when USE_POS... is not defined, 'tm' has no
     // type, which the compiler complains about.
 #ifdef USE_POSIX_THREADS
@@ -100,19 +97,16 @@ XDRStreamMarshaller::~XDRStreamMarshaller()
     xdr_destroy(&d_sink);
 }
 
-void XDRStreamMarshaller::put_byte(dods_byte val)
-{
-     if (!xdr_setpos(&d_sink, 0))
+void XDRStreamMarshaller::put_byte(dods_byte val) {
+    if (!xdr_setpos(&d_sink, 0))
         throw Error("Network I/O Error. Could not send byte data - unable to set stream position.");
 
-    if (!xdr_char(&d_sink, (char *) &val))
-        throw Error(
-            "Network I/O Error. Could not send byte data.");
+    if (!xdr_char(&d_sink, (char *)&val))
+        throw Error("Network I/O Error. Could not send byte data.");
 
     unsigned int bytes_written = xdr_getpos(&d_sink);
     if (!bytes_written)
-        throw Error(
-            "Network I/O Error. Could not send byte data - unable to get stream position.");
+        throw Error("Network I/O Error. Could not send byte data - unable to get stream position.");
 
 #ifdef USE_POSIX_THREADS
     Locker lock(tm->get_mutex(), tm->get_cond(), tm->get_child_thread_count());
@@ -121,20 +115,16 @@ void XDRStreamMarshaller::put_byte(dods_byte val)
     d_out.write(d_buf, bytes_written);
 }
 
-void XDRStreamMarshaller::put_int16(dods_int16 val)
-{
+void XDRStreamMarshaller::put_int16(dods_int16 val) {
     if (!xdr_setpos(&d_sink, 0))
-        throw Error(
-            "Network I/O Error. Could not send int 16 data - unable to set stream position.");
+        throw Error("Network I/O Error. Could not send int 16 data - unable to set stream position.");
 
     if (!XDR_INT16(&d_sink, &val))
-        throw Error(
-            "Network I/O Error. Could not send int 16 data.");
+        throw Error("Network I/O Error. Could not send int 16 data.");
 
     unsigned int bytes_written = xdr_getpos(&d_sink);
     if (!bytes_written)
-        throw Error(
-            "Network I/O Error. Could not send int 16 data - unable to get stream position.");
+        throw Error("Network I/O Error. Could not send int 16 data - unable to get stream position.");
 
 #ifdef USE_POSIX_THREADS
     Locker lock(tm->get_mutex(), tm->get_cond(), tm->get_child_thread_count());
@@ -143,20 +133,16 @@ void XDRStreamMarshaller::put_int16(dods_int16 val)
     d_out.write(d_buf, bytes_written);
 }
 
-void XDRStreamMarshaller::put_int32(dods_int32 val)
-{
+void XDRStreamMarshaller::put_int32(dods_int32 val) {
     if (!xdr_setpos(&d_sink, 0))
-        throw Error(
-            "Network I/O Error. Could not send int 32 data - unable to set stream position.");
+        throw Error("Network I/O Error. Could not send int 32 data - unable to set stream position.");
 
     if (!XDR_INT32(&d_sink, &val))
-        throw Error(
-            "Network I/O Error. Culd not read int 32 data.");
+        throw Error("Network I/O Error. Culd not read int 32 data.");
 
     unsigned int bytes_written = xdr_getpos(&d_sink);
     if (!bytes_written)
-        throw Error(
-            "Network I/O Error. Could not send int 32 data - unable to get stream position.");
+        throw Error("Network I/O Error. Could not send int 32 data - unable to get stream position.");
 
 #ifdef USE_POSIX_THREADS
     Locker lock(tm->get_mutex(), tm->get_cond(), tm->get_child_thread_count());
@@ -165,20 +151,16 @@ void XDRStreamMarshaller::put_int32(dods_int32 val)
     d_out.write(d_buf, bytes_written);
 }
 
-void XDRStreamMarshaller::put_float32(dods_float32 val)
-{
+void XDRStreamMarshaller::put_float32(dods_float32 val) {
     if (!xdr_setpos(&d_sink, 0))
-        throw Error(
-            "Network I/O Error. Could not send float 32 data - unable to set stream position.");
+        throw Error("Network I/O Error. Could not send float 32 data - unable to set stream position.");
 
     if (!xdr_float(&d_sink, &val))
-        throw Error(
-            "Network I/O Error. Could not send float 32 data.");
+        throw Error("Network I/O Error. Could not send float 32 data.");
 
     unsigned int bytes_written = xdr_getpos(&d_sink);
     if (!bytes_written)
-        throw Error(
-            "Network I/O Error. Could not send float 32 data - unable to get stream position.");
+        throw Error("Network I/O Error. Could not send float 32 data - unable to get stream position.");
 
 #ifdef USE_POSIX_THREADS
     Locker lock(tm->get_mutex(), tm->get_cond(), tm->get_child_thread_count());
@@ -187,20 +169,16 @@ void XDRStreamMarshaller::put_float32(dods_float32 val)
     d_out.write(d_buf, bytes_written);
 }
 
-void XDRStreamMarshaller::put_float64(dods_float64 val)
-{
+void XDRStreamMarshaller::put_float64(dods_float64 val) {
     if (!xdr_setpos(&d_sink, 0))
-        throw Error(
-            "Network I/O Error. Could not send float 64 data - unable to set stream position.");
+        throw Error("Network I/O Error. Could not send float 64 data - unable to set stream position.");
 
     if (!xdr_double(&d_sink, &val))
-        throw Error(
-            "Network I/O Error. Could not send float 64 data.");
+        throw Error("Network I/O Error. Could not send float 64 data.");
 
     unsigned int bytes_written = xdr_getpos(&d_sink);
     if (!bytes_written)
-        throw Error(
-            "Network I/O Error. Could not send float 64 data - unable to get stream position.");
+        throw Error("Network I/O Error. Could not send float 64 data - unable to get stream position.");
 
 #ifdef USE_POSIX_THREADS
     Locker lock(tm->get_mutex(), tm->get_cond(), tm->get_child_thread_count());
@@ -209,20 +187,16 @@ void XDRStreamMarshaller::put_float64(dods_float64 val)
     d_out.write(d_buf, bytes_written);
 }
 
-void XDRStreamMarshaller::put_uint16(dods_uint16 val)
-{
+void XDRStreamMarshaller::put_uint16(dods_uint16 val) {
     if (!xdr_setpos(&d_sink, 0))
-        throw Error(
-            "Network I/O Error. Could not send uint 16 data - unable to set stream position.");
+        throw Error("Network I/O Error. Could not send uint 16 data - unable to set stream position.");
 
     if (!XDR_UINT16(&d_sink, &val))
-        throw Error(
-            "Network I/O Error. Could not send uint 16 data.");
+        throw Error("Network I/O Error. Could not send uint 16 data.");
 
     unsigned int bytes_written = xdr_getpos(&d_sink);
     if (!bytes_written)
-        throw Error(
-            "Network I/O Error. Could not send uint 16 data - unable to get stream position.");
+        throw Error("Network I/O Error. Could not send uint 16 data - unable to get stream position.");
 
 #ifdef USE_POSIX_THREADS
     Locker lock(tm->get_mutex(), tm->get_cond(), tm->get_child_thread_count());
@@ -231,20 +205,16 @@ void XDRStreamMarshaller::put_uint16(dods_uint16 val)
     d_out.write(d_buf, bytes_written);
 }
 
-void XDRStreamMarshaller::put_uint32(dods_uint32 val)
-{
+void XDRStreamMarshaller::put_uint32(dods_uint32 val) {
     if (!xdr_setpos(&d_sink, 0))
-        throw Error(
-            "Network I/O Error. Could not send uint 32 data - unable to set stream position.");
+        throw Error("Network I/O Error. Could not send uint 32 data - unable to set stream position.");
 
     if (!XDR_UINT32(&d_sink, &val))
-        throw Error(
-            "Network I/O Error. Could not send uint 32 data.");
+        throw Error("Network I/O Error. Could not send uint 32 data.");
 
     unsigned int bytes_written = xdr_getpos(&d_sink);
     if (!bytes_written)
-        throw Error(
-            "Network I/O Error. Could not send uint 32 data - unable to get stream position.");
+        throw Error("Network I/O Error. Could not send uint 32 data - unable to get stream position.");
 
 #ifdef USE_POSIX_THREADS
     Locker lock(tm->get_mutex(), tm->get_cond(), tm->get_child_thread_count());
@@ -253,8 +223,7 @@ void XDRStreamMarshaller::put_uint32(dods_uint32 val)
     d_out.write(d_buf, bytes_written);
 }
 
-void XDRStreamMarshaller::put_str(const string &val)
-{
+void XDRStreamMarshaller::put_str(const string &val) {
     int size = val.length() + 8;
 
     XDR str_sink;
@@ -264,18 +233,15 @@ void XDRStreamMarshaller::put_str(const string &val)
         xdrmem_create(&str_sink, str_buf.data(), size, XDR_ENCODE);
 
         if (!xdr_setpos(&str_sink, 0))
-            throw Error(
-                "Network I/O Error. Could not send string data - unable to set stream position.");
+            throw Error("Network I/O Error. Could not send string data - unable to set stream position.");
 
         const char *out_tmp = val.c_str();
-        if (!xdr_string(&str_sink, (char **) &out_tmp, size))
-            throw Error(
-                "Network I/O Error. Could not send string data.");
+        if (!xdr_string(&str_sink, (char **)&out_tmp, size))
+            throw Error("Network I/O Error. Could not send string data.");
 
         unsigned int bytes_written = xdr_getpos(&str_sink);
         if (!bytes_written)
-            throw Error(
-                "Network I/O Error. Could not send string data - unable to get stream position.");
+            throw Error("Network I/O Error. Could not send string data - unable to get stream position.");
 
 #ifdef USE_POSIX_THREADS
         Locker lock(tm->get_mutex(), tm->get_cond(), tm->get_child_thread_count());
@@ -284,35 +250,27 @@ void XDRStreamMarshaller::put_str(const string &val)
         d_out.write(str_buf.data(), bytes_written);
 
         xdr_destroy(&str_sink);
-    }
-    catch (...) {
+    } catch (...) {
         xdr_destroy(&str_sink);
         throw;
     }
 }
 
-void XDRStreamMarshaller::put_url(const string &val)
-{
-    put_str(val);
-}
+void XDRStreamMarshaller::put_url(const string &val) { put_str(val); }
 
-void XDRStreamMarshaller::put_opaque(char *val, unsigned int len)
-{
+void XDRStreamMarshaller::put_opaque(char *val, unsigned int len) {
     if (len > XDR_DAP_BUFF_SIZE)
         throw Error("Network I/O Error. Could not send opaque data - length of opaque data larger than allowed");
 
     if (!xdr_setpos(&d_sink, 0))
-        throw Error(
-            "Network I/O Error. Could not send opaque data - unable to set stream position.");
+        throw Error("Network I/O Error. Could not send opaque data - unable to set stream position.");
 
     if (!xdr_opaque(&d_sink, val, len))
-        throw Error(
-            "Network I/O Error. Could not send opaque data.");
+        throw Error("Network I/O Error. Could not send opaque data.");
 
     unsigned int bytes_written = xdr_getpos(&d_sink);
     if (!bytes_written)
-        throw Error(
-            "Network I/O Error. Could not send opaque data - unable to get stream position.");
+        throw Error("Network I/O Error. Could not send opaque data - unable to get stream position.");
 
 #ifdef USE_POSIX_THREADS
     Locker lock(tm->get_mutex(), tm->get_cond(), tm->get_child_thread_count());
@@ -321,20 +279,16 @@ void XDRStreamMarshaller::put_opaque(char *val, unsigned int len)
     d_out.write(d_buf, bytes_written);
 }
 
-void XDRStreamMarshaller::put_int(int val)
-{
+void XDRStreamMarshaller::put_int(int val) {
     if (!xdr_setpos(&d_sink, 0))
-        throw Error(
-            "Network I/O Error. Could not send int data - unable to set stream position.");
+        throw Error("Network I/O Error. Could not send int data - unable to set stream position.");
 
     if (!xdr_int(&d_sink, &val))
-        throw Error(
-            "Network I/O Error(1). Could not send int data.");
+        throw Error("Network I/O Error(1). Could not send int data.");
 
     unsigned int bytes_written = xdr_getpos(&d_sink);
     if (!bytes_written)
-        throw Error(
-            "Network I/O Error. Could not send int data - unable to get stream position.");
+        throw Error("Network I/O Error. Could not send int data - unable to get stream position.");
 
 #ifdef USE_POSIX_THREADS
     Locker lock(tm->get_mutex(), tm->get_cond(), tm->get_child_thread_count());
@@ -343,12 +297,10 @@ void XDRStreamMarshaller::put_int(int val)
     d_out.write(d_buf, bytes_written);
 }
 
-void XDRStreamMarshaller::put_vector(char *val, int num, int width, Vector &vec)
-{
+void XDRStreamMarshaller::put_vector(char *val, int num, int width, Vector &vec) {
     put_vector(val, num, width, vec.var()->type());
 }
 
-
 /**
  * Prepare to send a single array/vector using a series of 'put' calls.
  *
@@ -356,8 +308,7 @@ void XDRStreamMarshaller::put_vector(char *val, int num, int width, Vector &vec)
  * @see put_vector_part()
  * @see put_vector_end()
  */
-void XDRStreamMarshaller::put_vector_start(int num)
-{
+void XDRStreamMarshaller::put_vector_start(int num) {
     put_int(num);
     put_int(num);
 
@@ -370,8 +321,7 @@ void XDRStreamMarshaller::put_vector_start(int num)
  * @see put_vector_start()
  * @see put_vector_part()
  */
-void XDRStreamMarshaller::put_vector_end()
-{
+void XDRStreamMarshaller::put_vector_end() {
 #ifdef USE_POSIX_THREADS
     Locker lock(tm->get_mutex(), tm->get_cond(), tm->get_child_thread_count());
 #endif
@@ -379,22 +329,23 @@ void XDRStreamMarshaller::put_vector_end()
     // Compute the trailing (padding) bytes
 
     // Note that the XDR standard pads values to 4 byte boundaries.
-    //unsigned int pad = (d_partial_put_byte_count % 4) == 0 ? 0: 4 - (d_partial_put_byte_count % 4);
+    // unsigned int pad = (d_partial_put_byte_count % 4) == 0 ? 0: 4 - (d_partial_put_byte_count % 4);
     unsigned int mod_4 = d_partial_put_byte_count & 0x03;
-    unsigned int pad = (mod_4 == 0) ? 0: 4 - mod_4;
+    unsigned int pad = (mod_4 == 0) ? 0 : 4 - mod_4;
 
     if (pad) {
         vector<char> padding(4, 0); // 4 zeros
 
         d_out.write(padding.data(), pad);
-        if (d_out.fail()) throw Error("Network I/O Error. Could not send vector data padding");
+        if (d_out.fail())
+            throw Error("Network I/O Error. Could not send vector data padding");
     }
 }
 
 // Start of parallel I/O support. jhrg 8/19/15
-void XDRStreamMarshaller::put_vector(char *val, int num, Vector &)
-{
-    if (!val) throw InternalErr(__FILE__, __LINE__, "Could not send byte vector data. Buffer pointer is not set.");
+void XDRStreamMarshaller::put_vector(char *val, int num, Vector &) {
+    if (!val)
+        throw InternalErr(__FILE__, __LINE__, "Could not send byte vector data. Buffer pointer is not set.");
 
     // write the number of members of the array being written and then set the position to 0
     put_int(num);
@@ -410,7 +361,7 @@ void XDRStreamMarshaller::put_vector(char *val, int num, Vector &)
         if (!xdr_setpos(&byte_sink, 0))
             throw Error("Network I/O Error. Could not send byte vector data - unable to set stream position.");
 
-        if (!xdr_bytes(&byte_sink, (char **) &val, (unsigned int *) &num, num + add_to))
+        if (!xdr_bytes(&byte_sink, (char **)&val, (unsigned int *)&num, num + add_to))
             throw Error("Network I/O Error(2). Could not send byte vector data - unable to encode data.");
 
         unsigned int bytes_written = xdr_getpos(&byte_sink);
@@ -425,14 +376,13 @@ void XDRStreamMarshaller::put_vector(char *val, int num, Vector &)
 #else
         d_out.write(byte_buf, bytes_written);
         xdr_destroy(&byte_sink);
-        delete [] byte_buf;
+        delete[] byte_buf;
 #endif
 
-    }
-    catch (...) {
+    } catch (...) {
         DBG(cerr << "Caught an exception in put_vector_thread" << endl);
         xdr_destroy(&byte_sink);
-        delete [] byte_buf;
+        delete[] byte_buf;
         throw;
     }
 }
@@ -448,8 +398,7 @@ void XDRStreamMarshaller::put_vector(char *val, int num, Vector &)
  * @param width The number of bytes in each element
  * @param type The DAP type of the elements
  */
-void XDRStreamMarshaller::put_vector(char *val, unsigned int num, int width, Type type)
-{
+void XDRStreamMarshaller::put_vector(char *val, unsigned int num, int width, Type type) {
     assert(val || num == 0);
 
     // write the number of array members being written, then set the position back to 0
@@ -459,14 +408,15 @@ void XDRStreamMarshaller::put_vector(char *val, unsigned int num, int width, Typ
         return;
 
     int use_width = width;
-    if (use_width < 4) use_width = 4;
+    if (use_width < 4)
+        use_width = 4;
 
     // the size is the number of elements num times the width of each
     // element, then add 4 bytes for the number of elements
     int size = (num * use_width) + 4;
 
     // allocate enough memory for the elements
-    //vector<char> vec_buf(size);
+    // vector<char> vec_buf(size);
     char *vec_buf = new char[size];
     XDR vec_sink;
     try {
@@ -477,7 +427,7 @@ void XDRStreamMarshaller::put_vector(char *val, unsigned int num, int width, Typ
             throw Error("Network I/O Error. Could not send vector data - unable to set stream position.");
 
         // write the array to the buffer
-        if (!xdr_array(&vec_sink, (char **) &val, (unsigned int *) &num, size, width, XDRUtils::xdr_coder(type)))
+        if (!xdr_array(&vec_sink, (char **)&val, (unsigned int *)&num, size, width, XDRUtils::xdr_coder(type)))
             throw Error("Network I/O Error(2). Could not send vector data - unable to encode.");
 
         // how much was written to the buffer
@@ -493,12 +443,11 @@ void XDRStreamMarshaller::put_vector(char *val, unsigned int num, int width, Typ
 #else
         d_out.write(vec_buf, bytes_written);
         xdr_destroy(&vec_sink);
-        delete [] vec_buf;
+        delete[] vec_buf;
 #endif
-    }
-    catch (...) {
+    } catch (...) {
         xdr_destroy(&vec_sink);
-        delete [] vec_buf;
+        delete[] vec_buf;
         throw;
     }
 }
@@ -514,14 +463,13 @@ void XDRStreamMarshaller::put_vector(char *val, unsigned int num, int width, Typ
  * @see put_vector_start()
  * @see put_vector_end()
  */
-void XDRStreamMarshaller::put_vector_part(char *val, unsigned int num, int width, Type type)
-{
+void XDRStreamMarshaller::put_vector_part(char *val, unsigned int num, int width, Type type) {
     if (width == 1) {
         // Add space for the 4 bytes of length info and 4 bytes for padding, even though
         // we will not send either of those.
         const unsigned int add_to = 8;
         unsigned int bufsiz = num + add_to;
-        //vector<char> byte_buf(bufsiz);
+        // vector<char> byte_buf(bufsiz);
         char *byte_buf = new char[bufsiz];
         XDR byte_sink;
         try {
@@ -529,7 +477,7 @@ void XDRStreamMarshaller::put_vector_part(char *val, unsigned int num, int width
             if (!xdr_setpos(&byte_sink, 0))
                 throw Error("Network I/O Error. Could not send byte vector data - unable to set stream position.");
 
-            if (!xdr_bytes(&byte_sink, (char **) &val, (unsigned int *) &num, bufsiz))
+            if (!xdr_bytes(&byte_sink, (char **)&val, (unsigned int *)&num, bufsiz))
                 throw Error("Network I/O Error(2). Could not send byte vector data - unable to encode data.");
 
 #ifdef USE_POSIX_THREADS
@@ -548,22 +496,20 @@ void XDRStreamMarshaller::put_vector_part(char *val, unsigned int num, int width
             d_out.write(byte_buf + 4, num);
 
             if (d_out.fail())
-            throw Error ("Network I/O Error. Could not send initial part of byte vector data");
+                throw Error("Network I/O Error. Could not send initial part of byte vector data");
 
             // Now increment the element count so we can figure out about the padding in put_vector_last()
             d_partial_put_byte_count += num;
 
             xdr_destroy(&byte_sink);
-            delete [] byte_buf;
+            delete[] byte_buf;
 #endif
-        }
-        catch (...) {
+        } catch (...) {
             xdr_destroy(&byte_sink);
-            delete [] byte_buf;
+            delete[] byte_buf;
             throw;
         }
-    }
-    else {
+    } else {
         int use_width = (width < 4) ? 4 : width;
 
         // the size is the number of elements num times the width of each
@@ -571,7 +517,7 @@ void XDRStreamMarshaller::put_vector_part(char *val, unsigned int num, int width
         int size = (num * use_width) + 4;
 
         // allocate enough memory for the elements
-        //vector<char> vec_buf(size);
+        // vector<char> vec_buf(size);
         char *vec_buf = new char[size];
         XDR vec_sink;
         try {
@@ -582,7 +528,7 @@ void XDRStreamMarshaller::put_vector_part(char *val, unsigned int num, int width
                 throw Error("Network I/O Error. Could not send vector data - unable to set stream position.");
 
             // write the array to the buffer
-            if (!xdr_array(&vec_sink, (char **) &val, (unsigned int *) &num, size, width, XDRUtils::xdr_coder(type)))
+            if (!xdr_array(&vec_sink, (char **)&val, (unsigned int *)&num, size, width, XDRUtils::xdr_coder(type)))
                 throw Error("Network I/O Error(2). Could not send vector data -unable to encode data.");
 
 #ifdef USE_POSIX_THREADS
@@ -599,27 +545,24 @@ void XDRStreamMarshaller::put_vector_part(char *val, unsigned int num, int width
             d_out.write(vec_buf + 4, size - 4);
 
             if (d_out.fail())
-                throw Error ("Network I/O Error. Could not send part of vector data");
+                throw Error("Network I/O Error. Could not send part of vector data");
 
             // Now increment the element count so we can figure out about the padding in put_vector_last()
             d_partial_put_byte_count += (size - 4);
 
             xdr_destroy(&vec_sink);
-            delete [] vec_buf;
+            delete[] vec_buf;
 #endif
-        }
-        catch (...) {
+        } catch (...) {
             xdr_destroy(&vec_sink);
-            delete [] vec_buf;
+            delete[] vec_buf;
             throw;
         }
     }
 }
 
-void XDRStreamMarshaller::dump(ostream &strm) const
-{
-    strm << DapIndent::LMarg << "XDRStreamMarshaller::dump - (" << (void *) this << ")" << endl;
+void XDRStreamMarshaller::dump(ostream &strm) const {
+    strm << DapIndent::LMarg << "XDRStreamMarshaller::dump - (" << (void *)this << ")" << endl;
 }
 
 } // namespace libdap
-
