@@ -29,32 +29,32 @@
 //
 // Authors:
 //      pwest       Patrick West <pwest@ucar.edu>
-#include "config.h"
 #include "XDRStreamUnMarshaller.h"
+#include "config.h"
 
 #include <cstring> // for memcpy
-#include <string>
 #include <sstream>
+#include <string>
 
-//#define DODS_DEBUG2 1
-//#define DODS_DEBUG 1
+// #define DODS_DEBUG2 1
+// #define DODS_DEBUG 1
 
-#include "Str.h"
 #include "Array.h"
-#include "util.h"
-#include "InternalErr.h"
-#include "debug.h"
 #include "DapIndent.h"
+#include "InternalErr.h"
+#include "Str.h"
+#include "debug.h"
+#include "util.h"
 
 namespace libdap {
 
 char *XDRStreamUnMarshaller::d_buf = 0;
 
-XDRStreamUnMarshaller::XDRStreamUnMarshaller(istream &in) : /*&d_source( 0 ),*/
-        d_in(in)
-{
+XDRStreamUnMarshaller::XDRStreamUnMarshaller(istream &in)
+    : /*&d_source( 0 ),*/
+      d_in(in) {
     if (!d_buf)
-        d_buf = (char *) malloc(XDR_DAP_BUFF_SIZE);
+        d_buf = (char *)malloc(XDR_DAP_BUFF_SIZE);
     if (!d_buf)
         throw Error(internal_error, "Failed to allocate memory for data serialization.");
 
@@ -62,33 +62,26 @@ XDRStreamUnMarshaller::XDRStreamUnMarshaller(istream &in) : /*&d_source( 0 ),*/
     xdrmem_create(&d_source, d_buf, XDR_DAP_BUFF_SIZE, XDR_DECODE);
 }
 
-XDRStreamUnMarshaller::XDRStreamUnMarshaller() :
-        UnMarshaller(), /*&d_source( 0 ),*/d_in(cin)
-{
+XDRStreamUnMarshaller::XDRStreamUnMarshaller() : UnMarshaller(), /*&d_source( 0 ),*/ d_in(cin) {
     throw InternalErr(__FILE__, __LINE__, "Default constructor not implemented.");
 }
 
-XDRStreamUnMarshaller::XDRStreamUnMarshaller(const XDRStreamUnMarshaller &um) :
-        UnMarshaller(um), /*&d_source( 0 ),*/d_in(cin)
-{
+XDRStreamUnMarshaller::XDRStreamUnMarshaller(const XDRStreamUnMarshaller &um)
+    : UnMarshaller(um), /*&d_source( 0 ),*/ d_in(cin) {
     throw InternalErr(__FILE__, __LINE__, "Copy constructor not implemented.");
 }
 
-XDRStreamUnMarshaller &
-XDRStreamUnMarshaller::operator=(const XDRStreamUnMarshaller &)
-{
+XDRStreamUnMarshaller &XDRStreamUnMarshaller::operator=(const XDRStreamUnMarshaller &) {
     throw InternalErr(__FILE__, __LINE__, "Copy operator not implemented.");
 }
 
-XDRStreamUnMarshaller::~XDRStreamUnMarshaller()
-{
-    xdr_destroy( &d_source );
+XDRStreamUnMarshaller::~XDRStreamUnMarshaller() {
+    xdr_destroy(&d_source);
     //&d_source = 0;
 }
 
-void XDRStreamUnMarshaller::get_byte(dods_byte &val)
-{
-    if (xdr_setpos( &d_source, 0 ) < 0)
+void XDRStreamUnMarshaller::get_byte(dods_byte &val) {
+    if (xdr_setpos(&d_source, 0) < 0)
         throw Error("Failed to reposition input stream");
     if (!(d_in.read(d_buf, 4))) {
         if (d_in.eof())
@@ -100,74 +93,66 @@ void XDRStreamUnMarshaller::get_byte(dods_byte &val)
         }
     }
 
-    DBG2( std::cerr << "_in.gcount(): " << d_in.gcount() << std::endl );
-    DBG2( std::cerr << "_in.tellg(): " << d_in.tellg() << std::endl );
-    DBG2( std::cerr << "_buf[0]: " << hex << d_buf[0] << "; _buf[1]: " << d_buf[1]
-            << "; _buf[2]: " << d_buf[2] << "; _buf[3]: " << d_buf[3]
-            << dec << std::endl );
+    DBG2(std::cerr << "_in.gcount(): " << d_in.gcount() << std::endl);
+    DBG2(std::cerr << "_in.tellg(): " << d_in.tellg() << std::endl);
+    DBG2(std::cerr << "_buf[0]: " << hex << d_buf[0] << "; _buf[1]: " << d_buf[1] << "; _buf[2]: " << d_buf[2]
+                   << "; _buf[3]: " << d_buf[3] << dec << std::endl);
 
-    if (!xdr_char(&d_source, (char *) &val))
+    if (!xdr_char(&d_source, (char *)&val))
         throw Error("Network I/O Error. Could not read byte data.");
 
-    DBG2(std::cerr << "get_byte: " << val << std::endl );
+    DBG2(std::cerr << "get_byte: " << val << std::endl);
 }
 
-void XDRStreamUnMarshaller::get_int16(dods_int16 &val)
-{
-    xdr_setpos( &d_source, 0);
+void XDRStreamUnMarshaller::get_int16(dods_int16 &val) {
+    xdr_setpos(&d_source, 0);
     d_in.read(d_buf, 4);
 
     if (!XDR_INT16(&d_source, &val))
         throw Error("Network I/O Error. Could not read int 16 data.");
 }
 
-void XDRStreamUnMarshaller::get_int32(dods_int32 &val)
-{
-    xdr_setpos( &d_source, 0);
+void XDRStreamUnMarshaller::get_int32(dods_int32 &val) {
+    xdr_setpos(&d_source, 0);
     d_in.read(d_buf, 4);
 
     if (!XDR_INT32(&d_source, &val))
         throw Error("Network I/O Error. Could not read int 32 data.");
 }
 
-void XDRStreamUnMarshaller::get_float32(dods_float32 &val)
-{
-    xdr_setpos( &d_source, 0);
+void XDRStreamUnMarshaller::get_float32(dods_float32 &val) {
+    xdr_setpos(&d_source, 0);
     d_in.read(d_buf, 4);
 
     if (!xdr_float(&d_source, &val))
         throw Error("Network I/O Error. Could not read float 32 data.");
 }
 
-void XDRStreamUnMarshaller::get_float64(dods_float64 &val)
-{
-    xdr_setpos( &d_source, 0);
+void XDRStreamUnMarshaller::get_float64(dods_float64 &val) {
+    xdr_setpos(&d_source, 0);
     d_in.read(d_buf, 8);
 
     if (!xdr_double(&d_source, &val))
         throw Error("Network I/O Error. Could not read float 64 data.");
 }
 
-void XDRStreamUnMarshaller::get_uint16(dods_uint16 &val)
-{
-    xdr_setpos( &d_source, 0);
+void XDRStreamUnMarshaller::get_uint16(dods_uint16 &val) {
+    xdr_setpos(&d_source, 0);
     d_in.read(d_buf, 4);
 
     if (!XDR_UINT16(&d_source, &val))
         throw Error("Network I/O Error. Could not read uint 16 data.");
 }
 
-void XDRStreamUnMarshaller::get_uint32(dods_uint32 &val)
-{
-    xdr_setpos( &d_source, 0);
+void XDRStreamUnMarshaller::get_uint32(dods_uint32 &val) {
+    xdr_setpos(&d_source, 0);
     d_in.read(d_buf, 4);
 
     if (!XDR_UINT32(&d_source, &val))
         throw Error("Network I/O Error. Could not read uint 32 data.");
 }
 
-void XDRStreamUnMarshaller::get_str(string &val)
-{
+void XDRStreamUnMarshaller::get_str(string &val) {
     int i;
     get_int(i);
     DBG(std::cerr << "i: " << i << std::endl);
@@ -177,35 +162,34 @@ void XDRStreamUnMarshaller::get_str(string &val)
     DBG(std::cerr << "i: " << i << std::endl);
 
     char *in_tmp = 0;
-    //char *buf = 0;
-    //XDR *source = 0;
-    // Must address the case where the string is larger than the buffer
+    // char *buf = 0;
+    // XDR *source = 0;
+    //  Must address the case where the string is larger than the buffer
     if (i + 4 > XDR_DAP_BUFF_SIZE) {
 #if 0
         char *buf = (char *) malloc(i + 4);
         if (!buf)
             throw InternalErr(__FILE__, __LINE__, "Error allocating memory");
 #endif
-        vector<char> buf(i+4);
+        vector<char> buf(i + 4);
 
-        XDR source;// = new XDR;
+        XDR source; // = new XDR;
         xdrmem_create(&source, buf.data(), i + 4, XDR_DECODE);
         memcpy(buf.data(), d_buf, 4);
 
         d_in.read(buf.data() + 4, i);
 
-        xdr_setpos( &source, 0);
-        if (!xdr_string( &source, &in_tmp, max_str_len)) {
-            xdr_destroy( &source );
+        xdr_setpos(&source, 0);
+        if (!xdr_string(&source, &in_tmp, max_str_len)) {
+            xdr_destroy(&source);
             throw Error("Network I/O Error. Could not read string data.");
         }
 
-        xdr_destroy( &source );
-    }
-    else {
+        xdr_destroy(&source);
+    } else {
         d_in.read(d_buf + 4, i);
 
-        xdr_setpos( &d_source, 0);
+        xdr_setpos(&d_source, 0);
         if (!xdr_string(&d_source, &in_tmp, max_str_len))
             throw Error("Network I/O Error. Could not read string data.");
     }
@@ -215,14 +199,10 @@ void XDRStreamUnMarshaller::get_str(string &val)
     free(in_tmp);
 }
 
-void XDRStreamUnMarshaller::get_url(string &val)
-{
-    get_str(val);
-}
+void XDRStreamUnMarshaller::get_url(string &val) { get_str(val); }
 
-void XDRStreamUnMarshaller::get_opaque(char *val, unsigned int len)
-{
-    xdr_setpos( &d_source, 0);
+void XDRStreamUnMarshaller::get_opaque(char *val, unsigned int len) {
+    xdr_setpos(&d_source, 0);
 
     // Round len up to the next multiple of 4. There is also the RNDUP()
     // macro in xdr.h, at least on OS/X.
@@ -235,9 +215,8 @@ void XDRStreamUnMarshaller::get_opaque(char *val, unsigned int len)
     xdr_opaque(&d_source, val, len);
 }
 
-void XDRStreamUnMarshaller::get_int(int &val)
-{
-    xdr_setpos( &d_source, 0);
+void XDRStreamUnMarshaller::get_int(int &val) {
+    xdr_setpos(&d_source, 0);
     d_in.read(d_buf, 4);
 
     if (!xdr_int(&d_source, &val))
@@ -246,8 +225,7 @@ void XDRStreamUnMarshaller::get_int(int &val)
     DBG(std::cerr << "get_int: " << val << std::endl);
 }
 
-void XDRStreamUnMarshaller::get_vector(char **val, unsigned int &num, Vector &)
-{
+void XDRStreamUnMarshaller::get_vector(char **val, unsigned int &num, Vector &) {
     int i;
     get_int(i); // This leaves the XDR encoded value in d_buf; used later
     DBG(std::cerr << "i: " << i << std::endl);
@@ -256,11 +234,11 @@ void XDRStreamUnMarshaller::get_vector(char **val, unsigned int &num, Vector &)
     i += i & 3;
     DBG(std::cerr << "i: " << i << std::endl);
 
-    //char *buf = 0;
-    //XDR *source = 0;
-    // Must address the case where the string is larger than the buffer
+    // char *buf = 0;
+    // XDR *source = 0;
+    //  Must address the case where the string is larger than the buffer
     if (i + 4 > XDR_DAP_BUFF_SIZE) {
-    	vector<char> buf(i+4);
+        vector<char> buf(i + 4);
         XDR source;
         xdrmem_create(&source, buf.data(), i + 4, XDR_DECODE);
         memcpy(buf.data(), d_buf, 4);
@@ -274,9 +252,8 @@ void XDRStreamUnMarshaller::get_vector(char **val, unsigned int &num, Vector &)
             throw Error("Network I/O Error. Could not read byte array data.");
         }
 
-        xdr_destroy( &source );
-    }
-    else {
+        xdr_destroy(&source);
+    } else {
         d_in.read(d_buf + 4, i);
         DBG2(cerr << "bytes read: " << d_in.gcount() << endl);
 
@@ -286,13 +263,11 @@ void XDRStreamUnMarshaller::get_vector(char **val, unsigned int &num, Vector &)
     }
 }
 
-void XDRStreamUnMarshaller::get_vector(char **val, unsigned int &num, int width, Vector &vec)
-{
+void XDRStreamUnMarshaller::get_vector(char **val, unsigned int &num, int width, Vector &vec) {
     get_vector(val, num, width, vec.var()->type());
 }
 
-void XDRStreamUnMarshaller::get_vector(char **val, unsigned int &num, int width, Type type)
-{
+void XDRStreamUnMarshaller::get_vector(char **val, unsigned int &num, int width, Type type) {
     int i;
     get_int(i); // This leaves the XDR encoded value in d_buf; used later
     DBG(std::cerr << "i: " << i << std::endl);
@@ -304,7 +279,7 @@ void XDRStreamUnMarshaller::get_vector(char **val, unsigned int &num, int width,
 
     // Must address the case where the string is larger than the buffer
     if (size > XDR_DAP_BUFF_SIZE) {
-    	vector<char> buf(size+4);
+        vector<char> buf(size + 4);
         XDR source;
         xdrmem_create(&source, buf.data(), size + 4, XDR_DECODE);
         DBG(cerr << "size: " << size << endl);
@@ -315,26 +290,23 @@ void XDRStreamUnMarshaller::get_vector(char **val, unsigned int &num, int width,
 
         xdr_setpos(&source, 0);
         if (!xdr_array(&source, val, &num, DODS_MAX_ARRAY, width, XDRUtils::xdr_coder(type))) {
-            xdr_destroy( &source );
+            xdr_destroy(&source);
             throw Error("Network I/O Error. Could not read array data.");
         }
 
-        xdr_destroy( &source );
-    }
-    else {
+        xdr_destroy(&source);
+    } else {
         d_in.read(d_buf + 4, size);
         DBG(cerr << "bytes read (2): " << d_in.gcount() << endl);
 
-        xdr_setpos( &d_source, 0);
+        xdr_setpos(&d_source, 0);
         if (!xdr_array(&d_source, val, &num, DODS_MAX_ARRAY, width, XDRUtils::xdr_coder(type)))
             throw Error("Network I/O Error. Could not read array data.");
     }
 }
 
-void XDRStreamUnMarshaller::dump(ostream &strm) const
-{
-    strm << DapIndent::LMarg << "XDRStreamUnMarshaller::dump - (" << (void *) this << ")" << endl;
+void XDRStreamUnMarshaller::dump(ostream &strm) const {
+    strm << DapIndent::LMarg << "XDRStreamUnMarshaller::dump - (" << (void *)this << ")" << endl;
 }
 
 } // namespace libdap
-
