@@ -602,15 +602,15 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   254,   254,   261,   263,   263,   268,   274,   275,   281,
-     294,   298,   302,   327,   334,   341,   348,   355,   362,   369,
-     379,   390,   394,   402,   409,   413,   421,   428,   432,   440,
-     447,   451,   459,   466,   470,   478,   485,   489,   497,   504,
-     508,   516,   523,   546,   547,   553,   562,   573,   580,   594,
-     595,   605,   609,   615,   622,   631,   636,   641,   675,   709,
-     719,   725,   733,   739,   750,   755,   769,   773,   787,   799,
-     810,   828,   849,   866,   888,   903,   904,   905,   906,   907,
-     908,   909
+       0,   254,   254,   260,   262,   262,   263,   266,   267,   273,
+     285,   289,   293,   317,   323,   329,   335,   341,   347,   353,
+     362,   373,   377,   385,   392,   396,   404,   411,   415,   423,
+     430,   434,   442,   449,   453,   461,   468,   472,   480,   487,
+     491,   499,   506,   529,   530,   536,   545,   556,   563,   577,
+     578,   588,   592,   598,   605,   614,   619,   624,   658,   693,
+     703,   709,   717,   723,   734,   739,   753,   757,   771,   783,
+     794,   812,   833,   850,   872,   887,   888,   889,   890,   891,
+     892,   893
 };
 #endif
 
@@ -1505,79 +1505,72 @@ yyreduce:
 #line 254 "ce_expr.yy" /* yacc.c:1667  */
     {
     DBG(cerr << "Mark all variables" << endl);
-    DDS(arg)
-        ->mark_all(true);
+    DDS(arg)->mark_all(true);
     (yyval.boolean) = true;
 }
-#line 1513 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1512 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 4:
-#line 263 "ce_expr.yy" /* yacc.c:1667  */
-    { DDS(arg)
-          ->mark_all(true); }
-#line 1520 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 262 "ce_expr.yy" /* yacc.c:1667  */
+    { DDS(arg)->mark_all(true); }
+#line 1518 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 5:
-#line 265 "ce_expr.yy" /* yacc.c:1667  */
-    {
-              (yyval.boolean) = (yyvsp[0].boolean);
-          }
-#line 1528 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 262 "ce_expr.yy" /* yacc.c:1667  */
+    { (yyval.boolean) = (yyvsp[0].boolean); }
+#line 1524 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 6:
-#line 269 "ce_expr.yy" /* yacc.c:1667  */
-    {
-    (yyval.boolean) = (yyvsp[-2].boolean) && (yyvsp[0].boolean);
-}
-#line 1536 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 263 "ce_expr.yy" /* yacc.c:1667  */
+    {  (yyval.boolean) = (yyvsp[-2].boolean) && (yyvsp[0].boolean); }
+#line 1530 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 8:
-#line 276 "ce_expr.yy" /* yacc.c:1667  */
+#line 268 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.boolean) = (yyvsp[-2].boolean) && (yyvsp[0].boolean);
 }
-#line 1544 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1538 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 9:
-#line 282 "ce_expr.yy" /* yacc.c:1667  */
+#line 274 "ce_expr.yy" /* yacc.c:1667  */
     {
     BaseType *var = DDS(arg)->var((yyvsp[0].id));
     if (var) {
         DBG(cerr << "Marking " << (yyvsp[0].id) << endl);
-        (yyval.boolean) = DDS(arg)
-            ->mark((yyvsp[0].id), true);
+        (yyval.boolean) = DDS(arg)->mark((yyvsp[0].id), true);
         DBG(cerr << "result: " << (yyval.boolean) << endl);
     }
     else {
         no_such_ident("identifier");
     }
 }
-#line 1561 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1554 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 10:
-#line 295 "ce_expr.yy" /* yacc.c:1667  */
+#line 286 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.boolean) = (yyvsp[0].boolean);
 }
-#line 1569 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1562 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 11:
-#line 299 "ce_expr.yy" /* yacc.c:1667  */
+#line 290 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.boolean) = (yyvsp[0].boolean);
 }
-#line 1577 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1570 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 12:
-#line 303 "ce_expr.yy" /* yacc.c:1667  */
+#line 294 "ce_expr.yy" /* yacc.c:1667  */
     {
     Array *array = dynamic_cast<Array*>((yyvsp[0].rval_ptr)->bvalue(*DDS(arg)));
     if (array) {
@@ -1586,8 +1579,7 @@ yyreduce:
            streamlines testing (and is likely what is intended). */
 
         array->set_send_p(true);
-        DDS(arg)
-            ->add_var_nocopy(array);
+        DDS(arg)->add_var_nocopy(array);
 
         return true;
     }
@@ -1596,74 +1588,67 @@ yyreduce:
         return false;
     }
 }
-#line 1600 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1592 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 13:
-#line 328 "ce_expr.yy" /* yacc.c:1667  */
+#line 318 "ce_expr.yy" /* yacc.c:1667  */
     {
-    (yyval.rval_ptr) = build_constant_array<dods_byte, Byte>((yyvsp[-1].byte_values), DDS(arg)
-                                               );
+    (yyval.rval_ptr) = build_constant_array<dods_byte, Byte>((yyvsp[-1].byte_values), DDS(arg));
 }
-#line 1609 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1600 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 14:
-#line 335 "ce_expr.yy" /* yacc.c:1667  */
+#line 324 "ce_expr.yy" /* yacc.c:1667  */
     {
-    (yyval.rval_ptr) = build_constant_array<dods_int16, Int16>((yyvsp[-1].int16_values), DDS(arg)
-                                                 );
+    (yyval.rval_ptr) = build_constant_array<dods_int16, Int16>((yyvsp[-1].int16_values), DDS(arg));
 }
-#line 1618 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1608 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 15:
-#line 342 "ce_expr.yy" /* yacc.c:1667  */
+#line 330 "ce_expr.yy" /* yacc.c:1667  */
     {
-    (yyval.rval_ptr) = build_constant_array<dods_uint16, UInt16>((yyvsp[-1].uint16_values), DDS(arg)
-                                                   );
+    (yyval.rval_ptr) = build_constant_array<dods_uint16, UInt16>((yyvsp[-1].uint16_values), DDS(arg));
 }
-#line 1627 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1616 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 16:
-#line 349 "ce_expr.yy" /* yacc.c:1667  */
+#line 336 "ce_expr.yy" /* yacc.c:1667  */
     {
-    (yyval.rval_ptr) = build_constant_array<dods_int32, Int32>((yyvsp[-1].int32_values), DDS(arg)
-                                                 );
+    (yyval.rval_ptr) = build_constant_array<dods_int32, Int32>((yyvsp[-1].int32_values), DDS(arg));
 }
-#line 1636 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1624 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 17:
-#line 356 "ce_expr.yy" /* yacc.c:1667  */
+#line 342 "ce_expr.yy" /* yacc.c:1667  */
     {
-    (yyval.rval_ptr) = build_constant_array<dods_uint32, UInt32>((yyvsp[-1].uint32_values), DDS(arg)
-                                                   );
+    (yyval.rval_ptr) = build_constant_array<dods_uint32, UInt32>((yyvsp[-1].uint32_values), DDS(arg));
 }
-#line 1645 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1632 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 18:
-#line 363 "ce_expr.yy" /* yacc.c:1667  */
+#line 348 "ce_expr.yy" /* yacc.c:1667  */
     {
-    (yyval.rval_ptr) = build_constant_array<dods_float32, Float32>((yyvsp[-1].float32_values), DDS(arg)
-                                                     );
+    (yyval.rval_ptr) = build_constant_array<dods_float32, Float32>((yyvsp[-1].float32_values), DDS(arg));
 }
-#line 1654 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1640 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 19:
-#line 370 "ce_expr.yy" /* yacc.c:1667  */
+#line 354 "ce_expr.yy" /* yacc.c:1667  */
     {
-    (yyval.rval_ptr) = build_constant_array<dods_float64, Float64>((yyvsp[-1].float64_values), DDS(arg)
-                                                     );
+    (yyval.rval_ptr) = build_constant_array<dods_float64, Float64>((yyvsp[-1].float64_values), DDS(arg));
 }
-#line 1663 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1648 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 20:
-#line 380 "ce_expr.yy" /* yacc.c:1667  */
+#line 363 "ce_expr.yy" /* yacc.c:1667  */
     {
     if (!check_int32((yyvsp[0].id)))
         throw Error(malformed_expr, "$<type>(hint, value, ...) special form expected hint to be an integer");
@@ -1671,179 +1656,179 @@ yyreduce:
     arg_length_hint_value = atoi((yyvsp[0].id));
     (yyval.boolean) = true;
 }
-#line 1675 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1660 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 21:
-#line 391 "ce_expr.yy" /* yacc.c:1667  */
+#line 374 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.byte_values) = make_fast_arg_list<byte_arg_list, dods_byte>(arg_length_hint_value, (yyvsp[0].byte_value));
 }
-#line 1683 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1668 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 22:
-#line 395 "ce_expr.yy" /* yacc.c:1667  */
+#line 378 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.byte_values) = make_fast_arg_list<byte_arg_list, dods_byte>((yyvsp[-2].byte_values), (yyvsp[0].byte_value));
 }
-#line 1691 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1676 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 23:
-#line 403 "ce_expr.yy" /* yacc.c:1667  */
+#line 386 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.byte_value) = strtol((yyvsp[0].id), 0, 0);
 }
-#line 1699 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1684 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 24:
-#line 410 "ce_expr.yy" /* yacc.c:1667  */
+#line 393 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.int16_values) = make_fast_arg_list<int16_arg_list, dods_int16>(arg_length_hint_value, (yyvsp[0].int16_value));
 }
-#line 1707 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1692 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 25:
-#line 414 "ce_expr.yy" /* yacc.c:1667  */
+#line 397 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.int16_values) = make_fast_arg_list<int16_arg_list, dods_int16>((yyvsp[-2].int16_values), (yyvsp[0].int16_value));
 }
-#line 1715 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1700 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 26:
-#line 422 "ce_expr.yy" /* yacc.c:1667  */
+#line 405 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.int16_value) = strtol((yyvsp[0].id), 0, 0);
 }
-#line 1723 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1708 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 27:
-#line 429 "ce_expr.yy" /* yacc.c:1667  */
+#line 412 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.uint16_values) = make_fast_arg_list<uint16_arg_list, dods_uint16>(arg_length_hint_value, (yyvsp[0].uint16_value));
 }
-#line 1731 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1716 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 28:
-#line 433 "ce_expr.yy" /* yacc.c:1667  */
+#line 416 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.uint16_values) = make_fast_arg_list<uint16_arg_list, dods_uint16>((yyvsp[-2].uint16_values), (yyvsp[0].uint16_value));
 }
-#line 1739 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1724 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 29:
-#line 441 "ce_expr.yy" /* yacc.c:1667  */
+#line 424 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.uint16_value) = strtoul((yyvsp[0].id), 0, 0);
 }
-#line 1747 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1732 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 30:
-#line 448 "ce_expr.yy" /* yacc.c:1667  */
+#line 431 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.int32_values) = make_fast_arg_list<int32_arg_list, dods_int32>(arg_length_hint_value, (yyvsp[0].int32_value));
 }
-#line 1755 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1740 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 31:
-#line 452 "ce_expr.yy" /* yacc.c:1667  */
+#line 435 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.int32_values) = make_fast_arg_list<int32_arg_list, dods_int32>((yyvsp[-2].int32_values), (yyvsp[0].int32_value));
 }
-#line 1763 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1748 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 32:
-#line 460 "ce_expr.yy" /* yacc.c:1667  */
+#line 443 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.int32_value) = strtol((yyvsp[0].id), 0, 0);
 }
-#line 1771 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1756 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 33:
-#line 467 "ce_expr.yy" /* yacc.c:1667  */
+#line 450 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.uint32_values) = make_fast_arg_list<uint32_arg_list, dods_uint32>(arg_length_hint_value, (yyvsp[0].uint32_value));
 }
-#line 1779 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1764 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 34:
-#line 471 "ce_expr.yy" /* yacc.c:1667  */
+#line 454 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.uint32_values) = make_fast_arg_list<uint32_arg_list, dods_uint32>((yyvsp[-2].uint32_values), (yyvsp[0].uint32_value));
 }
-#line 1787 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1772 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 35:
-#line 479 "ce_expr.yy" /* yacc.c:1667  */
+#line 462 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.uint32_value) = strtoul((yyvsp[0].id), 0, 0);
 }
-#line 1795 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1780 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 36:
-#line 486 "ce_expr.yy" /* yacc.c:1667  */
+#line 469 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.float32_values) = make_fast_arg_list<float32_arg_list, dods_float32>(arg_length_hint_value, (yyvsp[0].float32_value));
 }
-#line 1803 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1788 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 37:
-#line 490 "ce_expr.yy" /* yacc.c:1667  */
+#line 473 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.float32_values) = make_fast_arg_list<float32_arg_list, dods_float32>((yyvsp[-2].float32_values), (yyvsp[0].float32_value));
 }
-#line 1811 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1796 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 38:
-#line 498 "ce_expr.yy" /* yacc.c:1667  */
+#line 481 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.float32_value) = strtof((yyvsp[0].id), 0);
 }
-#line 1819 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1804 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 39:
-#line 505 "ce_expr.yy" /* yacc.c:1667  */
+#line 488 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.float64_values) = make_fast_arg_list<float64_arg_list, dods_float64>(arg_length_hint_value, (yyvsp[0].float64_value));
 }
-#line 1827 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1812 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 40:
-#line 509 "ce_expr.yy" /* yacc.c:1667  */
+#line 492 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.float64_values) = make_fast_arg_list<float64_arg_list, dods_float64>((yyvsp[-2].float64_values), (yyvsp[0].float64_value));
 }
-#line 1835 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1820 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 41:
-#line 517 "ce_expr.yy" /* yacc.c:1667  */
+#line 500 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.float64_value) = strtod((yyvsp[0].id), 0);
 }
-#line 1843 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1828 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 42:
-#line 524 "ce_expr.yy" /* yacc.c:1667  */
+#line 507 "ce_expr.yy" /* yacc.c:1667  */
     {
     proj_func p_f = 0;
     btp_func f = 0;
@@ -1864,19 +1849,19 @@ yyreduce:
         no_such_func();
     }
 }
-#line 1868 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1853 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 44:
-#line 548 "ce_expr.yy" /* yacc.c:1667  */
+#line 531 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.boolean) = (yyvsp[-2].boolean) && (yyvsp[0].boolean);
 }
-#line 1876 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1861 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 45:
-#line 554 "ce_expr.yy" /* yacc.c:1667  */
+#line 537 "ce_expr.yy" /* yacc.c:1667  */
     {
     if ((yyvsp[-4].rval_ptr)) {
         EVALUATOR(arg)->append_clause((yyvsp[-3].op), (yyvsp[-4].rval_ptr), (yyvsp[-1].r_val_l_ptr));
@@ -1885,11 +1870,11 @@ yyreduce:
     else
         (yyval.boolean) = false;
 }
-#line 1889 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1874 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 46:
-#line 563 "ce_expr.yy" /* yacc.c:1667  */
+#line 546 "ce_expr.yy" /* yacc.c:1667  */
     {
     if ((yyvsp[-2].rval_ptr)) {
         rvalue_list *rv = new rvalue_list;
@@ -1900,19 +1885,19 @@ yyreduce:
     else
         (yyval.boolean) = false;
 }
-#line 1904 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1889 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 47:
-#line 574 "ce_expr.yy" /* yacc.c:1667  */
+#line 557 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.boolean) = (yyvsp[0].boolean);
 }
-#line 1912 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1897 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 48:
-#line 581 "ce_expr.yy" /* yacc.c:1667  */
+#line 564 "ce_expr.yy" /* yacc.c:1667  */
     {
     bool_func b_func = get_function((*EVALUATOR(arg)), (yyvsp[-3].id));
     if (!b_func) {
@@ -1923,11 +1908,11 @@ yyreduce:
         (yyval.boolean) = true;
     }
 }
-#line 1927 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1912 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 50:
-#line 596 "ce_expr.yy" /* yacc.c:1667  */
+#line 579 "ce_expr.yy" /* yacc.c:1667  */
     {
     btp_func func = get_btp_function((*EVALUATOR(arg)), (yyvsp[-3].id));
     if (func) {
@@ -1937,65 +1922,65 @@ yyreduce:
         no_such_func();
     }
 }
-#line 1941 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1926 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 51:
-#line 606 "ce_expr.yy" /* yacc.c:1667  */
+#line 589 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.rval_ptr) = (yyvsp[0].rval_ptr);
 }
-#line 1949 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1934 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 52:
-#line 610 "ce_expr.yy" /* yacc.c:1667  */
+#line 593 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.rval_ptr) = (yyvsp[0].rval_ptr);
 }
-#line 1957 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1942 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 53:
-#line 616 "ce_expr.yy" /* yacc.c:1667  */
+#line 599 "ce_expr.yy" /* yacc.c:1667  */
     {
     if ((yyvsp[0].rval_ptr))
         (yyval.r_val_l_ptr) = make_rvalue_list((yyvsp[0].rval_ptr));
     else
         (yyval.r_val_l_ptr) = 0;
 }
-#line 1968 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1953 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 54:
-#line 623 "ce_expr.yy" /* yacc.c:1667  */
+#line 606 "ce_expr.yy" /* yacc.c:1667  */
     {
     if ((yyvsp[-2].r_val_l_ptr) && (yyvsp[0].rval_ptr))
         (yyval.r_val_l_ptr) = append_rvalue_list((yyvsp[-2].r_val_l_ptr), (yyvsp[0].rval_ptr));
     else
         (yyval.r_val_l_ptr) = 0;
 }
-#line 1979 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1964 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 55:
-#line 632 "ce_expr.yy" /* yacc.c:1667  */
+#line 615 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.r_val_l_ptr) = (yyvsp[0].r_val_l_ptr);
 }
-#line 1987 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1972 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 56:
-#line 636 "ce_expr.yy" /* yacc.c:1667  */
+#line 619 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.r_val_l_ptr) = 0;
 }
-#line 1995 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 1980 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 57:
-#line 642 "ce_expr.yy" /* yacc.c:1667  */
+#line 625 "ce_expr.yy" /* yacc.c:1667  */
     {
     BaseType *btp = DDS(arg)->var(www2id((yyvsp[0].id)));
     if (btp) {
@@ -2029,11 +2014,11 @@ yyreduce:
         (yyval.rval_ptr) = new rvalue(btp);
     }
 }
-#line 2033 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 2018 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 58:
-#line 676 "ce_expr.yy" /* yacc.c:1667  */
+#line 659 "ce_expr.yy" /* yacc.c:1667  */
     {
     if ((yyvsp[0].str) == 0 || (yyvsp[0].str)->empty())
         ce_exprerror("Malformed string");
@@ -2055,6 +2040,7 @@ yyreduce:
 #endif
         var = make_variable((*EVALUATOR(arg)), tmp);
         (yyval.rval_ptr) = new rvalue(var);
+        delete (tmp.v.s);
     }
     // When the scanner (ce_expr.lex) returns the SCAN_STR token type
     // it makes a local copy of the string in a new std::string object
@@ -2062,11 +2048,11 @@ yyreduce:
     // See ticket 2240. jhrg 7/30/14
     delete (yyvsp[0].str);
 }
-#line 2066 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 2052 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 59:
-#line 710 "ce_expr.yy" /* yacc.c:1667  */
+#line 694 "ce_expr.yy" /* yacc.c:1667  */
     {
     if (!bracket_projection((*DDS(arg)), (yyvsp[-1].id), (yyvsp[0].slices_ptr)))
         no_such_ident("array, grid or sequence");
@@ -2074,19 +2060,19 @@ yyreduce:
     DDS(arg)->mark((yyvsp[-1].id), true);
     (yyval.rval_ptr) = new rvalue(DDS(arg)->var((yyvsp[-1].id)));
 }
-#line 2078 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 2064 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 60:
-#line 720 "ce_expr.yy" /* yacc.c:1667  */
+#line 704 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.boolean) = (*DDS(arg)).mark((yyvsp[0].id), true);
 }
-#line 2086 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 2072 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 61:
-#line 726 "ce_expr.yy" /* yacc.c:1667  */
+#line 710 "ce_expr.yy" /* yacc.c:1667  */
     {
     if (!bracket_projection((*DDS(arg)), (yyvsp[-1].id), (yyvsp[0].slices_ptr)))
         no_such_ident("array, grid or sequence");
@@ -2094,21 +2080,21 @@ yyreduce:
     strncpy((yyval.id), (yyvsp[-1].id), ID_MAX-1);
     (yyval.id)[ID_MAX-1] = '\0';
 }
-#line 2098 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 2084 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 62:
-#line 734 "ce_expr.yy" /* yacc.c:1667  */
+#line 718 "ce_expr.yy" /* yacc.c:1667  */
     {
     string name = string((yyvsp[-1].id)).append((yyvsp[0].id)); //  + string($2);
     strncpy((yyval.id), name.c_str(), ID_MAX-1);
     (yyval.id)[ID_MAX-1] = '\0';
 }
-#line 2108 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 2094 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 63:
-#line 740 "ce_expr.yy" /* yacc.c:1667  */
+#line 724 "ce_expr.yy" /* yacc.c:1667  */
     {
     string name = string((yyvsp[-2].id)).append((yyvsp[-1].id)); // + string($2);
     if (!bracket_projection((*DDS(arg)), name.c_str(), (yyvsp[0].slices_ptr)))
@@ -2117,20 +2103,20 @@ yyreduce:
     strncpy((yyval.id), name.c_str(), ID_MAX-1);
     (yyval.id)[ID_MAX-1] = '\0';
 }
-#line 2121 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 2107 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 64:
-#line 751 "ce_expr.yy" /* yacc.c:1667  */
+#line 735 "ce_expr.yy" /* yacc.c:1667  */
     {
     strncpy((yyval.id), www2id((yyvsp[0].id)).c_str(), ID_MAX-1);
     (yyval.id)[ID_MAX-1] = '\0';
 }
-#line 2130 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 2116 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 65:
-#line 756 "ce_expr.yy" /* yacc.c:1667  */
+#line 740 "ce_expr.yy" /* yacc.c:1667  */
     {
     if ((yyvsp[0].str) == 0 || (yyvsp[0].str)->empty())
         ce_exprerror("Malformed string");
@@ -2142,27 +2128,27 @@ yyreduce:
 
     (yyval.id)[ID_MAX-1] = '\0';
 }
-#line 2146 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 2132 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 66:
-#line 770 "ce_expr.yy" /* yacc.c:1667  */
+#line 754 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.slices_ptr) = make_array_slices((yyvsp[0].dim_slice_ptr));
 }
-#line 2154 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 2140 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 67:
-#line 774 "ce_expr.yy" /* yacc.c:1667  */
+#line 758 "ce_expr.yy" /* yacc.c:1667  */
     {
     (yyval.slices_ptr) = append_array_slices((yyvsp[-1].slices_ptr), (yyvsp[0].dim_slice_ptr));
 }
-#line 2162 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 2148 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 68:
-#line 788 "ce_expr.yy" /* yacc.c:1667  */
+#line 772 "ce_expr.yy" /* yacc.c:1667  */
     {
     if (!check_uint32((yyvsp[-1].id)))
         throw Error(malformed_expr, "Expected an array index.");
@@ -2174,11 +2160,11 @@ yyreduce:
     value i((yyvsp[-1].id), false, dods_uint32_c);
     (yyval.dim_slice_ptr) = make_array_slice(i);
 }
-#line 2178 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 2164 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 69:
-#line 800 "ce_expr.yy" /* yacc.c:1667  */
+#line 784 "ce_expr.yy" /* yacc.c:1667  */
     {
 #if 0
     value i;
@@ -2189,11 +2175,11 @@ yyreduce:
 #endif
     (yyval.dim_slice_ptr) = make_array_slice(i);
 }
-#line 2193 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 2179 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 70:
-#line 811 "ce_expr.yy" /* yacc.c:1667  */
+#line 795 "ce_expr.yy" /* yacc.c:1667  */
     {
     if (!check_uint32((yyvsp[-3].id)))
         throw Error(malformed_expr, "Expected an array index.");
@@ -2211,11 +2197,11 @@ yyreduce:
 
     (yyval.dim_slice_ptr) = make_array_slice(i, j);
 }
-#line 2215 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 2201 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 71:
-#line 829 "ce_expr.yy" /* yacc.c:1667  */
+#line 813 "ce_expr.yy" /* yacc.c:1667  */
     {
     // TODO These tests are redundant - the value ctor performs them, too
     if (!(check_int32((yyvsp[-6].id)) || check_float64((yyvsp[-6].id))))
@@ -2236,11 +2222,11 @@ yyreduce:
 
     (yyval.dim_slice_ptr) = make_array_slice(i, j);
 }
-#line 2240 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 2226 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 72:
-#line 850 "ce_expr.yy" /* yacc.c:1667  */
+#line 834 "ce_expr.yy" /* yacc.c:1667  */
     {
     if (!check_uint32((yyvsp[-3].id)))
         throw Error(malformed_expr, "Expected an array index.");
@@ -2257,11 +2243,11 @@ yyreduce:
 
     (yyval.dim_slice_ptr) = make_array_slice(i, j);
 }
-#line 2261 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 2247 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 73:
-#line 867 "ce_expr.yy" /* yacc.c:1667  */
+#line 851 "ce_expr.yy" /* yacc.c:1667  */
     {
     if (!check_uint32((yyvsp[-5].id)))
         throw Error(malformed_expr, "Expected an array index.");
@@ -2283,11 +2269,11 @@ yyreduce:
 
     (yyval.dim_slice_ptr) = make_array_slice(i, j, k);
 }
-#line 2287 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 2273 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 74:
-#line 889 "ce_expr.yy" /* yacc.c:1667  */
+#line 873 "ce_expr.yy" /* yacc.c:1667  */
     {
     if (!check_uint32((yyvsp[-5].id)))
         throw Error(malformed_expr, "Expected an array index.");
@@ -2300,11 +2286,11 @@ yyreduce:
 
     (yyval.dim_slice_ptr) = make_array_slice(i, j, k);
 }
-#line 2304 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 2290 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
 
-#line 2308 "ce_expr.tab.cc" /* yacc.c:1667  */
+#line 2294 "ce_expr.tab.cc" /* yacc.c:1667  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2535,7 +2521,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 912 "ce_expr.yy" /* yacc.c:1918  */
+#line 896 "ce_expr.yy" /* yacc.c:1918  */
 
 
 // All these error reporting function now throw instances of Error. The expr
@@ -2609,7 +2595,7 @@ bool bracket_projection(DDS &table, const char *name, slices *s)
                9/1/98 jhrg */
             /* var->set_send_p(true); */
             //table.mark(name, true);
-            // We don't call mark() here for an array. Instead it is called from
+            // We don't call mark() here for an array, instead it is called from
             // within the parser. jhrg 10/10/08
             process_array_slices(var, s); // throws on error
         }
@@ -2652,7 +2638,7 @@ bool bracket_projection(DDS &table, const char *name, slices *s)
 dim_slice *
 make_array_slice(value &v1, value &v2, value &v3)
 {
-    auto_ptr<dim_slice> ds(new dim_slice);
+    unique_ptr<dim_slice> ds(new dim_slice);
     ds->push_back(v1);
     ds->push_back(v2);
     ds->push_back(v3);
@@ -2706,7 +2692,7 @@ make_array_slice(value &v1)
 slices *
 make_array_slices(dim_slice *ds)
 {
-    auto_ptr<slices> s(new slices);
+    unique_ptr<slices> s(new slices);
     s->push_back(ds);
     return s.release();
 }
@@ -2791,7 +2777,7 @@ void process_array_slices(BaseType *variable, slices *s)
     for (; p != s->end() && r != a->dim_end(); p++, r++) {
         dim_slice *ds = *p;
 
-	dim_slice::iterator q = ds->begin();
+	    dim_slice::iterator q = ds->begin();
         assert(q != ds->end());
 
         int start = q->v.i;
@@ -2821,6 +2807,16 @@ void process_array_slices(BaseType *variable, slices *s)
             && (a->dimension_start(r, true) != start || (a->dimension_stop(r, true) != stop && stop != -1) || a->dimension_stride(r, true) != stride))
             throw Error(malformed_expr, string("One or more Array variables were projected multiple times in the constraint expression."));
 
+        // Add a fix for ticket 'With constraint indices are reversed, the server fails'
+        // (https://bugs.earthdata.nasa.gov/browse/HYRAX-540). Note that the values can be the
+        // same (e.g., [0:1:0]) and the stride may be larger than the difference between
+        // start and stop - one value will be sent. jhrg 2/2/22
+        // The '&& stop != -1' is a hack - we added '*' after the fact to DAP2 and use -1
+        // as the value of stop to signal that. So in that case start > stop will be true,
+        // but the constraint is valid and we should not throw an exception. jhrg 2/4/22
+        if (start > stop && stop != -1)
+            throw Error(malformed_expr, string("The start value of an array index is past the stop value."));
+
         a->add_constraint(r, start, stride, stop);
 
         DBG(cerr << "Set Constraint: " << a->dimension_size(r, true) << endl);
@@ -2976,6 +2972,9 @@ void process_sequence_slices(BaseType *variable, slices *s)
     else
         throw Error(string("Expected an integer value for the bracket subset operator used with Sequence '") + seq->name() + "'.");
 
+    if (start > stop)
+        throw Error(malformed_expr, string("The start value of an index into a sequence is past the stop value."));
+
     seq->set_row_number_constraint(start, stop, stride);
 }
 
