@@ -41,7 +41,7 @@
 
 
 // Unqualified %code blocks.
-#line 79 "d4_function_parser.yy" // lalr1.cc:435
+#line 80 "d4_function_parser.yy" // lalr1.cc:435
 
     #include "BaseType.h"
     #include "DMR.h"
@@ -154,7 +154,7 @@
 #define YYERROR         goto yyerrorlab
 #define YYRECOVERING()  (!!yyerrstatus_)
 
-#line 34 "d4_function_parser.yy" // lalr1.cc:510
+#line 35 "d4_function_parser.yy" // lalr1.cc:510
 namespace libdap {
 #line 160 "d4_function_parser.tab.cc" // lalr1.cc:510
 
@@ -1031,7 +1031,7 @@ namespace libdap {
 
 
     // User initialization code.
-#line 71 "d4_function_parser.yy" // lalr1.cc:791
+#line 72 "d4_function_parser.yy" // lalr1.cc:791
 {
     // Initialize the initial location. This is printed when the parser builds
     // its own error messages - when the parse fails as opposed to when the 
@@ -1243,7 +1243,7 @@ namespace libdap {
           switch (yyn)
             {
   case 2:
-#line 158 "d4_function_parser.yy" // lalr1.cc:919
+#line 159 "d4_function_parser.yy" // lalr1.cc:919
     { 
     evaluator.set_result(yystack_[0].value.as < D4RValueList* > ()); 
 }
@@ -1251,7 +1251,7 @@ namespace libdap {
     break;
 
   case 3:
-#line 164 "d4_function_parser.yy" // lalr1.cc:919
+#line 165 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < D4RValueList* > () = new D4RValueList(yystack_[0].value.as < D4RValue* > ()); 
 }
@@ -1259,7 +1259,7 @@ namespace libdap {
     break;
 
   case 4:
-#line 168 "d4_function_parser.yy" // lalr1.cc:919
+#line 169 "d4_function_parser.yy" // lalr1.cc:919
     { 
     yystack_[2].value.as < D4RValueList* > ()->add_rvalue(yystack_[0].value.as < D4RValue* > ());
     yylhs.value.as < D4RValueList* > () = yystack_[2].value.as < D4RValueList* > (); 
@@ -1268,7 +1268,7 @@ namespace libdap {
     break;
 
   case 5:
-#line 175 "d4_function_parser.yy" // lalr1.cc:919
+#line 176 "d4_function_parser.yy" // lalr1.cc:919
     { 
     yylhs.value.as < D4RValue* > () = new D4RValue(yystack_[3].value.as < D4Function > (), yystack_[1].value.as < D4RValueList* > ()); // Build a D4RValue from a D4Function pointer and a D4RValueList 
 }
@@ -1276,7 +1276,7 @@ namespace libdap {
     break;
 
   case 6:
-#line 181 "d4_function_parser.yy" // lalr1.cc:919
+#line 182 "d4_function_parser.yy" // lalr1.cc:919
     { 
     D4Function f;
     if (!evaluator.sf_list()->find_function(yystack_[0].value.as < std::string > (), &f)) {
@@ -1290,7 +1290,7 @@ namespace libdap {
     break;
 
   case 7:
-#line 193 "d4_function_parser.yy" // lalr1.cc:919
+#line 194 "d4_function_parser.yy" // lalr1.cc:919
     { 
     yylhs.value.as < D4RValueList* > () = new D4RValueList(yystack_[0].value.as < D4RValue* > ()); // build a D4RValueList from the D4RValue
 }
@@ -1298,7 +1298,7 @@ namespace libdap {
     break;
 
   case 8:
-#line 197 "d4_function_parser.yy" // lalr1.cc:919
+#line 198 "d4_function_parser.yy" // lalr1.cc:919
     { 
     yystack_[2].value.as < D4RValueList* > ()->add_rvalue(yystack_[0].value.as < D4RValue* > ());
     yylhs.value.as < D4RValueList* > () = yystack_[2].value.as < D4RValueList* > (); // Append the D4RValue ($3) to the D4RValueList ($1), then return
@@ -1307,7 +1307,7 @@ namespace libdap {
     break;
 
   case 9:
-#line 204 "d4_function_parser.yy" // lalr1.cc:919
+#line 205 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < D4RValue* > () = yystack_[0].value.as < D4RValue* > ();
 }
@@ -1315,7 +1315,7 @@ namespace libdap {
     break;
 
   case 10:
-#line 208 "d4_function_parser.yy" // lalr1.cc:919
+#line 209 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < D4RValue* > () = yystack_[0].value.as < D4RValue* > ();
 }
@@ -1323,7 +1323,7 @@ namespace libdap {
     break;
 
   case 11:
-#line 212 "d4_function_parser.yy" // lalr1.cc:919
+#line 213 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < D4RValue* > () = yystack_[0].value.as < D4RValue* > ();
 }
@@ -1331,7 +1331,7 @@ namespace libdap {
     break;
 
   case 12:
-#line 216 "d4_function_parser.yy" // lalr1.cc:919
+#line 217 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < D4RValue* > () = 0;
 }
@@ -1339,377 +1339,379 @@ namespace libdap {
     break;
 
   case 13:
-#line 222 "d4_function_parser.yy" // lalr1.cc:919
+#line 223 "d4_function_parser.yy" // lalr1.cc:919
     {
     D4RValue *rvalue = evaluator.build_rvalue(yystack_[0].value.as < std::string > ());
     if (!rvalue) {
-        throw Error(malformed_expr, "'" + yystack_[0].value.as < std::string > () + "' is not a variable, number or string.");
+        // Do not echo value from the CE in an error message. This
+        // change to prevent xss attacks. jhrg 4/14/20
+        throw Error(malformed_expr, "A function argument was not a variable, number or string.");
     }
     
     yylhs.value.as < D4RValue* > () = rvalue;
 }
-#line 1352 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1354 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 14:
-#line 234 "d4_function_parser.yy" // lalr1.cc:919
+#line 237 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_byte>* > ()));
     delete yystack_[1].value.as < std::vector<dods_byte>* > ();
 }
-#line 1361 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1363 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 15:
-#line 240 "d4_function_parser.yy" // lalr1.cc:919
+#line 243 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_byte>* > ()));
     delete yystack_[1].value.as < std::vector<dods_byte>* > ();
 }
-#line 1370 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1372 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 16:
-#line 246 "d4_function_parser.yy" // lalr1.cc:919
+#line 249 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_int8>* > ()));
     delete yystack_[1].value.as < std::vector<dods_int8>* > ();
 }
-#line 1379 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1381 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 17:
-#line 252 "d4_function_parser.yy" // lalr1.cc:919
+#line 255 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_uint16>* > ()));
     delete yystack_[1].value.as < std::vector<dods_uint16>* > ();
 }
-#line 1388 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1390 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 18:
-#line 258 "d4_function_parser.yy" // lalr1.cc:919
+#line 261 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_int16>* > ()));
     delete yystack_[1].value.as < std::vector<dods_int16>* > ();
 }
-#line 1397 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1399 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 19:
-#line 264 "d4_function_parser.yy" // lalr1.cc:919
+#line 267 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_uint32>* > ()));
     delete yystack_[1].value.as < std::vector<dods_uint32>* > ();
 }
-#line 1406 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1408 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 20:
-#line 270 "d4_function_parser.yy" // lalr1.cc:919
+#line 273 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_int32>* > ()));
     delete yystack_[1].value.as < std::vector<dods_int32>* > ();
 }
-#line 1415 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1417 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 21:
-#line 276 "d4_function_parser.yy" // lalr1.cc:919
+#line 279 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_uint64>* > ()));
     delete yystack_[1].value.as < std::vector<dods_uint64>* > ();
 }
-#line 1424 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1426 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 22:
-#line 282 "d4_function_parser.yy" // lalr1.cc:919
+#line 285 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_int64>* > ()));
     delete yystack_[1].value.as < std::vector<dods_int64>* > ();
 }
-#line 1433 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1435 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 23:
-#line 288 "d4_function_parser.yy" // lalr1.cc:919
+#line 291 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_float32>* > ()));
     delete yystack_[1].value.as < std::vector<dods_float32>* > ();
 }
-#line 1442 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1444 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 24:
-#line 294 "d4_function_parser.yy" // lalr1.cc:919
+#line 297 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_float64>* > ()));
     delete yystack_[1].value.as < std::vector<dods_float64>* > ();
 }
-#line 1451 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1453 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 25:
-#line 306 "d4_function_parser.yy" // lalr1.cc:919
+#line 309 "d4_function_parser.yy" // lalr1.cc:919
     {
     evaluator.set_arg_length_hint(get_uint64(yystack_[0].value.as < std::string > ().c_str()));
 }
-#line 1459 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1461 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 26:
-#line 312 "d4_function_parser.yy" // lalr1.cc:919
+#line 315 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::vector<dods_byte>* > () = evaluator.init_arg_list(dods_byte(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
 }
-#line 1467 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1469 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 27:
-#line 316 "d4_function_parser.yy" // lalr1.cc:919
+#line 319 "d4_function_parser.yy" // lalr1.cc:919
     {
     yystack_[2].value.as < std::vector<dods_byte>* > ()->push_back(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
     yylhs.value.as < std::vector<dods_byte>* > () = yystack_[2].value.as < std::vector<dods_byte>* > ();
 }
-#line 1476 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1478 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 28:
-#line 323 "d4_function_parser.yy" // lalr1.cc:919
+#line 326 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::vector<dods_int8>* > () = evaluator.init_arg_list(dods_int8(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
 }
-#line 1484 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1486 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 29:
-#line 327 "d4_function_parser.yy" // lalr1.cc:919
+#line 330 "d4_function_parser.yy" // lalr1.cc:919
     {
     yystack_[2].value.as < std::vector<dods_int8>* > ()->push_back(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
     yylhs.value.as < std::vector<dods_int8>* > () = yystack_[2].value.as < std::vector<dods_int8>* > ();
 }
-#line 1493 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1495 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 30:
-#line 334 "d4_function_parser.yy" // lalr1.cc:919
+#line 337 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::vector<dods_uint16>* > () = evaluator.init_arg_list(dods_uint16(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
 }
-#line 1501 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1503 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 31:
-#line 338 "d4_function_parser.yy" // lalr1.cc:919
+#line 341 "d4_function_parser.yy" // lalr1.cc:919
     {
     yystack_[2].value.as < std::vector<dods_uint16>* > ()->push_back(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
     yylhs.value.as < std::vector<dods_uint16>* > () = yystack_[2].value.as < std::vector<dods_uint16>* > ();
 }
-#line 1510 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1512 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 32:
-#line 345 "d4_function_parser.yy" // lalr1.cc:919
+#line 348 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::vector<dods_int16>* > () = evaluator.init_arg_list(dods_int16(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
 }
-#line 1518 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1520 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 33:
-#line 349 "d4_function_parser.yy" // lalr1.cc:919
+#line 352 "d4_function_parser.yy" // lalr1.cc:919
     {
     yystack_[2].value.as < std::vector<dods_int16>* > ()->push_back(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
     yylhs.value.as < std::vector<dods_int16>* > () = yystack_[2].value.as < std::vector<dods_int16>* > ();
 }
-#line 1527 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1529 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 34:
-#line 356 "d4_function_parser.yy" // lalr1.cc:919
+#line 359 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::vector<dods_uint32>* > () = evaluator.init_arg_list(dods_uint32(strtoul(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
 }
-#line 1535 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1537 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 35:
-#line 360 "d4_function_parser.yy" // lalr1.cc:919
+#line 363 "d4_function_parser.yy" // lalr1.cc:919
     {
     yystack_[2].value.as < std::vector<dods_uint32>* > ()->push_back(strtoul(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
     yylhs.value.as < std::vector<dods_uint32>* > () = yystack_[2].value.as < std::vector<dods_uint32>* > ();
 }
-#line 1544 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1546 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 36:
-#line 366 "d4_function_parser.yy" // lalr1.cc:919
+#line 369 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::vector<dods_int32>* > () = evaluator.init_arg_list(dods_int32(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
 }
-#line 1552 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1554 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 37:
-#line 370 "d4_function_parser.yy" // lalr1.cc:919
+#line 373 "d4_function_parser.yy" // lalr1.cc:919
     {
     yystack_[2].value.as < std::vector<dods_int32>* > ()->push_back(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
     yylhs.value.as < std::vector<dods_int32>* > () = yystack_[2].value.as < std::vector<dods_int32>* > ();
 }
-#line 1561 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1563 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 38:
-#line 377 "d4_function_parser.yy" // lalr1.cc:919
+#line 380 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::vector<dods_uint64>* > () = evaluator.init_arg_list(dods_uint64(strtoull(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
 }
-#line 1569 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1571 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 39:
-#line 381 "d4_function_parser.yy" // lalr1.cc:919
+#line 384 "d4_function_parser.yy" // lalr1.cc:919
     {
     yystack_[2].value.as < std::vector<dods_uint64>* > ()->push_back(strtoull(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
     yylhs.value.as < std::vector<dods_uint64>* > () = yystack_[2].value.as < std::vector<dods_uint64>* > ();
 }
-#line 1578 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1580 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 40:
-#line 388 "d4_function_parser.yy" // lalr1.cc:919
+#line 391 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::vector<dods_int64>* > () = evaluator.init_arg_list(dods_int64(strtoll(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
 }
-#line 1586 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1588 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 41:
-#line 392 "d4_function_parser.yy" // lalr1.cc:919
+#line 395 "d4_function_parser.yy" // lalr1.cc:919
     {
     yystack_[2].value.as < std::vector<dods_int64>* > ()->push_back(strtoll(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
     yylhs.value.as < std::vector<dods_int64>* > () = yystack_[2].value.as < std::vector<dods_int64>* > ();
 }
-#line 1595 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1597 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 42:
-#line 402 "d4_function_parser.yy" // lalr1.cc:919
+#line 405 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::vector<dods_float32>* > () = evaluator.init_arg_list(dods_float32(strtof(yystack_[0].value.as < std::string > ().c_str(), 0)));
 }
-#line 1603 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1605 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 43:
-#line 406 "d4_function_parser.yy" // lalr1.cc:919
+#line 409 "d4_function_parser.yy" // lalr1.cc:919
     {
     yystack_[2].value.as < std::vector<dods_float32>* > ()->push_back(strtof(yystack_[0].value.as < std::string > ().c_str(), 0));
     yylhs.value.as < std::vector<dods_float32>* > () = yystack_[2].value.as < std::vector<dods_float32>* > ();
 }
-#line 1612 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1614 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 44:
-#line 413 "d4_function_parser.yy" // lalr1.cc:919
+#line 416 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::vector<dods_float64>* > () = evaluator.init_arg_list(dods_float64(strtod(yystack_[0].value.as < std::string > ().c_str(), 0)));
 }
-#line 1620 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1622 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 45:
-#line 417 "d4_function_parser.yy" // lalr1.cc:919
+#line 420 "d4_function_parser.yy" // lalr1.cc:919
     {
     yystack_[2].value.as < std::vector<dods_float64>* > ()->push_back(strtod(yystack_[0].value.as < std::string > ().c_str(), 0));
     yylhs.value.as < std::vector<dods_float64>* > () = yystack_[2].value.as < std::vector<dods_float64>* > ();
 }
-#line 1629 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1631 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 46:
-#line 424 "d4_function_parser.yy" // lalr1.cc:919
+#line 427 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::string > () = yystack_[0].value.as < std::string > ();
 }
-#line 1637 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1639 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 47:
-#line 428 "d4_function_parser.yy" // lalr1.cc:919
+#line 431 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::string > ().append("/");
     yylhs.value.as < std::string > ().append(yystack_[0].value.as < std::string > ());
 }
-#line 1646 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1648 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 48:
-#line 433 "d4_function_parser.yy" // lalr1.cc:919
+#line 436 "d4_function_parser.yy" // lalr1.cc:919
     {
     yystack_[2].value.as < std::string > ().append("/");
     yystack_[2].value.as < std::string > ().append(yystack_[0].value.as < std::string > ());
     yylhs.value.as < std::string > () = yystack_[2].value.as < std::string > ();
 }
-#line 1656 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1658 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 49:
-#line 441 "d4_function_parser.yy" // lalr1.cc:919
+#line 444 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::string > ().append("/");
     yylhs.value.as < std::string > ().append(yystack_[0].value.as < std::string > ());
 }
-#line 1665 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1667 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 50:
-#line 446 "d4_function_parser.yy" // lalr1.cc:919
+#line 449 "d4_function_parser.yy" // lalr1.cc:919
     {
     yystack_[2].value.as < std::string > ().append(".");
     yystack_[2].value.as < std::string > ().append(yystack_[0].value.as < std::string > ());
     yylhs.value.as < std::string > () = yystack_[2].value.as < std::string > ();
 }
-#line 1675 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1677 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 51:
-#line 454 "d4_function_parser.yy" // lalr1.cc:919
+#line 457 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::string > () = yystack_[0].value.as < std::string > ();
 }
-#line 1683 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1685 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 52:
-#line 458 "d4_function_parser.yy" // lalr1.cc:919
+#line 461 "d4_function_parser.yy" // lalr1.cc:919
     {
     yystack_[2].value.as < std::string > ().append(".");
     yystack_[2].value.as < std::string > ().append(yystack_[0].value.as < std::string > ());
     yylhs.value.as < std::string > () = yystack_[2].value.as < std::string > ();
 }
-#line 1693 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1695 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 53:
-#line 469 "d4_function_parser.yy" // lalr1.cc:919
+#line 472 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::string > ()=yystack_[0].value.as < std::string > ();
 }
-#line 1701 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1703 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 54:
-#line 473 "d4_function_parser.yy" // lalr1.cc:919
+#line 476 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::string > ()=yystack_[0].value.as < std::string > ();
 }
-#line 1709 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1711 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
 
-#line 1713 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1715 "d4_function_parser.tab.cc" // lalr1.cc:919
             default:
               break;
             }
@@ -2140,12 +2142,12 @@ namespace libdap {
   const unsigned short
   D4FunctionParser::yyrline_[] =
   {
-       0,   157,   157,   163,   167,   174,   180,   192,   196,   203,
-     207,   211,   216,   221,   233,   239,   245,   251,   257,   263,
-     269,   275,   281,   287,   293,   305,   311,   315,   322,   326,
-     333,   337,   344,   348,   355,   359,   365,   369,   376,   380,
-     387,   391,   401,   405,   412,   416,   423,   427,   432,   440,
-     445,   453,   457,   468,   472
+       0,   158,   158,   164,   168,   175,   181,   193,   197,   204,
+     208,   212,   217,   222,   236,   242,   248,   254,   260,   266,
+     272,   278,   284,   290,   296,   308,   314,   318,   325,   329,
+     336,   340,   347,   351,   358,   362,   368,   372,   379,   383,
+     390,   394,   404,   408,   415,   419,   426,   430,   435,   443,
+     448,   456,   460,   471,   475
   };
 
   // Print the state stack on the debug stream.
@@ -2228,10 +2230,10 @@ namespace libdap {
       return undef_token_;
   }
 
-#line 34 "d4_function_parser.yy" // lalr1.cc:1242
+#line 35 "d4_function_parser.yy" // lalr1.cc:1242
 } // libdap
-#line 2234 "d4_function_parser.tab.cc" // lalr1.cc:1242
-#line 478 "d4_function_parser.yy" // lalr1.cc:1243
+#line 2236 "d4_function_parser.tab.cc" // lalr1.cc:1242
+#line 481 "d4_function_parser.yy" // lalr1.cc:1243
 
 
 // Forward the error to the driver for handling. The location parameter
