@@ -62,7 +62,8 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-
+/* Substitute the type names.  */
+#define YYSTYPE         DASSTYPE
 /* Substitute the variable and function names.  */
 #define yyparse         dasparse
 #define yylex           daslex
@@ -99,17 +100,25 @@
 #ifndef YY_DAS_DAS_TAB_HH_INCLUDED
 # define YY_DAS_DAS_TAB_HH_INCLUDED
 /* Debug traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 1
-#endif
+#ifndef DASDEBUG
+# if defined YYDEBUG
 #if YYDEBUG
+#   define DASDEBUG 1
+#  else
+#   define DASDEBUG 0
+#  endif
+# else /* ! defined YYDEBUG */
+#  define DASDEBUG 1
+# endif /* ! defined YYDEBUG */
+#endif  /* ! defined DASDEBUG */
+#if DASDEBUG
 extern int dasdebug;
 #endif
 /* "%code requires" blocks.  */
 #line 40 "das.yy" /* yacc.c:352  */
 
 
-#define YYSTYPE char *
+#define DASSTYPE char *
 #define ATTR_STRING_QUOTE_FIX
 #define YYERROR_VERBOSE 0
 
@@ -126,7 +135,6 @@ extern int dasdebug;
 #include "debug.h"
 #include "parser.h"
 #include "util.h"
-// #include "das.tab.hh"
 
 #ifdef TRACE_NEW
 #include "trace_new.h"
@@ -147,17 +155,15 @@ using namespace libdap ;
 
 #define DAS_OBJ(arg) ((DAS *)((parser_arg *)(arg))->_object)
 
-//#define YYPARSE_PARAM arg
-
 extern int das_line_num;	/* defined in das.lex */
 
 
-#line 156 "das.tab.cc" /* yacc.c:352  */
+#line 162 "das.tab.cc" /* yacc.c:352  */
 
 /* Token type.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-  enum yytokentype
+#ifndef DASTOKENTYPE
+# define DASTOKENTYPE
+  enum dastokentype
   {
     SCAN_ATTR = 258,
     SCAN_WORD = 259,
@@ -176,14 +182,14 @@ extern int das_line_num;	/* defined in das.lex */
 #endif
 
 /* Value type.  */
-#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef int YYSTYPE;
-# define YYSTYPE_IS_TRIVIAL 1
-# define YYSTYPE_IS_DECLARED 1
+#if ! defined DASSTYPE && ! defined DASSTYPE_IS_DECLARED
+typedef int DASSTYPE;
+# define DASSTYPE_IS_TRIVIAL 1
+# define DASSTYPE_IS_DECLARED 1
 #endif
 
 
-extern YYSTYPE daslval;
+extern DASSTYPE daslval;
 
 int dasparse (parser_arg *arg);
 
@@ -191,7 +197,7 @@ int dasparse (parser_arg *arg);
 
 
 /* Unqualified %code blocks.  */
-#line 86 "das.yy" /* yacc.c:355  */
+#line 83 "das.yy" /* yacc.c:355  */
 
 // No global static objects. We go through this every so often, I guess I
 // should learn... 1/24/2000 jhrg
@@ -231,7 +237,7 @@ static void add_bad_attribute(AttrTable *attr, const string &type,
 			      const string &msg);
 
 
-#line 235 "das.tab.cc" /* yacc.c:355  */
+#line 241 "das.tab.cc" /* yacc.c:355  */
 
 #ifdef short
 # undef short
@@ -403,7 +409,7 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 
 #if (! defined yyoverflow \
      && (! defined __cplusplus \
-         || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))
+         || (defined DASSTYPE_IS_TRIVIAL && DASSTYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
@@ -517,23 +523,23 @@ static const yytype_uint8 yytranslate[] =
       15
 };
 
-#if YYDEBUG
+#if DASDEBUG
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   197,   197,   197,   214,   215,   219,   220,   226,   227,
-     228,   231,   233,   234,   233,   237,   238,   237,   241,   242,
-     241,   245,   246,   245,   249,   250,   249,   253,   254,   253,
-     257,   258,   257,   261,   262,   261,   265,   266,   265,   269,
-     270,   269,   274,   294,   273,   302,   301,   307,   311,   317,
-     321,   327,   331,   337,   341,   347,   351,   357,   361,   367,
-     371,   377,   383,   391,   395,   401,   415,   418,   421,   424,
-     424,   424,   424,   424,   425,   425,   425,   425,   426,   426,
-     426,   426,   430,   434,   429
+       0,   192,   192,   192,   209,   210,   214,   215,   221,   222,
+     223,   226,   228,   229,   228,   232,   233,   232,   236,   237,
+     236,   240,   241,   240,   244,   245,   244,   248,   249,   248,
+     252,   253,   252,   256,   257,   256,   260,   261,   260,   264,
+     265,   264,   269,   289,   268,   297,   296,   302,   306,   312,
+     316,   322,   326,   332,   336,   342,   346,   352,   356,   362,
+     366,   372,   378,   386,   390,   396,   410,   413,   416,   419,
+     419,   419,   419,   419,   420,   420,   420,   420,   421,   421,
+     421,   421,   425,   429,   424
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || 0
+#if DASDEBUG || YYERROR_VERBOSE || 0
 /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const yytname[] =
@@ -752,7 +758,7 @@ static const yytype_uint8 yyr2[] =
 
 
 /* Enable debugging if requested.  */
-#if YYDEBUG
+#if DASDEBUG
 
 # ifndef YYFPRINTF
 #  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
@@ -874,12 +880,12 @@ do {                                    \
 /* Nonzero means print parse trace.  It is left uninitialized so that
    multiple parsers can coexist.  */
 int yydebug;
-#else /* !YYDEBUG */
+#else /* !DASDEBUG */
 # define YYDPRINTF(Args)
 # define YY_SYMBOL_PRINT(Title, Type, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
-#endif /* !YYDEBUG */
+#endif /* !DASDEBUG */
 
 
 /* YYINITDEPTH -- initial size of the parser's stacks.  */
@@ -1400,7 +1406,7 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 197 "das.yy" /* yacc.c:1667  */
+#line 192 "das.yy" /* yacc.c:1667  */
     {
 		if (!name) name = new string();
 		if (!type) type = new string();
@@ -1409,150 +1415,150 @@ yyreduce:
 		// push outermost AttrTable
 		PUSH(DAS_OBJ(arg)->get_top_level_attributes());
 	}
-#line 1413 "das.tab.cc" /* yacc.c:1667  */
+#line 1419 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 3:
-#line 206 "das.yy" /* yacc.c:1667  */
+#line 201 "das.yy" /* yacc.c:1667  */
     {
 		POP;	// pop the DAS/AttrTable before stack's dtor
 		delete name; name = 0;
 		delete type; type = 0;
 		delete attr_tab_stack; attr_tab_stack = 0;
 	}
-#line 1424 "das.tab.cc" /* yacc.c:1667  */
+#line 1430 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 7:
-#line 221 "das.yy" /* yacc.c:1667  */
+#line 216 "das.yy" /* yacc.c:1667  */
     {
 		    parse_error((parser_arg *)arg, NO_DAS_MSG, das_line_num);
 		}
-#line 1432 "das.tab.cc" /* yacc.c:1667  */
-    break;
-
-  case 12:
-#line 233 "das.yy" /* yacc.c:1667  */
-    { save_str(*type, "Byte", das_line_num); }
 #line 1438 "das.tab.cc" /* yacc.c:1667  */
     break;
 
-  case 13:
-#line 234 "das.yy" /* yacc.c:1667  */
-    { save_str(*name, yyvsp[0], das_line_num); }
+  case 12:
+#line 228 "das.yy" /* yacc.c:1667  */
+    { save_str(*type, "Byte", das_line_num); }
 #line 1444 "das.tab.cc" /* yacc.c:1667  */
     break;
 
-  case 15:
-#line 237 "das.yy" /* yacc.c:1667  */
-    { save_str(*type, "Int16", das_line_num); }
+  case 13:
+#line 229 "das.yy" /* yacc.c:1667  */
+    { save_str(*name, yyvsp[0], das_line_num); }
 #line 1450 "das.tab.cc" /* yacc.c:1667  */
     break;
 
-  case 16:
-#line 238 "das.yy" /* yacc.c:1667  */
-    { save_str(*name, yyvsp[0], das_line_num); }
+  case 15:
+#line 232 "das.yy" /* yacc.c:1667  */
+    { save_str(*type, "Int16", das_line_num); }
 #line 1456 "das.tab.cc" /* yacc.c:1667  */
     break;
 
-  case 18:
-#line 241 "das.yy" /* yacc.c:1667  */
-    { save_str(*type, "UInt16", das_line_num); }
+  case 16:
+#line 233 "das.yy" /* yacc.c:1667  */
+    { save_str(*name, yyvsp[0], das_line_num); }
 #line 1462 "das.tab.cc" /* yacc.c:1667  */
     break;
 
-  case 19:
-#line 242 "das.yy" /* yacc.c:1667  */
-    { save_str(*name, yyvsp[0], das_line_num); }
+  case 18:
+#line 236 "das.yy" /* yacc.c:1667  */
+    { save_str(*type, "UInt16", das_line_num); }
 #line 1468 "das.tab.cc" /* yacc.c:1667  */
     break;
 
-  case 21:
-#line 245 "das.yy" /* yacc.c:1667  */
-    { save_str(*type, "Int32", das_line_num); }
+  case 19:
+#line 237 "das.yy" /* yacc.c:1667  */
+    { save_str(*name, yyvsp[0], das_line_num); }
 #line 1474 "das.tab.cc" /* yacc.c:1667  */
     break;
 
-  case 22:
-#line 246 "das.yy" /* yacc.c:1667  */
-    { save_str(*name, yyvsp[0], das_line_num); }
+  case 21:
+#line 240 "das.yy" /* yacc.c:1667  */
+    { save_str(*type, "Int32", das_line_num); }
 #line 1480 "das.tab.cc" /* yacc.c:1667  */
     break;
 
-  case 24:
-#line 249 "das.yy" /* yacc.c:1667  */
-    { save_str(*type, "UInt32", das_line_num); }
+  case 22:
+#line 241 "das.yy" /* yacc.c:1667  */
+    { save_str(*name, yyvsp[0], das_line_num); }
 #line 1486 "das.tab.cc" /* yacc.c:1667  */
     break;
 
-  case 25:
-#line 250 "das.yy" /* yacc.c:1667  */
-    { save_str(*name, yyvsp[0], das_line_num); }
+  case 24:
+#line 244 "das.yy" /* yacc.c:1667  */
+    { save_str(*type, "UInt32", das_line_num); }
 #line 1492 "das.tab.cc" /* yacc.c:1667  */
     break;
 
-  case 27:
-#line 253 "das.yy" /* yacc.c:1667  */
-    { save_str(*type, "Float32", das_line_num); }
+  case 25:
+#line 245 "das.yy" /* yacc.c:1667  */
+    { save_str(*name, yyvsp[0], das_line_num); }
 #line 1498 "das.tab.cc" /* yacc.c:1667  */
     break;
 
-  case 28:
-#line 254 "das.yy" /* yacc.c:1667  */
-    { save_str(*name, yyvsp[0], das_line_num); }
+  case 27:
+#line 248 "das.yy" /* yacc.c:1667  */
+    { save_str(*type, "Float32", das_line_num); }
 #line 1504 "das.tab.cc" /* yacc.c:1667  */
     break;
 
-  case 30:
-#line 257 "das.yy" /* yacc.c:1667  */
-    { save_str(*type, "Float64", das_line_num); }
+  case 28:
+#line 249 "das.yy" /* yacc.c:1667  */
+    { save_str(*name, yyvsp[0], das_line_num); }
 #line 1510 "das.tab.cc" /* yacc.c:1667  */
     break;
 
-  case 31:
-#line 258 "das.yy" /* yacc.c:1667  */
-    { save_str(*name, yyvsp[0], das_line_num); }
+  case 30:
+#line 252 "das.yy" /* yacc.c:1667  */
+    { save_str(*type, "Float64", das_line_num); }
 #line 1516 "das.tab.cc" /* yacc.c:1667  */
     break;
 
-  case 33:
-#line 261 "das.yy" /* yacc.c:1667  */
-    { *type = "String"; }
+  case 31:
+#line 253 "das.yy" /* yacc.c:1667  */
+    { save_str(*name, yyvsp[0], das_line_num); }
 #line 1522 "das.tab.cc" /* yacc.c:1667  */
     break;
 
-  case 34:
-#line 262 "das.yy" /* yacc.c:1667  */
-    { *name = yyvsp[0]; }
+  case 33:
+#line 256 "das.yy" /* yacc.c:1667  */
+    { *type = "String"; }
 #line 1528 "das.tab.cc" /* yacc.c:1667  */
     break;
 
-  case 36:
-#line 265 "das.yy" /* yacc.c:1667  */
-    { *type = "Url"; }
+  case 34:
+#line 257 "das.yy" /* yacc.c:1667  */
+    { *name = yyvsp[0]; }
 #line 1534 "das.tab.cc" /* yacc.c:1667  */
     break;
 
-  case 37:
-#line 266 "das.yy" /* yacc.c:1667  */
-    { *name = yyvsp[0]; }
+  case 36:
+#line 260 "das.yy" /* yacc.c:1667  */
+    { *type = "Url"; }
 #line 1540 "das.tab.cc" /* yacc.c:1667  */
     break;
 
-  case 39:
-#line 269 "das.yy" /* yacc.c:1667  */
-    { *type = "OtherXML"; }
+  case 37:
+#line 261 "das.yy" /* yacc.c:1667  */
+    { *name = yyvsp[0]; }
 #line 1546 "das.tab.cc" /* yacc.c:1667  */
     break;
 
-  case 40:
-#line 270 "das.yy" /* yacc.c:1667  */
-    { *name = yyvsp[0]; }
+  case 39:
+#line 264 "das.yy" /* yacc.c:1667  */
+    { *type = "OtherXML"; }
 #line 1552 "das.tab.cc" /* yacc.c:1667  */
     break;
 
+  case 40:
+#line 265 "das.yy" /* yacc.c:1667  */
+    { *name = yyvsp[0]; }
+#line 1558 "das.tab.cc" /* yacc.c:1667  */
+    break;
+
   case 42:
-#line 274 "das.yy" /* yacc.c:1667  */
+#line 269 "das.yy" /* yacc.c:1667  */
     {
 		    DBG(cerr << "Processing ID: " << yyvsp[0] << endl);
 		    
@@ -1572,177 +1578,177 @@ yyreduce:
 		    DBG(cerr << " Pushed attr_tab: " << at << endl);
 
 		}
-#line 1576 "das.tab.cc" /* yacc.c:1667  */
+#line 1582 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 43:
-#line 294 "das.yy" /* yacc.c:1667  */
+#line 289 "das.yy" /* yacc.c:1667  */
     {
 		    /* pop top of stack; store in attr_tab */
 		    DBG(cerr << " Popped attr_tab: " << TOP_OF_STACK << endl);
 		    POP;
 		}
-#line 1586 "das.tab.cc" /* yacc.c:1667  */
+#line 1592 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 45:
-#line 302 "das.yy" /* yacc.c:1667  */
+#line 297 "das.yy" /* yacc.c:1667  */
     { 
 		    parse_error(ATTR_TUPLE_MSG, das_line_num, yyvsp[0]);
 		}
-#line 1594 "das.tab.cc" /* yacc.c:1667  */
+#line 1600 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 47:
-#line 308 "das.yy" /* yacc.c:1667  */
+#line 303 "das.yy" /* yacc.c:1667  */
     {
 		    add_attribute(*type, *name, yyvsp[0], &check_byte);
 		}
-#line 1602 "das.tab.cc" /* yacc.c:1667  */
+#line 1608 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 48:
-#line 312 "das.yy" /* yacc.c:1667  */
+#line 307 "das.yy" /* yacc.c:1667  */
     {
 		    add_attribute(*type, *name, yyvsp[0], &check_byte);
 		}
-#line 1610 "das.tab.cc" /* yacc.c:1667  */
+#line 1616 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 49:
-#line 318 "das.yy" /* yacc.c:1667  */
+#line 313 "das.yy" /* yacc.c:1667  */
     {
 		    add_attribute(*type, *name, yyvsp[0], &check_int16);
 		}
-#line 1618 "das.tab.cc" /* yacc.c:1667  */
+#line 1624 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 50:
-#line 322 "das.yy" /* yacc.c:1667  */
+#line 317 "das.yy" /* yacc.c:1667  */
     {
 		    add_attribute(*type, *name, yyvsp[0], &check_int16);
 		}
-#line 1626 "das.tab.cc" /* yacc.c:1667  */
+#line 1632 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 51:
-#line 328 "das.yy" /* yacc.c:1667  */
+#line 323 "das.yy" /* yacc.c:1667  */
     {
 		    add_attribute(*type, *name, yyvsp[0], &check_uint16);
 		}
-#line 1634 "das.tab.cc" /* yacc.c:1667  */
+#line 1640 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 52:
-#line 332 "das.yy" /* yacc.c:1667  */
+#line 327 "das.yy" /* yacc.c:1667  */
     {
 		    add_attribute(*type, *name, yyvsp[0], &check_uint16);
 		}
-#line 1642 "das.tab.cc" /* yacc.c:1667  */
+#line 1648 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 53:
-#line 338 "das.yy" /* yacc.c:1667  */
+#line 333 "das.yy" /* yacc.c:1667  */
     {
 		    add_attribute(*type, *name, yyvsp[0], &check_int32);
 		}
-#line 1650 "das.tab.cc" /* yacc.c:1667  */
+#line 1656 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 54:
-#line 342 "das.yy" /* yacc.c:1667  */
+#line 337 "das.yy" /* yacc.c:1667  */
     {
 		    add_attribute(*type, *name, yyvsp[0], &check_int32);
 		}
-#line 1658 "das.tab.cc" /* yacc.c:1667  */
+#line 1664 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 55:
-#line 348 "das.yy" /* yacc.c:1667  */
+#line 343 "das.yy" /* yacc.c:1667  */
     {
 		    add_attribute(*type, *name, yyvsp[0], &check_uint32);
 		}
-#line 1666 "das.tab.cc" /* yacc.c:1667  */
+#line 1672 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 56:
-#line 352 "das.yy" /* yacc.c:1667  */
+#line 347 "das.yy" /* yacc.c:1667  */
     {
 		    add_attribute(*type, *name, yyvsp[0], &check_uint32);
 		}
-#line 1674 "das.tab.cc" /* yacc.c:1667  */
+#line 1680 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 57:
-#line 358 "das.yy" /* yacc.c:1667  */
+#line 353 "das.yy" /* yacc.c:1667  */
     {
 		    add_attribute(*type, *name, yyvsp[0], &check_float32);
 		}
-#line 1682 "das.tab.cc" /* yacc.c:1667  */
+#line 1688 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 58:
-#line 362 "das.yy" /* yacc.c:1667  */
+#line 357 "das.yy" /* yacc.c:1667  */
     {
 		    add_attribute(*type, *name, yyvsp[0], &check_float32);
 		}
-#line 1690 "das.tab.cc" /* yacc.c:1667  */
+#line 1696 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 59:
-#line 368 "das.yy" /* yacc.c:1667  */
+#line 363 "das.yy" /* yacc.c:1667  */
     {
 		    add_attribute(*type, *name, yyvsp[0], &check_float64);
 		}
-#line 1698 "das.tab.cc" /* yacc.c:1667  */
+#line 1704 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 60:
-#line 372 "das.yy" /* yacc.c:1667  */
+#line 367 "das.yy" /* yacc.c:1667  */
     {
 		    add_attribute(*type, *name, yyvsp[0], &check_float64);
 		}
-#line 1706 "das.tab.cc" /* yacc.c:1667  */
+#line 1712 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 61:
-#line 378 "das.yy" /* yacc.c:1667  */
+#line 373 "das.yy" /* yacc.c:1667  */
     {
 		    string attr = remove_quotes(yyvsp[0]);
                     attr = unescattr(attr);
 		    add_attribute(*type, *name, attr, 0);
 		}
-#line 1716 "das.tab.cc" /* yacc.c:1667  */
+#line 1722 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 62:
-#line 384 "das.yy" /* yacc.c:1667  */
+#line 379 "das.yy" /* yacc.c:1667  */
     {
 		    string attr = remove_quotes(yyvsp[0]);
                     attr = unescattr(attr);
 		    add_attribute(*type, *name, attr, 0);
 		}
-#line 1726 "das.tab.cc" /* yacc.c:1667  */
+#line 1732 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 63:
-#line 392 "das.yy" /* yacc.c:1667  */
+#line 387 "das.yy" /* yacc.c:1667  */
     {
                     add_attribute(*type, *name, yyvsp[0], &check_url);
                 }
-#line 1734 "das.tab.cc" /* yacc.c:1667  */
+#line 1740 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 64:
-#line 396 "das.yy" /* yacc.c:1667  */
+#line 391 "das.yy" /* yacc.c:1667  */
     {
                     add_attribute(*type, *name, yyvsp[0], &check_url);
                 }
-#line 1742 "das.tab.cc" /* yacc.c:1667  */
+#line 1748 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 65:
-#line 402 "das.yy" /* yacc.c:1667  */
+#line 397 "das.yy" /* yacc.c:1667  */
     {
                     // XML must be quoted in the DAS but the quotes are an
                     // artifact of the DAS syntax so they are not part of the
@@ -1754,28 +1760,28 @@ yyreduce:
                     else
                         add_attribute(*type, *name, xml, 0);
                 }
-#line 1758 "das.tab.cc" /* yacc.c:1667  */
+#line 1764 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 82:
-#line 430 "das.yy" /* yacc.c:1667  */
+#line 425 "das.yy" /* yacc.c:1667  */
     { 
 		    *name = yyvsp[0];
 		}
-#line 1766 "das.tab.cc" /* yacc.c:1667  */
+#line 1772 "das.tab.cc" /* yacc.c:1667  */
     break;
 
   case 83:
-#line 434 "das.yy" /* yacc.c:1667  */
+#line 429 "das.yy" /* yacc.c:1667  */
     {
 		    add_alias( DAS_OBJ(arg)->get_top_level_attributes(),
 		               TOP_OF_STACK, *name, string(yyvsp[0]) ) ;
                 }
-#line 1775 "das.tab.cc" /* yacc.c:1667  */
+#line 1781 "das.tab.cc" /* yacc.c:1667  */
     break;
 
 
-#line 1779 "das.tab.cc" /* yacc.c:1667  */
+#line 1785 "das.tab.cc" /* yacc.c:1667  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2006,7 +2012,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 441 "das.yy" /* yacc.c:1918  */
+#line 436 "das.yy" /* yacc.c:1918  */
 
 
 // This function is required for linking, but DODS uses its own error
@@ -2054,13 +2060,6 @@ add_attribute(const string &type, const string &name, const string &value,
     }
     
     try {
-#if 0
-        // Special treatment for XML: remove the double quotes that were 
-        // included in the value by this parser.
-        if (type == OtherXML && is_quoted(value))
-            TOP_OF_STACK->append_attr(name, type, value.substr(1, value.size()-2));
-        else    
-#endif
 	    TOP_OF_STACK->append_attr(name, type, value);
     }
     catch (Error &e) {
@@ -2108,15 +2107,16 @@ add_bad_attribute(AttrTable *attr, const string &type, const string &name,
     // `<name_explanation.'. 
     
     if (attr->get_name().find("_dods_errors") != string::npos) {
-	attr->append_attr(name, type, value);
+	    attr->append_attr(name, type, value);
     }
     else {
-	string error_cont_name = attr->get_name() + "_dods_errors";
-	AttrTable *error_cont = attr->get_attr_table(error_cont_name);
+        string error_cont_name = attr->get_name() + "_dods_errors";
+        AttrTable *error_cont = attr->get_attr_table(error_cont_name);
 	if (!error_cont)
 	    error_cont = attr->append_container(error_cont_name);
 
 	error_cont->append_attr(name, type, value);
+
 #ifndef ATTR_STRING_QUOTE_FIX
     error_cont->append_attr(name + "_explanation", "String",
                 "\"" + msg + "\"");
