@@ -62,7 +62,8 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-
+/* Substitute the type names.  */
+#define YYSTYPE         DDSSTYPE
 /* Substitute the variable and function names.  */
 #define yyparse         ddsparse
 #define yylex           ddslex
@@ -99,10 +100,18 @@
 #ifndef YY_DDS_DDS_TAB_HH_INCLUDED
 # define YY_DDS_DDS_TAB_HH_INCLUDED
 /* Debug traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 1
-#endif
+#ifndef DDSDEBUG
+# if defined YYDEBUG
 #if YYDEBUG
+#   define DDSDEBUG 1
+#  else
+#   define DDSDEBUG 0
+#  endif
+# else /* ! defined YYDEBUG */
+#  define DDSDEBUG 1
+# endif /* ! defined YYDEBUG */
+#endif  /* ! defined DDSDEBUG */
+#if DDSDEBUG
 extern int ddsdebug;
 #endif
 /* "%code requires" blocks.  */
@@ -148,17 +157,15 @@ using namespace libdap;
 #define DDS_OBJ(arg) ((DDS *)((parser_arg *)(arg))->_object)
 #define YYERROR_VERBOSE 0
 
-// #define YYPARSE_PARAM arg
-
 extern int dds_line_num;	/* defined in dds.lex */
 
 
-#line 157 "dds.tab.cc" /* yacc.c:352  */
+#line 164 "dds.tab.cc" /* yacc.c:352  */
 
 /* Token type.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-  enum yytokentype
+#ifndef DDSTOKENTYPE
+# define DDSTOKENTYPE
+  enum ddstokentype
   {
     SCAN_WORD = 258,
     SCAN_DATASET = 259,
@@ -180,25 +187,25 @@ extern int dds_line_num;	/* defined in dds.lex */
 #endif
 
 /* Value type.  */
-#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+#if ! defined DDSSTYPE && ! defined DDSSTYPE_IS_DECLARED
 
-union YYSTYPE
+union DDSSTYPE
 {
-#line 133 "dds.yy" /* yacc.c:352  */
+#line 130 "dds.yy" /* yacc.c:352  */
 
     bool boolean;
     char word[ID_MAX];
 
-#line 193 "dds.tab.cc" /* yacc.c:352  */
+#line 200 "dds.tab.cc" /* yacc.c:352  */
 };
 
-typedef union YYSTYPE YYSTYPE;
-# define YYSTYPE_IS_TRIVIAL 1
-# define YYSTYPE_IS_DECLARED 1
+typedef union DDSSTYPE DDSSTYPE;
+# define DDSSTYPE_IS_TRIVIAL 1
+# define DDSSTYPE_IS_DECLARED 1
 #endif
 
 
-extern YYSTYPE ddslval;
+extern DDSSTYPE ddslval;
 
 int ddsparse (parser_arg *arg);
 
@@ -206,7 +213,7 @@ int ddsparse (parser_arg *arg);
 
 
 /* Unqualified %code blocks.  */
-#line 94 "dds.yy" /* yacc.c:355  */
+#line 92 "dds.yy" /* yacc.c:355  */
 
 
 // No global static objects in the dap library! 1/24/2000 jhrg
@@ -234,7 +241,7 @@ void invalid_declaration(parser_arg *arg, string semantic_err_msg,
 			 char *type, char *name);
 
 
-#line 238 "dds.tab.cc" /* yacc.c:355  */
+#line 245 "dds.tab.cc" /* yacc.c:355  */
 
 #ifdef short
 # undef short
@@ -406,7 +413,7 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 
 #if (! defined yyoverflow \
      && (! defined __cplusplus \
-         || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))
+         || (defined DDSSTYPE_IS_TRIVIAL && DDSSTYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
@@ -520,20 +527,20 @@ static const yytype_uint8 yytranslate[] =
       15,    16,    17,    18
 };
 
-#if YYDEBUG
+#if DDSDEBUG
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   162,   162,   162,   178,   179,   182,   186,   195,   198,
-     199,   208,   223,   222,   244,   243,   265,   277,   289,   264,
-     310,   320,   326,   332,   338,   339,   340,   341,   342,   343,
-     344,   345,   346,   349,   350,   353,   353,   353,   353,   353,
-     354,   354,   354,   354,   355,   355,   355,   355,   356,   359,
-     381,   385,   380,   411,   421,   422,   423
+       0,   159,   159,   159,   175,   176,   179,   183,   192,   195,
+     196,   205,   220,   219,   241,   240,   262,   274,   286,   261,
+     307,   317,   323,   329,   335,   336,   337,   338,   339,   340,
+     341,   342,   343,   346,   347,   350,   350,   350,   350,   350,
+     351,   351,   351,   351,   352,   352,   352,   352,   353,   356,
+     378,   382,   377,   408,   418,   419,   420
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || 0
+#if DDSDEBUG || YYERROR_VERBOSE || 0
 /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const yytname[] =
@@ -742,7 +749,7 @@ static const yytype_uint8 yyr2[] =
 
 
 /* Enable debugging if requested.  */
-#if YYDEBUG
+#if DDSDEBUG
 
 # ifndef YYFPRINTF
 #  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
@@ -864,12 +871,12 @@ do {                                    \
 /* Nonzero means print parse trace.  It is left uninitialized so that
    multiple parsers can coexist.  */
 int yydebug;
-#else /* !YYDEBUG */
+#else /* !DDSDEBUG */
 # define YYDPRINTF(Args)
 # define YY_SYMBOL_PRINT(Title, Type, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
-#endif /* !YYDEBUG */
+#endif /* !DDSDEBUG */
 
 
 /* YYINITDEPTH -- initial size of the parser's stacks.  */
@@ -1390,7 +1397,7 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 162 "dds.yy" /* yacc.c:1667  */
+#line 159 "dds.yy" /* yacc.c:1667  */
     {
 		    /* On entry to the parser, make the BaseType stack. 
 		       I use if (!ctor) here because in the tab.cc file,
@@ -1401,57 +1408,57 @@ yyreduce:
 		    if (!ctor)
 		    	ctor = new stack<BaseType *>;
         }
-#line 1405 "dds.tab.cc" /* yacc.c:1667  */
+#line 1412 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 3:
-#line 173 "dds.yy" /* yacc.c:1667  */
+#line 170 "dds.yy" /* yacc.c:1667  */
     {
 		    delete ctor; ctor = 0;
 		}
-#line 1413 "dds.tab.cc" /* yacc.c:1667  */
+#line 1420 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 6:
-#line 183 "dds.yy" /* yacc.c:1667  */
+#line 180 "dds.yy" /* yacc.c:1667  */
     {
 		    (yyval.boolean) = (yyvsp[-3].boolean) && (yyvsp[-1].boolean);
 		}
-#line 1421 "dds.tab.cc" /* yacc.c:1667  */
+#line 1428 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 7:
-#line 187 "dds.yy" /* yacc.c:1667  */
+#line 184 "dds.yy" /* yacc.c:1667  */
     {
 		    parse_error((parser_arg *)arg, NO_DDS_MSG, dds_line_num, (yyvsp[0].word));
 		    error_exit_cleanup();
 		    YYABORT;
 		}
-#line 1431 "dds.tab.cc" /* yacc.c:1667  */
+#line 1438 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 8:
-#line 195 "dds.yy" /* yacc.c:1667  */
+#line 192 "dds.yy" /* yacc.c:1667  */
     {
 		    (yyval.boolean) = true;
 		}
-#line 1439 "dds.tab.cc" /* yacc.c:1667  */
+#line 1446 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 9:
-#line 198 "dds.yy" /* yacc.c:1667  */
+#line 195 "dds.yy" /* yacc.c:1667  */
     { (yyval.boolean) = true; }
-#line 1445 "dds.tab.cc" /* yacc.c:1667  */
+#line 1452 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 10:
-#line 199 "dds.yy" /* yacc.c:1667  */
+#line 196 "dds.yy" /* yacc.c:1667  */
     { (yyval.boolean) = true; }
-#line 1451 "dds.tab.cc" /* yacc.c:1667  */
+#line 1458 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 11:
-#line 209 "dds.yy" /* yacc.c:1667  */
+#line 206 "dds.yy" /* yacc.c:1667  */
     { 
 		    string smsg;
 		    if (current->check_semantics(smsg)) {
@@ -1464,21 +1471,21 @@ yyreduce:
             strncpy((yyval.word),(yyvsp[-1].word),ID_MAX);
             (yyval.word)[ID_MAX-1] = '\0';
 		}
-#line 1468 "dds.tab.cc" /* yacc.c:1667  */
+#line 1475 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 12:
-#line 223 "dds.yy" /* yacc.c:1667  */
+#line 220 "dds.yy" /* yacc.c:1667  */
     { 
 		    if( current ) delete current ;
 		    current = ctor->top(); 
 		    ctor->pop();
 		}
-#line 1478 "dds.tab.cc" /* yacc.c:1667  */
+#line 1485 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 13:
-#line 229 "dds.yy" /* yacc.c:1667  */
+#line 226 "dds.yy" /* yacc.c:1667  */
     { 
 		    string smsg;
 		    if (current->check_semantics(smsg)) {
@@ -1492,21 +1499,21 @@ yyreduce:
             strncpy((yyval.word),(yyvsp[-1].word),ID_MAX);
             (yyval.word)[ID_MAX-1] = '\0';
 		}
-#line 1496 "dds.tab.cc" /* yacc.c:1667  */
+#line 1503 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 14:
-#line 244 "dds.yy" /* yacc.c:1667  */
+#line 241 "dds.yy" /* yacc.c:1667  */
     { 
 		    if( current ) delete current ;
 		    current = ctor->top(); 
 		    ctor->pop();
 		}
-#line 1506 "dds.tab.cc" /* yacc.c:1667  */
+#line 1513 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 15:
-#line 250 "dds.yy" /* yacc.c:1667  */
+#line 247 "dds.yy" /* yacc.c:1667  */
     { 
 		    string smsg;
 		    if (current->check_semantics(smsg)) {
@@ -1520,11 +1527,11 @@ yyreduce:
             strncpy((yyval.word),(yyvsp[-1].word),ID_MAX);
             (yyval.word)[ID_MAX-1] = '\0';
 		}
-#line 1524 "dds.tab.cc" /* yacc.c:1667  */
+#line 1531 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 16:
-#line 265 "dds.yy" /* yacc.c:1667  */
+#line 262 "dds.yy" /* yacc.c:1667  */
     { 
 		    if (is_keyword(string((yyvsp[-1].word)), "array")) {
 			    part = libdap::array;
@@ -1536,11 +1543,11 @@ yyreduce:
 			    YYABORT;
 		    }
         }
-#line 1540 "dds.tab.cc" /* yacc.c:1667  */
+#line 1547 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 17:
-#line 277 "dds.yy" /* yacc.c:1667  */
+#line 274 "dds.yy" /* yacc.c:1667  */
     { 
 		    if (is_keyword(string((yyvsp[-1].word)), "maps")) {
 			    part = maps; 
@@ -1552,21 +1559,21 @@ yyreduce:
 			    YYABORT;
 		    }
         }
-#line 1556 "dds.tab.cc" /* yacc.c:1667  */
+#line 1563 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 18:
-#line 289 "dds.yy" /* yacc.c:1667  */
+#line 286 "dds.yy" /* yacc.c:1667  */
     {
 		    if( current ) delete current ;
 		    current = ctor->top(); 
 		    ctor->pop();
 		}
-#line 1566 "dds.tab.cc" /* yacc.c:1667  */
+#line 1573 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 19:
-#line 295 "dds.yy" /* yacc.c:1667  */
+#line 292 "dds.yy" /* yacc.c:1667  */
     {
 		    string smsg;
 		    if (current->check_semantics(smsg)) {
@@ -1581,106 +1588,106 @@ yyreduce:
         strncpy((yyval.word),(yyvsp[-1].word),ID_MAX);
         (yyval.word)[ID_MAX-1] = '\0';
 		}
-#line 1585 "dds.tab.cc" /* yacc.c:1667  */
+#line 1592 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 20:
-#line 311 "dds.yy" /* yacc.c:1667  */
+#line 308 "dds.yy" /* yacc.c:1667  */
     {
 		    ostringstream msg;
 		    msg << BAD_DECLARATION;
 		    parse_error((parser_arg *)arg, msg.str().c_str(), dds_line_num, (yyvsp[0].word));
 		    YYABORT;
 		}
-#line 1596 "dds.tab.cc" /* yacc.c:1667  */
+#line 1603 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 21:
-#line 321 "dds.yy" /* yacc.c:1667  */
+#line 318 "dds.yy" /* yacc.c:1667  */
     { 
 		    ctor->push(DDS_OBJ(arg)->get_factory()->NewStructure()); 
 		}
-#line 1604 "dds.tab.cc" /* yacc.c:1667  */
+#line 1611 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 22:
-#line 327 "dds.yy" /* yacc.c:1667  */
+#line 324 "dds.yy" /* yacc.c:1667  */
     { 
 		    ctor->push(DDS_OBJ(arg)->get_factory()->NewSequence()); 
 		}
-#line 1612 "dds.tab.cc" /* yacc.c:1667  */
+#line 1619 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 23:
-#line 333 "dds.yy" /* yacc.c:1667  */
+#line 330 "dds.yy" /* yacc.c:1667  */
     { 
 		    ctor->push(DDS_OBJ(arg)->get_factory()->NewGrid()); 
 		}
-#line 1620 "dds.tab.cc" /* yacc.c:1667  */
+#line 1627 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 24:
-#line 338 "dds.yy" /* yacc.c:1667  */
+#line 335 "dds.yy" /* yacc.c:1667  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewByte(); }
-#line 1626 "dds.tab.cc" /* yacc.c:1667  */
+#line 1633 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 25:
-#line 339 "dds.yy" /* yacc.c:1667  */
+#line 336 "dds.yy" /* yacc.c:1667  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewInt16(); }
-#line 1632 "dds.tab.cc" /* yacc.c:1667  */
+#line 1639 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 26:
-#line 340 "dds.yy" /* yacc.c:1667  */
+#line 337 "dds.yy" /* yacc.c:1667  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewUInt16(); }
-#line 1638 "dds.tab.cc" /* yacc.c:1667  */
+#line 1645 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 27:
-#line 341 "dds.yy" /* yacc.c:1667  */
+#line 338 "dds.yy" /* yacc.c:1667  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewInt32(); }
-#line 1644 "dds.tab.cc" /* yacc.c:1667  */
+#line 1651 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 28:
-#line 342 "dds.yy" /* yacc.c:1667  */
+#line 339 "dds.yy" /* yacc.c:1667  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewUInt32(); }
-#line 1650 "dds.tab.cc" /* yacc.c:1667  */
+#line 1657 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 29:
-#line 343 "dds.yy" /* yacc.c:1667  */
+#line 340 "dds.yy" /* yacc.c:1667  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewFloat32(); }
-#line 1656 "dds.tab.cc" /* yacc.c:1667  */
+#line 1663 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 30:
-#line 344 "dds.yy" /* yacc.c:1667  */
+#line 341 "dds.yy" /* yacc.c:1667  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewFloat64(); }
-#line 1662 "dds.tab.cc" /* yacc.c:1667  */
+#line 1669 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 31:
-#line 345 "dds.yy" /* yacc.c:1667  */
+#line 342 "dds.yy" /* yacc.c:1667  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewStr(); }
-#line 1668 "dds.tab.cc" /* yacc.c:1667  */
+#line 1675 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 32:
-#line 346 "dds.yy" /* yacc.c:1667  */
+#line 343 "dds.yy" /* yacc.c:1667  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewUrl(); }
-#line 1674 "dds.tab.cc" /* yacc.c:1667  */
+#line 1681 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 33:
-#line 349 "dds.yy" /* yacc.c:1667  */
+#line 346 "dds.yy" /* yacc.c:1667  */
     { current->set_name((yyvsp[0].word)); }
-#line 1680 "dds.tab.cc" /* yacc.c:1667  */
+#line 1687 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 49:
-#line 360 "dds.yy" /* yacc.c:1667  */
+#line 357 "dds.yy" /* yacc.c:1667  */
     { 
 		    if (!check_int32((yyvsp[-1].word))) {
 			    string msg = "In the dataset descriptor object:\n";
@@ -1700,19 +1707,19 @@ yyreduce:
 
 		    (yyval.boolean) = true;
 		 }
-#line 1704 "dds.tab.cc" /* yacc.c:1667  */
+#line 1711 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 50:
-#line 381 "dds.yy" /* yacc.c:1667  */
+#line 378 "dds.yy" /* yacc.c:1667  */
     {
 		     if (!id) id = new string((yyvsp[0].word));
 		 }
-#line 1712 "dds.tab.cc" /* yacc.c:1667  */
+#line 1719 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 51:
-#line 385 "dds.yy" /* yacc.c:1667  */
+#line 382 "dds.yy" /* yacc.c:1667  */
     { 
 		     if (!check_int32((yyvsp[0].word))) {
 			     string msg = "In the dataset descriptor object:\n";
@@ -1734,19 +1741,19 @@ yyreduce:
 
 		     delete id; id = 0;
 		 }
-#line 1738 "dds.tab.cc" /* yacc.c:1667  */
+#line 1745 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 52:
-#line 407 "dds.yy" /* yacc.c:1667  */
+#line 404 "dds.yy" /* yacc.c:1667  */
     {
 		     (yyval.boolean) = true;
 		 }
-#line 1746 "dds.tab.cc" /* yacc.c:1667  */
+#line 1753 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 53:
-#line 412 "dds.yy" /* yacc.c:1667  */
+#line 409 "dds.yy" /* yacc.c:1667  */
     {
 		     ostringstream msg;
 		     msg << "In the dataset descriptor object:" << endl
@@ -1754,23 +1761,23 @@ yyreduce:
 		     parse_error((parser_arg *)arg, msg.str().c_str(), dds_line_num, (yyvsp[0].word));
 		     YYABORT;
 		 }
-#line 1758 "dds.tab.cc" /* yacc.c:1667  */
+#line 1765 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 54:
-#line 421 "dds.yy" /* yacc.c:1667  */
+#line 418 "dds.yy" /* yacc.c:1667  */
     { (*DDS_OBJ(arg)).set_dataset_name((yyvsp[0].word)); (yyval.boolean) = true;}
-#line 1764 "dds.tab.cc" /* yacc.c:1667  */
+#line 1771 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 55:
-#line 422 "dds.yy" /* yacc.c:1667  */
+#line 419 "dds.yy" /* yacc.c:1667  */
     { (*DDS_OBJ(arg)).set_dataset_name((yyvsp[0].word)); (yyval.boolean) = true; }
-#line 1770 "dds.tab.cc" /* yacc.c:1667  */
+#line 1777 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
   case 56:
-#line 424 "dds.yy" /* yacc.c:1667  */
+#line 421 "dds.yy" /* yacc.c:1667  */
     {
 		    ostringstream msg;
 		    msg << "Error parsing the dataset name." << endl
@@ -1778,11 +1785,11 @@ yyreduce:
 		    parse_error((parser_arg *)arg, msg.str().c_str(), dds_line_num, (yyvsp[0].word));
 		    YYABORT;
 		}
-#line 1782 "dds.tab.cc" /* yacc.c:1667  */
+#line 1789 "dds.tab.cc" /* yacc.c:1667  */
     break;
 
 
-#line 1786 "dds.tab.cc" /* yacc.c:1667  */
+#line 1793 "dds.tab.cc" /* yacc.c:1667  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2013,7 +2020,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 433 "dds.yy" /* yacc.c:1918  */
+#line 430 "dds.yy" /* yacc.c:1918  */
 
 
 /* 
