@@ -35,11 +35,11 @@
 
 #include "config.h"
 
-#include <cerrno>
 #include <cassert>
-#include <cstring>
+#include <cerrno>
 #include <cmath>
 #include <cstdlib>
+#include <cstring>
 
 #include <iostream>
 #include <sstream>
@@ -53,9 +53,9 @@ double w32strtod(const char *, char **);
 
 #include "Error.h"
 #include "debug.h"
-#include "parser.h"             // defines constants such as ID_MAX
 #include "dods-limits.h"
-#include "util.h"               // Jose Garcia: for append_long_to_string.
+#include "parser.h" // defines constants such as ID_MAX
+#include "util.h"   // Jose Garcia: for append_long_to_string.
 
 using std::cerr;
 using std::endl;
@@ -66,8 +66,7 @@ using std::endl;
 //  the product is obsolete as of 1/2007, but it is unknown if
 //  the issue is still there in later releases of that product.
 //  ROM - 01/2007
-double w32strtod(const char *val, char **ptr)
-{
+double w32strtod(const char *val, char **ptr) {
     //  Convert the two char arrays to compare to strings.
     string *sval = new string(val);
     string *snan = new string("NaN");
@@ -79,18 +78,15 @@ double w32strtod(const char *val, char **ptr)
 
     //  But if it does, return the bit pattern for Nan and point
     //  the parsing ptr arg at the trailing '\0'.
-    *ptr = (char *) val + strlen(val);
-    return (std::numeric_limits < double >::quiet_NaN());
+    *ptr = (char *)val + strlen(val);
+    return (std::numeric_limits<double>::quiet_NaN());
 }
 #endif
 
 namespace libdap {
 
 // Deprecated, but still used by the HDF4 EOS server code.
-void
-parse_error(parser_arg * arg, const char *msg, const int line_num,
-            const char *context)
-{
+void parse_error(parser_arg *arg, const char *msg, const int line_num, const char *context) {
     // Jose Garcia
     // This assert(s) is (are) only for developing purposes
     // For production servers remove it by compiling with NDEBUG
@@ -104,23 +100,19 @@ parse_error(parser_arg * arg, const char *msg, const int line_num,
     if (line_num != 0) {
         oss += "Error parsing the text on line ";
         append_long_to_string(line_num, 10, oss);
-    }
-    else {
+    } else {
         oss += "Parse error.";
     }
 
     if (context)
-        oss += (string) " at or near: " + context + (string) "\n" + msg
-               + (string) "\n";
+        oss += (string) " at or near: " + context + (string) "\n" + msg + (string) "\n";
     else
         oss += (string) "\n" + msg + (string) "\n";
 
     arg->set_error(new Error(unknown_error, oss));
 }
 
-void
-parse_error(const char *msg, const int line_num, const char *context)
-{
+void parse_error(const char *msg, const int line_num, const char *context) {
     // Jose Garcia
     // This assert(s) is (are) only for developing purposes
     // For production servers remove it by compiling with NDEBUG
@@ -131,14 +123,12 @@ parse_error(const char *msg, const int line_num, const char *context)
     if (line_num != 0) {
         oss += "Error parsing the text on line ";
         append_long_to_string(line_num, 10, oss);
-    }
-    else {
+    } else {
         oss += "Parse error.";
     }
 
     if (context)
-        oss += (string) " at or near: " + context + (string) "\n" + msg
-               + (string) "\n";
+        oss += (string) " at or near: " + context + (string) "\n" + msg + (string) "\n";
     else
         oss += (string) "\n" + msg + (string) "\n";
 
@@ -147,9 +137,7 @@ parse_error(const char *msg, const int line_num, const char *context)
 
 // context comes from the parser and will always be a char * unless the
 // parsers change dramatically.
-void
-parse_error(const string & msg, const int line_num, const char *context)
-{
+void parse_error(const string &msg, const int line_num, const char *context) {
     parse_error(msg.c_str(), line_num, context);
 }
 
@@ -168,13 +156,9 @@ void save_str(char *dst, const char *src, const int line_num)
 }
 #endif
 
-void save_str(string & dst, const char *src, const int)
-{
-    dst = src;
-}
+void save_str(string &dst, const char *src, const int) { dst = src; }
 
-bool is_keyword(string id, const string & keyword)
-{
+bool is_keyword(string id, const string &keyword) {
     downcase(id);
     id = prune_spaces(id);
     DBG(cerr << "is_keyword: " << keyword << " = " << id << endl);
@@ -191,8 +175,7 @@ bool is_keyword(string id, const string & keyword)
     @return Returns: TRUE (1) if <i>val</i> is a byte value, FALSE (0) otherwise.
     @brief Is the value a valid byte?
     */
-int check_byte(const char *val)
-{
+int check_byte(const char *val) {
     char *ptr;
     long v = strtol(val, &ptr, 0);
 
@@ -207,8 +190,7 @@ int check_byte(const char *val)
     // ASCII representation for the value might need to be tweaked. This is
     // especially the case for Java clients where Byte datatypes are
     // signed. 3/20/2000 jhrg
-    if ((v < 0 && v < DODS_SCHAR_MIN)
-        || (v > 0 && static_cast < unsigned long >(v) > DODS_UCHAR_MAX))
+    if ((v < 0 && v < DODS_SCHAR_MIN) || (v > 0 && static_cast<unsigned long>(v) > DODS_UCHAR_MAX))
         return FALSE;
 
     return TRUE;
@@ -217,10 +199,9 @@ int check_byte(const char *val)
 // This version of check_int will pass base 8, 10 and 16 numbers when they
 // use the ANSI standard for string representation of those number bases.
 
-int check_int16(const char *val)
-{
+int check_int16(const char *val) {
     char *ptr;
-    long v = strtol(val, &ptr, 0);      // `0' --> use val to determine base
+    long v = strtol(val, &ptr, 0); // `0' --> use val to determine base
 
     if ((v == 0 && val == ptr) || *ptr != '\0') {
         return FALSE;
@@ -233,8 +214,7 @@ int check_int16(const char *val)
     return TRUE;
 }
 
-int check_uint16(const char *val)
-{
+int check_uint16(const char *val) {
     char *ptr;
     unsigned long v = strtol(val, &ptr, 0);
 
@@ -249,11 +229,10 @@ int check_uint16(const char *val)
     return TRUE;
 }
 
-int check_int32(const char *val)
-{
+int check_int32(const char *val) {
     char *ptr;
     errno = 0;
-    long v = strtol(val, &ptr, 0);      // `0' --> use val to determine base
+    long v = strtol(val, &ptr, 0); // `0' --> use val to determine base
 
     if ((v == 0 && val == ptr) || *ptr != '\0') {
         return FALSE;
@@ -270,22 +249,20 @@ int check_int32(const char *val)
     // 64-bits and so 'v' can hold more than a DODS_INT32. jhrg 3/23/10
     else if (v > DODS_INT_MAX || v < DODS_INT_MIN) {
         return FALSE;
-    }
-    else {
+    } else {
         return TRUE;
     }
 }
 
-int check_uint32(const char *val)
-{
-  // Eat whitespace and check for an initial '-' sign...
-  // strtoul allows an initial minus. mjohnson
-    const char* c = val;
+int check_uint32(const char *val) {
+    // Eat whitespace and check for an initial '-' sign...
+    // strtoul allows an initial minus. mjohnson
+    const char *c = val;
     while (c && isspace(*c)) {
-         c++;
+        c++;
     }
     if (c && (*c == '-')) {
-         return FALSE;
+        return FALSE;
     }
 
     char *ptr;
@@ -296,26 +273,24 @@ int check_uint32(const char *val)
         return FALSE;
     }
 
-	// check overflow first, or the below check is invalid due to
-	// clamping to the maximum value by strtoul
-	// maybe consider using long long for these checks? mjohnson
-	if (errno == ERANGE) {
-		return FALSE;
-	}
-	// See above.
-	else if (v > DODS_UINT_MAX) {
-		return FALSE;
-	}
-	else {
-		return TRUE;
-	}
+    // check overflow first, or the below check is invalid due to
+    // clamping to the maximum value by strtoul
+    // maybe consider using long long for these checks? mjohnson
+    if (errno == ERANGE) {
+        return FALSE;
+    }
+    // See above.
+    else if (v > DODS_UINT_MAX) {
+        return FALSE;
+    } else {
+        return TRUE;
+    }
 }
 
-int check_int32(const char *val, int &v)
-{
+int check_int32(const char *val, int &v) {
     char *ptr;
     errno = 0;
-    long tmp = strtol(val, &ptr, 0);      // `0' --> use val to determine base
+    long tmp = strtol(val, &ptr, 0); // `0' --> use val to determine base
 
     if ((tmp == 0 && val == ptr) || *ptr != '\0') {
         return FALSE;
@@ -332,18 +307,16 @@ int check_int32(const char *val, int &v)
     // 64-bits and so 'v' can hold more than a DODS_INT32. jhrg 3/23/10
     else if (tmp > DODS_INT_MAX || tmp < DODS_INT_MIN) {
         return FALSE;
-    }
-    else {
+    } else {
         v = (int)tmp;
         return TRUE;
     }
 }
 
-int check_uint32(const char *val, unsigned int &v)
-{
+int check_uint32(const char *val, unsigned int &v) {
     // Eat whitespace and check for an initial '-' sign...
     // strtoul allows an initial minus. mjohnson
-    const char* c = val;
+    const char *c = val;
     while (c && isspace(*c)) {
         c++;
     }
@@ -368,18 +341,16 @@ int check_uint32(const char *val, unsigned int &v)
     // See above.
     else if (tmp > DODS_UINT_MAX) {
         return FALSE;
-    }
-    else {
+    } else {
         v = (unsigned int)tmp;
         return TRUE;
     }
 }
 
-int check_int64(const char *val)
-{
+int check_int64(const char *val) {
     char *ptr;
     errno = 0;
-    long long v = strtoll(val, &ptr, 0);      // `0' --> use val to determine base
+    long long v = strtoll(val, &ptr, 0); // `0' --> use val to determine base
 
     if ((v == 0 && val == ptr) || *ptr != '\0') {
         return FALSE;
@@ -406,13 +377,12 @@ int check_int64(const char *val)
     }
 }
 
-int check_uint64(const char *val)
-{
-  // Eat whitespace and check for an initial '-' sign...
-  // strtoul allows an initial minus. mjohnson
-    const char* c = val;
+int check_uint64(const char *val) {
+    // Eat whitespace and check for an initial '-' sign...
+    // strtoul allows an initial minus. mjohnson
+    const char *c = val;
     while (c && isspace(*c)) {
-         c++;
+        c++;
     }
     if (c && (*c == '-')) {
         return FALSE;
@@ -428,11 +398,9 @@ int check_uint64(const char *val)
 
     if (errno == ERANGE) {
         return FALSE;
-    }
-    else if (v > DODS_ULLONG_MAX) { // 2^61
+    } else if (v > DODS_ULLONG_MAX) { // 2^61
         return FALSE;
-    }
-    else {
+    } else {
         return v;
     }
 }
@@ -441,11 +409,10 @@ int check_uint64(const char *val)
 // (erroneously) to zero. Then make sure that the value is within
 // limits.
 
-int check_float32(const char *val)
-{
+int check_float32(const char *val) {
     char *ptr;
-    errno = 0;                  // Clear previous value. Fix for the 64bit
-				// IRIX from Rob Morris. 5/21/2001 jhrg
+    errno = 0; // Clear previous value. Fix for the 64bit
+               // IRIX from Rob Morris. 5/21/2001 jhrg
 
 #ifdef WIN32
     double v = w32strtod(val, &ptr);
@@ -453,8 +420,7 @@ int check_float32(const char *val)
     double v = strtod(val, &ptr);
 #endif
 
-    DBG(cerr << "v: " << v << ", ptr: " << ptr
-        << ", errno: " << errno << ", val==ptr: " << (val == ptr) << endl);
+    DBG(cerr << "v: " << v << ", ptr: " << ptr << ", errno: " << errno << ", val==ptr: " << (val == ptr) << endl);
 
     if (errno == ERANGE || (v == 0.0 && val == ptr) || *ptr != '\0')
         return FALSE;
@@ -468,18 +434,16 @@ int check_float32(const char *val)
 
     DBG(cerr << "fabs(" << val << ") = " << fabs(v) << endl);
     double abs_val = fabs(v);
-    if (abs_val > DODS_FLT_MAX
-        || (abs_val != 0.0 && abs_val < DODS_FLT_MIN))
+    if (abs_val > DODS_FLT_MAX || (abs_val != 0.0 && abs_val < DODS_FLT_MIN))
         return FALSE;
 
     return TRUE;
 }
 
-int check_float64(const char *val)
-{
+int check_float64(const char *val) {
     DBG(cerr << "val: " << val << endl);
     char *ptr;
-    errno = 0;                  // Clear previous value. 5/21/2001 jhrg
+    errno = 0; // Clear previous value. 5/21/2001 jhrg
 
 #ifdef WIN32
     double v = w32strtod(val, &ptr);
@@ -487,12 +451,10 @@ int check_float64(const char *val)
     double v = strtod(val, &ptr);
 #endif
 
-    DBG(cerr << "v: " << v << ", ptr: " << ptr
-        << ", errno: " << errno << ", val==ptr: " << (val == ptr) << endl);
-
+    DBG(cerr << "v: " << v << ", ptr: " << ptr << ", errno: " << errno << ", val==ptr: " << (val == ptr) << endl);
 
     if (errno == ERANGE || (v == 0.0 && val == ptr) || *ptr != '\0')
-	return FALSE;
+        return FALSE;
 #if 0
     if ((v == 0.0 && (val == ptr || errno == HUGE_VAL || errno == ERANGE))
         || *ptr != '\0') {
@@ -501,18 +463,16 @@ int check_float64(const char *val)
 #endif
     DBG(cerr << "fabs(" << val << ") = " << fabs(v) << endl);
     double abs_val = fabs(v);
-    if (abs_val > DODS_DBL_MAX
-        || (abs_val != 0.0 && abs_val < DODS_DBL_MIN))
+    if (abs_val > DODS_DBL_MAX || (abs_val != 0.0 && abs_val < DODS_DBL_MIN))
         return FALSE;
 
     return TRUE;
 }
 
-int check_float64(const char *val, double &v)
-{
+int check_float64(const char *val, double &v) {
     DBG(cerr << "val: " << val << endl);
     char *ptr;
-    errno = 0;                  // Clear previous value. 5/21/2001 jhrg
+    errno = 0; // Clear previous value. 5/21/2001 jhrg
 
 #ifdef WIN32
     v = w32strtod(val, &ptr);
@@ -520,9 +480,7 @@ int check_float64(const char *val, double &v)
     v = strtod(val, &ptr);
 #endif
 
-    DBG(cerr << "v: " << v << ", ptr: " << ptr
-             << ", errno: " << errno << ", val==ptr: " << (val == ptr) << endl);
-
+    DBG(cerr << "v: " << v << ", ptr: " << ptr << ", errno: " << errno << ", val==ptr: " << (val == ptr) << endl);
 
     if (errno == ERANGE || (v == 0.0 && val == ptr) || *ptr != '\0')
         return FALSE;
@@ -534,18 +492,16 @@ int check_float64(const char *val, double &v)
 #endif
     DBG(cerr << "fabs(" << val << ") = " << fabs(v) << endl);
     double abs_val = fabs(v);
-    if (abs_val > DODS_DBL_MAX
-        || (abs_val != 0.0 && abs_val < DODS_DBL_MIN))
+    if (abs_val > DODS_DBL_MAX || (abs_val != 0.0 && abs_val < DODS_DBL_MIN))
         return FALSE;
 
     return TRUE;
 }
 
-long long get_int64(const char *val)
-{
+long long get_int64(const char *val) {
     char *ptr;
     errno = 0;
-    long long v = strtoll(val, &ptr, 0);      // `0' --> use val to determine base
+    long long v = strtoll(val, &ptr, 0); // `0' --> use val to determine base
 
     if ((v == 0 && val == ptr) || *ptr != '\0') {
         throw Error("Expected a 64-bit integer, but found other characters.");
@@ -576,11 +532,10 @@ long long get_int64(const char *val)
     }
 }
 
-unsigned long long get_uint64(const char *val)
-{
+unsigned long long get_uint64(const char *val) {
     // Eat whitespace and check for an initial '-' sign...
     // strtoul allows an initial minus. mjohnson
-    const char* c = val;
+    const char *c = val;
     while (c && isspace(*c)) {
         c++;
     }
@@ -610,11 +565,10 @@ unsigned long long get_uint64(const char *val)
     }
 }
 
-int get_int32(const char *val)
-{
+int get_int32(const char *val) {
     char *ptr;
     errno = 0;
-    int v = strtol(val, &ptr, 0);      // `0' --> use val to determine base
+    int v = strtol(val, &ptr, 0); // `0' --> use val to determine base
 
     if ((v == 0 && val == ptr) || *ptr != '\0') {
         throw Error("Expected a 32-bit integer, but found other characters.");
@@ -638,11 +592,10 @@ int get_int32(const char *val)
     }
 }
 
-unsigned int get_uint32(const char *val)
-{
+unsigned int get_uint32(const char *val) {
     // Eat whitespace and check for an initial '-' sign...
     // strtoul allows an initial minus. mjohnson
-    const char* c = val;
+    const char *c = val;
     while (c && isspace(*c)) {
         c++;
     }
@@ -664,17 +617,15 @@ unsigned int get_uint32(const char *val)
     // See above.
     else if (v > DODS_UINT_MAX) {
         return FALSE;
-    }
-    else {
+    } else {
         return v;
     }
 }
 
-double get_float64(const char *val)
-{
+double get_float64(const char *val) {
     DBG(cerr << "val: " << val << endl);
     char *ptr;
-    errno = 0;                  // Clear previous value. 5/21/2001 jhrg
+    errno = 0; // Clear previous value. 5/21/2001 jhrg
 
 #ifdef WIN32
     double v = w32strtod(val, &ptr);
@@ -683,12 +634,14 @@ double get_float64(const char *val)
 #endif
 
     if (errno == ERANGE || (v == 0.0 && val == ptr) || *ptr != '\0')
-        throw Error("The 64-bit floating point value is out of range.");;
+        throw Error("The 64-bit floating point value is out of range.");
+    ;
 
     DBG(cerr << "fabs(" << val << ") = " << fabs(v) << endl);
     double abs_val = fabs(v);
     if (abs_val > DODS_DBL_MAX || (abs_val != 0.0 && abs_val < DODS_DBL_MIN))
-        throw Error("The 64-bit floating point value is out of range.");;
+        throw Error("The 64-bit floating point value is out of range.");
+    ;
 
     return v;
 }
@@ -697,9 +650,6 @@ double get_float64(const char *val)
   Maybe someday we will really check the Urls to see if they are valid...
 */
 
-int check_url(const char *)
-{
-    return TRUE;
-}
+int check_url(const char *) { return TRUE; }
 
 } // namespace libdap
