@@ -28,45 +28,32 @@
 #ifndef WIN64
 #include <unistd.h>
 #else
-#include <io.h>
 #include <fcntl.h>
+#include <io.h>
 #include <process.h>
 #endif
 
-//#define DODS_DEBUG
+// #define DODS_DEBUG
 
 #include "TestD4Enum.h"
 #include "debug.h"
 
 extern int test_variable_sleep_interval;
 
-void
-TestD4Enum::_duplicate(const TestD4Enum &ts)
-{
-    d_series_values = ts.d_series_values;
-}
+void TestD4Enum::_duplicate(const TestD4Enum &ts) { d_series_values = ts.d_series_values; }
 
-TestD4Enum::TestD4Enum(const string &n, Type t) : D4Enum(n, t), TestCommon(), d_series_values(false)
-{
-    set_value(0);
-}
+TestD4Enum::TestD4Enum(const string &n, Type t) : D4Enum(n, t), TestCommon(), d_series_values(false) { set_value(0); }
 
 TestD4Enum::TestD4Enum(const string &n, const string &d, Type t)
-    : D4Enum(n, d, t), TestCommon(), d_series_values(false)
-{
+    : D4Enum(n, d, t), TestCommon(), d_series_values(false) {
     set_value(0);
 }
 
-TestD4Enum::TestD4Enum(const TestD4Enum &rhs) : D4Enum(rhs), TestCommon(rhs)
-{
-    _duplicate(rhs);
-}
+TestD4Enum::TestD4Enum(const TestD4Enum &rhs) : D4Enum(rhs), TestCommon(rhs) { _duplicate(rhs); }
 
-TestD4Enum &
-TestD4Enum::operator=(const TestD4Enum &rhs)
-{
+TestD4Enum &TestD4Enum::operator=(const TestD4Enum &rhs) {
     if (this == &rhs)
-	return *this;
+        return *this;
 
     D4Enum::operator=(rhs); // run Constructor=
 
@@ -75,23 +62,17 @@ TestD4Enum::operator=(const TestD4Enum &rhs)
     return *this;
 }
 
-BaseType *
-TestD4Enum::ptr_duplicate()
-{
-    return new TestD4Enum(*this);
-}
+BaseType *TestD4Enum::ptr_duplicate() { return new TestD4Enum(*this); }
 
-void
-TestD4Enum::output_values(std::ostream &out)
-{
-    print_val(out, "", false);
-}
+void TestD4Enum::output_values(std::ostream &out) { print_val(out, "", false); }
 
 bool TestD4Enum::read() {
     DBG(cerr << "Entering TestD4Enum::read for " << name() << endl);
-    if (read_p()) return true;
+    if (read_p())
+        return true;
 
-    if (test_variable_sleep_interval > 0) sleep(test_variable_sleep_interval);
+    if (test_variable_sleep_interval > 0)
+        sleep(test_variable_sleep_interval);
 
     if (get_series_values()) {
         int64_t v;
@@ -100,8 +81,7 @@ bool TestD4Enum::read() {
             set_value(1);
         else
             set_value(v + 1);
-    }
-    else {
+    } else {
         set_value(1);
     }
 
