@@ -23,7 +23,7 @@
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
-//#define DODS_DEBUG
+// #define DODS_DEBUG
 
 #include "config.h"
 
@@ -31,28 +31,15 @@
 
 #include "debug.h"
 
-void
-TestD4Group::m_duplicate(const TestD4Group &ts)
-{
-    d_series_values = ts.d_series_values;
-}
+void TestD4Group::m_duplicate(const TestD4Group &ts) { d_series_values = ts.d_series_values; }
 
-TestD4Group *
-TestD4Group::ptr_duplicate()
-{
-    return new TestD4Group(*this);
-}
+TestD4Group *TestD4Group::ptr_duplicate() { return new TestD4Group(*this); }
 
-TestD4Group::TestD4Group(const TestD4Group &rhs) : D4Group(rhs), TestCommon(rhs)
-{
-    m_duplicate(rhs);
-}
+TestD4Group::TestD4Group(const TestD4Group &rhs) : D4Group(rhs), TestCommon(rhs) { m_duplicate(rhs); }
 
-TestD4Group &
-TestD4Group::operator=(const TestD4Group &rhs)
-{
+TestD4Group &TestD4Group::operator=(const TestD4Group &rhs) {
     if (this == &rhs)
-	return *this;
+        return *this;
 
     D4Group::operator=(rhs); // run Constructor=
 
@@ -61,76 +48,64 @@ TestD4Group::operator=(const TestD4Group &rhs)
     return *this;
 }
 
-TestD4Group::TestD4Group(const string &n) : D4Group(n), d_series_values(false)
-{
-}
+TestD4Group::TestD4Group(const string &n) : D4Group(n), d_series_values(false) {}
 
-TestD4Group::TestD4Group(const string &n, const string &d)
-    : D4Group(n, d), d_series_values(false)
-{
-}
+TestD4Group::TestD4Group(const string &n, const string &d) : D4Group(n, d), d_series_values(false) {}
 
-TestD4Group::~TestD4Group()
-{
-}
+TestD4Group::~TestD4Group() {}
 
-void
-TestD4Group::output_values(std::ostream &out)
-{
-    out << "{ " ;
+void TestD4Group::output_values(std::ostream &out) {
+    out << "{ ";
 
     bool value_written = false;
     Vars_citer i = var_begin();
 
     // Write the first (and maybe only) value.
-    while(i != var_end() && ! value_written) {
+    while (i != var_end() && !value_written) {
         if ((*i)->send_p()) {
             (*i++)->print_val(out, "", false);
             value_written = true;
-        }
-        else {
+        } else {
             ++i;
         }
     }
     // Each subsequent value will be preceded by a comma
-    while(i != var_end()) {
+    while (i != var_end()) {
         if ((*i)->send_p()) {
             out << ", ";
             (*i++)->print_val(out, "", false);
-        }
-        else {
+        } else {
             ++i;
         }
     }
 
-    out << " }" ;
+    out << " }";
 }
 
-bool TestD4Group::read()
-{
-	if (read_p()) return true;
+bool TestD4Group::read() {
+    if (read_p())
+        return true;
 
-	for (Vars_iter i = var_begin(); i != var_end(); i++) {
-		if (!(*i)->read()) {
-			return false;
-		}
-	}
+    for (Vars_iter i = var_begin(); i != var_end(); i++) {
+        if (!(*i)->read()) {
+            return false;
+        }
+    }
 
-	set_read_p(true);
+    set_read_p(true);
 
-	return true;
+    return true;
 }
 
-void TestD4Group::set_series_values(bool sv)
-{
-	Vars_iter i = var_begin();
-	while (i != var_end()) {
-		TestCommon *tc = dynamic_cast<TestCommon*>(*i);
-		if (!tc)
-		    throw InternalErr (__FILE__, __LINE__, "Variable '" + (*i)->name() + "' is not a TestCommon.");
-		tc->set_series_values(sv);
-		++i;
-	}
+void TestD4Group::set_series_values(bool sv) {
+    Vars_iter i = var_begin();
+    while (i != var_end()) {
+        TestCommon *tc = dynamic_cast<TestCommon *>(*i);
+        if (!tc)
+            throw InternalErr(__FILE__, __LINE__, "Variable '" + (*i)->name() + "' is not a TestCommon.");
+        tc->set_series_values(sv);
+        ++i;
+    }
 
-	d_series_values = sv;
+    d_series_values = sv;
 }
