@@ -33,14 +33,13 @@
 //
 // jhrg 10/27/96
 
-
 #include "config.h"
 
 #ifndef WIN32
 #include <unistd.h>
 #else
-#include <io.h>
 #include <fcntl.h>
+#include <io.h>
 #include <process.h>
 #endif
 
@@ -48,34 +47,17 @@
 
 extern int test_variable_sleep_interval;
 
-void
-TestUInt32::_duplicate(const TestUInt32 &ts)
-{
-    d_series_values = ts.d_series_values;
-}
+void TestUInt32::_duplicate(const TestUInt32 &ts) { d_series_values = ts.d_series_values; }
 
+TestUInt32::TestUInt32(const string &n) : UInt32(n), d_series_values(false) { d_buf = 1; }
 
-TestUInt32::TestUInt32(const string &n) : UInt32(n), d_series_values(false)
-{
-    d_buf = 1;
-}
+TestUInt32::TestUInt32(const string &n, const string &d) : UInt32(n, d), d_series_values(false) { d_buf = 1; }
 
-TestUInt32::TestUInt32(const string &n, const string &d)
-    : UInt32(n, d), d_series_values(false)
-{
-    d_buf = 1;
-}
+TestUInt32::TestUInt32(const TestUInt32 &rhs) : UInt32(rhs), TestCommon(rhs) { _duplicate(rhs); }
 
-TestUInt32::TestUInt32(const TestUInt32 &rhs) : UInt32(rhs), TestCommon(rhs)
-{
-    _duplicate(rhs);
-}
-
-TestUInt32 &
-TestUInt32::operator=(const TestUInt32 &rhs)
-{
+TestUInt32 &TestUInt32::operator=(const TestUInt32 &rhs) {
     if (this == &rhs)
-	return *this;
+        return *this;
 
     UInt32::operator=(rhs); // run Constructor=
 
@@ -84,39 +66,27 @@ TestUInt32::operator=(const TestUInt32 &rhs)
     return *this;
 }
 
+BaseType *TestUInt32::ptr_duplicate() { return new TestUInt32(*this); }
 
-BaseType *
-TestUInt32::ptr_duplicate()
-{
-    return new TestUInt32(*this);
-}
+void TestUInt32::output_values(std::ostream &out) { print_val(out, "", false); }
 
-void
-TestUInt32::output_values(std::ostream &out)
-{
-    print_val(out, "", false);
-}
-
-bool
-TestUInt32::read()
-{
+bool TestUInt32::read() {
     if (read_p())
-	return true;
+        return true;
 
     if (test_variable_sleep_interval > 0)
-	sleep(test_variable_sleep_interval);
+        sleep(test_variable_sleep_interval);
 
     if (get_series_values()) {
-   		// This line stopped working when I upgraded the compiler on osx 10.9.
-		// to version Apple LLVM version 5.1 (clang-503.0.38) (based on LLVM 3.4svn)
-		// jhrg 3/12/14
-		// d_buf = d_buf * 32;
-		d_buf <<= 5;
-		if (!d_buf)
-			d_buf = 32;
-    }
-    else {
-        d_buf = 0xf0000000;		// about 4 billion
+        // This line stopped working when I upgraded the compiler on osx 10.9.
+        // to version Apple LLVM version 5.1 (clang-503.0.38) (based on LLVM 3.4svn)
+        // jhrg 3/12/14
+        // d_buf = d_buf * 32;
+        d_buf <<= 5;
+        if (!d_buf)
+            d_buf = 32;
+    } else {
+        d_buf = 0xf0000000; // about 4 billion
     }
 
     set_read_p(true);
