@@ -10,12 +10,12 @@
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
 // version 2.1 of the License, or (at your option) any later version.
-// 
+//
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -23,8 +23,8 @@
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
 #include <cppunit/TextTestRunner.h>
-#include <cppunit/extensions/TestFactoryRegistry.h>
 #include <cppunit/extensions/HelperMacros.h>
+#include <cppunit/extensions/TestFactoryRegistry.h>
 
 #include <cstring>
 #include <string>
@@ -34,13 +34,13 @@
 #include "GNURegex.h"
 
 #include "Array.h"
+#include "D4Dimensions.h"
+#include "D4Enum.h"
+#include "Float32.h"
 #include "Int16.h"
 #include "Int64.h"
-#include "Float32.h"
 #include "Str.h"
-#include "D4Enum.h"
 #include "Structure.h"
-#include "D4Dimensions.h"
 
 #include "run_tests_cppunit.h"
 #include "test_config.h"
@@ -50,7 +50,7 @@ using namespace std;
 
 namespace libdap {
 
-class ArrayTest: public TestFixture {
+class ArrayTest : public TestFixture {
 private:
     Array *d_cardinal = nullptr;
     Array *d_string = nullptr;
@@ -61,34 +61,32 @@ private:
     Str *d_str = nullptr;
     Structure *d_struct = nullptr;
 
-    string svalues[4] = {"0 String", "1 String", "2 String", "3 String" };
-    
+    string svalues[4] = {"0 String", "1 String", "2 String", "3 String"};
+
 public:
     ArrayTest() = default;
 
     ~ArrayTest() = default;
 
-    void setUp()
-    {
+    void setUp() {
         d_int16 = new Int16("Int16");
         DBG(cerr << "d_int16: " << d_int16 << endl);
         d_cardinal = new Array("Array_of_Int16", d_int16);
         d_cardinal->append_dim(4, "dimension");
-        dods_int16 buffer[4] = { 0, 1, 2, 3 };
+        dods_int16 buffer[4] = {0, 1, 2, 3};
         d_cardinal->val2buf(buffer);
 
         // Added to test if Arrays with DAP4 protos will have is_dap4() == true. jhrg 7/27/22
         Int64 i64("");
         d_card_dap4 = new Array("Array_of_Int64", &i64);
         d_card_dap4->append_dim(4, "dimension");
-        dods_int64 buffer64[4] = { 0, 1, 2, 3 };
+        dods_int64 buffer64[4] = {0, 1, 2, 3};
         d_card_dap4->val2buf(buffer64);
 
-
         d_str = new Str("Str");
         d_string = new Array("Array_of_String", d_str);
         d_string->append_dim(4, "dimension");
-        string sbuffer[4] = { "0 String", "1 String", "2 String", "3 String" };
+        string sbuffer[4] = {"0 String", "1 String", "2 String", "3 String"};
         d_string->val2buf(sbuffer);
 
         d_struct = new Structure("Structure");
@@ -120,45 +118,41 @@ public:
         d_struct = 0;
     }
 
-    void tearDown()
-    {
+    void tearDown() {
         delete d_cardinal;
         delete d_card_dap4;
         delete d_string;
         delete d_structure;
     }
 
-    bool re_match(Regex &r, const char *s)
-    {
+    bool re_match(Regex &r, const char *s) {
         int match_position = r.match(s, strlen(s));
-        DBG(cerr << "match position: " << match_position
-            << " string length: " << (int)strlen(s) << endl);
-        return match_position == (int) strlen(s);
+        DBG(cerr << "match position: " << match_position << " string length: " << (int)strlen(s) << endl);
+        return match_position == (int)strlen(s);
     }
 
-    CPPUNIT_TEST_SUITE (ArrayTest);
+    CPPUNIT_TEST_SUITE(ArrayTest);
 
-    CPPUNIT_TEST (cons_test);
-    CPPUNIT_TEST (test_is_dap4_1);
-    CPPUNIT_TEST (test_is_dap4_2);
-    CPPUNIT_TEST (test_is_dap4_3);
-    CPPUNIT_TEST (test_is_dap4_4);
-    CPPUNIT_TEST (assignment_test_1);
-    CPPUNIT_TEST (assignment_test_2);
-    CPPUNIT_TEST (assignment_test_3);
-    CPPUNIT_TEST (prepend_dim_test);
-    CPPUNIT_TEST (prepend_dim_2_test);
-    CPPUNIT_TEST (clear_dims_test);
-    CPPUNIT_TEST (error_handling_test);
-    CPPUNIT_TEST (error_handling_2_test);
-    CPPUNIT_TEST (duplicate_cardinal_test);
-    CPPUNIT_TEST (duplicate_string_test);
-    CPPUNIT_TEST (duplicate_structure_test);
+    CPPUNIT_TEST(cons_test);
+    CPPUNIT_TEST(test_is_dap4_1);
+    CPPUNIT_TEST(test_is_dap4_2);
+    CPPUNIT_TEST(test_is_dap4_3);
+    CPPUNIT_TEST(test_is_dap4_4);
+    CPPUNIT_TEST(assignment_test_1);
+    CPPUNIT_TEST(assignment_test_2);
+    CPPUNIT_TEST(assignment_test_3);
+    CPPUNIT_TEST(prepend_dim_test);
+    CPPUNIT_TEST(prepend_dim_2_test);
+    CPPUNIT_TEST(clear_dims_test);
+    CPPUNIT_TEST(error_handling_test);
+    CPPUNIT_TEST(error_handling_2_test);
+    CPPUNIT_TEST(duplicate_cardinal_test);
+    CPPUNIT_TEST(duplicate_string_test);
+    CPPUNIT_TEST(duplicate_structure_test);
 
     CPPUNIT_TEST_SUITE_END();
 
-    void cons_test()
-    {
+    void cons_test() {
         Array a1 = Array("a", "b", d_int16, true);
         CPPUNIT_ASSERT(a1.name() == "a");
     }
@@ -178,7 +172,7 @@ public:
         D4Enum enum16("", dods_int16_c);
         unique_ptr<Array> enum_array_dap4(new Array("Array_of_Enum", &enum16));
         enum_array_dap4->append_dim(4, "dimension");
-        dods_int16 buffer16[4] = { 0, 1, 2, 3 };
+        dods_int16 buffer16[4] = {0, 1, 2, 3};
         enum_array_dap4->val2buf(buffer16);
 
         DBG(enum_array_dap4->dump(cerr));
@@ -189,15 +183,14 @@ public:
         D4Enum enum64("", dods_int64_c);
         unique_ptr<Array> enum_array_dap4(new Array("Array_of_Enum", &enum64));
         enum_array_dap4->append_dim(4, "dimension");
-        dods_int64 buffer64[4] = { 0, 1, 2, 3 };
+        dods_int64 buffer64[4] = {0, 1, 2, 3};
         enum_array_dap4->val2buf(buffer64);
 
         DBG(enum_array_dap4->dump(cerr));
         CPPUNIT_ASSERT_MESSAGE("This Array should register as DAP4", enum_array_dap4->is_dap4());
     }
 
-    void assignment_test_1()
-    {
+    void assignment_test_1() {
         // Are fields from the object copied by the assignment
         Array a1 = Array("a", d_int16);
         a1.append_dim(17, "bob");
@@ -206,8 +199,7 @@ public:
         CPPUNIT_ASSERT(a1.dimension_size(a1.dim_begin()) == 4);
     }
 
-    void assignment_test_2()
-    {
+    void assignment_test_2() {
         // Self-assignment; are objects changed by the assignment?
         Array a1 = Array("a", d_int16);
         Array *before = &a1;
@@ -218,8 +210,7 @@ public:
 
     // This tests that the assignment operator defined in Array correctly copies
     // information held in a parent class (Vector). jhrg 2/9/22
-    void assignment_test_3()
-    {
+    void assignment_test_3() {
         // Array copies the proto pointer and manages the storage
         unique_ptr<Float32> f32(new Float32("float_proto"));
         Array a1 = Array("a", f32.get());
@@ -228,14 +219,13 @@ public:
         Array a1 = Array("a", f32_ptr);
 	delete f32_ptr;
 #endif
-	
+
         CPPUNIT_ASSERT_MESSAGE("The type of a1.var() should be dods_float32", a1.var()->type() == dods_float32_c);
         a1 = *d_cardinal;
         CPPUNIT_ASSERT_MESSAGE("The type of a1.var() should now be dods_int16_c", a1.var()->type() == dods_int16_c);
     }
 
-    void prepend_dim_test()
-    {
+    void prepend_dim_test() {
         Array a1 = Array("a", d_int16);
         Array::Dim_iter i = a1.dim_begin();
         CPPUNIT_ASSERT(a1.dimension_size(i) == 0);
@@ -245,15 +235,14 @@ public:
         a1.prepend_dim(3, "dim_b");
     }
 
-    void prepend_dim_2_test()
-    {
+    void prepend_dim_2_test() {
         Array a1 = Array("a", d_int16);
         string expected_name[2] = {"dim_b", "myDim"};
         int j = 0;
 #if 0
         D4Dimensions *dims = new D4Dimensions();
         D4Dimension *d = new D4Dimension("dim_b", 2, dims);
-#endif 
+#endif
         unique_ptr<D4Dimensions> dims(new D4Dimensions());
         D4Dimension *d = new D4Dimension("dim_b", 2, dims.get());
 #if 0
@@ -272,8 +261,7 @@ public:
         delete d;
     }
 
-    void clear_dims_test()
-    {
+    void clear_dims_test() {
         Array a1 = Array("a", d_int16);
         a1.prepend_dim(2, "dim_a");
         a1.prepend_dim(3, "dim_b");
@@ -282,8 +270,7 @@ public:
         CPPUNIT_ASSERT(a1.dimension_size(i) == 0);
     }
 
-    void error_handling_test()
-    {
+    void error_handling_test() {
         Array a1 = Array("a", d_int16);
         Array::Dim_iter i = a1.dim_begin();
         string msg;
@@ -291,8 +278,7 @@ public:
         CPPUNIT_ASSERT(!a1.check_semantics(msg));
     }
 
-    void error_handling_2_test()
-    {
+    void error_handling_2_test() {
         Array a1 = Array("a", d_int16);
         a1.append_dim(2, "dim_a");
         Array::Dim_iter i = a1.dim_begin();
@@ -302,16 +288,15 @@ public:
         CPPUNIT_ASSERT_THROW(a1.add_constraint(i, 0, 3, 1), Error);
     }
 
-    void duplicate_structure_test()
-    {
+    void duplicate_structure_test() {
         Array::Dim_iter i = d_structure->dim_begin();
         CPPUNIT_ASSERT(d_structure->dimension_size(i) == 4);
 #ifdef DODS_DEBUG
         for (int i = 0; i < 4; ++i) {
-            Structure *s = dynamic_cast<Structure*>(d_structure->var(i));
+            Structure *s = dynamic_cast<Structure *>(d_structure->var(i));
             DBG(cerr << "s: " << s << endl);
             if (s)
-            s->print_decl(cerr);
+                s->print_decl(cerr);
         }
 #endif
 
@@ -323,8 +308,8 @@ public:
             // The point of this test is to ensure that the const ctor
             // performs a deep copy; first test to make sure the pointers
             // to BaseType instnaces are different in the two objects.
-            Structure *src = dynamic_cast<Structure*>(d_structure->var(i));
-            Structure *dest = dynamic_cast<Structure*>(a->var(i));
+            Structure *src = dynamic_cast<Structure *>(d_structure->var(i));
+            Structure *dest = dynamic_cast<Structure *>(a->var(i));
             CPPUNIT_ASSERT(src != dest);
 
             // However, for the deep copy to be correct, the two arrays must
@@ -339,12 +324,11 @@ public:
         a = 0;
     }
 
-    void duplicate_string_test()
-    {
+    void duplicate_string_test() {
         Array::Dim_iter i = d_string->dim_begin();
         CPPUNIT_ASSERT(d_string->dimension_size(i) == 4);
         string *s = new string[4];
-        d_string->buf2val((void**) &s);
+        d_string->buf2val((void **)&s);
         for (int i = 0; i < 4; ++i) {
             CPPUNIT_ASSERT(s[i] == svalues[i]);
             DBG(cerr << "s[" << i << "]: " << s[i] << endl);
@@ -355,7 +339,7 @@ public:
         CPPUNIT_ASSERT(a.dimension_size(i) == 4);
 
         string *s2 = new string[4];
-        d_string->buf2val((void**) &s2);
+        d_string->buf2val((void **)&s2);
         for (int i = 0; i < 4; ++i) {
             CPPUNIT_ASSERT(s2[i] == svalues[i]);
             DBG(cerr << "s2[" << i << "]: " << s2[i] << endl);
@@ -367,12 +351,11 @@ public:
         s2 = 0;
     }
 
-    void duplicate_cardinal_test()
-    {
+    void duplicate_cardinal_test() {
         Array::Dim_iter i = d_cardinal->dim_begin();
         CPPUNIT_ASSERT(d_cardinal->dimension_size(i) == 4);
         dods_int16 *b = new dods_int16[4];
-        d_cardinal->buf2val((void**) &b);
+        d_cardinal->buf2val((void **)&b);
         for (int i = 0; i < 4; ++i) {
             CPPUNIT_ASSERT(b[i] == i);
             DBG(cerr << "b[" << i << "]: " << b[i] << endl);
@@ -385,7 +368,7 @@ public:
         CPPUNIT_ASSERT(a.dimension_size(i) == 4);
 
         dods_int16 *b2 = new dods_int16[4];
-        d_cardinal->buf2val((void**) &b2);
+        d_cardinal->buf2val((void **)&b2);
         for (int i = 0; i < 4; ++i) {
             CPPUNIT_ASSERT(b2[i] == i);
             DBG(cerr << "b2[" << i << "]: " << b2[i] << endl);
@@ -393,14 +376,10 @@ public:
         delete[] b2;
         b2 = 0;
     }
-
 };
 
-CPPUNIT_TEST_SUITE_REGISTRATION (ArrayTest);
+CPPUNIT_TEST_SUITE_REGISTRATION(ArrayTest);
 
 } // namespace libdap
 
-int main(int argc, char *argv[])
-{
-    return run_tests<libdap::ArrayTest>(argc, argv) ? 0: 1;
-}
+int main(int argc, char *argv[]) { return run_tests<libdap::ArrayTest>(argc, argv) ? 0 : 1; }
