@@ -25,69 +25,58 @@
 #include "config.h"
 
 #include <cppunit/TextTestRunner.h>
-#include <cppunit/extensions/TestFactoryRegistry.h>
 #include <cppunit/extensions/HelperMacros.h>
+#include <cppunit/extensions/TestFactoryRegistry.h>
 
 #include <sstream>
 #include <string.h>
 
-#include "Byte.h"
-#include "Int8.h"
-#include "Int16.h"
-#include "UInt16.h"
+#include "Array.h"
 #include "BaseTypeFactory.h"
-#include "UInt32.h"
-#include "Int64.h"
-#include "UInt64.h"
+#include "Byte.h"
 #include "Float32.h"
 #include "Float64.h"
-#include "Str.h"
-#include "Url.h"
-#include "Array.h"
-#include "Structure.h"
-#include "Sequence.h"
 #include "Grid.h"
+#include "Int16.h"
+#include "Int64.h"
+#include "Int8.h"
+#include "Sequence.h"
+#include "Str.h"
+#include "Structure.h"
+#include "UInt16.h"
+#include "UInt32.h"
+#include "UInt64.h"
+#include "Url.h"
 #include "crc.h"
 
 #include "DDS.h"
 
 #include "GNURegex.h"
 
-#include "util.h"
-#include "debug.h"
 #include "ce_expr.tab.hh"
+#include "debug.h"
+#include "util.h"
 
+#include "run_tests_cppunit.h"
 #include "testFile.h"
-#include "run_tests_cppunit.h"
-#include "run_tests_cppunit.h"
 #include "test_config.h"
 
-
 using namespace CppUnit;
 using namespace std;
 
 namespace libdap {
 
-class BaseTypeFactoryTest: public TestFixture {
+class BaseTypeFactoryTest : public TestFixture {
 private:
     BaseTypeFactory btf;
-    
+
 public:
-    BaseTypeFactoryTest()
-    {
-    }
-    ~BaseTypeFactoryTest()
-    {
-    }
+    BaseTypeFactoryTest() {}
+    ~BaseTypeFactoryTest() {}
 
-    void setUp()
-    {
-        btf = BaseTypeFactory();
-    }
+    void setUp() { btf = BaseTypeFactory(); }
 
-    void tearDown()
-    {
-    }
+    void tearDown() {}
 
     CPPUNIT_TEST_SUITE(BaseTypeFactoryTest);
 
@@ -96,59 +85,56 @@ public:
 
     CPPUNIT_TEST_SUITE_END();
 
-    void ctor_test()
-    {
+    void ctor_test() {
         BaseTypeFactory *btf1 = new BaseTypeFactory();
         delete btf1;
     }
 
-    void new_variables_test()
-    {
+    void new_variables_test() {
         BaseType *bt;
-        
+
         bt = btf.NewVariable(dods_byte_c, "a");
-        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Byte*>(bt) && !bt->is_dap4());
+        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Byte *>(bt) && !bt->is_dap4());
         delete bt;
         bt = btf.NewVariable(dods_int16_c, "a");
-        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Int16*>(bt) && !bt->is_dap4());
+        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Int16 *>(bt) && !bt->is_dap4());
         delete bt;
         bt = btf.NewVariable(dods_uint16_c, "a");
-        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<UInt16*>(bt) && !bt->is_dap4());
+        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<UInt16 *>(bt) && !bt->is_dap4());
         delete bt;
         bt = btf.NewVariable(dods_int32_c, "a");
-        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Int32*>(bt) && !bt->is_dap4());
+        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Int32 *>(bt) && !bt->is_dap4());
         delete bt;
         bt = btf.NewVariable(dods_uint32_c, "a");
-        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<UInt32*>(bt) && !bt->is_dap4());
+        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<UInt32 *>(bt) && !bt->is_dap4());
         delete bt;
         bt = btf.NewVariable(dods_float32_c, "a");
-        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Float32*>(bt) && !bt->is_dap4());
+        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Float32 *>(bt) && !bt->is_dap4());
         delete bt;
         bt = btf.NewVariable(dods_float64_c, "a");
-        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Float64*>(bt) && !bt->is_dap4());
+        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Float64 *>(bt) && !bt->is_dap4());
         delete bt;
         bt = btf.NewVariable(dods_str_c, "a");
-        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Str*>(bt) && !bt->is_dap4());
+        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Str *>(bt) && !bt->is_dap4());
         delete bt;
         bt = btf.NewVariable(dods_url_c, "a");
-        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Url*>(bt) && !bt->is_dap4());
+        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Url *>(bt) && !bt->is_dap4());
         delete bt;
         bt = btf.NewVariable(dods_array_c, "a");
-        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Array*>(bt) && !bt->is_dap4());
+        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Array *>(bt) && !bt->is_dap4());
         delete bt;
         bt = btf.NewVariable(dods_structure_c, "a");
-        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Structure*>(bt) && !bt->is_dap4());
+        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Structure *>(bt) && !bt->is_dap4());
         delete bt;
         bt = btf.NewVariable(dods_sequence_c, "a");
-        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Sequence*>(bt) && !bt->is_dap4());
+        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Sequence *>(bt) && !bt->is_dap4());
         delete bt;
         bt = btf.NewVariable(dods_grid_c, "a");
-        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Grid*>(bt) && !bt->is_dap4());
+        CPPUNIT_ASSERT(bt->name() == "a" && dynamic_cast<Grid *>(bt) && !bt->is_dap4());
         delete bt;
     }
 
-    void error_test()
-    {
+    void error_test() {
         CPPUNIT_ASSERT_THROW(btf.NewVariable(dods_group_c, "a"), InternalErr);
         CPPUNIT_ASSERT_THROW(btf.ptr_duplicate(), InternalErr);
     }
@@ -158,7 +144,4 @@ CPPUNIT_TEST_SUITE_REGISTRATION(BaseTypeFactoryTest);
 
 } // namespace libdap
 
-int main(int argc, char *argv[])
-{
-    return run_tests<BaseTypeFactoryTest>(argc, argv) ? 0: 1;
-}
+int main(int argc, char *argv[]) { return run_tests<BaseTypeFactoryTest>(argc, argv) ? 0 : 1; }
