@@ -25,29 +25,24 @@
 #include "config.h"
 
 #include <cppunit/TextTestRunner.h>
-#include <cppunit/extensions/TestFactoryRegistry.h>
 #include <cppunit/extensions/HelperMacros.h>
+#include <cppunit/extensions/TestFactoryRegistry.h>
 
-//#define DODS_DEBUG
+// #define DODS_DEBUG
 
 #include "D4Attributes.h"
 #include "XMLWriter.h"
 #include "debug.h"
 
-#include "testFile.h"
 #include "run_tests_cppunit.h"
+#include "testFile.h"
 #include "test_config.h"
 
-
-
 using namespace CppUnit;
 using namespace std;
 using namespace libdap;
 
-
-
-
-class D4AttributesTest: public TestFixture {
+class D4AttributesTest : public TestFixture {
 private:
     XMLWriter *xml;
     D4Attributes *attrs;
@@ -55,16 +50,11 @@ private:
     D4Attribute a, a2, a3, a4, a5, c, c2;
 
 public:
-    D4AttributesTest()
-    {
-    }
+    D4AttributesTest() {}
 
-    ~D4AttributesTest()
-    {
-    }
+    ~D4AttributesTest() {}
 
-    void setUp()
-    {
+    void setUp() {
         attrs = new D4Attributes;
         xml = new XMLWriter;
 
@@ -100,14 +90,12 @@ public:
         c2.attributes()->add_attribute(&c);
     }
 
-    void tearDown()
-    {
+    void tearDown() {
         delete xml;
         delete attrs;
     }
 
-    void test_type_to_string()
-    {
+    void test_type_to_string() {
         CPPUNIT_ASSERT(D4AttributeTypeToString(attr_null_c) == "null");
         CPPUNIT_ASSERT(D4AttributeTypeToString(attr_byte_c) == "Byte");
         CPPUNIT_ASSERT(D4AttributeTypeToString(attr_int16_c) == "Int16");
@@ -128,8 +116,7 @@ public:
         CPPUNIT_ASSERT(D4AttributeTypeToString(attr_otherxml_c) == "OtherXML");
     }
 
-    void test_string_to_type()
-    {
+    void test_string_to_type() {
         CPPUNIT_ASSERT(StringToD4AttributeType("null") == attr_null_c);
         CPPUNIT_ASSERT(StringToD4AttributeType("Byte") == attr_byte_c);
         CPPUNIT_ASSERT(StringToD4AttributeType("Int16") == attr_int16_c);
@@ -151,15 +138,13 @@ public:
         CPPUNIT_ASSERT(StringToD4AttributeType("Punk") == attr_null_c);
     }
 
-    void test_attr_type()
-    {
-        //attrs->get_dap2_AttrType(attr_null_c);
+    void test_attr_type() {
+        // attrs->get_dap2_AttrType(attr_null_c);
     }
 
     // An empty D4Dimensions object prints nothing; the XMLWriter class adds
     // a xml doc preface.
-    void test_print_empty()
-    {
+    void test_print_empty() {
         attrs->print_dap4(*xml);
         string doc = xml->get_doc();
         string baseline = read_test_baseline(string(TEST_SRC_DIR) + "/D4-xml/D4Attributes_empty.xml");
@@ -167,18 +152,15 @@ public:
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_print_single_attribute()
-    {
+    void test_print_single_attribute() {
         a.print_dap4(*xml);
         string doc = xml->get_doc();
         string baseline = read_test_baseline(string(TEST_SRC_DIR) + "/D4-xml/D4Attributes_values_1.xml");
         DBG(cerr << "D4Attributes: " << doc << endl);
         CPPUNIT_ASSERT(doc == baseline);
-
     }
 
-    void test_print_1()
-    {
+    void test_print_1() {
         attrs->add_attribute(&a);
 
         attrs->print_dap4(*xml);
@@ -188,8 +170,7 @@ public:
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_print_2()
-    {
+    void test_print_2() {
         attrs->add_attribute(&a);
         attrs->add_attribute(&a2);
 
@@ -200,8 +181,7 @@ public:
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_print_3()
-    {
+    void test_print_3() {
         attrs->add_attribute(&a);
         attrs->add_attribute(&a2);
         attrs->add_attribute(&c);
@@ -214,23 +194,20 @@ public:
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_dump()
-    {
+    void test_dump() {
         attrs->add_attribute(&c2);
-        ostringstream sof;        
+        ostringstream sof;
         attrs->dump(sof);
         CPPUNIT_ASSERT(sof.str().find("<Attribute name=\"container_2\" type=\"Container\">") != string::npos);
     }
 
-    void test_2_dump()
-    {
-        ostringstream sof;        
+    void test_2_dump() {
+        ostringstream sof;
         a.dump(sof);
         CPPUNIT_ASSERT(sof.str().find("<Attribute name=\"first\" type=\"Byte\">") != string::npos);
     }
 
-    void test_print_assignment()
-    {
+    void test_print_assignment() {
         attrs->add_attribute(&a);
         attrs->add_attribute(&a2);
 
@@ -243,8 +220,7 @@ public:
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_print_assignment_2()
-    {
+    void test_print_assignment_2() {
         attrs->add_attribute(&a);
         attrs->add_attribute(&a2);
         attrs->add_attribute(&c);
@@ -259,8 +235,7 @@ public:
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_print_copy_ctor()
-    {
+    void test_print_copy_ctor() {
         attrs->add_attribute(&a);
         attrs->add_attribute(&a2);
 
@@ -273,8 +248,7 @@ public:
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_find()
-    {
+    void test_find() {
         attrs->add_attribute(&a);
         attrs->add_attribute(&a2);
         attrs->add_attribute(&c);
@@ -299,8 +273,7 @@ public:
         CPPUNIT_ASSERT(baseline == find_result);
     }
 
-    void test_get()
-    {
+    void test_get() {
         attrs->add_attribute(&a);
         attrs->add_attribute(&a2);
         attrs->add_attribute(&c);
@@ -325,8 +298,7 @@ public:
         CPPUNIT_ASSERT(baseline == get_result);
     }
 
-    void test_get2()
-    {
+    void test_get2() {
         attrs->add_attribute(&a);
         attrs->add_attribute(&a2);
         attrs->add_attribute(&c);
@@ -359,8 +331,7 @@ public:
     }
 
     // test erasing an attribute
-    void test_erase_1()
-    {
+    void test_erase_1() {
         attrs->add_attribute(&a);
         attrs->add_attribute(&a2);
         attrs->add_attribute(&c);
@@ -379,8 +350,7 @@ public:
     }
 
     // test erasing an attribute in a container
-    void test_erase_2()
-    {
+    void test_erase_2() {
         attrs->add_attribute(&a);
         attrs->add_attribute(&a2);
         attrs->add_attribute(&c);
@@ -396,13 +366,12 @@ public:
 
         color = attrs->get("container_1.color");
         // attrs->dump(cerr), attrs <-- Trick to get a return value for the ternary op. jhrg 2/16/22
-        DBG(cerr << "after erase: attrs: " << (attrs != nullptr ? attrs->dump(cerr), attrs: 0) << endl);
+        DBG(cerr << "after erase: attrs: " << (attrs != nullptr ? attrs->dump(cerr), attrs : 0) << endl);
         CPPUNIT_ASSERT_MESSAGE("The attribute should not be present after calling erase()", color == nullptr);
     }
 
     // test erasing a container
-    void test_erase_3()
-    {
+    void test_erase_3() {
         attrs->add_attribute(&a);
         attrs->add_attribute(&a2);
         attrs->add_attribute(&c);
@@ -418,13 +387,12 @@ public:
 
         color = attrs->get("container_1");
         // attrs->dump(cerr), attrs <-- Trick to get a return value for the ternary op. jhrg 2/16/22
-        DBG(cerr << "after erase: attrs: " << (attrs != nullptr ? attrs->dump(cerr), attrs: 0) << endl);
+        DBG(cerr << "after erase: attrs: " << (attrs != nullptr ? attrs->dump(cerr), attrs : 0) << endl);
         CPPUNIT_ASSERT_MESSAGE("The attribute should not be present after calling erase()", color == nullptr);
     }
 
     // test erasing a container, using erase_named_attribute() and instead of erase()
-    void test_erase_4()
-    {
+    void test_erase_4() {
         attrs->add_attribute(&a);
         attrs->add_attribute(&a2);
         attrs->add_attribute(&c);
@@ -440,42 +408,39 @@ public:
 
         color = attrs->get("container_1");
         // attrs->dump(cerr), attrs <-- Trick to get a return value for the ternary op. jhrg 2/16/22
-        DBG(cerr << "after erase: attrs: " << (attrs != nullptr ? attrs->dump(cerr), attrs: 0) << endl);
+        DBG(cerr << "after erase: attrs: " << (attrs != nullptr ? attrs->dump(cerr), attrs : 0) << endl);
         CPPUNIT_ASSERT_MESSAGE("The attribute should not be present after calling erase()", color == nullptr);
     }
 
-    CPPUNIT_TEST_SUITE (D4AttributesTest);
+    CPPUNIT_TEST_SUITE(D4AttributesTest);
 
-    CPPUNIT_TEST (test_type_to_string);
-    
-    CPPUNIT_TEST (test_print_empty);
-    CPPUNIT_TEST (test_print_single_attribute);
-    CPPUNIT_TEST (test_print_1);
-    CPPUNIT_TEST (test_print_2);
-    CPPUNIT_TEST (test_print_3);
-    CPPUNIT_TEST (test_dump);
-    CPPUNIT_TEST (test_2_dump);
+    CPPUNIT_TEST(test_type_to_string);
 
-    CPPUNIT_TEST (test_print_assignment);
-    CPPUNIT_TEST (test_print_assignment_2);
+    CPPUNIT_TEST(test_print_empty);
+    CPPUNIT_TEST(test_print_single_attribute);
+    CPPUNIT_TEST(test_print_1);
+    CPPUNIT_TEST(test_print_2);
+    CPPUNIT_TEST(test_print_3);
+    CPPUNIT_TEST(test_dump);
+    CPPUNIT_TEST(test_2_dump);
 
-    CPPUNIT_TEST (test_print_copy_ctor);
+    CPPUNIT_TEST(test_print_assignment);
+    CPPUNIT_TEST(test_print_assignment_2);
 
-    CPPUNIT_TEST (test_find);
-    CPPUNIT_TEST (test_get);
-    CPPUNIT_TEST (test_get2);
+    CPPUNIT_TEST(test_print_copy_ctor);
 
-    CPPUNIT_TEST (test_erase_1);
-    CPPUNIT_TEST (test_erase_2);
-    CPPUNIT_TEST (test_erase_3);
-    CPPUNIT_TEST (test_erase_4);
+    CPPUNIT_TEST(test_find);
+    CPPUNIT_TEST(test_get);
+    CPPUNIT_TEST(test_get2);
+
+    CPPUNIT_TEST(test_erase_1);
+    CPPUNIT_TEST(test_erase_2);
+    CPPUNIT_TEST(test_erase_3);
+    CPPUNIT_TEST(test_erase_4);
 
     CPPUNIT_TEST_SUITE_END();
 };
 
-CPPUNIT_TEST_SUITE_REGISTRATION (D4AttributesTest);
+CPPUNIT_TEST_SUITE_REGISTRATION(D4AttributesTest);
 
-int main(int argc, char*argv[])
-{
-    return run_tests<D4AttributesTest>(argc, argv) ? 0: 1;
-}
+int main(int argc, char *argv[]) { return run_tests<D4AttributesTest>(argc, argv) ? 0 : 1; }
