@@ -25,12 +25,12 @@
 #include "config.h"
 
 #include <cppunit/TextTestRunner.h>
-#include <cppunit/extensions/TestFactoryRegistry.h>
 #include <cppunit/extensions/HelperMacros.h>
+#include <cppunit/extensions/TestFactoryRegistry.h>
 
- // Part of libdap
+// Part of libdap
 
-//#define DODS_DEBUG
+// #define DODS_DEBUG
 
 #include "D4Dimensions.h"
 #include "XMLWriter.h"
@@ -38,49 +38,37 @@
 #include "Error.h"
 #include "debug.h"
 
-#include "testFile.h"
 #include "run_tests_cppunit.h"
+#include "testFile.h"
 #include "test_config.h"
 
-
 using namespace CppUnit;
 using namespace std;
 using namespace libdap;
 
-
-
-
-class D4DimensionsTest: public TestFixture {
+class D4DimensionsTest : public TestFixture {
 private:
     XMLWriter *xml;
     D4Dimensions *d;
 
 public:
-    D4DimensionsTest() :
-        xml(0), d(0)
-    {
-    }
+    D4DimensionsTest() : xml(0), d(0) {}
 
-    ~D4DimensionsTest()
-    {
-    }
+    ~D4DimensionsTest() {}
 
-    void setUp()
-    {
+    void setUp() {
         d = new D4Dimensions;
         xml = new XMLWriter;
     }
 
-    void tearDown()
-    {
+    void tearDown() {
         delete xml;
         delete d;
     }
 
     // An empty D4Dimensions object prints nothing; the XMLWriter class adds
     // a xml doc preface.
-    void test_print_empty()
-    {
+    void test_print_empty() {
         d->print_dap4(*xml);
         string doc = xml->get_doc();
         string baseline = read_test_baseline(string(TEST_SRC_DIR) + "/D4-xml/D4Dimensions_empty.xml");
@@ -89,8 +77,7 @@ public:
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_print_1()
-    {
+    void test_print_1() {
         d->add_dim_nocopy(new D4Dimension("first", 10));
 
         d->print_dap4(*xml);
@@ -101,8 +88,7 @@ public:
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_print_2()
-    {
+    void test_print_2() {
         d->add_dim_nocopy(new D4Dimension("first", 10));
         d->add_dim_nocopy(new D4Dimension("second", 100));
 
@@ -114,8 +100,7 @@ public:
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_error()
-    {
+    void test_error() {
         D4Dimension *d3, *d2;
         try {
             d2 = new D4Dimension();
@@ -128,16 +113,14 @@ public:
             delete d3;
             delete d2;
             CPPUNIT_FAIL("Should throw an Error");
-        }
-        catch (...) {
+        } catch (...) {
             delete d3;
             delete d2;
             throw;
         }
     }
 
-    void test_error_2()
-    {
+    void test_error_2() {
         D4Dimension *d3;
         try {
             d3 = new D4Dimension();
@@ -145,8 +128,7 @@ public:
             d3->set_size("bad");
             delete d3;
             CPPUNIT_FAIL("Should throw an Error");
-        }
-        catch (...) {
+        } catch (...) {
             delete d3;
             throw;
         }
@@ -165,13 +147,12 @@ public:
         CPPUNIT_ASSERT(doc == baseline);
     }
 #endif
-    void test_print_insert_dim()
-    {
+    void test_print_insert_dim() {
         d->add_dim_nocopy(new D4Dimension("first", 10));
         d->add_dim_nocopy(new D4Dimension("second", 100));
         d->add_dim_nocopy(new D4Dimension("third", 1000));
 
-        //vector<D4Dimensions::dimension>::iterator i = d->dim_begin() + 1;
+        // vector<D4Dimensions::dimension>::iterator i = d->dim_begin() + 1;
         D4Dimensions::D4DimensionsIter i = d->dim_begin() + 1;
         d->insert_dim_nocopy(new D4Dimension("odd", 20), i);
 
@@ -183,8 +164,7 @@ public:
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_print_assignment()
-    {
+    void test_print_assignment() {
         d->add_dim_nocopy(new D4Dimension("first", 10));
         d->add_dim_nocopy(new D4Dimension("second", 100));
         d->add_dim_nocopy(new D4Dimension("third", 1000));
@@ -199,8 +179,7 @@ public:
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_print_copy_ctor()
-    {
+    void test_print_copy_ctor() {
         d->add_dim_nocopy(new D4Dimension("first", 10));
         d->add_dim_nocopy(new D4Dimension("second", 100));
         d->add_dim_nocopy(new D4Dimension("third", 1000));
@@ -215,28 +194,25 @@ public:
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    CPPUNIT_TEST_SUITE (D4DimensionsTest);
+    CPPUNIT_TEST_SUITE(D4DimensionsTest);
 
-    CPPUNIT_TEST (test_print_empty);
-    CPPUNIT_TEST (test_print_1);
-    CPPUNIT_TEST (test_print_2);
+    CPPUNIT_TEST(test_print_empty);
+    CPPUNIT_TEST(test_print_1);
+    CPPUNIT_TEST(test_print_2);
 
-    CPPUNIT_TEST_EXCEPTION( test_error, Error );
-    //CPPUNIT_TEST( test_error );
-    CPPUNIT_TEST_EXCEPTION( test_error_2, Error );
+    CPPUNIT_TEST_EXCEPTION(test_error, Error);
+    // CPPUNIT_TEST( test_error );
+    CPPUNIT_TEST_EXCEPTION(test_error_2, Error);
 #ifdef VARYING
     CPPUNIT_TEST(test_print_varying);
 #endif
-    CPPUNIT_TEST (test_print_insert_dim);
-    CPPUNIT_TEST (test_print_assignment);
-    CPPUNIT_TEST (test_print_copy_ctor);
+    CPPUNIT_TEST(test_print_insert_dim);
+    CPPUNIT_TEST(test_print_assignment);
+    CPPUNIT_TEST(test_print_copy_ctor);
 
     CPPUNIT_TEST_SUITE_END();
 };
 
-CPPUNIT_TEST_SUITE_REGISTRATION (D4DimensionsTest);
+CPPUNIT_TEST_SUITE_REGISTRATION(D4DimensionsTest);
 
-int main(int argc, char*argv[])
-{
-    return run_tests<D4DimensionsTest>(argc, argv) ? 0: 1;
-}
+int main(int argc, char *argv[]) { return run_tests<D4DimensionsTest>(argc, argv) ? 0 : 1; }
