@@ -25,30 +25,25 @@
 #include "config.h"
 
 #include <cppunit/TextTestRunner.h>
-#include <cppunit/extensions/TestFactoryRegistry.h>
 #include <cppunit/extensions/HelperMacros.h>
+#include <cppunit/extensions/TestFactoryRegistry.h>
 
-//#define DODS_DEBUG
+// #define DODS_DEBUG
 
-#include "dods-limits.h"
 #include "D4EnumDefs.h"
 #include "XMLWriter.h"
 #include "debug.h"
+#include "dods-limits.h"
 
-#include "testFile.h"
 #include "run_tests_cppunit.h"
+#include "testFile.h"
 #include "test_config.h"
 
-
-
-
 using namespace CppUnit;
 using namespace std;
 using namespace libdap;
 
-
-
-class D4EnumDefsTest: public TestFixture {
+class D4EnumDefsTest : public TestFixture {
 private:
     XMLWriter *xml;
     D4EnumDefs *d;
@@ -56,16 +51,11 @@ private:
     D4EnumDef e, e2;
 
 public:
-    D4EnumDefsTest()
-    {
-    }
+    D4EnumDefsTest() {}
 
-    ~D4EnumDefsTest()
-    {
-    }
+    ~D4EnumDefsTest() {}
 
-    void setUp()
-    {
+    void setUp() {
         d = new D4EnumDefs;
         xml = new XMLWriter;
 
@@ -80,25 +70,23 @@ public:
         e2.add_value("ice", 10000);
     }
 
-    void tearDown()
-    {
+    void tearDown() {
         delete xml;
         delete d;
     }
 
     // An empty D4Dimensions object prints nothing; the XMLWriter class adds
     // a xml doc preface.
-    void test_print_empty()
-    {
+    void test_print_empty() {
         d->print_dap4(*xml);
         string doc = xml->get_doc();
         string baseline = read_test_baseline(string(TEST_SRC_DIR) + "/D4-xml/D4EnumDefs_empty.xml");
-        DBG(cerr << "test_print_empty: doc: " << doc << endl);DBG(cerr << "test_print_empty: baseline: " << baseline << endl);
+        DBG(cerr << "test_print_empty: doc: " << doc << endl);
+        DBG(cerr << "test_print_empty: baseline: " << baseline << endl);
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_print_enum_values_only()
-    {
+    void test_print_enum_values_only() {
         D4EnumDef e;
         e.add_value("red", 1);
         e.add_value("blue", 2);
@@ -106,36 +94,35 @@ public:
         e.print_dap4(*xml);
         string doc = xml->get_doc();
         string baseline = read_test_baseline(string(TEST_SRC_DIR) + "/D4-xml/D4EnumDefs_values_1.xml");
-        DBG(cerr << "test_print_enum_values_only: doc: " << doc << endl);DBG(cerr << "test_print_enum_values_only: baseline: " << baseline << endl);
+        DBG(cerr << "test_print_enum_values_only: doc: " << doc << endl);
+        DBG(cerr << "test_print_enum_values_only: baseline: " << baseline << endl);
         CPPUNIT_ASSERT(doc == baseline);
-
     }
 
-    void test_print_1()
-    {
+    void test_print_1() {
         d->add_enum(&e);
 
         d->print_dap4(*xml);
         string doc = xml->get_doc();
         string baseline = read_test_baseline(string(TEST_SRC_DIR) + "/D4-xml/D4EnumDefs_1.xml");
-        DBG(cerr << "test_print_1: doc: " << doc << endl);DBG(cerr << "test_print_1: baseline: " << baseline << endl);
+        DBG(cerr << "test_print_1: doc: " << doc << endl);
+        DBG(cerr << "test_print_1: baseline: " << baseline << endl);
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_print_2()
-    {
+    void test_print_2() {
         d->add_enum(&e);
         d->add_enum(&e2);
 
         d->print_dap4(*xml);
         string doc = xml->get_doc();
         string baseline = read_test_baseline(string(TEST_SRC_DIR) + "/D4-xml/D4EnumDefs_2.xml");
-        DBG(cerr << "test_print_2: doc: " << doc << endl);DBG(cerr << "test_print_2: baseline: " << baseline << endl);
+        DBG(cerr << "test_print_2: doc: " << doc << endl);
+        DBG(cerr << "test_print_2: baseline: " << baseline << endl);
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_print_insert_enum()
-    {
+    void test_print_insert_enum() {
         d->add_enum(&e);
 
         // "second' winds up before 'first'
@@ -145,12 +132,12 @@ public:
         d->print_dap4(*xml);
         string doc = xml->get_doc();
         string baseline = read_test_baseline(string(TEST_SRC_DIR) + "/D4-xml/D4EnumDefs_3.xml");
-        DBG(cerr << "test_print_insert_enum: doc: " << doc << endl);DBG(cerr << "test_print_insert_enum: baseline: " << baseline << endl);
+        DBG(cerr << "test_print_insert_enum: doc: " << doc << endl);
+        DBG(cerr << "test_print_insert_enum: baseline: " << baseline << endl);
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_print_assignment()
-    {
+    void test_print_assignment() {
         d->add_enum(&e);
         d->add_enum(&e2);
 
@@ -159,12 +146,12 @@ public:
         lhs.print_dap4(*xml);
         string doc = xml->get_doc();
         string baseline = read_test_baseline(string(TEST_SRC_DIR) + "/D4-xml/D4EnumDefs_2.xml");
-        DBG(cerr << "test_print_assignment: doc: " << doc << endl);DBG(cerr << "test_print_assignment: baseline: " << baseline << endl);
+        DBG(cerr << "test_print_assignment: doc: " << doc << endl);
+        DBG(cerr << "test_print_assignment: baseline: " << baseline << endl);
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_print_copy_ctor()
-    {
+    void test_print_copy_ctor() {
         d->add_enum(&e);
         d->add_enum(&e2);
 
@@ -173,13 +160,13 @@ public:
         lhs.print_dap4(*xml);
         string doc = xml->get_doc();
         string baseline = read_test_baseline(string(TEST_SRC_DIR) + "/D4-xml/D4EnumDefs_2.xml");
-        DBG(cerr << "test_print_copy_ctor: doc: " << doc << endl);DBG(cerr << "test_print_copy_ctor: baseline: " << baseline << endl);
+        DBG(cerr << "test_print_copy_ctor: doc: " << doc << endl);
+        DBG(cerr << "test_print_copy_ctor: baseline: " << baseline << endl);
         CPPUNIT_ASSERT(doc == baseline);
     }
 
     // D4EnumDef::is_valid_enum_value(long long value)
-    void test_is_valid_enum_value_1()
-    {
+    void test_is_valid_enum_value_1() {
         // e is an enum that holds a Byte
         // e2 is an enum for int32 values
 
@@ -188,46 +175,41 @@ public:
         CPPUNIT_ASSERT_MESSAGE("-1 Should be a valid byte value", !e.is_valid_enum_value(-1));
     }
 
-    void test_is_valid_enum_value_2()
-    {
+    void test_is_valid_enum_value_2() {
         CPPUNIT_ASSERT_MESSAGE("-1 Should be a valid int32 enum value", e2.is_valid_enum_value(-1));
         CPPUNIT_ASSERT_MESSAGE("-65536 Should be a valid int32 enum value", e2.is_valid_enum_value(-65536));
         CPPUNIT_ASSERT_MESSAGE("65536 Should be a valid int32 enum value", e2.is_valid_enum_value(-65536));
     }
 
-    void test_is_valid_enum_value_3()
-    {
+    void test_is_valid_enum_value_3() {
         CPPUNIT_ASSERT_MESSAGE("DODS_INT_MIN Should be a valid int32 enum value", e2.is_valid_enum_value(DODS_INT_MIN));
         CPPUNIT_ASSERT_MESSAGE("DODS_INT_MAX Should be a valid int32 enum value", e2.is_valid_enum_value(DODS_INT_MAX));
     }
 
-    void test_is_valid_enum_value_4()
-    {
-        CPPUNIT_ASSERT_MESSAGE("DODS_UINT_MAX Should not be a valid int32 enum value", !e2.is_valid_enum_value(DODS_UINT_MAX));
+    void test_is_valid_enum_value_4() {
+        CPPUNIT_ASSERT_MESSAGE("DODS_UINT_MAX Should not be a valid int32 enum value",
+                               !e2.is_valid_enum_value(DODS_UINT_MAX));
     }
 
-    CPPUNIT_TEST_SUITE (D4EnumDefsTest);
+    CPPUNIT_TEST_SUITE(D4EnumDefsTest);
 
-    CPPUNIT_TEST (test_print_empty);
-    CPPUNIT_TEST (test_print_enum_values_only);
-    CPPUNIT_TEST (test_print_1);
-    CPPUNIT_TEST (test_print_2);
+    CPPUNIT_TEST(test_print_empty);
+    CPPUNIT_TEST(test_print_enum_values_only);
+    CPPUNIT_TEST(test_print_1);
+    CPPUNIT_TEST(test_print_2);
 
-    CPPUNIT_TEST (test_print_insert_enum);
-    CPPUNIT_TEST (test_print_assignment);
-    CPPUNIT_TEST (test_print_copy_ctor);
+    CPPUNIT_TEST(test_print_insert_enum);
+    CPPUNIT_TEST(test_print_assignment);
+    CPPUNIT_TEST(test_print_copy_ctor);
 
-    CPPUNIT_TEST (test_is_valid_enum_value_1);
-    CPPUNIT_TEST (test_is_valid_enum_value_2);
-    CPPUNIT_TEST (test_is_valid_enum_value_3);
-    CPPUNIT_TEST (test_is_valid_enum_value_4);
+    CPPUNIT_TEST(test_is_valid_enum_value_1);
+    CPPUNIT_TEST(test_is_valid_enum_value_2);
+    CPPUNIT_TEST(test_is_valid_enum_value_3);
+    CPPUNIT_TEST(test_is_valid_enum_value_4);
 
     CPPUNIT_TEST_SUITE_END();
 };
 
-CPPUNIT_TEST_SUITE_REGISTRATION (D4EnumDefsTest);
+CPPUNIT_TEST_SUITE_REGISTRATION(D4EnumDefsTest);
 
-int main(int argc, char*argv[])
-{
-    return run_tests<D4EnumDefsTest>(argc, argv) ? 0: 1;
-}
+int main(int argc, char *argv[]) { return run_tests<D4EnumDefsTest>(argc, argv) ? 0 : 1; }
