@@ -25,16 +25,16 @@
 #include "config.h"
 
 #include <cppunit/TextTestRunner.h>
-#include <cppunit/extensions/TestFactoryRegistry.h>
 #include <cppunit/extensions/HelperMacros.h>
+#include <cppunit/extensions/TestFactoryRegistry.h>
 
 #include <sstream>
 
 #include "Byte.h"
-#include "Int8.h"
 #include "Int16.h"
-#include "UInt16.h"
 #include "Int32.h"
+#include "Int8.h"
+#include "UInt16.h"
 #include "UInt32.h"
 
 #include "Float32.h"
@@ -42,16 +42,15 @@
 
 #include "Str.h"
 #include "Url.h"
-//#include "Array.h"
+// #include "Array.h"
 #include "Structure.h"
 
-#include "D4RValue.h"
 #include "D4FilterClause.h"
-#include "DMR.h"    // We need this because D4FilterClause::value needs it (sort of).
+#include "D4RValue.h"
+#include "DMR.h" // We need this because D4FilterClause::value needs it (sort of).
 
-
-#include "util.h"
 #include "debug.h"
+#include "util.h"
 
 #include "run_tests_cppunit.h"
 #include "test_config.h"
@@ -61,7 +60,7 @@ using namespace std;
 
 namespace libdap {
 
-class D4FilterClauseTest: public TestFixture {
+class D4FilterClauseTest : public TestFixture {
     // Build a DMR and build several D4RValue objects that reference its variables.
     // Then build several D4RValue objects that hold constants
 
@@ -74,16 +73,10 @@ private:
     DMR dmr;
 
 public:
-    D4FilterClauseTest() :
-        byte(0), f32(0), str(0), url(0)
-    {
-    }
-    ~D4FilterClauseTest()
-    {
-    }
+    D4FilterClauseTest() : byte(0), f32(0), str(0), url(0) {}
+    ~D4FilterClauseTest() {}
 
-    void setUp()
-    {
+    void setUp() {
         byte = new Byte("byte");
         byte->set_value(17);
 
@@ -97,8 +90,7 @@ public:
         url->set_value("https://github.com/opendap");
     }
 
-    void tearDown()
-    {
+    void tearDown() {
         delete byte;
         delete str;
         delete f32;
@@ -107,83 +99,80 @@ public:
 
     // FilterClauseList tests further down...
 
-    void Byte_and_long_long_test()
-    {
-        D4RValue *arg1 = new D4RValue(byte);    // holds 17
-        D4RValue *arg2 = new D4RValue((long long) 21);
+    void Byte_and_long_long_test() {
+        D4RValue *arg1 = new D4RValue(byte); // holds 17
+        D4RValue *arg2 = new D4RValue((long long)21);
 
         unique_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
         CPPUNIT_ASSERT(less->value(dmr));
 
-        D4RValue *arg2_1 = new D4RValue(byte);    // holds 17
-        D4RValue *arg2_2 = new D4RValue((long long) 21);
+        D4RValue *arg2_1 = new D4RValue(byte); // holds 17
+        D4RValue *arg2_2 = new D4RValue((long long)21);
 
         unique_ptr<D4FilterClause> greater(new D4FilterClause(D4FilterClause::greater, arg2_1, arg2_2));
         CPPUNIT_ASSERT(!greater->value(dmr));
 
-        D4RValue *arg3_1 = new D4RValue(byte);    // holds 17
-        D4RValue *arg3_2 = new D4RValue((long long) 21);
+        D4RValue *arg3_1 = new D4RValue(byte); // holds 17
+        D4RValue *arg3_2 = new D4RValue((long long)21);
 
         unique_ptr<D4FilterClause> equal(new D4FilterClause(D4FilterClause::equal, arg3_1, arg3_2));
         CPPUNIT_ASSERT(!equal->value(dmr));
 
-        D4RValue *arg4_1 = new D4RValue(byte);    // holds 17
-        D4RValue *arg4_2 = new D4RValue((long long) 21);
+        D4RValue *arg4_1 = new D4RValue(byte); // holds 17
+        D4RValue *arg4_2 = new D4RValue((long long)21);
 
         unique_ptr<D4FilterClause> not_equal(new D4FilterClause(D4FilterClause::not_equal, arg4_1, arg4_2));
         CPPUNIT_ASSERT(not_equal->value(dmr));
     }
 
     // This version uses the D4FilterClause::value() and not value(DMR&) method
-    void Byte_and_long_long_test_2()
-    {
-        D4RValue *arg1 = new D4RValue(byte);    // holds 17
-        D4RValue *arg2 = new D4RValue((long long) 21);
+    void Byte_and_long_long_test_2() {
+        D4RValue *arg1 = new D4RValue(byte); // holds 17
+        D4RValue *arg2 = new D4RValue((long long)21);
 
         unique_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
         CPPUNIT_ASSERT(less->value());
 
-        D4RValue *arg2_1 = new D4RValue(byte);    // holds 17
-        D4RValue *arg2_2 = new D4RValue((long long) 21);
+        D4RValue *arg2_1 = new D4RValue(byte); // holds 17
+        D4RValue *arg2_2 = new D4RValue((long long)21);
 
         unique_ptr<D4FilterClause> greater(new D4FilterClause(D4FilterClause::greater, arg2_1, arg2_2));
         CPPUNIT_ASSERT(!greater->value());
 
-        D4RValue *arg3_1 = new D4RValue(byte);    // holds 17
-        D4RValue *arg3_2 = new D4RValue((long long) 21);
+        D4RValue *arg3_1 = new D4RValue(byte); // holds 17
+        D4RValue *arg3_2 = new D4RValue((long long)21);
 
         unique_ptr<D4FilterClause> equal(new D4FilterClause(D4FilterClause::equal, arg3_1, arg3_2));
         CPPUNIT_ASSERT(!equal->value());
 
-        D4RValue *arg4_1 = new D4RValue(byte);    // holds 17
-        D4RValue *arg4_2 = new D4RValue((long long) 21);
+        D4RValue *arg4_1 = new D4RValue(byte); // holds 17
+        D4RValue *arg4_2 = new D4RValue((long long)21);
 
         unique_ptr<D4FilterClause> not_equal(new D4FilterClause(D4FilterClause::not_equal, arg4_1, arg4_2));
         CPPUNIT_ASSERT(not_equal->value());
     }
 
-    void Byte_and_double_test()
-    {
-        D4RValue *arg1 = new D4RValue(byte);    // holds 17
-        D4RValue *arg2 = new D4RValue((double) 21.0);
+    void Byte_and_double_test() {
+        D4RValue *arg1 = new D4RValue(byte); // holds 17
+        D4RValue *arg2 = new D4RValue((double)21.0);
 
         unique_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
         CPPUNIT_ASSERT(less->value(dmr));
 
-        D4RValue *arg2_1 = new D4RValue(byte);    // holds 17
-        D4RValue *arg2_2 = new D4RValue((double) 21);
+        D4RValue *arg2_1 = new D4RValue(byte); // holds 17
+        D4RValue *arg2_2 = new D4RValue((double)21);
 
         unique_ptr<D4FilterClause> greater(new D4FilterClause(D4FilterClause::greater, arg2_1, arg2_2));
         CPPUNIT_ASSERT(!greater->value(dmr));
 
-        D4RValue *arg3_1 = new D4RValue(byte);    // holds 17
-        D4RValue *arg3_2 = new D4RValue((double) 21);
+        D4RValue *arg3_1 = new D4RValue(byte); // holds 17
+        D4RValue *arg3_2 = new D4RValue((double)21);
 
         unique_ptr<D4FilterClause> equal(new D4FilterClause(D4FilterClause::equal, arg3_1, arg3_2));
         CPPUNIT_ASSERT(!equal->value(dmr));
 
-        D4RValue *arg4_1 = new D4RValue(byte);    // holds 17
-        D4RValue *arg4_2 = new D4RValue((double) 21);
+        D4RValue *arg4_1 = new D4RValue(byte); // holds 17
+        D4RValue *arg4_2 = new D4RValue((double)21);
 
         unique_ptr<D4FilterClause> not_equal(new D4FilterClause(D4FilterClause::not_equal, arg4_1, arg4_2));
         CPPUNIT_ASSERT(not_equal->value(dmr));
@@ -192,30 +181,25 @@ public:
     /** @defgroup type_conv Tests for type promotion
      * @{
      */
-    void Byte_and_int_test()
-    {
-        D4RValue *arg1 = new D4RValue(byte);    // holds 17
-        D4RValue *arg2 = new D4RValue((unsigned long long) (21));
+    void Byte_and_int_test() {
+        D4RValue *arg1 = new D4RValue(byte); // holds 17
+        D4RValue *arg2 = new D4RValue((unsigned long long)(21));
 
         unique_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
         CPPUNIT_ASSERT(less->value());
-
     }
 
-    void Byte_and_float_test()
-    {
-        D4RValue *arg1 = new D4RValue(byte);    // holds 17
-        D4RValue *arg2 = new D4RValue((float) 21.0);
+    void Byte_and_float_test() {
+        D4RValue *arg1 = new D4RValue(byte); // holds 17
+        D4RValue *arg2 = new D4RValue((float)21.0);
 
         unique_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
         CPPUNIT_ASSERT(less->value());
-
     }
     /** @} */
 
     // this uses a mix of value() and value(dmr), just for cover both cases
-    void Str_and_str_test()
-    {
+    void Str_and_str_test() {
         D4RValue *arg1 = new D4RValue(str);
         D4RValue *arg2 = new D4RValue(string("Tesla"));
 
@@ -241,8 +225,7 @@ public:
         CPPUNIT_ASSERT(not_equal->value(dmr));
     }
 
-    void Str_and_match_test()
-    {
+    void Str_and_match_test() {
         D4RValue *arg1 = new D4RValue(str);
         D4RValue *arg2 = new D4RValue(string("E.*n"));
 
@@ -250,10 +233,9 @@ public:
         CPPUNIT_ASSERT(match->value());
     }
 
-    void Str_and_number_error_test()
-    {
+    void Str_and_number_error_test() {
         D4RValue *arg1 = new D4RValue(str);
-        D4RValue *arg2 = new D4RValue((long long) 21);
+        D4RValue *arg2 = new D4RValue((long long)21);
 
         try {
             unique_ptr<D4FilterClause> less(new D4FilterClause(D4FilterClause::less, arg1, arg2));
@@ -263,15 +245,13 @@ public:
 
             less->value();
             CPPUNIT_FAIL("Expected error");
-        }
-        catch (Error &e) {
+        } catch (Error &e) {
             DBG(cerr << "Caught error: " + e.get_error_message() << endl);
             CPPUNIT_ASSERT("Caught error");
         }
     }
 
-    void Byte_and_string_error_test()
-    {
+    void Byte_and_string_error_test() {
         D4RValue *arg1 = new D4RValue(byte);
         D4RValue *arg2 = new D4RValue("Tesla");
 
@@ -280,17 +260,15 @@ public:
 
             CPPUNIT_ASSERT(less->value());
             CPPUNIT_FAIL("Expected error");
-        }
-        catch (Error &e) {
+        } catch (Error &e) {
             DBG(cerr << "Caught error: " + e.get_error_message() << endl);
             CPPUNIT_ASSERT("Caught error");
         }
     }
 
-    void Structure_and_string_error_test()
-    {
+    void Structure_and_string_error_test() {
         unique_ptr<Structure> s(new Structure("s"));
-        s->add_var(byte); // copy the object
+        s->add_var(byte);                       // copy the object
         D4RValue *arg1 = new D4RValue(s.get()); // BaseType*s are not free'd by D4RValue
         D4RValue *arg2 = new D4RValue("Tesla");
 
@@ -299,16 +277,14 @@ public:
 
             CPPUNIT_ASSERT(less->value());
             CPPUNIT_FAIL("Expected error");
-        }
-        catch (Error &e) {
+        } catch (Error &e) {
             DBG(cerr << "Caught error: " + e.get_error_message() << endl);
             CPPUNIT_ASSERT("Caught error");
         }
     }
 
     // There's no way this will get past the parser, but ...
-    void Byte_and_Structure_error_test()
-    {
+    void Byte_and_Structure_error_test() {
         unique_ptr<Structure> s(new Structure("s"));
         s->add_var(str); // copy the object
         D4RValue *arg1 = new D4RValue(byte);
@@ -319,16 +295,14 @@ public:
 
             CPPUNIT_ASSERT(less->value());
             CPPUNIT_FAIL("Expected error");
-        }
-        catch (Error &e) {
+        } catch (Error &e) {
             DBG(cerr << "Caught error: " + e.get_error_message() << endl);
             CPPUNIT_ASSERT("Caught error");
         }
     }
 
     // There's no way this will get past the parser, but ...
-    void Str_and_Structure_error_test()
-    {
+    void Str_and_Structure_error_test() {
         unique_ptr<Structure> s(new Structure("s"));
         s->add_var(str); // copy the object
         D4RValue *arg1 = new D4RValue(str);
@@ -339,16 +313,14 @@ public:
 
             CPPUNIT_ASSERT(less->value());
             CPPUNIT_FAIL("Expected error");
-        }
-        catch (Error &e) {
+        } catch (Error &e) {
             DBG(cerr << "Caught error: " + e.get_error_message() << endl);
             CPPUNIT_ASSERT("Caught error");
         }
     }
 
     // test Url and Float32
-    void grab_bag_test()
-    {
+    void grab_bag_test() {
         D4RValue *arg2_1 = new D4RValue(f32);
         D4RValue *arg2_2 = new D4RValue(17.0);
 
@@ -374,8 +346,7 @@ public:
         CPPUNIT_ASSERT(match->value(dmr));
     }
 
-    void float_test()
-    {
+    void float_test() {
         D4RValue *arg2_1 = new D4RValue(f32);
         D4RValue *arg2_2 = new D4RValue(3.1415);
 
@@ -383,8 +354,7 @@ public:
         CPPUNIT_ASSERT(clause->value());
     }
 
-    void float_test_2()
-    {
+    void float_test_2() {
         D4RValue *arg2_1 = new D4RValue(f32);
         D4RValue *arg2_2 = new D4RValue(3.1415);
 
@@ -392,8 +362,7 @@ public:
         CPPUNIT_ASSERT(clause->value());
     }
 
-    void float_test_3()
-    {
+    void float_test_3() {
         D4RValue *arg2_1 = new D4RValue(f32);
         D4RValue *arg2_2 = new D4RValue(3.1415);
 
@@ -401,27 +370,25 @@ public:
         CPPUNIT_ASSERT(clause->value());
     }
 
-    void int_test()
-    {
+    void int_test() {
         unique_ptr<Int8> i8(new Int8(""));
         i8->set_value(17);
         D4RValue *arg2_1 = new D4RValue(i8.get());
-        D4RValue *arg2_2 = new D4RValue((long long) 17);
+        D4RValue *arg2_2 = new D4RValue((long long)17);
 
         unique_ptr<D4FilterClause> clause(new D4FilterClause(D4FilterClause::equal, arg2_1, arg2_2));
         CPPUNIT_ASSERT(clause->value());
     }
 
-    void true_clauses_test()
-    {
+    void true_clauses_test() {
         // Testing this as a pointer since that's how it will be stored in D4Sequence
         unique_ptr<D4FilterClauseList> clauses(new D4FilterClauseList());
 
-        D4RValue *arg1_1 = new D4RValue(byte);    // holds 17
-        D4RValue *arg1_2 = new D4RValue((double) 21.0);
+        D4RValue *arg1_1 = new D4RValue(byte); // holds 17
+        D4RValue *arg1_2 = new D4RValue((double)21.0);
         clauses->add_clause(new D4FilterClause(D4FilterClause::less, arg1_1, arg1_2));
 
-        D4RValue *arg2_1 = new D4RValue(f32);       // holds pi
+        D4RValue *arg2_1 = new D4RValue(f32); // holds pi
         D4RValue *arg2_2 = new D4RValue(17.0);
         clauses->add_clause(new D4FilterClause(D4FilterClause::less, arg2_1, arg2_2));
 
@@ -439,8 +406,7 @@ public:
     }
 
     // This should return true
-    void no_clauses_test()
-    {
+    void no_clauses_test() {
         unique_ptr<D4FilterClauseList> clauses(new D4FilterClauseList());
 
         CPPUNIT_ASSERT(clauses->size() == 0);
@@ -448,16 +414,15 @@ public:
         CPPUNIT_ASSERT(clauses->value());
     }
 
-    void false_clauses_test()
-    {
+    void false_clauses_test() {
         unique_ptr<D4FilterClauseList> clauses(new D4FilterClauseList());
 
-        D4RValue *arg1_1 = new D4RValue(byte);    // holds 17
-        D4RValue *arg1_2 = new D4RValue((double) 21.0);
+        D4RValue *arg1_1 = new D4RValue(byte); // holds 17
+        D4RValue *arg1_2 = new D4RValue((double)21.0);
         clauses->add_clause(new D4FilterClause(D4FilterClause::less, arg1_1, arg1_2));
 
         // This clause will fail
-        D4RValue *arg2_1 = new D4RValue(f32);       // holds pi
+        D4RValue *arg2_1 = new D4RValue(f32); // holds pi
         D4RValue *arg2_2 = new D4RValue(17.0);
         clauses->add_clause(new D4FilterClause(D4FilterClause::greater, arg2_1, arg2_2));
 
@@ -474,17 +439,16 @@ public:
         CPPUNIT_ASSERT(clauses->value() == false);
     }
 
-    void evaluation_order_test()
-    {
+    void evaluation_order_test() {
         unique_ptr<D4FilterClauseList> clauses(new D4FilterClauseList());
 
-        D4RValue *arg1_1 = new D4RValue(byte);    // holds 17
-        D4RValue *arg1_2 = new D4RValue((double) 21.0);
+        D4RValue *arg1_1 = new D4RValue(byte); // holds 17
+        D4RValue *arg1_2 = new D4RValue((double)21.0);
         clauses->add_clause(new D4FilterClause(D4FilterClause::less, arg1_1, arg1_2));
 
         // This clause will fail and we should not get to the next clause, which will
         // throw and exception.
-        D4RValue *arg2_1 = new D4RValue(f32);       // holds pi
+        D4RValue *arg2_1 = new D4RValue(f32); // holds pi
         D4RValue *arg2_2 = new D4RValue(17.0);
         clauses->add_clause(new D4FilterClause(D4FilterClause::greater, arg2_1, arg2_2));
 
@@ -500,25 +464,22 @@ public:
             CPPUNIT_ASSERT(clauses->size() == 4);
             CPPUNIT_ASSERT(clauses->value(dmr) == false);
             CPPUNIT_ASSERT(clauses->value() == false);
-        }
-        catch (Error &e) {
+        } catch (Error &e) {
             DBG(cerr << "Caught error: " + e.get_error_message() << endl);
             CPPUNIT_FAIL("Exception, but the thrid clause should not have been evaluated");
-
         }
     }
 
-    void evaluation_order_test_2()
-    {
+    void evaluation_order_test_2() {
         unique_ptr<D4FilterClauseList> clauses(new D4FilterClauseList());
 
-        D4RValue *arg1_1 = new D4RValue(byte);    // holds 17
-        D4RValue *arg1_2 = new D4RValue((double) 21.0);
+        D4RValue *arg1_1 = new D4RValue(byte); // holds 17
+        D4RValue *arg1_2 = new D4RValue((double)21.0);
         clauses->add_clause(new D4FilterClause(D4FilterClause::less, arg1_1, arg1_2));
 
         // This clause will *pass* and we *should* get to the next clause, which will
         // throw and exception.
-        D4RValue *arg2_1 = new D4RValue(f32);       // holds pi
+        D4RValue *arg2_1 = new D4RValue(f32); // holds pi
         D4RValue *arg2_2 = new D4RValue(17.0);
         clauses->add_clause(new D4FilterClause(D4FilterClause::less, arg2_1, arg2_2));
 
@@ -535,51 +496,47 @@ public:
             CPPUNIT_ASSERT(clauses->value(dmr));
 
             CPPUNIT_FAIL("Expected the third clause to throw an exception.");
-        }
-        catch (Error &e) {
+        } catch (Error &e) {
             DBG(cerr << "Caught error: " + e.get_error_message() << endl);
             CPPUNIT_ASSERT("Expected exception found.");
         }
     }
 
-    CPPUNIT_TEST_SUITE (D4FilterClauseTest);
+    CPPUNIT_TEST_SUITE(D4FilterClauseTest);
 
-    CPPUNIT_TEST (Byte_and_long_long_test);
-    CPPUNIT_TEST (Byte_and_long_long_test_2);
-    CPPUNIT_TEST (Byte_and_double_test);
+    CPPUNIT_TEST(Byte_and_long_long_test);
+    CPPUNIT_TEST(Byte_and_long_long_test_2);
+    CPPUNIT_TEST(Byte_and_double_test);
     // These float --> double, etc.
-    CPPUNIT_TEST (Byte_and_int_test);
-    CPPUNIT_TEST (Byte_and_float_test);
+    CPPUNIT_TEST(Byte_and_int_test);
+    CPPUNIT_TEST(Byte_and_float_test);
 
-    CPPUNIT_TEST (Str_and_str_test);
-    CPPUNIT_TEST (Str_and_match_test);
-    CPPUNIT_TEST (Str_and_number_error_test);
-    CPPUNIT_TEST (Byte_and_string_error_test);
-    CPPUNIT_TEST (Structure_and_string_error_test);
-    CPPUNIT_TEST (Byte_and_Structure_error_test);
-    CPPUNIT_TEST (Str_and_Structure_error_test);
+    CPPUNIT_TEST(Str_and_str_test);
+    CPPUNIT_TEST(Str_and_match_test);
+    CPPUNIT_TEST(Str_and_number_error_test);
+    CPPUNIT_TEST(Byte_and_string_error_test);
+    CPPUNIT_TEST(Structure_and_string_error_test);
+    CPPUNIT_TEST(Byte_and_Structure_error_test);
+    CPPUNIT_TEST(Str_and_Structure_error_test);
 
-    CPPUNIT_TEST (grab_bag_test);
-    CPPUNIT_TEST (float_test);
-    CPPUNIT_TEST (float_test_2);
-    CPPUNIT_TEST (float_test_3);
-    CPPUNIT_TEST (int_test);
+    CPPUNIT_TEST(grab_bag_test);
+    CPPUNIT_TEST(float_test);
+    CPPUNIT_TEST(float_test_2);
+    CPPUNIT_TEST(float_test_3);
+    CPPUNIT_TEST(int_test);
 
     // FilterClauseList tests
-    CPPUNIT_TEST (true_clauses_test);
-    CPPUNIT_TEST (no_clauses_test);
-    CPPUNIT_TEST (false_clauses_test);
-    CPPUNIT_TEST (evaluation_order_test);
-    CPPUNIT_TEST (evaluation_order_test_2);
+    CPPUNIT_TEST(true_clauses_test);
+    CPPUNIT_TEST(no_clauses_test);
+    CPPUNIT_TEST(false_clauses_test);
+    CPPUNIT_TEST(evaluation_order_test);
+    CPPUNIT_TEST(evaluation_order_test_2);
 
     CPPUNIT_TEST_SUITE_END();
 };
 
-CPPUNIT_TEST_SUITE_REGISTRATION (D4FilterClauseTest);
+CPPUNIT_TEST_SUITE_REGISTRATION(D4FilterClauseTest);
 
-} // namepsace libdap
+} // namespace libdap
 
-int main(int argc, char*argv[])
-{
-    return run_tests<libdap::D4FilterClauseTest>(argc, argv) ? 0: 1;
-}
+int main(int argc, char *argv[]) { return run_tests<libdap::D4FilterClauseTest>(argc, argv) ? 0 : 1; }
