@@ -25,47 +25,46 @@
 #include "config.h"
 
 #include <cppunit/TextTestRunner.h>
-#include <cppunit/extensions/TestFactoryRegistry.h>
 #include <cppunit/extensions/HelperMacros.h>
+#include <cppunit/extensions/TestFactoryRegistry.h>
 
 #include <sstream>
 
+#include "Array.h"
 #include "Byte.h"
-#include "Int16.h"
-#include "UInt16.h"
-#include "Int32.h"
-#include "UInt32.h"
 #include "Float32.h"
 #include "Float64.h"
-#include "Str.h"
-#include "Url.h"
-#include "Array.h"
-#include "Structure.h"
-#include "Sequence.h"
 #include "Grid.h"
+#include "Int16.h"
+#include "Int32.h"
+#include "Sequence.h"
+#include "Str.h"
+#include "Structure.h"
+#include "UInt16.h"
+#include "UInt32.h"
+#include "Url.h"
 
+#include "D4BaseTypeFactory.h"
+#include "D4ParserSax2.h"
 #include "DDS.h"
 #include "DMR.h"
 #include "XMLWriter.h"
-#include "D4BaseTypeFactory.h"
-#include "D4ParserSax2.h"
 
 #include "GNURegex.h"
 
-#include "util.h"
 #include "debug.h"
+#include "util.h"
 
-#include "testFile.h"
 #include "run_tests_cppunit.h"
+#include "testFile.h"
 #include "test_config.h"
 
 using namespace CppUnit;
 using namespace std;
 using namespace libdap;
 
-class DMRTest: public TestFixture {
+class DMRTest : public TestFixture {
 private:
-
 public:
     DMRTest() = default;
     ~DMRTest() = default;
@@ -73,8 +72,7 @@ public:
     // void setUp()
     // void tearDown()
 
-    bool re_match(Regex &r, const string &s)
-    {
+    bool re_match(Regex &r, const string &s) {
         int match = r.match(s.c_str(), s.length());
         DBG(cerr << "Match: " << match << " should be: " << s.length() << endl);
         return match == static_cast<int>(s.length());
@@ -88,8 +86,7 @@ public:
      * @param attr
      * @return A pointer to the new DMR; caller must delete
      */
-    DMR *build_dmr(const string &dds_file, const string &das_file = "")
-    {
+    DMR *build_dmr(const string &dds_file, const string &das_file = "") {
         DBG(cerr << __func__ << "() - BEGIN" << endl);
         DBG(cerr << __func__ << "() - dds_file: " << dds_file << endl);
         DBG(cerr << __func__ << "() - das_file: " << das_file << endl);
@@ -117,16 +114,14 @@ public:
             D4BaseTypeFactory d4_factory;
             DBG(cerr << __func__ << "() - END" << endl);
             return new DMR(&d4_factory, dds);
-        }
-        catch (Error &e) {
+        } catch (Error &e) {
             CPPUNIT_FAIL(string("Caught Error: ") + e.get_error_message());
         }
 
         return 0;
     }
 
-    void test_template(const string &dds_file, const string &dmr_baseline, const string &attr = "")
-    {
+    void test_template(const string &dds_file, const string &dmr_baseline, const string &attr = "") {
         DBG(cerr << __func__ << "() - BEGIN" << endl);
         DMR *dmr = 0;
         try {
@@ -138,15 +133,14 @@ public:
             string prefix = string(TEST_SRC_DIR) + "/dmr-testsuite/";
             CPPUNIT_ASSERT(string(xml.get_doc()) == read_test_baseline(prefix + dmr_baseline));
             delete dmr;
-        }
-        catch (Error &e) {
+        } catch (Error &e) {
             delete dmr;
             CPPUNIT_FAIL(string("Caught Error: ") + e.get_error_message());
         }
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    CPPUNIT_TEST_SUITE (DMRTest);
+    CPPUNIT_TEST_SUITE(DMRTest);
 
     CPPUNIT_TEST(test_dmr_from_dds_1);
     CPPUNIT_TEST(test_dmr_from_dds_2);
@@ -166,66 +160,57 @@ public:
     CPPUNIT_TEST_SUITE_END();
 
     // Test a DDS with simple scalar types and no attributes
-    void test_dmr_from_dds_1()
-    {
+    void test_dmr_from_dds_1() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("test.1", "test.1.dmr");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
     // What about arrays? This should build shared dimensions
-    void test_dmr_from_dds_2()
-    {
+    void test_dmr_from_dds_2() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("fnoc1.nc.dds", "fnoc1.nc.dmr");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void test_dmr_from_dds_3()
-    {
+    void test_dmr_from_dds_3() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("3B42.980909.5.HDF.dds", "3B42.980909.5.HDF.dmr");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void test_dmr_from_dds_4()
-    {
+    void test_dmr_from_dds_4() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("S2000415.HDF.dds", "S2000415.HDF.dmr");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void test_dmr_from_dds_5()
-    {
+    void test_dmr_from_dds_5() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("coads_climatology.nc.dds", "coads_climatology.nc.dmr");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void test_dmr_from_dds_6()
-    {
+    void test_dmr_from_dds_6() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("structure_1.dds", "structure_1.dds.dmr");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void test_dmr_from_dds_with_attr_1()
-    {
+    void test_dmr_from_dds_with_attr_1() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("test.1", "test.1.attr.dmr", "test.1.das");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void test_dmr_from_dds_with_attr_2()
-    {
+    void test_dmr_from_dds_with_attr_2() {
         // The 'hacked' file has global attributes
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("3B42.980909.5.HDF.dds", "3B42.980909.5.hacked.2.HDF.attr.dmr", "3B42.980909.5.hacked.2.HDF.das");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void test_copy_ctor()
-    {
+    void test_copy_ctor() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         DMR *dmr = build_dmr("test.1", "test.1.das");
         DMR *dmr_2 = new DMR(*dmr);
@@ -250,8 +235,7 @@ public:
     }
 
     // This tests if using the copy still works after the original is deleted
-    void test_copy_ctor_2()
-    {
+    void test_copy_ctor_2() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         DMR *dmr = build_dmr("test.1", "test.1.das");
         DMR *dmr_2 = new DMR(*dmr);
@@ -275,8 +259,7 @@ public:
     }
 
     // Test the grid/coverage and copy ctor code
-    void test_copy_ctor_3()
-    {
+    void test_copy_ctor_3() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         DMR *dmr = build_dmr("coads_climatology.nc.dds", "coads_climatology.nc.das");
         DMR *dmr_2 = new DMR(*dmr);
@@ -300,8 +283,7 @@ public:
     }
 
     // Make the same test as above, but bypass the DMR ctor that uses a DDS object.
-    void test_copy_ctor_4()
-    {
+    void test_copy_ctor_4() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         D4BaseTypeFactory factory;
         DMR *dmr = new DMR(&factory, "coads");
@@ -339,12 +321,8 @@ public:
         delete dmr_3;
         DBG(cerr << __func__ << "() - END" << endl);
     }
-
 };
 
 CPPUNIT_TEST_SUITE_REGISTRATION(DMRTest);
 
-int main(int argc, char *argv[])
-{
-    return run_tests<DMRTest>(argc, argv) ? 0: 1;
-}
+int main(int argc, char *argv[]) { return run_tests<DMRTest>(argc, argv) ? 0 : 1; }
