@@ -25,50 +25,58 @@
 #include "config.h"
 
 #include <cppunit/TextTestRunner.h>
-#include <cppunit/extensions/TestFactoryRegistry.h>
 #include <cppunit/extensions/HelperMacros.h>
+#include <cppunit/extensions/TestFactoryRegistry.h>
 
-#include <sstream>
 #include <memory>
+#include <sstream>
 
+#include "Array.h"
 #include "Byte.h"
-#include "Int16.h"
-#include "UInt16.h"
-#include "Int32.h"
-#include "UInt32.h"
 #include "Float32.h"
 #include "Float64.h"
-#include "Str.h"
-#include "Url.h"
-#include "Array.h"
-#include "Structure.h"
-#include "Sequence.h"
 #include "Grid.h"
+#include "Int16.h"
+#include "Int32.h"
+#include "Sequence.h"
+#include "Str.h"
+#include "Structure.h"
+#include "UInt16.h"
+#include "UInt32.h"
+#include "Url.h"
 
+#include "D4BaseTypeFactory.h"
+#include "D4ParserSax2.h"
 #include "DDS.h"
 #include "DMR.h"
 #include "XMLWriter.h"
-#include "D4BaseTypeFactory.h"
-#include "D4ParserSax2.h"
 
 #include "GNURegex.h"
 
-#include "util.h"
-#include "mime_util.h"
 #include "debug.h"
+#include "mime_util.h"
+#include "util.h"
 
-#include "testFile.h"
 #include "run_tests_cppunit.h"
+#include "testFile.h"
 #include "test_config.h"
 
-
-
 static bool mo_debug = false;
 
 #undef DBG
 #undef DBG2
-#define DBG(x) do { if (debug) {x;} } while(false)
-#define DBG2(x) do { if (mo_debug) {x;} } while(false)
+#define DBG(x)                                                                                                         \
+    do {                                                                                                               \
+        if (debug) {                                                                                                   \
+            x;                                                                                                         \
+        }                                                                                                              \
+    } while (false)
+#define DBG2(x)                                                                                                        \
+    do {                                                                                                               \
+        if (mo_debug) {                                                                                                \
+            x;                                                                                                         \
+        }                                                                                                              \
+    } while (false)
 
 using namespace CppUnit;
 using namespace std;
@@ -76,27 +84,17 @@ using namespace libdap;
 
 static string THE_TESTS_DIR("/dmr-to-dap2-testsuite/");
 
-class DmrToDap2Test: public TestFixture {
+class DmrToDap2Test : public TestFixture {
 private:
-
 public:
-    DmrToDap2Test()
-    {
-    }
-    ~DmrToDap2Test()
-    {
-    }
+    DmrToDap2Test() {}
+    ~DmrToDap2Test() {}
 
-    void setUp()
-    {
-    }
+    void setUp() {}
 
-    void tearDown()
-    {
-    }
+    void tearDown() {}
 
-    bool re_match(Regex &r, const string &s)
-    {
+    bool re_match(Regex &r, const string &s) {
         int match = r.match(s.c_str(), s.length());
         DBG2(cerr << "Match: " << match << " should be: " << s.length() << endl);
         return match == static_cast<int>(s.length());
@@ -110,8 +108,7 @@ public:
      * @param attr
      * @return A pointer to the new DMR; caller must delete
      */
-    DMR *build_dmr(const string &dmr_file)
-    {
+    DMR *build_dmr(const string &dmr_file) {
         DBG2(cerr << __func__ << "() - BEGIN" << endl);
         DBG2(cerr << __func__ << "() - dmr_file: " << dmr_file << endl);
 
@@ -119,7 +116,7 @@ public:
             DMR *dmr = new DMR();
             dmr->set_filename(dmr_file);
             dmr->set_name(name_path(dmr_file));
-            D4BaseTypeFactory BaseFactory;   // Use the factory for this handler's types
+            D4BaseTypeFactory BaseFactory; // Use the factory for this handler's types
             dmr->set_factory(&BaseFactory);
             D4ParserSax2 parser;
             ifstream in(dmr_file.c_str(), ios::in);
@@ -127,19 +124,16 @@ public:
             dmr->set_factory(0);
             DBG2(cerr << __func__ << "() - END" << endl);
             return dmr;
-        }
-        catch (Error &e) {
+        } catch (Error &e) {
             CPPUNIT_FAIL(string("Caught Error: ") + e.get_error_message());
-        }
-        catch (...) {
+        } catch (...) {
             CPPUNIT_FAIL(string("CPPUNIT FAIL: OUCH! Caught unknown exception! "));
         }
 
         return 0;
     }
 
-    void test_template(const string &test_base_name)
-    {
+    void test_template(const string &test_base_name) {
         string prefix = string(TEST_SRC_DIR) + THE_TESTS_DIR;
 
         string dmr_file = prefix + test_base_name + ".dmr";
@@ -156,7 +150,8 @@ public:
             string result_dmr(xml.get_doc());
             string baseline_dmr = read_test_baseline(dmr_file);
 
-            DBG2(cerr << "BASELINE DMR(" << baseline_dmr.size() << " chars): " << dmr_file << endl << baseline_dmr << endl);
+            DBG2(cerr << "BASELINE DMR(" << baseline_dmr.size() << " chars): " << dmr_file << endl
+                      << baseline_dmr << endl);
             DBG2(cerr << "RESULT DMR(" << result_dmr.size() << " chars): " << endl << result_dmr << endl);
 
             CPPUNIT_ASSERT(result_dmr == baseline_dmr);
@@ -166,7 +161,8 @@ public:
             dds->print(result_dds);
             string baseline_dds = read_test_baseline(dds_file);
 
-            DBG2(cerr << "BASELINE DDS(" << baseline_dds.size() << " chars): " << dds_file << endl << baseline_dds << endl);
+            DBG2(cerr << "BASELINE DDS(" << baseline_dds.size() << " chars): " << dds_file << endl
+                      << baseline_dds << endl);
             DBG2(cerr << "RESULT DDS(" << result_dds.str().size() << " chars): " << endl << result_dds.str() << endl);
 
             CPPUNIT_ASSERT(result_dds.str() == baseline_dds);
@@ -179,14 +175,11 @@ public:
             DBG2(cerr << "RESULT DAS(" << result_das.str().size() << " chars): " << endl << result_das.str() << endl);
 
             CPPUNIT_ASSERT(result_das.str() == source_das);
-        }
-        catch (Error &e) {
+        } catch (Error &e) {
             CPPUNIT_FAIL(string("Caught Error: ") + e.get_error_message());
-        }
-        catch (CPPUNIT_NS::Exception &e) {
+        } catch (CPPUNIT_NS::Exception &e) {
             CPPUNIT_FAIL(string("CPPUNIT FAIL: ") + e.message().details());
-        }
-        catch (...) {
+        } catch (...) {
             CPPUNIT_FAIL(string("CPPUNIT FAIL: OUCH! Caught unknown exception! "));
         }
 
@@ -194,220 +187,188 @@ public:
     }
 
     // Test a DDS with simple scalar types and no attributes
-    void dmr_to_dap2_01()
-    {
+    void dmr_to_dap2_01() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("test.1");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
     // Test a DDS with simple scalar types and no attributes
-    void basic_dmr_to_dap2_0_0()
-    {
+    void basic_dmr_to_dap2_0_0() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("DMR_0.0");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void basic_dmr_to_dap2_0_1()
-    {
+    void basic_dmr_to_dap2_0_1() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("DMR_0.1");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void basic_dmr_to_dap2_1_0()
-    {
+    void basic_dmr_to_dap2_1_0() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("DMR_1.0");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void basic_dmr_to_dap2_2_0()
-    {
+    void basic_dmr_to_dap2_2_0() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("DMR_2.0");
         DBG(cerr << __func__ << "() - END" << endl);
     }
-    void basic_dmr_to_dap2_2_1()
-    {
+    void basic_dmr_to_dap2_2_1() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("DMR_2.1");
         DBG(cerr << __func__ << "() - END" << endl);
     }
-    void basic_dmr_to_dap2_2_2()
-    {
+    void basic_dmr_to_dap2_2_2() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("DMR_2.2");
         DBG(cerr << __func__ << "() - END" << endl);
     }
-    void basic_dmr_to_dap2_2_3()
-    {
+    void basic_dmr_to_dap2_2_3() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("DMR_2.3");
         DBG(cerr << __func__ << "() - END" << endl);
     }
-    void basic_dmr_to_dap2_2_4()
-    {
+    void basic_dmr_to_dap2_2_4() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("DMR_2.4");
         DBG(cerr << __func__ << "() - END" << endl);
     }
-    void basic_dmr_to_dap2_2_5()
-    {
+    void basic_dmr_to_dap2_2_5() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("DMR_2.5");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void basic_dmr_to_dap2_3_0()
-    {
+    void basic_dmr_to_dap2_3_0() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("DMR_3.0");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void enum_dmr_to_dap2_0_0()
-    {
+    void enum_dmr_to_dap2_0_0() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("EnumDMR_0.0");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void enum_dmr_to_dap2_0_1()
-    {
+    void enum_dmr_to_dap2_0_1() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("EnumDMR_0.1");
         DBG(cerr << __func__ << "() - END" << endl);
     }
-    void enum_dmr_to_dap2_1_0()
-    {
+    void enum_dmr_to_dap2_1_0() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("EnumDMR_1.0");
         DBG(cerr << __func__ << "() - END" << endl);
     }
-    void enum_dmr_to_dap2_1_1()
-    {
+    void enum_dmr_to_dap2_1_1() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("EnumDMR_1.1");
         DBG(cerr << __func__ << "() - END" << endl);
     }
-    void enum_dmr_to_dap2_1_2()
-    {
+    void enum_dmr_to_dap2_1_2() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("EnumDMR_1.2");
         DBG(cerr << __func__ << "() - END" << endl);
     }
-    void enum_dmr_to_dap2_1_3()
-    {
+    void enum_dmr_to_dap2_1_3() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("EnumDMR_1.3");
         DBG(cerr << __func__ << "() - END" << endl);
     }
-    void enum_dmr_to_dap2_1_4()
-    {
+    void enum_dmr_to_dap2_1_4() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("EnumDMR_1.4");
         DBG(cerr << __func__ << "() - END" << endl);
     }
-    void enum_dmr_to_dap2_1_5()
-    {
+    void enum_dmr_to_dap2_1_5() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("EnumDMR_1.5");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void enum_dmr_to_dap2_2_0()
-    {
+    void enum_dmr_to_dap2_2_0() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("EnumDMR_2.0");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void enum_dmr_to_dap2_2_1()
-    {
+    void enum_dmr_to_dap2_2_1() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("EnumDMR_2.1");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void enum_dmr_to_dap2_3_0()
-    {
+    void enum_dmr_to_dap2_3_0() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("EnumDMR_3.0");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void enum_dmr_to_dap2_3_1()
-    {
+    void enum_dmr_to_dap2_3_1() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("EnumDMR_3.1");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void enum_dmr_to_dap2_4_0()
-    {
+    void enum_dmr_to_dap2_4_0() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("EnumDMR_4.0");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void enum_dmr_to_dap2_4_1()
-    {
+    void enum_dmr_to_dap2_4_1() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("EnumDMR_4.1");
         DBG(cerr << __func__ << "() - END" << endl);
     }
-    void enum_dmr_to_dap2_4_2()
-    {
+    void enum_dmr_to_dap2_4_2() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("EnumDMR_4.2");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void dmr_to_grid_01()
-    {
+    void dmr_to_grid_01() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("coads_climatology.nc");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void dmr_to_grid_02()
-    {
+    void dmr_to_grid_02() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("sst.mnmean.nc.gz");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void dmr_to_grid_03()
-    {
+    void dmr_to_grid_03() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("sresa1b_ncar_ccsm3_0_run1_200001.nc");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void dmr_to_grid_04()
-    {
+    void dmr_to_grid_04() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("tos_O1_2001-2002.nc");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void dmr_to_grid_05()
-    {
+    void dmr_to_grid_05() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("cami_0000-09-01_64x128_L26_c030918.nc");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    void big_airs_metadata()
-    {
+    void big_airs_metadata() {
         DBG(cerr << endl << __func__ << "() - BEGIN" << endl);
         test_template("big_airs_metadata");
         DBG(cerr << __func__ << "() - END" << endl);
     }
 
-    CPPUNIT_TEST_SUITE (DmrToDap2Test);
+    CPPUNIT_TEST_SUITE(DmrToDap2Test);
 
     // good (as in should be working) tests
     CPPUNIT_TEST(dmr_to_dap2_01);
@@ -445,7 +406,7 @@ public:
 
     // bad tests, here then is the woodshed of Testville.
 
-    CPPUNIT_TEST_FAIL(big_airs_metadata); // Expect this test to fail. jhrg 6/17/19 HK-403
+    CPPUNIT_TEST_FAIL(big_airs_metadata);    // Expect this test to fail. jhrg 6/17/19 HK-403
     CPPUNIT_TEST_FAIL(enum_dmr_to_dap2_1_5); // Broken: Parser issue with look-ahead
 
     CPPUNIT_TEST_SUITE_END();
@@ -457,7 +418,4 @@ public:
 CPPUNIT_TEST_SUITE_REGISTRATION(DmrToDap2Test);
 #endif
 
-int main(int argc, char *argv[])
-{
-    return run_tests<DmrToDap2Test>(argc, argv) ? 0: 1;
-}
+int main(int argc, char *argv[]) { return run_tests<DmrToDap2Test>(argc, argv) ? 0 : 1; }
