@@ -22,27 +22,27 @@
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
-#include <unistd.h>   // for access stat
-#include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/types.h>
+#include <unistd.h> // for access stat
 
-#include <cstdio>     // for create_cache_root_test
+#include <algorithm>
+#include <cstdio> // for create_cache_root_test
+#include <iterator>
+#include <memory>
 #include <string>
 #include <vector>
-#include <algorithm>
-#include <memory>
-#include <iterator>
 
 #include <cppunit/TextTestRunner.h>
-#include <cppunit/extensions/TestFactoryRegistry.h>
 #include <cppunit/extensions/HelperMacros.h>
+#include <cppunit/extensions/TestFactoryRegistry.h>
 
 #include "HTTPCache.h"
-#include "HTTPConnect.h"	// Used to generate a response to cache.
-#ifndef WIN32			// Signals are exquisitely non-portable.
-#include "SignalHandler.h"	// Needed to clean up this singleton.
+#include "HTTPConnect.h"   // Used to generate a response to cache.
+#ifndef WIN32              // Signals are exquisitely non-portable.
+#include "SignalHandler.h" // Needed to clean up this singleton.
 #endif
-#include "RCReader.h"		// ditto
+#include "RCReader.h" // ditto
 
 #include "debug.h"
 #include "run_tests_cppunit.h"
@@ -60,8 +60,7 @@ using namespace std;
 
 namespace libdap {
 
-inline static int file_size(string name)
-{
+inline static int file_size(string name) {
     struct stat s;
     stat(name.c_str(), &s);
     return s.st_size;
@@ -73,7 +72,7 @@ inline static int file_size(string name)
 // test is run. So by the time we're at the first line of the test, The
 // persistent store's lock has already been grabbed. 10/14/02 jhrg
 
-class HTTPCacheTest: public TestFixture {
+class HTTPCacheTest : public TestFixture {
 private:
     HTTPCache *hc;
     HTTPConnect *http_conn;
@@ -84,19 +83,16 @@ private:
     vector<string> h;
 
 protected:
-
 public:
-    HTTPCacheTest() :
-        hc(0), http_conn(0)
-    {
-        putenv((char*) "DODS_CONF=./cache-testsuite/dodsrc");
+    HTTPCacheTest() : hc(0), http_conn(0) {
+        putenv((char *)"DODS_CONF=./cache-testsuite/dodsrc");
         http_conn = new HTTPConnect(RCReader::instance());
 
         DBG2(cerr << "Entering HTTPCacheTest ctor... ");
         hash_value = 656;
         localhost_url = "http://test.opendap.org/test-304.html";
-        index_file_line =
-            "http://test.opendap.org/test-304.html cache-testsuite/dods_cache/656/dodsKbcD0h \"3f62c-157-139c2680\" 1121283146 -1 343 0 656 1 7351 1121360379 3723 0";
+        index_file_line = "http://test.opendap.org/test-304.html cache-testsuite/dods_cache/656/dodsKbcD0h "
+                          "\"3f62c-157-139c2680\" 1121283146 -1 343 0 656 1 7351 1121360379 3723 0";
 
         expired = "http://test.opendap.org/cgi-bin/expires.sh";
 
@@ -107,11 +103,11 @@ public:
         DBG2(cerr << "exiting." << endl);
     }
 
-    ~HTTPCacheTest()
-    {
+    ~HTTPCacheTest() {
         delete http_conn;
         http_conn = 0;
-        DBG2(cerr << "Entering the HTTPCacheTest dtor... ");DBG2(cerr << "exiting." << endl);
+        DBG2(cerr << "Entering the HTTPCacheTest dtor... ");
+        DBG2(cerr << "exiting." << endl);
     }
 
 #if 0
@@ -126,8 +122,7 @@ public:
     }
 #endif
 
-    void setUp()
-    {
+    void setUp() {
         DBG(cerr << endl);
 
         // Called before every test.
@@ -136,8 +131,7 @@ public:
         DBG2(cerr << "exiting setUp" << endl);
     }
 
-    void tearDown()
-    {
+    void tearDown() {
         // Called after every test.
         DBG2(cerr << "Entering HTTPCacheTest::tearDown... " << endl);
         delete hc;
@@ -145,46 +139,45 @@ public:
         DBG2(cerr << "exiting tearDown" << endl);
     }
 
-    CPPUNIT_TEST_SUITE (HTTPCacheTest);
+    CPPUNIT_TEST_SUITE(HTTPCacheTest);
 
-    CPPUNIT_TEST (constructor_test);
-    CPPUNIT_TEST (cache_index_read_test);
-    CPPUNIT_TEST (cache_index_parse_line_test);
-    CPPUNIT_TEST (get_entry_from_cache_table_test);
-    CPPUNIT_TEST (cache_index_write_test);
-    CPPUNIT_TEST (create_cache_root_test);
-    CPPUNIT_TEST (set_cache_root_test);
-    CPPUNIT_TEST (get_single_user_lock_test);
+    CPPUNIT_TEST(constructor_test);
+    CPPUNIT_TEST(cache_index_read_test);
+    CPPUNIT_TEST(cache_index_parse_line_test);
+    CPPUNIT_TEST(get_entry_from_cache_table_test);
+    CPPUNIT_TEST(cache_index_write_test);
+    CPPUNIT_TEST(create_cache_root_test);
+    CPPUNIT_TEST(set_cache_root_test);
+    CPPUNIT_TEST(get_single_user_lock_test);
 
-    CPPUNIT_TEST (release_single_user_lock_test);
-    CPPUNIT_TEST (create_hash_directory_test);
-    CPPUNIT_TEST (create_location_test);
-    CPPUNIT_TEST (parse_headers_test);
+    CPPUNIT_TEST(release_single_user_lock_test);
+    CPPUNIT_TEST(create_hash_directory_test);
+    CPPUNIT_TEST(create_location_test);
+    CPPUNIT_TEST(parse_headers_test);
 
-    CPPUNIT_TEST (calculate_time_test);
-    CPPUNIT_TEST (write_metadata_test);
-    CPPUNIT_TEST (cache_response_test);
+    CPPUNIT_TEST(calculate_time_test);
+    CPPUNIT_TEST(write_metadata_test);
+    CPPUNIT_TEST(cache_response_test);
 #if 0
     // This test does not seem to work in New Zealand - maybe because
     // of the dateline??? jhrg 1/31/13
     CPPUNIT_TEST(is_url_valid_test);
 #endif
-    CPPUNIT_TEST (get_cached_response_test);
+    CPPUNIT_TEST(get_cached_response_test);
 
-    CPPUNIT_TEST (perform_garbage_collection_test);
-    CPPUNIT_TEST (purge_cache_and_release_cached_response_test);
-    CPPUNIT_TEST (get_conditional_response_headers_test);
-    CPPUNIT_TEST (update_response_test);
-    CPPUNIT_TEST (cache_gc_test);
+    CPPUNIT_TEST(perform_garbage_collection_test);
+    CPPUNIT_TEST(purge_cache_and_release_cached_response_test);
+    CPPUNIT_TEST(get_conditional_response_headers_test);
+    CPPUNIT_TEST(update_response_test);
+    CPPUNIT_TEST(cache_gc_test);
 
     // Make this the last test because when distcheck is run, running
     // it before other tests will break them.
-    CPPUNIT_TEST (instance_test);
+    CPPUNIT_TEST(instance_test);
 
     CPPUNIT_TEST_SUITE_END();
 
-    void constructor_test()
-    {
+    void constructor_test() {
         DBG(cerr << "hc->cache_index: " << hc->d_http_cache_table->d_cache_index << endl);
         CPPUNIT_ASSERT(hc->d_http_cache_table->d_cache_index == "cache-testsuite/dods_cache/.index");
         CPPUNIT_ASSERT(hc->d_cache_root == "cache-testsuite/dods_cache/");
@@ -193,8 +186,7 @@ public:
         CPPUNIT_ASSERT(hc->d_http_cache_table->d_current_size == hc->d_http_cache_table->d_block_size);
     }
 
-    void cache_index_read_test()
-    {
+    void cache_index_read_test() {
         CPPUNIT_ASSERT(hc->d_http_cache_table->cache_index_read());
 
         HTTPCacheTable::CacheEntry *e = hc->d_http_cache_table->get_locked_entry_from_cache_table(localhost_url);
@@ -204,8 +196,7 @@ public:
         e->unlock_read_response();
     }
 
-    void cache_index_parse_line_test()
-    {
+    void cache_index_parse_line_test() {
         HTTPCacheTable::CacheEntry *e = hc->d_http_cache_table->cache_index_parse_line(index_file_line.c_str());
 
         CPPUNIT_ASSERT(e->url == localhost_url);
@@ -225,8 +216,7 @@ public:
     }
 
     // This will also test the add_entry_to_cache_table() method.
-    void get_entry_from_cache_table_test()
-    {
+    void get_entry_from_cache_table_test() {
         HTTPCacheTable::CacheEntry *e = hc->d_http_cache_table->cache_index_parse_line(index_file_line.c_str());
 
         // Test adding an entry and getting it back.
@@ -257,10 +247,9 @@ public:
         CPPUNIT_ASSERT(g == 0);
     }
 
-    void cache_index_write_test()
-    {
+    void cache_index_write_test() {
         try {
-            HTTPCache * hc_3 = new HTTPCache("cache-testsuite/dods_cache/", true);
+            HTTPCache *hc_3 = new HTTPCache("cache-testsuite/dods_cache/", true);
             hc_3->d_http_cache_table->add_entry_to_cache_table(
                 hc->d_http_cache_table->cache_index_parse_line(index_file_line.c_str()));
 
@@ -281,15 +270,13 @@ public:
             hc_3 = 0;
             delete hc_4;
             hc_4 = 0;
-        }
-        catch (Error &e) {
-            //cerr << "Fail: " << e.get_error_message() << endl;
+        } catch (Error &e) {
+            // cerr << "Fail: " << e.get_error_message() << endl;
             CPPUNIT_FAIL(e.get_error_message());
         }
     }
 
-    void create_cache_root_test()
-    {
+    void create_cache_root_test() {
         hc->create_cache_root("/tmp/silly/");
         CPPUNIT_ASSERT(access("/tmp/silly/", F_OK) == 0);
         remove("/tmp/silly");
@@ -310,8 +297,7 @@ public:
 #endif
     }
 
-    void set_cache_root_test()
-    {
+    void set_cache_root_test() {
 #if 0
         // env var support removed 3/22/11 jhrg
         putenv("DODS_CACHE=/home/jimg");
@@ -324,8 +310,7 @@ public:
         remove("/home/jimg/test_cache/");
     }
 
-    void get_single_user_lock_test()
-    {
+    void get_single_user_lock_test() {
         hc->set_cache_root("/tmp/dods_test_cache");
         hc->release_single_user_lock();
 
@@ -336,8 +321,7 @@ public:
         CPPUNIT_ASSERT(!hc->get_single_user_lock());
     }
 
-    void release_single_user_lock_test()
-    {
+    void release_single_user_lock_test() {
         hc->set_cache_root("/tmp/dods_test_cache");
         remove("/tmp/dods_test_cache/.lock"); // in case prev. test fails
         hc->d_locked_open_file = 0;
@@ -354,8 +338,7 @@ public:
         remove("/tmp/dods_test_cache/.lock");
     }
 
-    void create_hash_directory_test()
-    {
+    void create_hash_directory_test() {
         hc->set_cache_root("/tmp/dods_test_cache");
         CPPUNIT_ASSERT(hc->d_http_cache_table->create_hash_directory(391) == "/tmp/dods_test_cache/391");
         CPPUNIT_ASSERT(access("/tmp/dods_test_cache/391", W_OK) == 0);
@@ -372,11 +355,9 @@ public:
         }
 #endif
         remove("/tmp/dods_test_cache/391");
-
     }
 
-    void create_location_test()
-    {
+    void create_location_test() {
         hc->set_cache_root("/tmp/dods_test_cache");
         HTTPCacheTable::CacheEntry *e = new HTTPCacheTable::CacheEntry;
         e->url = localhost_url;
@@ -384,8 +365,7 @@ public:
         try {
             hc->d_http_cache_table->create_location(e);
             CPPUNIT_ASSERT(e->cachename != "");
-        }
-        catch (Error &e) {
+        } catch (Error &e) {
             CPPUNIT_ASSERT(true && "could not create entry file");
         }
         remove(e->cachename.c_str());
@@ -394,8 +374,7 @@ public:
         e = 0;
     }
 
-    void parse_headers_test()
-    {
+    void parse_headers_test() {
         HTTPCacheTable::CacheEntry *e = new HTTPCacheTable::CacheEntry;
 
         hc->d_http_cache_table->parse_headers(e, hc->d_max_entry_size, h);
@@ -405,8 +384,7 @@ public:
         e = 0;
     }
 
-    void calculate_time_test()
-    {
+    void calculate_time_test() {
         HTTPCacheTable::CacheEntry *e = new HTTPCacheTable::CacheEntry;
 
         hc->d_http_cache_table->parse_headers(e, hc->d_max_entry_size, h);
@@ -418,16 +396,14 @@ public:
         e = 0;
     }
 
-    void write_metadata_test()
-    {
+    void write_metadata_test() {
         hc->set_cache_root("/tmp/dods_test_cache");
         HTTPCacheTable::CacheEntry *e = new HTTPCacheTable::CacheEntry;
         try {
             e->hash = 101;
             hc->d_http_cache_table->create_location(e);
             CPPUNIT_ASSERT(e->cachename != "");
-        }
-        catch (Error &e) {
+        } catch (Error &e) {
             CPPUNIT_ASSERT(true && "could not create entry file");
         }
 
@@ -446,8 +422,7 @@ public:
         e = 0;
     }
 
-    void cache_response_test()
-    {
+    void cache_response_test() {
         HTTPResponse *rs = http_conn->fetch_url(localhost_url);
         try {
             time_t now = time(0);
@@ -461,8 +436,7 @@ public:
             e->unlock_read_response();
             delete rs;
             rs = 0;
-        }
-        catch (Error &e) {
+        } catch (Error &e) {
             delete rs;
             rs = 0;
             cerr << "Error: " << e.get_error_message() << endl;
@@ -470,14 +444,12 @@ public:
         }
     }
 
-    void is_url_valid_test()
-    {
+    void is_url_valid_test() {
         cache_response_test(); // This should get a response into the cache.
         CPPUNIT_ASSERT(hc->is_url_valid(localhost_url));
     }
 
-    void get_cached_response_test()
-    {
+    void get_cached_response_test() {
         cache_response_test(); // Get a response into the cache.
         vector<string> cached_headers;
         FILE *cached_body = hc->get_cached_response(localhost_url, cached_headers);
@@ -488,7 +460,7 @@ public:
         // headers and cached_headers should match, except for the values.
         vector<string>::iterator i, j;
         for (i = cached_headers.begin(), j = headers->begin(); i != cached_headers.end() && j != headers->end();
-            ++i, ++j) {
+             ++i, ++j) {
             string ch = (*i).substr(0, (*i).find(": "));
             // Skip over headers that won't be cached. jhrg 7/4/05
             while (is_hop_by_hop_header(*j))
@@ -518,7 +490,8 @@ public:
             int cn = fread(&cb, 1, 1, cached_body);
             int n = fread(&b, 1, 1, rs->get_stream());
             CPPUNIT_ASSERT(cn == n);
-            if (cn == 1) CPPUNIT_ASSERT(cb == b);
+            if (cn == 1)
+                CPPUNIT_ASSERT(cb == b);
         }
         CPPUNIT_ASSERT(feof(rs->get_stream()) && feof(cached_body));
 
@@ -527,8 +500,7 @@ public:
         rs = 0;
     }
 
-    void perform_garbage_collection_test()
-    {
+    void perform_garbage_collection_test() {
         try {
             delete hc;
             hc = nullptr;
@@ -561,19 +533,16 @@ public:
             gc->d_http_cache_table->cache_index_write();
             DBG(cerr << prolog << "gc->d_http_cache_table->cache_index_write() completed." << endl);
 
-            bool expired_is_in_cache=gc->is_url_in_cache(expired);
-            DBG(cerr << prolog << "expired_is_in_cache: " << (expired_is_in_cache?"true":"false") << endl);
-            CPPUNIT_ASSERT(
-                    !expired_is_in_cache && "This may fail if sleep is not long enough before gc above");
-        }
-        catch (Error &e) {
+            bool expired_is_in_cache = gc->is_url_in_cache(expired);
+            DBG(cerr << prolog << "expired_is_in_cache: " << (expired_is_in_cache ? "true" : "false") << endl);
+            CPPUNIT_ASSERT(!expired_is_in_cache && "This may fail if sleep is not long enough before gc above");
+        } catch (Error &e) {
             cerr << "Exception: " << e.get_error_message() << endl;
             CPPUNIT_ASSERT(false);
         }
     }
 
-    void purge_cache_and_release_cached_response_test()
-    {
+    void purge_cache_and_release_cached_response_test() {
         try {
             unique_ptr<HTTPCache> pc(new HTTPCache("cache-testsuite/purge_cache", true));
             DBG(cerr << "get_cache_root: " << pc->get_cache_root() << endl);
@@ -608,8 +577,7 @@ public:
             try {
                 pc->purge_cache();
                 CPPUNIT_ASSERT(!"This call should throw Error");
-            }
-            catch (Error &e) {
+            } catch (Error &e) {
                 CPPUNIT_ASSERT("Caught Error as expected");
             }
 
@@ -622,15 +590,13 @@ public:
             CPPUNIT_ASSERT(access(e1_file.c_str(), F_OK) != 0);
             CPPUNIT_ASSERT(access(e2_file.c_str(), F_OK) != 0);
             CPPUNIT_ASSERT(pc->d_http_cache_table->d_current_size == 0);
-        }
-        catch (Error &e) {
+        } catch (Error &e) {
             cerr << "Exception: " << e.get_error_message() << endl;
             CPPUNIT_ASSERT(false);
         }
     }
 
-    void instance_test()
-    {
+    void instance_test() {
         try {
             // FIXME: Explain
             HTTPCache::delete_instance();
@@ -667,8 +633,7 @@ public:
             CPPUNIT_ASSERT(!c->is_url_in_cache(expired));
             CPPUNIT_ASSERT(access(e1_file.c_str(), F_OK) != 0);
             CPPUNIT_ASSERT(access(e2_file.c_str(), F_OK) != 0);
-        }
-        catch (Error &e) {
+        } catch (Error &e) {
             cerr << "Exception: " << e.get_error_message() << endl;
             CPPUNIT_ASSERT(false);
         }
@@ -679,15 +644,14 @@ public:
         // value of _instance and simply returns with it's zero.
         HTTPCache::delete_instance();
 #ifndef WIN32
-        SignalHandler::delete_instance();
+        // jhrg 3/15/24 SignalHandler::delete_instance();
 #endif
     }
 
 #define IF_NONE_MATCH "If-None-Match: "
 #define IF_MODIFIED_SINCE "If-Modified-Since: "
 
-    void get_conditional_response_headers_test()
-    {
+    void get_conditional_response_headers_test() {
         try {
             unique_ptr<HTTPCache> c(new HTTPCache("cache-testsuite/header_cache", true));
             DBG(cerr << prolog << "c->get_cache_root(): " << c->get_cache_root() << endl);
@@ -709,13 +673,13 @@ public:
 
             bool found_it = false;
             vector<string> h = c->get_conditional_request_headers(localhost_url);
-            DBG(cerr << prolog <<  "Number of headers: " << h.size() << endl);
+            DBG(cerr << prolog << "Number of headers: " << h.size() << endl);
             DBG(copy(h.begin(), h.end(), ostream_iterator<string>(cout, "\n")));
-            for(const auto &hdr: h){
+            for (const auto &hdr : h) {
                 // I know what the strings should start with...
                 auto index = hdr.find(IF_NONE_MATCH);
                 DBG(cerr << prolog << IF_NONE_MATCH << " location: " << index << endl);
-                if(index == 0){
+                if (index == 0) {
                     found_it = true;
                     break;
                 }
@@ -724,26 +688,24 @@ public:
 
             found_it = false;
             h = c->get_conditional_request_headers(expired);
-            DBG(cerr << prolog <<  "Number of headers: " << h.size() << endl);
+            DBG(cerr << prolog << "Number of headers: " << h.size() << endl);
             DBG(copy(h.begin(), h.end(), ostream_iterator<string>(cout, "\n")));
-            for(const auto &hdr: h){
+            for (const auto &hdr : h) {
                 // I know what the strings should start with...
                 auto index = hdr.find(IF_MODIFIED_SINCE);
                 DBG(cerr << prolog << IF_MODIFIED_SINCE << " location: " << index << endl);
-                if(index == 0){
+                if (index == 0) {
                     found_it = true;
                     break;
                 }
             }
             CPPUNIT_ASSERT(found_it && "Located If-Modified-Since header.");
-        }
-        catch (Error &e) {
+        } catch (Error &e) {
             CPPUNIT_FAIL(e.get_error_message());
         }
     }
 
-    void update_response_test()
-    {
+    void update_response_test() {
         try {
             unique_ptr<HTTPCache> c(new HTTPCache("cache-testsuite/singleton_cache", true));
             DBG(cerr << "get_cache_root: " << c->get_cache_root() << endl);
@@ -797,16 +759,14 @@ public:
             // CPPUNIT_ASSERT(orig_h.size() + 1 == updated_h.size());
             CPPUNIT_ASSERT(find(updated_h.begin(), updated_h.end(), "XHTTPCache: 123456789") != updated_h.end());
             CPPUNIT_ASSERT(find(updated_h.begin(), updated_h.end(), "Date: <invalid date>") != updated_h.end());
-        }
-        catch (Error &e) {
+        } catch (Error &e) {
             CPPUNIT_FAIL(e.get_error_message());
         }
     }
 
     // Only run this interactively since you need to hit Ctrl-c to generate
     // SIGINT while the cache is doing its thing. 02/10/04 jhrg
-    void interrupt_test()
-    {
+    void interrupt_test() {
         try {
             unique_ptr<HTTPCache> c(new HTTPCache("cache-testsuite/singleton_cache", true));
             string coads = "http://test.opendap.org/dap/data/nc/coads_climatology.nc";
@@ -817,14 +777,12 @@ public:
                 cerr << "to late.";
                 delete rs;
             }
-        }
-        catch (Error &e) {
+        } catch (Error &e) {
             CPPUNIT_FAIL(e.get_error_message());
         }
     }
 
-    void cache_gc_test()
-    {
+    void cache_gc_test() {
         string fnoc1 = "http://test.opendap.org/dap/data/nc/fnoc1.nc.dds";
         string jan = "http://test.opendap.org/dap/data/nc/jan.nc.dds";
         string feb = "http://test.opendap.org/dap/data/nc/feb.nc.dds";
@@ -869,8 +827,7 @@ public:
             CPPUNIT_ASSERT(pc->is_url_in_cache(feb));
             delete rs;
             rs = 0;
-        }
-        catch (Error &e) {
+        } catch (Error &e) {
             CPPUNIT_FAIL(e.get_error_message());
         }
 
@@ -880,24 +837,21 @@ public:
         try {
             unique_ptr<HTTPCache> pc(new HTTPCache("cache-testsuite/purge_cache", true));
             CPPUNIT_ASSERT(!pc->is_url_in_cache(feb));
-        }
-        catch (Error &e) {
+        } catch (Error &e) {
             CPPUNIT_FAIL(e.get_error_message());
         }
     }
-
 };
 
-CPPUNIT_TEST_SUITE_REGISTRATION (HTTPCacheTest);
+CPPUNIT_TEST_SUITE_REGISTRATION(HTTPCacheTest);
 
 } // namespace libdap
 
-int main(int argc, char*argv[])
-{
+int main(int argc, char *argv[]) {
     // Run cleanup here, so that the first run works (since this code now
     // sets up the tests).
     // This gives valgrind fits...
     system("cd cache-testsuite && ./cleanup.sh");
 
-    return run_tests<libdap::HTTPCacheTest>(argc, argv) ? 0: 1;
+    return run_tests<libdap::HTTPCacheTest>(argc, argv) ? 0 : 1;
 }
