@@ -22,46 +22,44 @@
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
-//#include <cstdio>
+// #include <cstdio>
 
 #include <pthread.h>
 
 #include <cppunit/TextTestRunner.h>
-#include <cppunit/extensions/TestFactoryRegistry.h>
 #include <cppunit/extensions/HelperMacros.h>
+#include <cppunit/extensions/TestFactoryRegistry.h>
 
 #include "BaseType.h"
-#include "Str.h"
 #include "DDS.h"
 #include "ServerFunction.h"
 #include "ServerFunctionsList.h"
+#include "Str.h"
 
 #include "debug.h"
 #include "util.h"
 
 #include "debug.h"
-#include "util.h"
 #include "run_tests_cppunit.h"
 #include "test_config.h"
+#include "util.h"
 
 using namespace CppUnit;
 
-void sflut(int, libdap::BaseType *[], libdap::DDS &, libdap::BaseType **btpp)
-{
-    string info = string("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n") + "<function name=\"ugr4\" version=\"0.1\">\n"
-        + "ServeFunctionsList Unit Test.\n" + "usage: sflut()" + "\n" + "</function>";
+void sflut(int, libdap::BaseType *[], libdap::DDS &, libdap::BaseType **btpp) {
+    string info = string("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n") +
+                  "<function name=\"ugr4\" version=\"0.1\">\n" + "ServeFunctionsList Unit Test.\n" + "usage: sflut()" +
+                  "\n" + "</function>";
 
     libdap::Str *response = new libdap::Str("info");
     response->set_value(info);
     *btpp = response;
     return;
-
 }
 
-class SFLUT: public libdap::ServerFunction {
+class SFLUT : public libdap::ServerFunction {
 public:
-    SFLUT()
-    {
+    SFLUT() {
         setName("sflut");
         setDescriptionString("This is a unit test to test the ServerFunctionList class.");
         setUsageString("sflut()");
@@ -69,59 +67,49 @@ public:
         setDocUrl("http://docs.opendap.org/index.php/unit-tests");
         setFunction(sflut);
         setVersion("1.0");
-
     }
 };
 
 namespace libdap {
-class ServerFunctionsListUnitTest: public CppUnit::TestFixture {
+class ServerFunctionsListUnitTest : public CppUnit::TestFixture {
 
 public:
-
     // Called once before everything gets tested
-    ServerFunctionsListUnitTest()
-    {
+    ServerFunctionsListUnitTest() {
         //    DBG(cerr << " BindTest - Constructor" << endl);
-
     }
 
     // Called at the end of the test
-    ~ServerFunctionsListUnitTest()
-    {
+    ~ServerFunctionsListUnitTest() {
         //    DBG(cerr << " BindTest - Destructor" << endl);
     }
 
     // Called before each test
-    void setup()
-    {
+    void setup() {
         //    DBG(cerr << " BindTest - setup()" << endl);
     }
 
     // Called after each test
-    void tearDown()
-    {
+    void tearDown() {
         //    DBG(cerr << " tearDown()" << endl);
     }
 
-    CPPUNIT_TEST_SUITE (libdap::ServerFunctionsListUnitTest);
+    CPPUNIT_TEST_SUITE(libdap::ServerFunctionsListUnitTest);
 
-    CPPUNIT_TEST (sflut_test);
-    //CPPUNIT_TEST(always_pass);
+    CPPUNIT_TEST(sflut_test);
+    // CPPUNIT_TEST(always_pass);
 
     CPPUNIT_TEST_SUITE_END();
 
-    void printFunctionNames()
-    {
+    void printFunctionNames() {
         vector<string> *names = new vector<string>();
         printFunctionNames(names);
         delete names;
     }
 
-    void printFunctionNames(vector<string> *names)
-    {
-        DBG(
-            cerr << "Server_Function_List_Unit_Test::printFunctionNames() - ServerFunctionList::getFunctionNames(): "
-                << endl);
+    void printFunctionNames(vector<string> *names) {
+        DBG(cerr << "Server_Function_List_Unit_Test::printFunctionNames() - ServerFunctionList::getFunctionNames(): "
+                 << endl);
         if (names->empty()) {
             DBG(cerr << "     Function list is empty." << endl);
             return;
@@ -131,13 +119,9 @@ public:
             DBG(cerr << "   name[" << i << "]: " << (*names)[i] << endl);
         }
     }
-    void always_pass()
-    {
-        CPPUNIT_ASSERT(true);
-    }
+    void always_pass() { CPPUNIT_ASSERT(true); }
 
-    void sflut_test()
-    {
+    void sflut_test() {
         DBG(cerr << endl);
 
         SFLUT *ssf = new SFLUT();
@@ -172,17 +156,12 @@ public:
         printFunctionNames(&names);
         CPPUNIT_ASSERT(names.size()==0);
 #endif
-
     }
-
 };
-} // libdap namespace
+} // namespace libdap
 
 // BindTest
 
-CPPUNIT_TEST_SUITE_REGISTRATION (libdap::ServerFunctionsListUnitTest);
+CPPUNIT_TEST_SUITE_REGISTRATION(libdap::ServerFunctionsListUnitTest);
 
-int main(int argc, char*argv[])
-{
-    return run_tests<libdap::ServerFunctionsListUnitTest>(argc, argv) ? 0: 1;
-}
+int main(int argc, char *argv[]) { return run_tests<libdap::ServerFunctionsListUnitTest>(argc, argv) ? 0 : 1; }
