@@ -23,14 +23,16 @@
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
 
 #include <cppunit/TextTestRunner.h>
-#include <cppunit/extensions/TestFactoryRegistry.h>
 #include <cppunit/extensions/HelperMacros.h>
+#include <cppunit/extensions/TestFactoryRegistry.h>
 
 #ifndef WIN32
-#include <unistd.h>  // for alarm sleep
+
+#include <unistd.h> // for alarm sleep
+
 #else
-#include <io.h>
 #include <fcntl.h>
+#include <io.h>
 #include <process.h>
 #endif
 
@@ -45,91 +47,68 @@ using namespace std;
 namespace libdap {
 
 /** Test Handler. This is used with the SignalHandlerTest unit tests. */
-class TestHandler: public EventHandler {
+class TestHandler : public EventHandler {
 public:
-    int flag;
+    int flag = 0;
 
-    TestHandler() :
-        flag(0)
-    {
-    }
+    TestHandler() = default;
 
-    virtual void handle_signal(int signum)
-    {
+    void handle_signal(int signum) override {
         DBG(cerr << "signal number " << signum << " received" << endl);
         flag = 1;
     }
 };
 
-class SignalHandlerTest: public TestFixture {
+class SignalHandlerTest : public TestFixture {
 private:
-    SignalHandler *sh;
-    TestHandler *th;
+    SignalHandler *sh = nullptr;
+    std::unique_ptr<TestHandler> th = make_unique<TestHandler>();
 
 public:
-    SignalHandlerTest()
-    {
-    }
-    ~SignalHandlerTest()
-    {
-    }
+    SignalHandlerTest() = default;
 
-    void setUp()
-    {
-        sh = SignalHandler::instance();
-        th = new TestHandler;
-    }
+    ~SignalHandlerTest() = default;
 
-    void tearDown()
-    {
-        delete th;
-        th = 0;
-    }
+    void setUp() override { sh = SignalHandler::instance(); }
 
     // Tests for methods
-    void register_handler_test()
-    {
-        sh->register_handler(SIGALRM, th);
-        CPPUNIT_ASSERT(sh->d_signal_handlers[SIGALRM] == th);
+    void register_handler_test() {
+        SignalHandler::register_handler(SIGALRM, th.get());
+        CPPUNIT_ASSERT(sh->d_signal_handlers[SIGALRM] == th.get());
     }
 
-    void remove_handler_test()
-    {
-        sh->register_handler(SIGALRM, th);
-        CPPUNIT_ASSERT(sh->remove_handler(SIGALRM) == th);
+    void remove_handler_test() {
+        SignalHandler::register_handler(SIGALRM, th.get());
+        CPPUNIT_ASSERT(SignalHandler::remove_handler(SIGALRM) == th.get());
     }
 
-    void alarm_test()
-    {
-        sh->register_handler(SIGALRM, th, true);
+    void alarm_test() {
+        SignalHandler::register_handler(SIGALRM, th.get(), true);
         CPPUNIT_ASSERT(th->flag == 0);
         alarm(1);
 
         // sleep(2) also works _except_ when run with valgrind; reason
         // unknown. jhrg 4/26/13
-        int start, end;
-        start = end = time(0);
+        time_t start, end;
+        start = end = time(nullptr);
         while (end < start + 2)
-            end = time(0);
+            end = time(nullptr);
 
         DBG(cerr << "Event handler 'flag' value: " << th->flag << endl);
         CPPUNIT_ASSERT(th->flag == 1);
     }
 
-    CPPUNIT_TEST_SUITE (SignalHandlerTest);
+    CPPUNIT_TEST_SUITE(SignalHandlerTest);
 
-    CPPUNIT_TEST (register_handler_test);
-    CPPUNIT_TEST (remove_handler_test);
-    CPPUNIT_TEST (alarm_test);
+    CPPUNIT_TEST(register_handler_test);
+    CPPUNIT_TEST(remove_handler_test);
+    CPPUNIT_TEST(alarm_test);
 
     CPPUNIT_TEST_SUITE_END();
 };
 
-CPPUNIT_TEST_SUITE_REGISTRATION (SignalHandlerTest);
+CPPUNIT_TEST_SUITE_REGISTRATION(SignalHandlerTest);
 
-}
+} // namespace libdap
 
-int main(int argc, char*argv[])
-{
-    return run_tests<libdap::SignalHandlerTest>(argc, argv) ? 0: 1;
-}
+int main(int argc, char *argv[]) { return run_tests<libdap::SignalHandlerTest>(argc, argv) ? 0 : 1; }
