@@ -25,15 +25,15 @@
 // Tests for the util functions in util.cc and escaping.cc
 
 #include <cppunit/TextTestRunner.h>
-#include <cppunit/extensions/TestFactoryRegistry.h>
 #include <cppunit/extensions/HelperMacros.h>
+#include <cppunit/extensions/TestFactoryRegistry.h>
 
 #include <cstring>
 #include <string>
 
 #include "debug.h"
-#include "util.h"
 #include "escaping.h"
+#include "util.h"
 
 #include "run_tests_cppunit.h"
 #include "test_config.h"
@@ -45,56 +45,51 @@ using std::string;
 using namespace CppUnit;
 using namespace libdap;
 
-class generalUtilTest: public TestFixture {
+class generalUtilTest : public TestFixture {
 private:
-
 public:
     generalUtilTest() = default;
     ~generalUtilTest() = default;
-    CPPUNIT_TEST_SUITE (generalUtilTest);
+    CPPUNIT_TEST_SUITE(generalUtilTest);
 
-    CPPUNIT_TEST (octal_to_hex_test);
-    CPPUNIT_TEST (prune_spaces_test);
-    CPPUNIT_TEST (path_to_filename_test);
-    CPPUNIT_TEST (hexstring_test);
-    CPPUNIT_TEST (unhexstring_test);
-    CPPUNIT_TEST (id2www_test);
-    CPPUNIT_TEST (www2id_test);
-    CPPUNIT_TEST (ce_string_parse_test);
-    CPPUNIT_TEST (escattr_test);
-    CPPUNIT_TEST (unescattr_test);
-    CPPUNIT_TEST (munge_error_message_test);
-    CPPUNIT_TEST (id2xml_test);
-    CPPUNIT_TEST (xml2id_test);
+    CPPUNIT_TEST(octal_to_hex_test);
+    CPPUNIT_TEST(prune_spaces_test);
+    CPPUNIT_TEST(path_to_filename_test);
+    CPPUNIT_TEST(hexstring_test);
+    CPPUNIT_TEST(unhexstring_test);
+    CPPUNIT_TEST(id2www_test);
+    CPPUNIT_TEST(www2id_test);
+    CPPUNIT_TEST(ce_string_parse_test);
+    CPPUNIT_TEST(escattr_test);
+    CPPUNIT_TEST(unescattr_test);
+    CPPUNIT_TEST(munge_error_message_test);
+    CPPUNIT_TEST(id2xml_test);
+    CPPUNIT_TEST(xml2id_test);
 
-    CPPUNIT_TEST (glob_test_1);
-    CPPUNIT_TEST (glob_test_2);
-    CPPUNIT_TEST (glob_test_3);
+    CPPUNIT_TEST(glob_test_1);
+    CPPUNIT_TEST(glob_test_2);
+    CPPUNIT_TEST(glob_test_3);
 
     CPPUNIT_TEST_SUITE_END();
 
     // Tests for methods
-    void glob_test_1()
-    {
+    void glob_test_1() {
         string t = "This is a test";
         int status = glob("This is a test", t.c_str());
         CPPUNIT_ASSERT(status == 0);
     }
-    void glob_test_2()
-    {
+    void glob_test_2() {
         string t = "This is a test";
         int status = glob("This * test", t.c_str());
         CPPUNIT_ASSERT(status == 0);
     }
-    void glob_test_3()
-    {
+    void glob_test_3() {
         string t = "This is a test";
         int status = glob("* is * test", t.c_str());
         CPPUNIT_ASSERT(status == 0);
     }
 
-    void octal_to_hex_test()
-    {
+    void octal_to_hex_test() {
         string hex;
         hex = octal_to_hex("000");
         CPPUNIT_ASSERT(hex == "00");
@@ -106,8 +101,7 @@ public:
         CPPUNIT_ASSERT(hex == "3f");
     }
 
-    void prune_spaces_test()
-    {
+    void prune_spaces_test() {
         string test_server = "http://test.opendap.org";
         CPPUNIT_ASSERT(prune_spaces(test_server) == test_server);
 
@@ -118,8 +112,7 @@ public:
         CPPUNIT_ASSERT(prune_spaces(test_server_ce) == test_server_ce);
 
         string test_server_ce_spaces = "http://test.opendap.org/file.txt? u,v";
-        DBG(cerr << "Test Server CE Spaces: "
-            << prune_spaces(test_server_ce_spaces) << endl);
+        DBG(cerr << "Test Server CE Spaces: " << prune_spaces(test_server_ce_spaces) << endl);
         CPPUNIT_ASSERT(prune_spaces(test_server_ce_spaces) == test_server_ce);
 
         string hdf_two_var =
@@ -127,24 +120,21 @@ public:
         CPPUNIT_ASSERT(prune_spaces(hdf_two_var) == hdf_two_var);
     }
 
-    void path_to_filename_test()
-    {
+    void path_to_filename_test() {
         CPPUNIT_ASSERT(path_to_filename("/this/is/the/end/my.friend") == "my.friend");
         CPPUNIT_ASSERT(path_to_filename("this.dat") == "this.dat");
         CPPUNIT_ASSERT(path_to_filename("/this.dat") == "this.dat");
         CPPUNIT_ASSERT(path_to_filename("/this.dat/") == "");
     }
 
-    void hexstring_test()
-    {
+    void hexstring_test() {
         CPPUNIT_ASSERT(hexstring('[') == "5b");
         CPPUNIT_ASSERT(hexstring(']') == "5d");
         CPPUNIT_ASSERT(hexstring(' ') == "20");
         CPPUNIT_ASSERT(hexstring('%') == "25");
     }
 
-    void unhexstring_test()
-    {
+    void unhexstring_test() {
         CPPUNIT_ASSERT(unhexstring("5b") == "[");
         CPPUNIT_ASSERT(unhexstring("5d") == "]");
         CPPUNIT_ASSERT(unhexstring("20") == " ");
@@ -153,8 +143,7 @@ public:
         CPPUNIT_ASSERT(unhexstring("5D") == "]");
     }
 
-    void id2www_test()
-    {
+    void id2www_test() {
         CPPUNIT_ASSERT(id2www("this") == "this");
         CPPUNIT_ASSERT(id2www("This is a test") == "This%20is%20a%20test");
         CPPUNIT_ASSERT(id2www("This.is") == "This.is");
@@ -166,8 +155,7 @@ public:
         CPPUNIT_ASSERT(id2www("%This&is") == "%25This%26is");
     }
 
-    void www2id_test()
-    {
+    void www2id_test() {
         CPPUNIT_ASSERT(www2id("This_is_a_test") == "This_is_a_test");
         CPPUNIT_ASSERT(www2id("This is a test") == "This is a test");
         CPPUNIT_ASSERT(www2id("%5b") == "[");
@@ -183,17 +171,16 @@ public:
         CPPUNIT_ASSERT(www2id("Grid%20Data%26Fields[20][20]", "%", "%20") == "Grid%20Data&Fields[20][20]");
 
         CPPUNIT_ASSERT(www2id("Grid%20Data%26Fields[20][20]", "%", "%20%26") == "Grid%20Data%26Fields[20][20]");
-        //cerr << "www2id(\"%25This%26is\"): " << www2id("%25This%26is") << endl;
+        // cerr << "www2id(\"%25This%26is\"): " << www2id("%25This%26is") << endl;
         CPPUNIT_ASSERT(www2id("%25This%26is") == "%This&is");
-        //cerr << "www2id(\"OPF_MaxSpectralPixelsMissing%d4\"): " << www2id("OPF_MaxSpectralPixelsMissing%d4") << endl;
-        //CPPUNIT_ASSERT(www2id("OPF_MaxSpectralPixelsMissing%d4") == "OPF_MaxSpectralPixelsMissing?");
+        // cerr << "www2id(\"OPF_MaxSpectralPixelsMissing%d4\"): " << www2id("OPF_MaxSpectralPixelsMissing%d4") << endl;
+        // CPPUNIT_ASSERT(www2id("OPF_MaxSpectralPixelsMissing%d4") == "OPF_MaxSpectralPixelsMissing?");
     }
 
     // This is the code in expr.lex that removes enclosing double quotes and
     // %20 sequences from a string. I copied this here because that actual
     // function uses globals and would be hard to test. 7/11/2001 jhrg
-    string *store_str(const char *text)
-    {
+    string *store_str(const char *text) {
         string *s = new string(www2id(string(text)));
 
         if (*s->begin() == '\"' && *(s->end() - 1) == '\"') {
@@ -206,8 +193,7 @@ public:
 
     // The MS VC++ compiler does not like escapes in string arguments passed
     // to macros. 04/23/03 jhrg
-    void ce_string_parse_test()
-    {
+    void ce_string_parse_test() {
         string *str = new string("testing");
         string *str1 = new string("testing");
         string *result = store_str(str->c_str());
@@ -229,8 +215,7 @@ public:
         str1 = 0;
     }
 
-    void escattr_test()
-    {
+    void escattr_test() {
         // The backslash escapes the double quote; in the returned string the
         // first two backslashes are a single escaped bs, the third bs
         // escapes the double quote.
@@ -243,8 +228,7 @@ public:
         CPPUNIT_ASSERT(escattr(str) == str1);
     }
 
-    void unescattr_test()
-    {
+    void unescattr_test() {
         CPPUNIT_ASSERT(unescattr("attr") == "attr");
 
         CPPUNIT_ASSERT(unescattr("\\\\attr") == "\\attr");
@@ -252,7 +236,7 @@ public:
         DBG(cerr << "XXX" << unescattr("\\\"attr") << "XXX" << endl);
         CPPUNIT_ASSERT(unescattr("\\\"attr") == "\"attr");
 
-        char A_200_177[4] = { (char) 128, 127, 'A', '\0' };
+        char A_200_177[4] = {(char)128, 127, 'A', '\0'};
         DBG(cerr << "XXX" << unescattr("\\200\\177A") << "XXX" << endl);
         CPPUNIT_ASSERT(unescattr("\\200\\177A") == string(A_200_177));
 
@@ -264,8 +248,7 @@ public:
         DBG(cerr << "XXX" << unescattr("\\\\200") << "XXX" << endl);
     }
 
-    void munge_error_message_test()
-    {
+    void munge_error_message_test() {
         string str = "An Error";
         string str1 = "\"An Error\"";
         DBG(cerr << "Munge: " << munge_error_message(str) << endl);
@@ -318,8 +301,7 @@ public:
     }
 #endif
 
-    void id2xml_test()
-    {
+    void id2xml_test() {
         CPPUNIT_ASSERT(id2xml("abcdef") == "abcdef");
         CPPUNIT_ASSERT(id2xml("abc<def") == "abc&lt;def");
         CPPUNIT_ASSERT(id2xml("abc>def") == "abc&gt;def");
@@ -336,8 +318,7 @@ public:
         CPPUNIT_ASSERT(id2xml("octal escape: \\\\012") == "octal escape: \\\\012");
     }
 
-    void xml2id_test()
-    {
+    void xml2id_test() {
         CPPUNIT_ASSERT(xml2id("abcdef") == "abcdef");
         CPPUNIT_ASSERT(xml2id("abc&lt;def") == "abc<def");
         CPPUNIT_ASSERT(xml2id("abc&gt;def") == "abc>def");
@@ -352,9 +333,6 @@ public:
     }
 };
 
-CPPUNIT_TEST_SUITE_REGISTRATION (generalUtilTest);
+CPPUNIT_TEST_SUITE_REGISTRATION(generalUtilTest);
 
-int main(int argc, char*argv[])
-{
-    return run_tests<generalUtilTest>(argc, argv) ? 0: 1;
-}
+int main(int argc, char *argv[]) { return run_tests<generalUtilTest>(argc, argv) ? 0 : 1; }
