@@ -1,18 +1,18 @@
-#include <cppunit/TestFixture.h>
+#include <cppunit/CompilerOutputter.h>
 #include <cppunit/TestAssert.h>
+#include <cppunit/TestFixture.h>
+#include <cppunit/extensions/HelperMacros.h>
 #include <cppunit/extensions/TestFactoryRegistry.h>
 #include <cppunit/ui/text/TestRunner.h>
-#include <cppunit/extensions/HelperMacros.h>
-#include <cppunit/CompilerOutputter.h>
 
-#include <iostream>
-#include "TestSequence.h"
 #include "TestInt16.h"
+#include "TestSequence.h"
 #include "TestStr.h"
 #include "TestTypeFactory.h"
-#include "util.h"
 #include "run_tests_cppunit.h"
 #include "test_config.h"
+#include "util.h"
+#include <iostream>
 
 using std::cerr;
 using std::endl;
@@ -23,29 +23,25 @@ using namespace CppUnit;
 int test_variable_sleep_interval = 0; // Used in Test* classes for testing
 // timeouts.
 
-class sequenceT: public CppUnit::TestFixture {
+class sequenceT : public CppUnit::TestFixture {
 
-    CPPUNIT_TEST_SUITE (sequenceT);
-    CPPUNIT_TEST (sequenceT_test);CPPUNIT_TEST_SUITE_END( );
+    CPPUNIT_TEST_SUITE(sequenceT);
+    CPPUNIT_TEST(sequenceT_test);
+    CPPUNIT_TEST_SUITE_END();
 
 private:
     /* TEST PRIVATE DATA */
     TestTypeFactory *factory;
 
 public:
-    void setUp()
-    {
-        factory = new TestTypeFactory;
-    }
+    void setUp() { factory = new TestTypeFactory; }
 
-    void tearDown()
-    {
+    void tearDown() {
         delete factory;
         factory = 0;
     }
 
-    void sequenceT_test()
-    {
+    void sequenceT_test() {
         TestSequence s("Supporters");
 
         BaseType *nm = factory->NewStr("Name");
@@ -54,7 +50,7 @@ public:
         BaseType *age = factory->NewInt16("Age");
         s.add_var(age);
 
-        TestSequence *friends = (TestSequence *) factory->NewSequence("Friends");
+        TestSequence *friends = (TestSequence *)factory->NewSequence("Friends");
         friends->add_var(nm);
         delete nm;
         nm = 0;
@@ -115,8 +111,7 @@ public:
         CPPUNIT_ASSERT(v == s.var_end() && e == elems.end());
         if (v != s.var_end() && e == elems.end()) {
             CPPUNIT_FAIL("Too many elements");
-        }
-        else if (v == s.var_end() && e != elems.end()) {
+        } else if (v == s.var_end() && e != elems.end()) {
             CPPUNIT_FAIL("Too few elements");
         }
 
@@ -125,11 +120,8 @@ public:
     }
 };
 
-CPPUNIT_TEST_SUITE_REGISTRATION (sequenceT);
+CPPUNIT_TEST_SUITE_REGISTRATION(sequenceT);
 
 /* NOTHING NEEDS TO BE CHANGED BELOW HERE */
 
-int main(int argc, char*argv[])
-{
-    return run_tests<sequenceT>(argc, argv) ? 0: 1;
-}
+int main(int argc, char *argv[]) { return run_tests<sequenceT>(argc, argv) ? 0 : 1; }
